/* Generated by Cython 3.0.2 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "serpyco.serializer",
        "sources": [
            "serpyco/serializer.pyx"
        ]
    },
    "module_name": "serpyco.serializer"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_2" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030002F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        PyObject *version_info; // borrowed
        PyObject *py_minor_version = NULL;
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11; // we don't yet need to distinguish between versions > 11
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        Py_XDECREF(py_minor_version);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);  // we don't have access to __pyx_empty_bytes here
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE(obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__serpyco__serializer
#define __PYX_HAVE_API__serpyco__serializer
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else  // Py < 3.12
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "serpyco/serializer.pyx",
  "<stringsource>",
};
/* #### Code section: utility_code_proto_before_types ### */
/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_7serpyco_7encoder_FieldEncoder;
struct __pyx_obj_7serpyco_10serializer_SerializerField;
struct __pyx_obj_7serpyco_10serializer_Caster;
struct __pyx_obj_7serpyco_10serializer_Serializer;
struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder;
struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder;
struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr;
struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder;
struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr;
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump;
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load;
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json;
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json;

/* "serpyco/serializer.pyx":343
 *         return self._dataclass
 * 
 *     cpdef inline dump(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump {
  int __pyx_n;
  int validate;
  int many;
};

/* "serpyco/serializer.pyx":379
 *         return data
 * 
 *     cpdef inline load(             # <<<<<<<<<<<<<<
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 */
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load {
  int __pyx_n;
  int validate;
  int many;
};

/* "serpyco/serializer.pyx":425
 *         return obj
 * 
 *     cpdef inline str dump_json(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json {
  int __pyx_n;
  int validate;
  int many;
};

/* "serpyco/serializer.pyx":468
 *         return rapidjson.dumps(data)
 * 
 *     cpdef inline load_json(             # <<<<<<<<<<<<<<
 *         self,
 *         str js,
 */
struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json {
  int __pyx_n;
  int validate;
  int many;
};

/* "serpyco/encoder.pxd":4
 * 
 * 
 * cdef class FieldEncoder(object):             # <<<<<<<<<<<<<<
 *     cpdef dump(self, value)
 *     cpdef load(self, value)
 */
struct __pyx_obj_7serpyco_7encoder_FieldEncoder {
  PyObject_HEAD
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *__pyx_vtab;
};


/* "serpyco/serializer.pyx":50
 * }
 * 
 * cdef class SerializerField:             # <<<<<<<<<<<<<<
 *     cdef str field_name
 *     cdef str dict_key
 */
struct __pyx_obj_7serpyco_10serializer_SerializerField {
  PyObject_HEAD
  PyObject *field_name;
  PyObject *dict_key;
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *encoder;
  PyObject *getter;
  int init;
  PyObject *__pyx_default;
  PyObject *default_factory;
};


/* "serpyco/serializer.pyx":78
 * 
 * 
 * cdef class Caster(object):             # <<<<<<<<<<<<<<
 *     cdef str dict_key
 *     cdef object caster
 */
struct __pyx_obj_7serpyco_10serializer_Caster {
  PyObject_HEAD
  PyObject *dict_key;
  PyObject *caster;
};


/* "serpyco/serializer.pyx":112
 * 
 * @cython.final
 * cdef class Serializer(object):             # <<<<<<<<<<<<<<
 *     """
 *     Serializer class for dataclasses instances.
 */
struct __pyx_obj_7serpyco_10serializer_Serializer {
  PyObject_HEAD
  struct __pyx_vtabstruct_7serpyco_10serializer_Serializer *__pyx_vtab;
  PyObject *_fields;
  PyObject *_dataclass_params;
  PyObject *_dataclass;
  int _frozen_dataclass;
  int _has_post_init;
  PyObject *_validator;
  PyObject *_parent_serializers;
  PyObject *_pre_dumpers;
  PyObject *_post_dumpers;
  PyObject *_pre_loaders;
  PyObject *_post_loaders;
  PyObject *_field_casters;
  PyObject *_field_encoders;
  PyObject *_type_encoders;
  PyObject *_load_as_type;
  PyObject *_only;
  PyObject *_excluded_fields;
};


/* "serpyco/serializer.pyx":709
 * # builtin field encoders
 * @cython.final
 * cdef class EnumFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef object _enum_type
 * 
 */
struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
  PyObject *_enum_type;
};


/* "serpyco/serializer.pyx":726
 * 
 * @cython.final
 * cdef class DataClassFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef Serializer _serializer
 * 
 */
struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
  struct __pyx_obj_7serpyco_10serializer_Serializer *_serializer;
};


/* "serpyco/serializer.pyx":743
 * 
 * @cython.final
 * cdef class DataClassIterableFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef Serializer _serializer
 *     cdef object _iterable_type
 */
struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
  struct __pyx_obj_7serpyco_10serializer_Serializer *_serializer;
  PyObject *_iterable_type;
};


/* "serpyco/serializer.pyx":774
 * 
 * @cython.final
 * cdef class FixedTupleFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef tuple _item_encoders
 *     cdef int _item_encoders_count
 */
struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
  PyObject *_item_encoders;
  int _item_encoders_count;
};


/* "serpyco/serializer.pyx":815
 * 
 * @cython.final
 * cdef class IterableFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef FieldEncoder _item_encoder
 *     cdef object _iterable_type
 */
struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *_item_encoder;
  PyObject *_iterable_type;
};


/* "serpyco/serializer.pyx":847
 * 
 * @cython.final
 * cdef class DictFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef FieldEncoder _key_encoder
 *     cdef FieldEncoder _value_encoder
 */
struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *_key_encoder;
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *_value_encoder;
};


/* "serpyco/serializer.pyx":898
 * 
 * @cython.final
 * cdef class DateTimeFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     """Encodes datetimes to RFC3339/ISO8601 format"""
 * 
 */
struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
};


/* "serpyco/serializer.pyx":928
 * 
 * @cython.final
 * cdef class UuidFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value):
 */
struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
};


/* "serpyco/serializer.pyx":941
 * 
 * @cython.final
 * cdef class UnionFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 * 
 *     cdef tuple _type_encoders
 */
struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder __pyx_base;
  PyObject *_type_encoders;
};


/* "serpyco/serializer.pyx":219
 *             if hints.cast_on_load:
 *                 field_casters.append(Caster(hints.dict_key, field_type))
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)             # <<<<<<<<<<<<<<
 * 
 *         builder = SchemaBuilder(
 */
struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v__;
  PyObject *__pyx_v_serializer_field;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
};


/* "serpyco/serializer.pyx":598
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 * 
 *     def _get_encoder(self, field_type, hints):             # <<<<<<<<<<<<<<
 *         cdef DataClassFieldEncoder dencoder
 *         cdef Serializer serializer
 */
struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder {
  PyObject_HEAD
  PyObject *__pyx_v_hints;
};


/* "serpyco/serializer.pyx":681
 *         # This avoids infinite recursion if dataclasses establish a cycle
 *         excluded_field_names = tuple(
 *             f.name for f in dataclasses.fields(params.type_)             # <<<<<<<<<<<<<<
 *             if (
 *                 hints.ignore
 */
struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr {
  PyObject_HEAD
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_f;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};



/* "serpyco/encoder.pxd":4
 * 
 * 
 * cdef class FieldEncoder(object):             # <<<<<<<<<<<<<<
 *     cpdef dump(self, value)
 *     cpdef load(self, value)
 */

struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder {
  PyObject *(*dump)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*load)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;


/* "serpyco/serializer.pyx":112
 * 
 * @cython.final
 * cdef class Serializer(object):             # <<<<<<<<<<<<<<
 *     """
 *     Serializer class for dataclasses instances.
 */

struct __pyx_vtabstruct_7serpyco_10serializer_Serializer {
  PyObject *(*dump)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump *__pyx_optional_args);
  PyObject *(*load)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load *__pyx_optional_args);
  PyObject *(*dump_json)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json *__pyx_optional_args);
  PyObject *(*load_json)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json *__pyx_optional_args);
  PyObject *(*_dump)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *);
  PyObject *(*_load)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *);
};
static struct __pyx_vtabstruct_7serpyco_10serializer_Serializer *__pyx_vtabptr_7serpyco_10serializer_Serializer;
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_dump(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump *__pyx_optional_args);
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_load(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load *__pyx_optional_args);
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_dump_json(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json *__pyx_optional_args);
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_load_json(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json *__pyx_optional_args);
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer__dump(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer__load(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *);


/* "serpyco/serializer.pyx":709
 * # builtin field encoders
 * @cython.final
 * cdef class EnumFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef object _enum_type
 * 
 */

struct __pyx_vtabstruct_7serpyco_10serializer_EnumFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_EnumFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_EnumFieldEncoder;


/* "serpyco/serializer.pyx":726
 * 
 * @cython.final
 * cdef class DataClassFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef Serializer _serializer
 * 
 */

struct __pyx_vtabstruct_7serpyco_10serializer_DataClassFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_DataClassFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_DataClassFieldEncoder;


/* "serpyco/serializer.pyx":743
 * 
 * @cython.final
 * cdef class DataClassIterableFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef Serializer _serializer
 *     cdef object _iterable_type
 */

struct __pyx_vtabstruct_7serpyco_10serializer_DataClassIterableFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_DataClassIterableFieldEncoder;


/* "serpyco/serializer.pyx":774
 * 
 * @cython.final
 * cdef class FixedTupleFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef tuple _item_encoders
 *     cdef int _item_encoders_count
 */

struct __pyx_vtabstruct_7serpyco_10serializer_FixedTupleFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_FixedTupleFieldEncoder;


/* "serpyco/serializer.pyx":815
 * 
 * @cython.final
 * cdef class IterableFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef FieldEncoder _item_encoder
 *     cdef object _iterable_type
 */

struct __pyx_vtabstruct_7serpyco_10serializer_IterableFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_IterableFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_IterableFieldEncoder;


/* "serpyco/serializer.pyx":847
 * 
 * @cython.final
 * cdef class DictFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     cdef FieldEncoder _key_encoder
 *     cdef FieldEncoder _value_encoder
 */

struct __pyx_vtabstruct_7serpyco_10serializer_DictFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_DictFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_DictFieldEncoder;


/* "serpyco/serializer.pyx":898
 * 
 * @cython.final
 * cdef class DateTimeFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 *     """Encodes datetimes to RFC3339/ISO8601 format"""
 * 
 */

struct __pyx_vtabstruct_7serpyco_10serializer_DateTimeFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_DateTimeFieldEncoder;


/* "serpyco/serializer.pyx":928
 * 
 * @cython.final
 * cdef class UuidFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value):
 */

struct __pyx_vtabstruct_7serpyco_10serializer_UuidFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_UuidFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_UuidFieldEncoder;


/* "serpyco/serializer.pyx":941
 * 
 * @cython.final
 * cdef class UnionFieldEncoder(FieldEncoder):             # <<<<<<<<<<<<<<
 * 
 *     cdef tuple _type_encoders
 */

struct __pyx_vtabstruct_7serpyco_10serializer_UnionFieldEncoder {
  struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder __pyx_base;
};
static struct __pyx_vtabstruct_7serpyco_10serializer_UnionFieldEncoder *__pyx_vtabptr_7serpyco_10serializer_UnionFieldEncoder;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg // no-op
    #define __Pyx_Arg_XDECREF_VARARGS(arg) // no-op - arg is borrowed
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg // no-op, __Pyx_Arg_FASTCALL is direct and this needs
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)  // no-op - arg was returned from array
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* RaiseMappingExpected.proto */
static void __Pyx_RaiseMappingExpectedError(PyObject* arg);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* RaiseClosureNameError.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right)
    #endif
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_ConcatInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_ConcatInPlaceSafe(left, right) ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_ConcatInPlace(left, right))

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_0_2
#define __PYX_HAVE_RT_ImportType_proto_3_0_2
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_2(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_2(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_0_2 {
   __Pyx_ImportType_CheckSize_Error_3_0_2 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_0_2 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_0_2 = 2
};
static PyTypeObject *__Pyx_ImportType_3_0_2(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_2 check_size);
#endif

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_IsCyOrPyCFunction(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* ClassMethod.proto */
#include "descrobject.h"
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* CoroutineBase.proto */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_dump(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_load(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_data, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_dump_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_load_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_js, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer__dump(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer__load(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_data); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16EnumFieldEncoder_dump(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16EnumFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20IterableFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20IterableFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16DictFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16DictFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_dump(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_load(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16UuidFieldEncoder_dump(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16UuidFieldEncoder_load(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_17UnionFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7serpyco_10serializer_17UnionFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "serpyco.encoder" */

/* Module declarations from "serpyco.serializer" */
static PyObject *__pyx_v_7serpyco_10serializer_dataclasses_MISSING = 0;
static PyObject *__pyx_v_7serpyco_10serializer_new_object = 0;
static CYTHON_INLINE int __pyx_f_7serpyco_10serializer_cast_fields(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer___pyx_unpickle_SerializerField__set_state(struct __pyx_obj_7serpyco_10serializer_SerializerField *, PyObject *); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer___pyx_unpickle_DateTimeFieldEncoder__set_state(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *, PyObject *); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer___pyx_unpickle_UuidFieldEncoder__set_state(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "serpyco.serializer"
extern int __pyx_module_is_main_serpyco__serializer;
int __pyx_module_is_main_serpyco__serializer = 0;

/* Implementation of "serpyco.serializer" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_map;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_OverflowError;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = ": ";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_h[] = "h";
static const char __pyx_k__3[] = "'";
static const char __pyx_k__4[] = ",";
static const char __pyx_k__5[] = "]";
static const char __pyx_k__7[] = ".";
static const char __pyx_k__9[] = "*";
static const char __pyx_k_as[] = "' as '";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_in[] = " in ";
static const char __pyx_k_js[] = "js";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_sh[] = "sh";
static const char __pyx_k_Any[] = "Any";
static const char __pyx_k_Set[] = "Set";
static const char __pyx_k__97[] = "?";
static const char __pyx_k_arg[] = "arg";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_map[] = "map";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_ser[] = "ser";
static const char __pyx_k_zip[] = "zip";
static const char __pyx_k_Enum[] = "Enum";
static const char __pyx_k_List[] = "List";
static const char __pyx_k_None[] = "None";
static const char __pyx_k_UUID[] = "UUID";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_bool[] = "bool";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_dump[] = "dump";
static const char __pyx_k_enum[] = "enum";
static const char __pyx_k_init[] = "init";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_load[] = "load";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_many[] = "many";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_only[] = "only";
static const char __pyx_k_part[] = "part";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_type[] = "type_";
static const char __pyx_k_uuid[] = "uuid";
static const char __pyx_k_Tuple[] = "Tuple";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_dumps[] = "dumps";
static const char __pyx_k_field[] = "field ";
static const char __pyx_k_hints[] = "hints";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_loads[] = "loads";
static const char __pyx_k_param[] = "param";
static const char __pyx_k_parse[] = "parse";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_Caster[] = "Caster";
static const char __pyx_k_caster[] = "caster";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_fields[] = "fields";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_frozen[] = "frozen";
static const char __pyx_k_getter[] = "getter";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_params[] = "params";
static const char __pyx_k_parser[] = "parser";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_remove[] = "remove";
static const char __pyx_k_return[] = "return";
static const char __pyx_k_sfield[] = "sfield";
static const char __pyx_k_strict[] = "strict";
static const char __pyx_k_string[] = "string";
static const char __pyx_k_type_2[] = "type";
static const char __pyx_k_typing[] = "typing";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_MISSING[] = "MISSING";
static const char __pyx_k_Mapping[] = "Mapping";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_encoder[] = "encoder";
static const char __pyx_k_exclude[] = "exclude";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_pattern[] = "pattern";
static const char __pyx_k_setattr[] = "__setattr__";
static const char __pyx_k_Iterable[] = "Iterable";
static const char __pyx_k_JsonDict[] = "JsonDict";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_PRE_DUMP[] = "PRE_DUMP";
static const char __pyx_k_PRE_LOAD[] = "PRE_LOAD";
static const char __pyx_k_arg_type[] = "arg_type";
static const char __pyx_k_datetime[] = "datetime";
static const char __pyx_k_dateutil[] = "dateutil";
static const char __pyx_k_dencoder[] = "dencoder";
static const char __pyx_k_dict_key[] = "dict_key";
static const char __pyx_k_evaluate[] = "evaluate";
static const char __pyx_k_get_args[] = "get_args";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_is_union[] = "_is_union";
static const char __pyx_k_metadata[] = "metadata";
static const char __pyx_k_obj_path[] = "obj_path";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_validate[] = "validate";
static const char __pyx_k_POST_DUMP[] = "POST_DUMP";
static const char __pyx_k_POST_LOAD[] = "POST_LOAD";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_arguments[] = "arguments";
static const char __pyx_k_dataclass[] = "dataclass";
static const char __pyx_k_date_time[] = "date-time";
static const char __pyx_k_dict_path[] = "dict_path";
static const char __pyx_k_dump_json[] = "dump_json";
static const char __pyx_k_enum_type[] = "enum_type";
static const char __pyx_k_for_class[] = "' for class '";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_isoformat[] = "isoformat";
static const char __pyx_k_item_type[] = "item_type";
static const char __pyx_k_load_json[] = "load_json";
static const char __pyx_k_omit_none[] = "omit_none";
static const char __pyx_k_post_init[] = "__post_init__";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_rapidjson[] = "rapidjson";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_supertype[] = "__supertype__";
static const char __pyx_k_FieldHints[] = "FieldHints";
static const char __pyx_k_Serializer[] = "Serializer";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_field_name[] = "field_name";
static const char __pyx_k_field_type[] = "field_type";
static const char __pyx_k_get_origin[] = "get_origin";
static const char __pyx_k_is_generic[] = "_is_generic";
static const char __pyx_k_param_args[] = "param_args";
static const char __pyx_k_parameters[] = "parameters";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_serializer[] = "serializer";
static const char __pyx_k_typing_Any[] = "typing.Any";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_dataclasses[] = "dataclasses";
static const char __pyx_k_get_encoder[] = "_get_encoder";
static const char __pyx_k_is_new_type[] = "is_new_type";
static const char __pyx_k_json_schema[] = "json_schema";
static const char __pyx_k_key_encoder[] = "key_encoder";
static const char __pyx_k_FieldEncoder[] = "FieldEncoder";
static const char __pyx_k_Serializer_2[] = "'Serializer'";
static const char __pyx_k_cast_on_load[] = "cast_on_load";
static const char __pyx_k_dict_encoder[] = "dict_encoder";
static const char __pyx_k_global_types[] = "_global_types";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_item_encoder[] = "item_encoder";
static const char __pyx_k_iter_encoder[] = "iter_encoder";
static const char __pyx_k_load_as_type[] = "load_as_type";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_resolve_type[] = "resolve_type";
static const char __pyx_k_serpyco_tags[] = "_serpyco_tags";
static const char __pyx_k_serpyco_util[] = "serpyco.util";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_Cannot_create[] = "Cannot create '";
static const char __pyx_k_DecoratorType[] = "DecoratorType";
static const char __pyx_k_JsonEncodable[] = "JsonEncodable";
static const char __pyx_k_OverflowError[] = "OverflowError";
static const char __pyx_k_SchemaBuilder[] = "SchemaBuilder";
static const char __pyx_k_Unknown_field[] = "Unknown field ";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_diter_encoder[] = "diter_encoder";
static const char __pyx_k_get_dict_path[] = "get_dict_path";
static const char __pyx_k_item_encoders[] = "item_encoders";
static const char __pyx_k_metadata_name[] = "_metadata_name";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_sequence_type[] = "sequence_type";
static const char __pyx_k_serpyco_field[] = "serpyco.field";
static const char __pyx_k_type_encoders[] = "type_encoders";
static const char __pyx_k_validate_json[] = "validate_json";
static const char __pyx_k_validate_user[] = "validate_user";
static const char __pyx_k_value_encoder[] = "value_encoder";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_NoEncoderError[] = "NoEncoderError";
static const char __pyx_k_No_encoder_for[] = "No encoder for '";
static const char __pyx_k_get_type_hints[] = "get_type_hints";
static const char __pyx_k_serpyco_schema[] = "serpyco.schema";
static const char __pyx_k_typing_inspect[] = "typing_inspect";
static const char __pyx_k_DataClassParams[] = "_DataClassParams";
static const char __pyx_k_SerializerField[] = "SerializerField";
static const char __pyx_k_Serializer_dump[] = "Serializer.dump";
static const char __pyx_k_Serializer_load[] = "Serializer.load";
static const char __pyx_k_ValidationError[] = "ValidationError";
static const char __pyx_k_dateutil_parser[] = "dateutil.parser";
static const char __pyx_k_default_factory[] = "default_factory";
static const char __pyx_k_get_object_path[] = "get_object_path";
static const char __pyx_k_iso8601_pattern[] = "iso8601_pattern";
static const char __pyx_k_issubclass_safe[] = "_issubclass_safe";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_typing_List_str[] = "typing.List[str]";
static const char __pyx_k_DictFieldEncoder[] = "DictFieldEncoder";
static const char __pyx_k_EnumFieldEncoder[] = "EnumFieldEncoder";
static const char __pyx_k_Unknown_dict_key[] = "Unknown dict key ";
static const char __pyx_k_UuidFieldEncoder[] = "UuidFieldEncoder";
static const char __pyx_k_dataclass_params[] = "_dataclass_params";
static const char __pyx_k_UnionFieldEncoder[] = "UnionFieldEncoder";
static const char __pyx_k_serpyco_decorator[] = "serpyco.decorator";
static const char __pyx_k_serpyco_exception[] = "serpyco.exception";
static const char __pyx_k_serpyco_validator[] = "serpyco.validator";
static const char __pyx_k_NotADataClassError[] = "NotADataClassError";
static const char __pyx_k_RapidJsonValidator[] = "RapidJsonValidator";
static const char __pyx_k_UNTYPED_DICT_TYPES[] = "UNTYPED_DICT_TYPES";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_dataclass_params_2[] = "__dataclass_params__";
static const char __pyx_k_is_not_a_dataclass[] = " is not a dataclass";
static const char __pyx_k_parent_serializers[] = "_parent_serializers";
static const char __pyx_k_serpyco_serializer[] = "serpyco.serializer";
static const char __pyx_k_typing_Sequence_str[] = "typing.Sequence[str]";
static const char __pyx_k_Could_not_cast_field[] = "Could not cast field ";
static const char __pyx_k_DateTimeFieldEncoder[] = "DateTimeFieldEncoder";
static const char __pyx_k_IterableFieldEncoder[] = "IterableFieldEncoder";
static const char __pyx_k_JSON_ENCODABLE_TYPES[] = "JSON_ENCODABLE_TYPES";
static const char __pyx_k_Serializer_dataclass[] = "Serializer.dataclass";
static const char __pyx_k_Serializer_dump_json[] = "Serializer.dump_json";
static const char __pyx_k_Serializer_load_json[] = "Serializer.load_json";
static const char __pyx_k_excluded_field_names[] = "excluded_field_names";
static const char __pyx_k_get_field_serializer[] = "_get_field_serializer";
static const char __pyx_k_register_global_type[] = "register_global_type";
static const char __pyx_k_DataClassFieldEncoder[] = "DataClassFieldEncoder";
static const char __pyx_k_DictFieldEncoder_dump[] = "DictFieldEncoder.dump";
static const char __pyx_k_DictFieldEncoder_load[] = "DictFieldEncoder.load";
static const char __pyx_k_EnumFieldEncoder_dump[] = "EnumFieldEncoder.dump";
static const char __pyx_k_EnumFieldEncoder_load[] = "EnumFieldEncoder.load";
static const char __pyx_k_UuidFieldEncoder_dump[] = "UuidFieldEncoder.dump";
static const char __pyx_k_UuidFieldEncoder_load[] = "UuidFieldEncoder.load";
static const char __pyx_k_Caster___reduce_cython[] = "Caster.__reduce_cython__";
static const char __pyx_k_FixedTupleFieldEncoder[] = "FixedTupleFieldEncoder";
static const char __pyx_k_ITERABLE_TYPES_MAPPING[] = "_ITERABLE_TYPES_MAPPING";
static const char __pyx_k_Serializer_json_schema[] = "Serializer.json_schema";
static const char __pyx_k_UNTYPED_ITERABLE_TYPES[] = "UNTYPED_ITERABLE_TYPES";
static const char __pyx_k_UnionFieldEncoder_dump[] = "UnionFieldEncoder.dump";
static const char __pyx_k_UnionFieldEncoder_load[] = "UnionFieldEncoder.load";
static const char __pyx_k_Unknown_decorator_type[] = "Unknown decorator type ";
static const char __pyx_k_cinit___locals_genexpr[] = "__cinit__.<locals>.genexpr";
static const char __pyx_k_serpyco_serializer_pyx[] = "serpyco/serializer.pyx";
static const char __pyx_k_unregister_global_type[] = "unregister_global_type";
static const char __pyx_k_Serializer__get_encoder[] = "Serializer._get_encoder";
static const char __pyx_k_is_not_a_valid_datetime[] = " is not a valid datetime";
static const char __pyx_k_Caster___setstate_cython[] = "Caster.__setstate_cython__";
static const char __pyx_k_Serializer_get_dict_path[] = "Serializer.get_dict_path";
static const char __pyx_k_DateTimeFieldEncoder_dump[] = "DateTimeFieldEncoder.dump";
static const char __pyx_k_DateTimeFieldEncoder_load[] = "DateTimeFieldEncoder.load";
static const char __pyx_k_IterableFieldEncoder_dump[] = "IterableFieldEncoder.dump";
static const char __pyx_k_IterableFieldEncoder_load[] = "IterableFieldEncoder.load";
static const char __pyx_k_DataClassFieldEncoder_dump[] = "DataClassFieldEncoder.dump";
static const char __pyx_k_DataClassFieldEncoder_load[] = "DataClassFieldEncoder.load";
static const char __pyx_k_Serializer___reduce_cython[] = "Serializer.__reduce_cython__";
static const char __pyx_k_Serializer_get_object_path[] = "Serializer.get_object_path";
static const char __pyx_k_get_encoder_locals_genexpr[] = "_get_encoder.<locals>.genexpr";
static const char __pyx_k_FixedTupleFieldEncoder_dump[] = "FixedTupleFieldEncoder.dump";
static const char __pyx_k_FixedTupleFieldEncoder_load[] = "FixedTupleFieldEncoder.load";
static const char __pyx_k_DictFieldEncoder_json_schema[] = "DictFieldEncoder.json_schema";
static const char __pyx_k_EnumFieldEncoder_json_schema[] = "EnumFieldEncoder.json_schema";
static const char __pyx_k_Serializer___setstate_cython[] = "Serializer.__setstate_cython__";
static const char __pyx_k_UuidFieldEncoder_json_schema[] = "UuidFieldEncoder.json_schema";
static const char __pyx_k_pyx_unpickle_SerializerField[] = "__pyx_unpickle_SerializerField";
static const char __pyx_k_DataClassIterableFieldEncoder[] = "DataClassIterableFieldEncoder";
static const char __pyx_k_UnionFieldEncoder_json_schema[] = "UnionFieldEncoder.json_schema";
static const char __pyx_k_pyx_unpickle_UuidFieldEncoder[] = "__pyx_unpickle_UuidFieldEncoder";
static const char __pyx_k_is_excluded_but_has_no_default[] = "' is excluded but has no default value/factory";
static const char __pyx_k_pyx_unpickle_DateTimeFieldEnco[] = "__pyx_unpickle_DateTimeFieldEncoder";
static const char __pyx_k_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9[] = "^[0-9]{4}-[0-9][0-9]-[0-9][0-9]T[0-9][0-9]:[0-9][0-9]:[0-9][0-9](\\.[0-9]+)?(([+-][0-9][0-9]:[0-9][0-9])|Z)?$";
static const char __pyx_k_DataClassIterableFieldEncoder_2[] = "DataClassIterableFieldEncoder.__reduce_cython__";
static const char __pyx_k_DataClassIterableFieldEncoder_3[] = "DataClassIterableFieldEncoder.__setstate_cython__";
static const char __pyx_k_DateTimeFieldEncoder___setstate[] = "DateTimeFieldEncoder.__setstate_cython__";
static const char __pyx_k_FixedTupleFieldEncoder___reduce[] = "FixedTupleFieldEncoder.__reduce_cython__";
static const char __pyx_k_IterableFieldEncoder___setstate[] = "IterableFieldEncoder.__setstate_cython__";
static const char __pyx_k_SerializerField___reduce_cython[] = "SerializerField.__reduce_cython__";
static const char __pyx_k_Serializer_register_global_type[] = "Serializer.register_global_type";
static const char __pyx_k_has_a_wrong_type_expected_any_o[] = " has a wrong type, expected any of [";
static const char __pyx_k_is_not_a_datetime_datetime_inst[] = " is not a datetime.datetime instance";
static const char __pyx_k_DataClassFieldEncoder___reduce_c[] = "DataClassFieldEncoder.__reduce_cython__";
static const char __pyx_k_DataClassFieldEncoder___setstate[] = "DataClassFieldEncoder.__setstate_cython__";
static const char __pyx_k_DataClassFieldEncoder_json_schem[] = "DataClassFieldEncoder.json_schema";
static const char __pyx_k_DataClassIterableFieldEncoder_du[] = "DataClassIterableFieldEncoder.dump";
static const char __pyx_k_DataClassIterableFieldEncoder_js[] = "DataClassIterableFieldEncoder.json_schema";
static const char __pyx_k_DataClassIterableFieldEncoder_lo[] = "DataClassIterableFieldEncoder.load";
static const char __pyx_k_DateTimeFieldEncoder___reduce_cy[] = "DateTimeFieldEncoder.__reduce_cython__";
static const char __pyx_k_DateTimeFieldEncoder_json_schema[] = "DateTimeFieldEncoder.json_schema";
static const char __pyx_k_DictFieldEncoder___reduce_cython[] = "DictFieldEncoder.__reduce_cython__";
static const char __pyx_k_DictFieldEncoder___setstate_cyth[] = "DictFieldEncoder.__setstate_cython__";
static const char __pyx_k_EnumFieldEncoder___reduce_cython[] = "EnumFieldEncoder.__reduce_cython__";
static const char __pyx_k_EnumFieldEncoder___setstate_cyth[] = "EnumFieldEncoder.__setstate_cython__";
static const char __pyx_k_FixedTupleFieldEncoder___setstat[] = "FixedTupleFieldEncoder.__setstate_cython__";
static const char __pyx_k_FixedTupleFieldEncoder_json_sche[] = "FixedTupleFieldEncoder.json_schema";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))";
static const char __pyx_k_Invalid_number_of_items_for_tupl[] = "Invalid number of items for tuple";
static const char __pyx_k_IterableFieldEncoder___reduce_cy[] = "IterableFieldEncoder.__reduce_cython__";
static const char __pyx_k_IterableFieldEncoder_json_schema[] = "IterableFieldEncoder.json_schema";
static const char __pyx_k_SerializerField___setstate_cytho[] = "SerializerField.__setstate_cython__";
static const char __pyx_k_Serializer__get_field_serializer[] = "Serializer._get_field_serializer";
static const char __pyx_k_Serializer_unregister_global_typ[] = "Serializer.unregister_global_type";
static const char __pyx_k_UnionFieldEncoder___reduce_cytho[] = "UnionFieldEncoder.__reduce_cython__";
static const char __pyx_k_UnionFieldEncoder___setstate_cyt[] = "UnionFieldEncoder.__setstate_cython__";
static const char __pyx_k_UuidFieldEncoder___reduce_cython[] = "UuidFieldEncoder.__reduce_cython__";
static const char __pyx_k_UuidFieldEncoder___setstate_cyth[] = "UuidFieldEncoder.__setstate_cython__";
static const char __pyx_k_data_dictionary_is_missing_requi[] = "data dictionary is missing required parameter '";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_typing_Union_dict_typing_Iterabl[] = "typing.Union[dict, typing.Iterable[dict]]";
static const char __pyx_k_typing_Union_object_typing_Itera[] = "typing.Union[object, typing.Iterable[object]]";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0_2[] = "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())";
/* #### Code section: decls ### */
static int __pyx_pf_7serpyco_10serializer_15SerializerField___init__(struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_self, PyObject *__pyx_v_field_name, PyObject *__pyx_v_dict_key, struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder, PyObject *__pyx_v_getter, int __pyx_v_init, PyObject *__pyx_v_default, PyObject *__pyx_v_default_factory); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_15SerializerField_2__reduce_cython__(struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_15SerializerField_4__setstate_cython__(struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_6Caster___cinit__(struct __pyx_obj_7serpyco_10serializer_Caster *__pyx_v_self, PyObject *__pyx_v_dict_key, PyObject *__pyx_v_caster); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_6Caster_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Caster *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_6Caster_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Caster *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_9__cinit___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static int __pyx_pf_7serpyco_10serializer_10Serializer___cinit__(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_dataclass, CYTHON_UNUSED PyObject *__pyx_v_omit_none, PyObject *__pyx_v_type_encoders, PyObject *__pyx_v_only, PyObject *__pyx_v_exclude, PyObject *__pyx_v_strict, PyTypeObject *__pyx_v_load_as_type, PyObject *__pyx_v__parent_serializers, PyObject *__pyx_v__dataclass_params); /* proto */
static Py_hash_t __pyx_pf_7serpyco_10serializer_10Serializer_2__hash__(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_4json_schema(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_many); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_6get_dict_path(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj_path); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_8get_object_path(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_dict_path); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_10register_global_type(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_field_type, struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_12unregister_global_type(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_field_type); /* proto */
static PyTypeObject *__pyx_pf_7serpyco_10serializer_10Serializer_14dataclass(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_16dump(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_validate, int __pyx_v_many); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_18load(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_data, int __pyx_v_validate, int __pyx_v_many); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_20dump_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_validate, int __pyx_v_many); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_22load_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_js, int __pyx_v_validate, int __pyx_v_many); /* proto */
static struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_pf_7serpyco_10serializer_10Serializer_24_get_field_serializer(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_12_get_encoder_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_26_get_encoder(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_field_type, PyObject *__pyx_v_hints); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_enum_type); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_2dump(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_4load(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_serializer); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_serializer, PyObject *__pyx_v_sequence_type); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_item_encoders); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_item_encoder, PyObject *__pyx_v_sequence_type); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_16DictFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_key_encoder, PyObject *__pyx_v_value_encoder); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_4json_schema(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_6__reduce_cython__(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_8__setstate_cython__(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_4json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_6__reduce_cython__(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_8__setstate_cython__(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_type_encoders); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_2dump(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_4load(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer___pyx_unpickle_SerializerField(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_2__pyx_unpickle_DateTimeFieldEncoder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_7serpyco_10serializer_4__pyx_unpickle_UuidFieldEncoder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_7serpyco_10serializer_SerializerField(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_Caster(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_Serializer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_EnumFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_DataClassFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_DataClassIterableFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_FixedTupleFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_IterableFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_DictFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_DateTimeFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_UuidFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer_UnionFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct__genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_1__get_encoder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_2_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_remove = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_7serpyco_10serializer_SerializerField;
  PyObject *__pyx_type_7serpyco_10serializer_Caster;
  PyObject *__pyx_type_7serpyco_10serializer_Serializer;
  PyObject *__pyx_type_7serpyco_10serializer_EnumFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_DataClassFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_IterableFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_DictFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_DateTimeFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_UuidFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer_UnionFieldEncoder;
  PyObject *__pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr;
  PyObject *__pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder;
  PyObject *__pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr;
  #endif
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_SerializerField;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_Caster;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_Serializer;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_DictFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder;
  PyTypeObject *__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr;
  PyObject *__pyx_kp_u_;
  PyObject *__pyx_kp_u_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9;
  PyObject *__pyx_n_s_Any;
  PyObject *__pyx_n_s_AttributeError;
  PyObject *__pyx_kp_u_Cannot_create;
  PyObject *__pyx_n_s_Caster;
  PyObject *__pyx_n_s_Caster___reduce_cython;
  PyObject *__pyx_n_s_Caster___setstate_cython;
  PyObject *__pyx_kp_u_Could_not_cast_field;
  PyObject *__pyx_n_s_DataClassFieldEncoder;
  PyObject *__pyx_n_s_DataClassFieldEncoder___reduce_c;
  PyObject *__pyx_n_s_DataClassFieldEncoder___setstate;
  PyObject *__pyx_n_s_DataClassFieldEncoder_dump;
  PyObject *__pyx_n_s_DataClassFieldEncoder_json_schem;
  PyObject *__pyx_n_s_DataClassFieldEncoder_load;
  PyObject *__pyx_n_s_DataClassIterableFieldEncoder;
  PyObject *__pyx_n_s_DataClassIterableFieldEncoder_2;
  PyObject *__pyx_n_s_DataClassIterableFieldEncoder_3;
  PyObject *__pyx_n_s_DataClassIterableFieldEncoder_du;
  PyObject *__pyx_n_s_DataClassIterableFieldEncoder_js;
  PyObject *__pyx_n_s_DataClassIterableFieldEncoder_lo;
  PyObject *__pyx_n_s_DataClassParams;
  PyObject *__pyx_n_s_DateTimeFieldEncoder;
  PyObject *__pyx_n_s_DateTimeFieldEncoder___reduce_cy;
  PyObject *__pyx_n_s_DateTimeFieldEncoder___setstate;
  PyObject *__pyx_n_s_DateTimeFieldEncoder_dump;
  PyObject *__pyx_n_s_DateTimeFieldEncoder_json_schema;
  PyObject *__pyx_n_s_DateTimeFieldEncoder_load;
  PyObject *__pyx_n_s_DecoratorType;
  PyObject *__pyx_n_s_DictFieldEncoder;
  PyObject *__pyx_n_s_DictFieldEncoder___reduce_cython;
  PyObject *__pyx_n_s_DictFieldEncoder___setstate_cyth;
  PyObject *__pyx_n_s_DictFieldEncoder_dump;
  PyObject *__pyx_n_s_DictFieldEncoder_json_schema;
  PyObject *__pyx_n_s_DictFieldEncoder_load;
  PyObject *__pyx_n_s_Enum;
  PyObject *__pyx_n_s_EnumFieldEncoder;
  PyObject *__pyx_n_s_EnumFieldEncoder___reduce_cython;
  PyObject *__pyx_n_s_EnumFieldEncoder___setstate_cyth;
  PyObject *__pyx_n_s_EnumFieldEncoder_dump;
  PyObject *__pyx_n_s_EnumFieldEncoder_json_schema;
  PyObject *__pyx_n_s_EnumFieldEncoder_load;
  PyObject *__pyx_n_s_FieldEncoder;
  PyObject *__pyx_n_s_FieldHints;
  PyObject *__pyx_n_s_FixedTupleFieldEncoder;
  PyObject *__pyx_n_s_FixedTupleFieldEncoder___reduce;
  PyObject *__pyx_n_s_FixedTupleFieldEncoder___setstat;
  PyObject *__pyx_n_s_FixedTupleFieldEncoder_dump;
  PyObject *__pyx_n_s_FixedTupleFieldEncoder_json_sche;
  PyObject *__pyx_n_s_FixedTupleFieldEncoder_load;
  PyObject *__pyx_n_s_ITERABLE_TYPES_MAPPING;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2;
  PyObject *__pyx_kp_u_Invalid_number_of_items_for_tupl;
  PyObject *__pyx_n_s_Iterable;
  PyObject *__pyx_n_s_IterableFieldEncoder;
  PyObject *__pyx_n_s_IterableFieldEncoder___reduce_cy;
  PyObject *__pyx_n_s_IterableFieldEncoder___setstate;
  PyObject *__pyx_n_s_IterableFieldEncoder_dump;
  PyObject *__pyx_n_s_IterableFieldEncoder_json_schema;
  PyObject *__pyx_n_s_IterableFieldEncoder_load;
  PyObject *__pyx_n_s_JSON_ENCODABLE_TYPES;
  PyObject *__pyx_n_s_JsonDict;
  PyObject *__pyx_n_s_JsonEncodable;
  PyObject *__pyx_n_s_KeyError;
  PyObject *__pyx_n_s_List;
  PyObject *__pyx_n_s_MISSING;
  PyObject *__pyx_n_s_Mapping;
  PyObject *__pyx_n_s_NoEncoderError;
  PyObject *__pyx_kp_u_No_encoder_for;
  PyObject *__pyx_n_s_None;
  PyObject *__pyx_kp_u_None;
  PyObject *__pyx_n_s_NotADataClassError;
  PyObject *__pyx_n_s_OverflowError;
  PyObject *__pyx_n_s_POST_DUMP;
  PyObject *__pyx_n_s_POST_LOAD;
  PyObject *__pyx_n_s_PRE_DUMP;
  PyObject *__pyx_n_s_PRE_LOAD;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_n_s_RapidJsonValidator;
  PyObject *__pyx_n_s_SchemaBuilder;
  PyObject *__pyx_n_s_Serializer;
  PyObject *__pyx_n_s_SerializerField;
  PyObject *__pyx_n_s_SerializerField___reduce_cython;
  PyObject *__pyx_n_s_SerializerField___setstate_cytho;
  PyObject *__pyx_kp_s_Serializer_2;
  PyObject *__pyx_n_s_Serializer___reduce_cython;
  PyObject *__pyx_n_s_Serializer___setstate_cython;
  PyObject *__pyx_n_s_Serializer__get_encoder;
  PyObject *__pyx_n_s_Serializer__get_field_serializer;
  PyObject *__pyx_n_s_Serializer_dataclass;
  PyObject *__pyx_n_s_Serializer_dump;
  PyObject *__pyx_n_s_Serializer_dump_json;
  PyObject *__pyx_n_s_Serializer_get_dict_path;
  PyObject *__pyx_n_s_Serializer_get_object_path;
  PyObject *__pyx_n_s_Serializer_json_schema;
  PyObject *__pyx_n_s_Serializer_load;
  PyObject *__pyx_n_s_Serializer_load_json;
  PyObject *__pyx_n_s_Serializer_register_global_type;
  PyObject *__pyx_n_s_Serializer_unregister_global_typ;
  PyObject *__pyx_n_s_Set;
  PyObject *__pyx_n_s_Tuple;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_n_s_UNTYPED_DICT_TYPES;
  PyObject *__pyx_n_s_UNTYPED_ITERABLE_TYPES;
  PyObject *__pyx_n_s_UUID;
  PyObject *__pyx_n_s_UnionFieldEncoder;
  PyObject *__pyx_n_s_UnionFieldEncoder___reduce_cytho;
  PyObject *__pyx_n_s_UnionFieldEncoder___setstate_cyt;
  PyObject *__pyx_n_s_UnionFieldEncoder_dump;
  PyObject *__pyx_n_s_UnionFieldEncoder_json_schema;
  PyObject *__pyx_n_s_UnionFieldEncoder_load;
  PyObject *__pyx_kp_u_Unknown_decorator_type;
  PyObject *__pyx_kp_u_Unknown_dict_key;
  PyObject *__pyx_kp_u_Unknown_field;
  PyObject *__pyx_n_s_UuidFieldEncoder;
  PyObject *__pyx_n_s_UuidFieldEncoder___reduce_cython;
  PyObject *__pyx_n_s_UuidFieldEncoder___setstate_cyth;
  PyObject *__pyx_n_s_UuidFieldEncoder_dump;
  PyObject *__pyx_n_s_UuidFieldEncoder_json_schema;
  PyObject *__pyx_n_s_UuidFieldEncoder_load;
  PyObject *__pyx_n_s_ValidationError;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_kp_u__3;
  PyObject *__pyx_kp_u__4;
  PyObject *__pyx_kp_u__5;
  PyObject *__pyx_kp_u__7;
  PyObject *__pyx_n_s__9;
  PyObject *__pyx_n_s__97;
  PyObject *__pyx_n_s_arg;
  PyObject *__pyx_n_s_arg_type;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_s_arguments;
  PyObject *__pyx_kp_u_as;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_bool;
  PyObject *__pyx_n_s_cast_on_load;
  PyObject *__pyx_n_s_caster;
  PyObject *__pyx_n_s_cinit___locals_genexpr;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_cls;
  PyObject *__pyx_n_s_data;
  PyObject *__pyx_kp_u_data_dictionary_is_missing_requi;
  PyObject *__pyx_n_s_dataclass;
  PyObject *__pyx_n_s_dataclass_params;
  PyObject *__pyx_n_s_dataclass_params_2;
  PyObject *__pyx_n_s_dataclasses;
  PyObject *__pyx_kp_u_date_time;
  PyObject *__pyx_n_s_datetime;
  PyObject *__pyx_n_s_dateutil;
  PyObject *__pyx_n_s_dateutil_parser;
  PyObject *__pyx_n_s_default;
  PyObject *__pyx_n_s_default_factory;
  PyObject *__pyx_n_s_dencoder;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_n_s_dict_encoder;
  PyObject *__pyx_n_s_dict_key;
  PyObject *__pyx_n_s_dict_path;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_diter_encoder;
  PyObject *__pyx_n_s_dump;
  PyObject *__pyx_n_s_dump_json;
  PyObject *__pyx_n_s_dumps;
  PyObject *__pyx_n_s_e;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_encoder;
  PyObject *__pyx_n_s_enum;
  PyObject *__pyx_n_s_enum_type;
  PyObject *__pyx_n_s_evaluate;
  PyObject *__pyx_n_s_exclude;
  PyObject *__pyx_n_s_excluded_field_names;
  PyObject *__pyx_n_s_f;
  PyObject *__pyx_kp_u_field;
  PyObject *__pyx_n_s_field_name;
  PyObject *__pyx_n_s_field_type;
  PyObject *__pyx_n_s_fields;
  PyObject *__pyx_kp_u_for_class;
  PyObject *__pyx_n_u_format;
  PyObject *__pyx_n_s_frozen;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_genexpr;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_get_args;
  PyObject *__pyx_n_s_get_dict_path;
  PyObject *__pyx_n_s_get_encoder;
  PyObject *__pyx_n_s_get_encoder_locals_genexpr;
  PyObject *__pyx_n_s_get_field_serializer;
  PyObject *__pyx_n_s_get_object_path;
  PyObject *__pyx_n_s_get_origin;
  PyObject *__pyx_n_s_get_type_hints;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_n_s_getter;
  PyObject *__pyx_n_s_global_types;
  PyObject *__pyx_n_s_h;
  PyObject *__pyx_kp_u_has_a_wrong_type_expected_any_o;
  PyObject *__pyx_n_s_hints;
  PyObject *__pyx_n_s_ignore;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_kp_u_in;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_kp_u_is_excluded_but_has_no_default;
  PyObject *__pyx_n_s_is_generic;
  PyObject *__pyx_n_s_is_new_type;
  PyObject *__pyx_kp_u_is_not_a_dataclass;
  PyObject *__pyx_kp_u_is_not_a_datetime_datetime_inst;
  PyObject *__pyx_kp_u_is_not_a_valid_datetime;
  PyObject *__pyx_n_s_is_union;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_iso8601_pattern;
  PyObject *__pyx_n_s_isoformat;
  PyObject *__pyx_n_s_issubclass_safe;
  PyObject *__pyx_n_s_item_encoder;
  PyObject *__pyx_n_s_item_encoders;
  PyObject *__pyx_n_s_item_type;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_iter_encoder;
  PyObject *__pyx_n_s_js;
  PyObject *__pyx_n_s_json_schema;
  PyObject *__pyx_n_s_key_encoder;
  PyObject *__pyx_n_s_keys;
  PyObject *__pyx_n_s_load;
  PyObject *__pyx_n_s_load_as_type;
  PyObject *__pyx_n_s_load_json;
  PyObject *__pyx_n_s_loads;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_many;
  PyObject *__pyx_n_s_map;
  PyObject *__pyx_n_s_metadata;
  PyObject *__pyx_n_s_metadata_name;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
  PyObject *__pyx_n_s_obj;
  PyObject *__pyx_n_s_obj_path;
  PyObject *__pyx_n_s_object;
  PyObject *__pyx_n_s_omit_none;
  PyObject *__pyx_n_s_only;
  PyObject *__pyx_n_s_param;
  PyObject *__pyx_n_s_param_args;
  PyObject *__pyx_n_s_parameters;
  PyObject *__pyx_n_s_params;
  PyObject *__pyx_n_s_parent_serializers;
  PyObject *__pyx_n_s_parse;
  PyObject *__pyx_n_s_parser;
  PyObject *__pyx_n_s_part;
  PyObject *__pyx_n_u_pattern;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_post_init;
  PyObject *__pyx_n_u_post_init;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_DateTimeFieldEnco;
  PyObject *__pyx_n_s_pyx_unpickle_SerializerField;
  PyObject *__pyx_n_s_pyx_unpickle_UuidFieldEncoder;
  PyObject *__pyx_n_s_pyx_vtable;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_rapidjson;
  PyObject *__pyx_n_s_re;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_register_global_type;
  PyObject *__pyx_n_s_remove;
  PyObject *__pyx_n_s_resolve_type;
  PyObject *__pyx_n_s_return;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_n_s_send;
  PyObject *__pyx_n_s_sequence_type;
  PyObject *__pyx_n_s_ser;
  PyObject *__pyx_n_s_serializer;
  PyObject *__pyx_n_s_serpyco_decorator;
  PyObject *__pyx_n_s_serpyco_exception;
  PyObject *__pyx_n_s_serpyco_field;
  PyObject *__pyx_n_s_serpyco_schema;
  PyObject *__pyx_n_s_serpyco_serializer;
  PyObject *__pyx_kp_s_serpyco_serializer_pyx;
  PyObject *__pyx_n_s_serpyco_tags;
  PyObject *__pyx_n_s_serpyco_util;
  PyObject *__pyx_n_s_serpyco_validator;
  PyObject *__pyx_n_s_setattr;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_sfield;
  PyObject *__pyx_n_s_sh;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_strict;
  PyObject *__pyx_n_u_string;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_supertype;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_throw;
  PyObject *__pyx_n_s_type;
  PyObject *__pyx_n_s_type_2;
  PyObject *__pyx_n_u_type_2;
  PyObject *__pyx_n_s_type_encoders;
  PyObject *__pyx_n_s_typing;
  PyObject *__pyx_kp_s_typing_Any;
  PyObject *__pyx_kp_s_typing_List_str;
  PyObject *__pyx_kp_s_typing_Sequence_str;
  PyObject *__pyx_kp_s_typing_Union_dict_typing_Iterabl;
  PyObject *__pyx_kp_s_typing_Union_object_typing_Itera;
  PyObject *__pyx_n_s_typing_inspect;
  PyObject *__pyx_n_s_unregister_global_type;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_use_setstate;
  PyObject *__pyx_n_s_uuid;
  PyObject *__pyx_n_u_uuid;
  PyObject *__pyx_n_s_validate;
  PyObject *__pyx_n_s_validate_json;
  PyObject *__pyx_n_s_validate_user;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_n_s_value_encoder;
  PyObject *__pyx_n_s_zip;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_79851409;
  PyObject *__pyx_int_146220692;
  PyObject *__pyx_int_222419149;
  PyObject *__pyx_int_228825662;
  PyObject *__pyx_int_238750788;
  PyObject *__pyx_int_246984282;
  PyObject *__pyx_slice__2;
  PyObject *__pyx_tuple__6;
  PyObject *__pyx_tuple__8;
  PyObject *__pyx_tuple__10;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__13;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__18;
  PyObject *__pyx_tuple__20;
  PyObject *__pyx_tuple__21;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__25;
  PyObject *__pyx_tuple__27;
  PyObject *__pyx_tuple__30;
  PyObject *__pyx_tuple__32;
  PyObject *__pyx_tuple__33;
  PyObject *__pyx_tuple__35;
  PyObject *__pyx_tuple__37;
  PyObject *__pyx_tuple__38;
  PyObject *__pyx_tuple__40;
  PyObject *__pyx_tuple__41;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__47;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_codeobj__12;
  PyObject *__pyx_codeobj__14;
  PyObject *__pyx_codeobj__16;
  PyObject *__pyx_codeobj__17;
  PyObject *__pyx_codeobj__19;
  PyObject *__pyx_codeobj__22;
  PyObject *__pyx_codeobj__24;
  PyObject *__pyx_codeobj__26;
  PyObject *__pyx_codeobj__28;
  PyObject *__pyx_codeobj__29;
  PyObject *__pyx_codeobj__31;
  PyObject *__pyx_codeobj__34;
  PyObject *__pyx_codeobj__36;
  PyObject *__pyx_codeobj__39;
  PyObject *__pyx_codeobj__42;
  PyObject *__pyx_codeobj__44;
  PyObject *__pyx_codeobj__45;
  PyObject *__pyx_codeobj__46;
  PyObject *__pyx_codeobj__48;
  PyObject *__pyx_codeobj__49;
  PyObject *__pyx_codeobj__50;
  PyObject *__pyx_codeobj__51;
  PyObject *__pyx_codeobj__52;
  PyObject *__pyx_codeobj__53;
  PyObject *__pyx_codeobj__54;
  PyObject *__pyx_codeobj__55;
  PyObject *__pyx_codeobj__56;
  PyObject *__pyx_codeobj__57;
  PyObject *__pyx_codeobj__58;
  PyObject *__pyx_codeobj__59;
  PyObject *__pyx_codeobj__60;
  PyObject *__pyx_codeobj__61;
  PyObject *__pyx_codeobj__62;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__64;
  PyObject *__pyx_codeobj__65;
  PyObject *__pyx_codeobj__66;
  PyObject *__pyx_codeobj__67;
  PyObject *__pyx_codeobj__68;
  PyObject *__pyx_codeobj__69;
  PyObject *__pyx_codeobj__70;
  PyObject *__pyx_codeobj__71;
  PyObject *__pyx_codeobj__72;
  PyObject *__pyx_codeobj__73;
  PyObject *__pyx_codeobj__74;
  PyObject *__pyx_codeobj__75;
  PyObject *__pyx_codeobj__76;
  PyObject *__pyx_codeobj__77;
  PyObject *__pyx_codeobj__78;
  PyObject *__pyx_codeobj__79;
  PyObject *__pyx_codeobj__80;
  PyObject *__pyx_codeobj__81;
  PyObject *__pyx_codeobj__82;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__84;
  PyObject *__pyx_codeobj__85;
  PyObject *__pyx_codeobj__86;
  PyObject *__pyx_codeobj__87;
  PyObject *__pyx_codeobj__88;
  PyObject *__pyx_codeobj__89;
  PyObject *__pyx_codeobj__90;
  PyObject *__pyx_codeobj__91;
  PyObject *__pyx_codeobj__92;
  PyObject *__pyx_codeobj__94;
  PyObject *__pyx_codeobj__95;
  PyObject *__pyx_codeobj__96;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_7encoder_FieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_SerializerField);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_SerializerField);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_Caster);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_Caster);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_Serializer);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_Serializer);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_EnumFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_DataClassFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_IterableFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_DictFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_DictFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_DateTimeFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_UuidFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer_UnionFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder);
  Py_CLEAR(clear_module_state->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_);
  Py_CLEAR(clear_module_state->__pyx_kp_u_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9);
  Py_CLEAR(clear_module_state->__pyx_n_s_Any);
  Py_CLEAR(clear_module_state->__pyx_n_s_AttributeError);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_create);
  Py_CLEAR(clear_module_state->__pyx_n_s_Caster);
  Py_CLEAR(clear_module_state->__pyx_n_s_Caster___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Caster___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Could_not_cast_field);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassFieldEncoder___reduce_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassFieldEncoder___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassFieldEncoder_json_schem);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassIterableFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassIterableFieldEncoder_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassIterableFieldEncoder_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassIterableFieldEncoder_du);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassIterableFieldEncoder_js);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassIterableFieldEncoder_lo);
  Py_CLEAR(clear_module_state->__pyx_n_s_DataClassParams);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateTimeFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateTimeFieldEncoder___reduce_cy);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateTimeFieldEncoder___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateTimeFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateTimeFieldEncoder_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateTimeFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_DecoratorType);
  Py_CLEAR(clear_module_state->__pyx_n_s_DictFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_DictFieldEncoder___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_DictFieldEncoder___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_DictFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_DictFieldEncoder_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_DictFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_Enum);
  Py_CLEAR(clear_module_state->__pyx_n_s_EnumFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_EnumFieldEncoder___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_EnumFieldEncoder___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_EnumFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_EnumFieldEncoder_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_EnumFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_FieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_FieldHints);
  Py_CLEAR(clear_module_state->__pyx_n_s_FixedTupleFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_FixedTupleFieldEncoder___reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_FixedTupleFieldEncoder___setstat);
  Py_CLEAR(clear_module_state->__pyx_n_s_FixedTupleFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_FixedTupleFieldEncoder_json_sche);
  Py_CLEAR(clear_module_state->__pyx_n_s_FixedTupleFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_ITERABLE_TYPES_MAPPING);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_number_of_items_for_tupl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Iterable);
  Py_CLEAR(clear_module_state->__pyx_n_s_IterableFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_IterableFieldEncoder___reduce_cy);
  Py_CLEAR(clear_module_state->__pyx_n_s_IterableFieldEncoder___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_IterableFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_IterableFieldEncoder_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_IterableFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_JSON_ENCODABLE_TYPES);
  Py_CLEAR(clear_module_state->__pyx_n_s_JsonDict);
  Py_CLEAR(clear_module_state->__pyx_n_s_JsonEncodable);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyError);
  Py_CLEAR(clear_module_state->__pyx_n_s_List);
  Py_CLEAR(clear_module_state->__pyx_n_s_MISSING);
  Py_CLEAR(clear_module_state->__pyx_n_s_Mapping);
  Py_CLEAR(clear_module_state->__pyx_n_s_NoEncoderError);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_encoder_for);
  Py_CLEAR(clear_module_state->__pyx_n_s_None);
  Py_CLEAR(clear_module_state->__pyx_kp_u_None);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotADataClassError);
  Py_CLEAR(clear_module_state->__pyx_n_s_OverflowError);
  Py_CLEAR(clear_module_state->__pyx_n_s_POST_DUMP);
  Py_CLEAR(clear_module_state->__pyx_n_s_POST_LOAD);
  Py_CLEAR(clear_module_state->__pyx_n_s_PRE_DUMP);
  Py_CLEAR(clear_module_state->__pyx_n_s_PRE_LOAD);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_RapidJsonValidator);
  Py_CLEAR(clear_module_state->__pyx_n_s_SchemaBuilder);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer);
  Py_CLEAR(clear_module_state->__pyx_n_s_SerializerField);
  Py_CLEAR(clear_module_state->__pyx_n_s_SerializerField___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_SerializerField___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Serializer_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer__get_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer__get_field_serializer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_dataclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_dump_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_get_dict_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_get_object_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_load_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_register_global_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_Serializer_unregister_global_typ);
  Py_CLEAR(clear_module_state->__pyx_n_s_Set);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tuple);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_UNTYPED_DICT_TYPES);
  Py_CLEAR(clear_module_state->__pyx_n_s_UNTYPED_ITERABLE_TYPES);
  Py_CLEAR(clear_module_state->__pyx_n_s_UUID);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnionFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnionFieldEncoder___reduce_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnionFieldEncoder___setstate_cyt);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnionFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnionFieldEncoder_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnionFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unknown_decorator_type);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unknown_dict_key);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unknown_field);
  Py_CLEAR(clear_module_state->__pyx_n_s_UuidFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_UuidFieldEncoder___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UuidFieldEncoder___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_UuidFieldEncoder_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_UuidFieldEncoder_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_UuidFieldEncoder_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValidationError);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_kp_u__3);
  Py_CLEAR(clear_module_state->__pyx_kp_u__4);
  Py_CLEAR(clear_module_state->__pyx_kp_u__5);
  Py_CLEAR(clear_module_state->__pyx_kp_u__7);
  Py_CLEAR(clear_module_state->__pyx_n_s__9);
  Py_CLEAR(clear_module_state->__pyx_n_s__97);
  Py_CLEAR(clear_module_state->__pyx_n_s_arg);
  Py_CLEAR(clear_module_state->__pyx_n_s_arg_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_arguments);
  Py_CLEAR(clear_module_state->__pyx_kp_u_as);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_bool);
  Py_CLEAR(clear_module_state->__pyx_n_s_cast_on_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_caster);
  Py_CLEAR(clear_module_state->__pyx_n_s_cinit___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_cls);
  Py_CLEAR(clear_module_state->__pyx_n_s_data);
  Py_CLEAR(clear_module_state->__pyx_kp_u_data_dictionary_is_missing_requi);
  Py_CLEAR(clear_module_state->__pyx_n_s_dataclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_dataclass_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_dataclass_params_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_dataclasses);
  Py_CLEAR(clear_module_state->__pyx_kp_u_date_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_dateutil);
  Py_CLEAR(clear_module_state->__pyx_n_s_dateutil_parser);
  Py_CLEAR(clear_module_state->__pyx_n_s_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_default_factory);
  Py_CLEAR(clear_module_state->__pyx_n_s_dencoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_path);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_diter_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_dump);
  Py_CLEAR(clear_module_state->__pyx_n_s_dump_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_dumps);
  Py_CLEAR(clear_module_state->__pyx_n_s_e);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_enum);
  Py_CLEAR(clear_module_state->__pyx_n_s_enum_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_evaluate);
  Py_CLEAR(clear_module_state->__pyx_n_s_exclude);
  Py_CLEAR(clear_module_state->__pyx_n_s_excluded_field_names);
  Py_CLEAR(clear_module_state->__pyx_n_s_f);
  Py_CLEAR(clear_module_state->__pyx_kp_u_field);
  Py_CLEAR(clear_module_state->__pyx_n_s_field_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_field_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_fields);
  Py_CLEAR(clear_module_state->__pyx_kp_u_for_class);
  Py_CLEAR(clear_module_state->__pyx_n_u_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_frozen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dict_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_encoder_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_field_serializer);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_object_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_origin);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_type_hints);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_getter);
  Py_CLEAR(clear_module_state->__pyx_n_s_global_types);
  Py_CLEAR(clear_module_state->__pyx_n_s_h);
  Py_CLEAR(clear_module_state->__pyx_kp_u_has_a_wrong_type_expected_any_o);
  Py_CLEAR(clear_module_state->__pyx_n_s_hints);
  Py_CLEAR(clear_module_state->__pyx_n_s_ignore);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_kp_u_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_excluded_but_has_no_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_generic);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_new_type);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_not_a_dataclass);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_not_a_datetime_datetime_inst);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_not_a_valid_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_union);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_iso8601_pattern);
  Py_CLEAR(clear_module_state->__pyx_n_s_isoformat);
  Py_CLEAR(clear_module_state->__pyx_n_s_issubclass_safe);
  Py_CLEAR(clear_module_state->__pyx_n_s_item_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_item_encoders);
  Py_CLEAR(clear_module_state->__pyx_n_s_item_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_iter_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_js);
  Py_CLEAR(clear_module_state->__pyx_n_s_json_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_key_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_load);
  Py_CLEAR(clear_module_state->__pyx_n_s_load_as_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_load_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_loads);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_many);
  Py_CLEAR(clear_module_state->__pyx_n_s_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_metadata);
  Py_CLEAR(clear_module_state->__pyx_n_s_metadata_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_omit_none);
  Py_CLEAR(clear_module_state->__pyx_n_s_only);
  Py_CLEAR(clear_module_state->__pyx_n_s_param);
  Py_CLEAR(clear_module_state->__pyx_n_s_param_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_parameters);
  Py_CLEAR(clear_module_state->__pyx_n_s_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_parent_serializers);
  Py_CLEAR(clear_module_state->__pyx_n_s_parse);
  Py_CLEAR(clear_module_state->__pyx_n_s_parser);
  Py_CLEAR(clear_module_state->__pyx_n_s_part);
  Py_CLEAR(clear_module_state->__pyx_n_u_pattern);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_post_init);
  Py_CLEAR(clear_module_state->__pyx_n_u_post_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_DateTimeFieldEnco);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_SerializerField);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_UuidFieldEncoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_vtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_rapidjson);
  Py_CLEAR(clear_module_state->__pyx_n_s_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_global_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_remove);
  Py_CLEAR(clear_module_state->__pyx_n_s_resolve_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_return);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_n_s_send);
  Py_CLEAR(clear_module_state->__pyx_n_s_sequence_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_ser);
  Py_CLEAR(clear_module_state->__pyx_n_s_serializer);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_decorator);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_field);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_schema);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_serializer);
  Py_CLEAR(clear_module_state->__pyx_kp_s_serpyco_serializer_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_tags);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_util);
  Py_CLEAR(clear_module_state->__pyx_n_s_serpyco_validator);
  Py_CLEAR(clear_module_state->__pyx_n_s_setattr);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_sfield);
  Py_CLEAR(clear_module_state->__pyx_n_s_sh);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_strict);
  Py_CLEAR(clear_module_state->__pyx_n_u_string);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_supertype);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_throw);
  Py_CLEAR(clear_module_state->__pyx_n_s_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_type_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_type_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_type_encoders);
  Py_CLEAR(clear_module_state->__pyx_n_s_typing);
  Py_CLEAR(clear_module_state->__pyx_kp_s_typing_Any);
  Py_CLEAR(clear_module_state->__pyx_kp_s_typing_List_str);
  Py_CLEAR(clear_module_state->__pyx_kp_s_typing_Sequence_str);
  Py_CLEAR(clear_module_state->__pyx_kp_s_typing_Union_dict_typing_Iterabl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_typing_Union_object_typing_Itera);
  Py_CLEAR(clear_module_state->__pyx_n_s_typing_inspect);
  Py_CLEAR(clear_module_state->__pyx_n_s_unregister_global_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_uuid);
  Py_CLEAR(clear_module_state->__pyx_n_u_uuid);
  Py_CLEAR(clear_module_state->__pyx_n_s_validate);
  Py_CLEAR(clear_module_state->__pyx_n_s_validate_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_validate_user);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_value_encoder);
  Py_CLEAR(clear_module_state->__pyx_n_s_zip);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_79851409);
  Py_CLEAR(clear_module_state->__pyx_int_146220692);
  Py_CLEAR(clear_module_state->__pyx_int_222419149);
  Py_CLEAR(clear_module_state->__pyx_int_228825662);
  Py_CLEAR(clear_module_state->__pyx_int_238750788);
  Py_CLEAR(clear_module_state->__pyx_int_246984282);
  Py_CLEAR(clear_module_state->__pyx_slice__2);
  Py_CLEAR(clear_module_state->__pyx_tuple__6);
  Py_CLEAR(clear_module_state->__pyx_tuple__8);
  Py_CLEAR(clear_module_state->__pyx_tuple__10);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__13);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__18);
  Py_CLEAR(clear_module_state->__pyx_tuple__20);
  Py_CLEAR(clear_module_state->__pyx_tuple__21);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__25);
  Py_CLEAR(clear_module_state->__pyx_tuple__27);
  Py_CLEAR(clear_module_state->__pyx_tuple__30);
  Py_CLEAR(clear_module_state->__pyx_tuple__32);
  Py_CLEAR(clear_module_state->__pyx_tuple__33);
  Py_CLEAR(clear_module_state->__pyx_tuple__35);
  Py_CLEAR(clear_module_state->__pyx_tuple__37);
  Py_CLEAR(clear_module_state->__pyx_tuple__38);
  Py_CLEAR(clear_module_state->__pyx_tuple__40);
  Py_CLEAR(clear_module_state->__pyx_tuple__41);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__47);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_codeobj__12);
  Py_CLEAR(clear_module_state->__pyx_codeobj__14);
  Py_CLEAR(clear_module_state->__pyx_codeobj__16);
  Py_CLEAR(clear_module_state->__pyx_codeobj__17);
  Py_CLEAR(clear_module_state->__pyx_codeobj__19);
  Py_CLEAR(clear_module_state->__pyx_codeobj__22);
  Py_CLEAR(clear_module_state->__pyx_codeobj__24);
  Py_CLEAR(clear_module_state->__pyx_codeobj__26);
  Py_CLEAR(clear_module_state->__pyx_codeobj__28);
  Py_CLEAR(clear_module_state->__pyx_codeobj__29);
  Py_CLEAR(clear_module_state->__pyx_codeobj__31);
  Py_CLEAR(clear_module_state->__pyx_codeobj__34);
  Py_CLEAR(clear_module_state->__pyx_codeobj__36);
  Py_CLEAR(clear_module_state->__pyx_codeobj__39);
  Py_CLEAR(clear_module_state->__pyx_codeobj__42);
  Py_CLEAR(clear_module_state->__pyx_codeobj__44);
  Py_CLEAR(clear_module_state->__pyx_codeobj__45);
  Py_CLEAR(clear_module_state->__pyx_codeobj__46);
  Py_CLEAR(clear_module_state->__pyx_codeobj__48);
  Py_CLEAR(clear_module_state->__pyx_codeobj__49);
  Py_CLEAR(clear_module_state->__pyx_codeobj__50);
  Py_CLEAR(clear_module_state->__pyx_codeobj__51);
  Py_CLEAR(clear_module_state->__pyx_codeobj__52);
  Py_CLEAR(clear_module_state->__pyx_codeobj__53);
  Py_CLEAR(clear_module_state->__pyx_codeobj__54);
  Py_CLEAR(clear_module_state->__pyx_codeobj__55);
  Py_CLEAR(clear_module_state->__pyx_codeobj__56);
  Py_CLEAR(clear_module_state->__pyx_codeobj__57);
  Py_CLEAR(clear_module_state->__pyx_codeobj__58);
  Py_CLEAR(clear_module_state->__pyx_codeobj__59);
  Py_CLEAR(clear_module_state->__pyx_codeobj__60);
  Py_CLEAR(clear_module_state->__pyx_codeobj__61);
  Py_CLEAR(clear_module_state->__pyx_codeobj__62);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__64);
  Py_CLEAR(clear_module_state->__pyx_codeobj__65);
  Py_CLEAR(clear_module_state->__pyx_codeobj__66);
  Py_CLEAR(clear_module_state->__pyx_codeobj__67);
  Py_CLEAR(clear_module_state->__pyx_codeobj__68);
  Py_CLEAR(clear_module_state->__pyx_codeobj__69);
  Py_CLEAR(clear_module_state->__pyx_codeobj__70);
  Py_CLEAR(clear_module_state->__pyx_codeobj__71);
  Py_CLEAR(clear_module_state->__pyx_codeobj__72);
  Py_CLEAR(clear_module_state->__pyx_codeobj__73);
  Py_CLEAR(clear_module_state->__pyx_codeobj__74);
  Py_CLEAR(clear_module_state->__pyx_codeobj__75);
  Py_CLEAR(clear_module_state->__pyx_codeobj__76);
  Py_CLEAR(clear_module_state->__pyx_codeobj__77);
  Py_CLEAR(clear_module_state->__pyx_codeobj__78);
  Py_CLEAR(clear_module_state->__pyx_codeobj__79);
  Py_CLEAR(clear_module_state->__pyx_codeobj__80);
  Py_CLEAR(clear_module_state->__pyx_codeobj__81);
  Py_CLEAR(clear_module_state->__pyx_codeobj__82);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__84);
  Py_CLEAR(clear_module_state->__pyx_codeobj__85);
  Py_CLEAR(clear_module_state->__pyx_codeobj__86);
  Py_CLEAR(clear_module_state->__pyx_codeobj__87);
  Py_CLEAR(clear_module_state->__pyx_codeobj__88);
  Py_CLEAR(clear_module_state->__pyx_codeobj__89);
  Py_CLEAR(clear_module_state->__pyx_codeobj__90);
  Py_CLEAR(clear_module_state->__pyx_codeobj__91);
  Py_CLEAR(clear_module_state->__pyx_codeobj__92);
  Py_CLEAR(clear_module_state->__pyx_codeobj__94);
  Py_CLEAR(clear_module_state->__pyx_codeobj__95);
  Py_CLEAR(clear_module_state->__pyx_codeobj__96);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_7encoder_FieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_SerializerField);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_SerializerField);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_Caster);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_Caster);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_Serializer);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_Serializer);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_EnumFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_DataClassFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_IterableFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_DictFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_DictFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_DateTimeFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_UuidFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer_UnionFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder);
  Py_VISIT(traverse_module_state->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_);
  Py_VISIT(traverse_module_state->__pyx_kp_u_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9);
  Py_VISIT(traverse_module_state->__pyx_n_s_Any);
  Py_VISIT(traverse_module_state->__pyx_n_s_AttributeError);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_create);
  Py_VISIT(traverse_module_state->__pyx_n_s_Caster);
  Py_VISIT(traverse_module_state->__pyx_n_s_Caster___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Caster___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Could_not_cast_field);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassFieldEncoder___reduce_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassFieldEncoder___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassFieldEncoder_json_schem);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassIterableFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassIterableFieldEncoder_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassIterableFieldEncoder_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassIterableFieldEncoder_du);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassIterableFieldEncoder_js);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassIterableFieldEncoder_lo);
  Py_VISIT(traverse_module_state->__pyx_n_s_DataClassParams);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateTimeFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateTimeFieldEncoder___reduce_cy);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateTimeFieldEncoder___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateTimeFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateTimeFieldEncoder_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateTimeFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_DecoratorType);
  Py_VISIT(traverse_module_state->__pyx_n_s_DictFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_DictFieldEncoder___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_DictFieldEncoder___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_DictFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_DictFieldEncoder_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_DictFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_Enum);
  Py_VISIT(traverse_module_state->__pyx_n_s_EnumFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_EnumFieldEncoder___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_EnumFieldEncoder___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_EnumFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_EnumFieldEncoder_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_EnumFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_FieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_FieldHints);
  Py_VISIT(traverse_module_state->__pyx_n_s_FixedTupleFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_FixedTupleFieldEncoder___reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_FixedTupleFieldEncoder___setstat);
  Py_VISIT(traverse_module_state->__pyx_n_s_FixedTupleFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_FixedTupleFieldEncoder_json_sche);
  Py_VISIT(traverse_module_state->__pyx_n_s_FixedTupleFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_ITERABLE_TYPES_MAPPING);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_number_of_items_for_tupl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Iterable);
  Py_VISIT(traverse_module_state->__pyx_n_s_IterableFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_IterableFieldEncoder___reduce_cy);
  Py_VISIT(traverse_module_state->__pyx_n_s_IterableFieldEncoder___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_IterableFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_IterableFieldEncoder_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_IterableFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_JSON_ENCODABLE_TYPES);
  Py_VISIT(traverse_module_state->__pyx_n_s_JsonDict);
  Py_VISIT(traverse_module_state->__pyx_n_s_JsonEncodable);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyError);
  Py_VISIT(traverse_module_state->__pyx_n_s_List);
  Py_VISIT(traverse_module_state->__pyx_n_s_MISSING);
  Py_VISIT(traverse_module_state->__pyx_n_s_Mapping);
  Py_VISIT(traverse_module_state->__pyx_n_s_NoEncoderError);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_encoder_for);
  Py_VISIT(traverse_module_state->__pyx_n_s_None);
  Py_VISIT(traverse_module_state->__pyx_kp_u_None);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotADataClassError);
  Py_VISIT(traverse_module_state->__pyx_n_s_OverflowError);
  Py_VISIT(traverse_module_state->__pyx_n_s_POST_DUMP);
  Py_VISIT(traverse_module_state->__pyx_n_s_POST_LOAD);
  Py_VISIT(traverse_module_state->__pyx_n_s_PRE_DUMP);
  Py_VISIT(traverse_module_state->__pyx_n_s_PRE_LOAD);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_RapidJsonValidator);
  Py_VISIT(traverse_module_state->__pyx_n_s_SchemaBuilder);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer);
  Py_VISIT(traverse_module_state->__pyx_n_s_SerializerField);
  Py_VISIT(traverse_module_state->__pyx_n_s_SerializerField___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_SerializerField___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Serializer_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer__get_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer__get_field_serializer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_dataclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_dump_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_get_dict_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_get_object_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_load_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_register_global_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_Serializer_unregister_global_typ);
  Py_VISIT(traverse_module_state->__pyx_n_s_Set);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tuple);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_UNTYPED_DICT_TYPES);
  Py_VISIT(traverse_module_state->__pyx_n_s_UNTYPED_ITERABLE_TYPES);
  Py_VISIT(traverse_module_state->__pyx_n_s_UUID);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnionFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnionFieldEncoder___reduce_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnionFieldEncoder___setstate_cyt);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnionFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnionFieldEncoder_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnionFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unknown_decorator_type);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unknown_dict_key);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unknown_field);
  Py_VISIT(traverse_module_state->__pyx_n_s_UuidFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_UuidFieldEncoder___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UuidFieldEncoder___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_UuidFieldEncoder_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_UuidFieldEncoder_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_UuidFieldEncoder_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValidationError);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_kp_u__3);
  Py_VISIT(traverse_module_state->__pyx_kp_u__4);
  Py_VISIT(traverse_module_state->__pyx_kp_u__5);
  Py_VISIT(traverse_module_state->__pyx_kp_u__7);
  Py_VISIT(traverse_module_state->__pyx_n_s__9);
  Py_VISIT(traverse_module_state->__pyx_n_s__97);
  Py_VISIT(traverse_module_state->__pyx_n_s_arg);
  Py_VISIT(traverse_module_state->__pyx_n_s_arg_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_arguments);
  Py_VISIT(traverse_module_state->__pyx_kp_u_as);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_bool);
  Py_VISIT(traverse_module_state->__pyx_n_s_cast_on_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_caster);
  Py_VISIT(traverse_module_state->__pyx_n_s_cinit___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_cls);
  Py_VISIT(traverse_module_state->__pyx_n_s_data);
  Py_VISIT(traverse_module_state->__pyx_kp_u_data_dictionary_is_missing_requi);
  Py_VISIT(traverse_module_state->__pyx_n_s_dataclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_dataclass_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_dataclass_params_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_dataclasses);
  Py_VISIT(traverse_module_state->__pyx_kp_u_date_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_dateutil);
  Py_VISIT(traverse_module_state->__pyx_n_s_dateutil_parser);
  Py_VISIT(traverse_module_state->__pyx_n_s_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_default_factory);
  Py_VISIT(traverse_module_state->__pyx_n_s_dencoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_path);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_diter_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_dump);
  Py_VISIT(traverse_module_state->__pyx_n_s_dump_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_dumps);
  Py_VISIT(traverse_module_state->__pyx_n_s_e);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_enum);
  Py_VISIT(traverse_module_state->__pyx_n_s_enum_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_evaluate);
  Py_VISIT(traverse_module_state->__pyx_n_s_exclude);
  Py_VISIT(traverse_module_state->__pyx_n_s_excluded_field_names);
  Py_VISIT(traverse_module_state->__pyx_n_s_f);
  Py_VISIT(traverse_module_state->__pyx_kp_u_field);
  Py_VISIT(traverse_module_state->__pyx_n_s_field_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_field_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_fields);
  Py_VISIT(traverse_module_state->__pyx_kp_u_for_class);
  Py_VISIT(traverse_module_state->__pyx_n_u_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_frozen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dict_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_encoder_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_field_serializer);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_object_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_origin);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_type_hints);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_getter);
  Py_VISIT(traverse_module_state->__pyx_n_s_global_types);
  Py_VISIT(traverse_module_state->__pyx_n_s_h);
  Py_VISIT(traverse_module_state->__pyx_kp_u_has_a_wrong_type_expected_any_o);
  Py_VISIT(traverse_module_state->__pyx_n_s_hints);
  Py_VISIT(traverse_module_state->__pyx_n_s_ignore);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_kp_u_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_excluded_but_has_no_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_generic);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_new_type);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_not_a_dataclass);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_not_a_datetime_datetime_inst);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_not_a_valid_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_union);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_iso8601_pattern);
  Py_VISIT(traverse_module_state->__pyx_n_s_isoformat);
  Py_VISIT(traverse_module_state->__pyx_n_s_issubclass_safe);
  Py_VISIT(traverse_module_state->__pyx_n_s_item_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_item_encoders);
  Py_VISIT(traverse_module_state->__pyx_n_s_item_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_iter_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_js);
  Py_VISIT(traverse_module_state->__pyx_n_s_json_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_key_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_load);
  Py_VISIT(traverse_module_state->__pyx_n_s_load_as_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_load_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_loads);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_many);
  Py_VISIT(traverse_module_state->__pyx_n_s_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_metadata);
  Py_VISIT(traverse_module_state->__pyx_n_s_metadata_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_omit_none);
  Py_VISIT(traverse_module_state->__pyx_n_s_only);
  Py_VISIT(traverse_module_state->__pyx_n_s_param);
  Py_VISIT(traverse_module_state->__pyx_n_s_param_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_parameters);
  Py_VISIT(traverse_module_state->__pyx_n_s_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_parent_serializers);
  Py_VISIT(traverse_module_state->__pyx_n_s_parse);
  Py_VISIT(traverse_module_state->__pyx_n_s_parser);
  Py_VISIT(traverse_module_state->__pyx_n_s_part);
  Py_VISIT(traverse_module_state->__pyx_n_u_pattern);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_post_init);
  Py_VISIT(traverse_module_state->__pyx_n_u_post_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_DateTimeFieldEnco);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_SerializerField);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_UuidFieldEncoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_vtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_rapidjson);
  Py_VISIT(traverse_module_state->__pyx_n_s_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_global_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_remove);
  Py_VISIT(traverse_module_state->__pyx_n_s_resolve_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_return);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_n_s_send);
  Py_VISIT(traverse_module_state->__pyx_n_s_sequence_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_ser);
  Py_VISIT(traverse_module_state->__pyx_n_s_serializer);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_decorator);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_field);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_schema);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_serializer);
  Py_VISIT(traverse_module_state->__pyx_kp_s_serpyco_serializer_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_tags);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_util);
  Py_VISIT(traverse_module_state->__pyx_n_s_serpyco_validator);
  Py_VISIT(traverse_module_state->__pyx_n_s_setattr);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_sfield);
  Py_VISIT(traverse_module_state->__pyx_n_s_sh);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_strict);
  Py_VISIT(traverse_module_state->__pyx_n_u_string);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_supertype);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_throw);
  Py_VISIT(traverse_module_state->__pyx_n_s_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_type_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_type_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_type_encoders);
  Py_VISIT(traverse_module_state->__pyx_n_s_typing);
  Py_VISIT(traverse_module_state->__pyx_kp_s_typing_Any);
  Py_VISIT(traverse_module_state->__pyx_kp_s_typing_List_str);
  Py_VISIT(traverse_module_state->__pyx_kp_s_typing_Sequence_str);
  Py_VISIT(traverse_module_state->__pyx_kp_s_typing_Union_dict_typing_Iterabl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_typing_Union_object_typing_Itera);
  Py_VISIT(traverse_module_state->__pyx_n_s_typing_inspect);
  Py_VISIT(traverse_module_state->__pyx_n_s_unregister_global_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_uuid);
  Py_VISIT(traverse_module_state->__pyx_n_u_uuid);
  Py_VISIT(traverse_module_state->__pyx_n_s_validate);
  Py_VISIT(traverse_module_state->__pyx_n_s_validate_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_validate_user);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_value_encoder);
  Py_VISIT(traverse_module_state->__pyx_n_s_zip);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_79851409);
  Py_VISIT(traverse_module_state->__pyx_int_146220692);
  Py_VISIT(traverse_module_state->__pyx_int_222419149);
  Py_VISIT(traverse_module_state->__pyx_int_228825662);
  Py_VISIT(traverse_module_state->__pyx_int_238750788);
  Py_VISIT(traverse_module_state->__pyx_int_246984282);
  Py_VISIT(traverse_module_state->__pyx_slice__2);
  Py_VISIT(traverse_module_state->__pyx_tuple__6);
  Py_VISIT(traverse_module_state->__pyx_tuple__8);
  Py_VISIT(traverse_module_state->__pyx_tuple__10);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__13);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__18);
  Py_VISIT(traverse_module_state->__pyx_tuple__20);
  Py_VISIT(traverse_module_state->__pyx_tuple__21);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__25);
  Py_VISIT(traverse_module_state->__pyx_tuple__27);
  Py_VISIT(traverse_module_state->__pyx_tuple__30);
  Py_VISIT(traverse_module_state->__pyx_tuple__32);
  Py_VISIT(traverse_module_state->__pyx_tuple__33);
  Py_VISIT(traverse_module_state->__pyx_tuple__35);
  Py_VISIT(traverse_module_state->__pyx_tuple__37);
  Py_VISIT(traverse_module_state->__pyx_tuple__38);
  Py_VISIT(traverse_module_state->__pyx_tuple__40);
  Py_VISIT(traverse_module_state->__pyx_tuple__41);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__47);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_codeobj__12);
  Py_VISIT(traverse_module_state->__pyx_codeobj__14);
  Py_VISIT(traverse_module_state->__pyx_codeobj__16);
  Py_VISIT(traverse_module_state->__pyx_codeobj__17);
  Py_VISIT(traverse_module_state->__pyx_codeobj__19);
  Py_VISIT(traverse_module_state->__pyx_codeobj__22);
  Py_VISIT(traverse_module_state->__pyx_codeobj__24);
  Py_VISIT(traverse_module_state->__pyx_codeobj__26);
  Py_VISIT(traverse_module_state->__pyx_codeobj__28);
  Py_VISIT(traverse_module_state->__pyx_codeobj__29);
  Py_VISIT(traverse_module_state->__pyx_codeobj__31);
  Py_VISIT(traverse_module_state->__pyx_codeobj__34);
  Py_VISIT(traverse_module_state->__pyx_codeobj__36);
  Py_VISIT(traverse_module_state->__pyx_codeobj__39);
  Py_VISIT(traverse_module_state->__pyx_codeobj__42);
  Py_VISIT(traverse_module_state->__pyx_codeobj__44);
  Py_VISIT(traverse_module_state->__pyx_codeobj__45);
  Py_VISIT(traverse_module_state->__pyx_codeobj__46);
  Py_VISIT(traverse_module_state->__pyx_codeobj__48);
  Py_VISIT(traverse_module_state->__pyx_codeobj__49);
  Py_VISIT(traverse_module_state->__pyx_codeobj__50);
  Py_VISIT(traverse_module_state->__pyx_codeobj__51);
  Py_VISIT(traverse_module_state->__pyx_codeobj__52);
  Py_VISIT(traverse_module_state->__pyx_codeobj__53);
  Py_VISIT(traverse_module_state->__pyx_codeobj__54);
  Py_VISIT(traverse_module_state->__pyx_codeobj__55);
  Py_VISIT(traverse_module_state->__pyx_codeobj__56);
  Py_VISIT(traverse_module_state->__pyx_codeobj__57);
  Py_VISIT(traverse_module_state->__pyx_codeobj__58);
  Py_VISIT(traverse_module_state->__pyx_codeobj__59);
  Py_VISIT(traverse_module_state->__pyx_codeobj__60);
  Py_VISIT(traverse_module_state->__pyx_codeobj__61);
  Py_VISIT(traverse_module_state->__pyx_codeobj__62);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__64);
  Py_VISIT(traverse_module_state->__pyx_codeobj__65);
  Py_VISIT(traverse_module_state->__pyx_codeobj__66);
  Py_VISIT(traverse_module_state->__pyx_codeobj__67);
  Py_VISIT(traverse_module_state->__pyx_codeobj__68);
  Py_VISIT(traverse_module_state->__pyx_codeobj__69);
  Py_VISIT(traverse_module_state->__pyx_codeobj__70);
  Py_VISIT(traverse_module_state->__pyx_codeobj__71);
  Py_VISIT(traverse_module_state->__pyx_codeobj__72);
  Py_VISIT(traverse_module_state->__pyx_codeobj__73);
  Py_VISIT(traverse_module_state->__pyx_codeobj__74);
  Py_VISIT(traverse_module_state->__pyx_codeobj__75);
  Py_VISIT(traverse_module_state->__pyx_codeobj__76);
  Py_VISIT(traverse_module_state->__pyx_codeobj__77);
  Py_VISIT(traverse_module_state->__pyx_codeobj__78);
  Py_VISIT(traverse_module_state->__pyx_codeobj__79);
  Py_VISIT(traverse_module_state->__pyx_codeobj__80);
  Py_VISIT(traverse_module_state->__pyx_codeobj__81);
  Py_VISIT(traverse_module_state->__pyx_codeobj__82);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__84);
  Py_VISIT(traverse_module_state->__pyx_codeobj__85);
  Py_VISIT(traverse_module_state->__pyx_codeobj__86);
  Py_VISIT(traverse_module_state->__pyx_codeobj__87);
  Py_VISIT(traverse_module_state->__pyx_codeobj__88);
  Py_VISIT(traverse_module_state->__pyx_codeobj__89);
  Py_VISIT(traverse_module_state->__pyx_codeobj__90);
  Py_VISIT(traverse_module_state->__pyx_codeobj__91);
  Py_VISIT(traverse_module_state->__pyx_codeobj__92);
  Py_VISIT(traverse_module_state->__pyx_codeobj__94);
  Py_VISIT(traverse_module_state->__pyx_codeobj__95);
  Py_VISIT(traverse_module_state->__pyx_codeobj__96);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7serpyco_7encoder_FieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_7encoder_FieldEncoder
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_7serpyco_10serializer_SerializerField __pyx_mstate_global->__pyx_type_7serpyco_10serializer_SerializerField
#define __pyx_type_7serpyco_10serializer_Caster __pyx_mstate_global->__pyx_type_7serpyco_10serializer_Caster
#define __pyx_type_7serpyco_10serializer_Serializer __pyx_mstate_global->__pyx_type_7serpyco_10serializer_Serializer
#define __pyx_type_7serpyco_10serializer_EnumFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_EnumFieldEncoder
#define __pyx_type_7serpyco_10serializer_DataClassFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_DataClassFieldEncoder
#define __pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder
#define __pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder
#define __pyx_type_7serpyco_10serializer_IterableFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_IterableFieldEncoder
#define __pyx_type_7serpyco_10serializer_DictFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_DictFieldEncoder
#define __pyx_type_7serpyco_10serializer_DateTimeFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_DateTimeFieldEncoder
#define __pyx_type_7serpyco_10serializer_UuidFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_UuidFieldEncoder
#define __pyx_type_7serpyco_10serializer_UnionFieldEncoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer_UnionFieldEncoder
#define __pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr __pyx_mstate_global->__pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr
#define __pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder __pyx_mstate_global->__pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder
#define __pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr __pyx_mstate_global->__pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr
#endif
#define __pyx_ptype_7serpyco_10serializer_SerializerField __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_SerializerField
#define __pyx_ptype_7serpyco_10serializer_Caster __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_Caster
#define __pyx_ptype_7serpyco_10serializer_Serializer __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_Serializer
#define __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_DictFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_DictFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder
#define __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder
#define __pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr
#define __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder
#define __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr __pyx_mstate_global->__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr
#define __pyx_kp_u_ __pyx_mstate_global->__pyx_kp_u_
#define __pyx_kp_u_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9 __pyx_mstate_global->__pyx_kp_u_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9
#define __pyx_n_s_Any __pyx_mstate_global->__pyx_n_s_Any
#define __pyx_n_s_AttributeError __pyx_mstate_global->__pyx_n_s_AttributeError
#define __pyx_kp_u_Cannot_create __pyx_mstate_global->__pyx_kp_u_Cannot_create
#define __pyx_n_s_Caster __pyx_mstate_global->__pyx_n_s_Caster
#define __pyx_n_s_Caster___reduce_cython __pyx_mstate_global->__pyx_n_s_Caster___reduce_cython
#define __pyx_n_s_Caster___setstate_cython __pyx_mstate_global->__pyx_n_s_Caster___setstate_cython
#define __pyx_kp_u_Could_not_cast_field __pyx_mstate_global->__pyx_kp_u_Could_not_cast_field
#define __pyx_n_s_DataClassFieldEncoder __pyx_mstate_global->__pyx_n_s_DataClassFieldEncoder
#define __pyx_n_s_DataClassFieldEncoder___reduce_c __pyx_mstate_global->__pyx_n_s_DataClassFieldEncoder___reduce_c
#define __pyx_n_s_DataClassFieldEncoder___setstate __pyx_mstate_global->__pyx_n_s_DataClassFieldEncoder___setstate
#define __pyx_n_s_DataClassFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_DataClassFieldEncoder_dump
#define __pyx_n_s_DataClassFieldEncoder_json_schem __pyx_mstate_global->__pyx_n_s_DataClassFieldEncoder_json_schem
#define __pyx_n_s_DataClassFieldEncoder_load __pyx_mstate_global->__pyx_n_s_DataClassFieldEncoder_load
#define __pyx_n_s_DataClassIterableFieldEncoder __pyx_mstate_global->__pyx_n_s_DataClassIterableFieldEncoder
#define __pyx_n_s_DataClassIterableFieldEncoder_2 __pyx_mstate_global->__pyx_n_s_DataClassIterableFieldEncoder_2
#define __pyx_n_s_DataClassIterableFieldEncoder_3 __pyx_mstate_global->__pyx_n_s_DataClassIterableFieldEncoder_3
#define __pyx_n_s_DataClassIterableFieldEncoder_du __pyx_mstate_global->__pyx_n_s_DataClassIterableFieldEncoder_du
#define __pyx_n_s_DataClassIterableFieldEncoder_js __pyx_mstate_global->__pyx_n_s_DataClassIterableFieldEncoder_js
#define __pyx_n_s_DataClassIterableFieldEncoder_lo __pyx_mstate_global->__pyx_n_s_DataClassIterableFieldEncoder_lo
#define __pyx_n_s_DataClassParams __pyx_mstate_global->__pyx_n_s_DataClassParams
#define __pyx_n_s_DateTimeFieldEncoder __pyx_mstate_global->__pyx_n_s_DateTimeFieldEncoder
#define __pyx_n_s_DateTimeFieldEncoder___reduce_cy __pyx_mstate_global->__pyx_n_s_DateTimeFieldEncoder___reduce_cy
#define __pyx_n_s_DateTimeFieldEncoder___setstate __pyx_mstate_global->__pyx_n_s_DateTimeFieldEncoder___setstate
#define __pyx_n_s_DateTimeFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_DateTimeFieldEncoder_dump
#define __pyx_n_s_DateTimeFieldEncoder_json_schema __pyx_mstate_global->__pyx_n_s_DateTimeFieldEncoder_json_schema
#define __pyx_n_s_DateTimeFieldEncoder_load __pyx_mstate_global->__pyx_n_s_DateTimeFieldEncoder_load
#define __pyx_n_s_DecoratorType __pyx_mstate_global->__pyx_n_s_DecoratorType
#define __pyx_n_s_DictFieldEncoder __pyx_mstate_global->__pyx_n_s_DictFieldEncoder
#define __pyx_n_s_DictFieldEncoder___reduce_cython __pyx_mstate_global->__pyx_n_s_DictFieldEncoder___reduce_cython
#define __pyx_n_s_DictFieldEncoder___setstate_cyth __pyx_mstate_global->__pyx_n_s_DictFieldEncoder___setstate_cyth
#define __pyx_n_s_DictFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_DictFieldEncoder_dump
#define __pyx_n_s_DictFieldEncoder_json_schema __pyx_mstate_global->__pyx_n_s_DictFieldEncoder_json_schema
#define __pyx_n_s_DictFieldEncoder_load __pyx_mstate_global->__pyx_n_s_DictFieldEncoder_load
#define __pyx_n_s_Enum __pyx_mstate_global->__pyx_n_s_Enum
#define __pyx_n_s_EnumFieldEncoder __pyx_mstate_global->__pyx_n_s_EnumFieldEncoder
#define __pyx_n_s_EnumFieldEncoder___reduce_cython __pyx_mstate_global->__pyx_n_s_EnumFieldEncoder___reduce_cython
#define __pyx_n_s_EnumFieldEncoder___setstate_cyth __pyx_mstate_global->__pyx_n_s_EnumFieldEncoder___setstate_cyth
#define __pyx_n_s_EnumFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_EnumFieldEncoder_dump
#define __pyx_n_s_EnumFieldEncoder_json_schema __pyx_mstate_global->__pyx_n_s_EnumFieldEncoder_json_schema
#define __pyx_n_s_EnumFieldEncoder_load __pyx_mstate_global->__pyx_n_s_EnumFieldEncoder_load
#define __pyx_n_s_FieldEncoder __pyx_mstate_global->__pyx_n_s_FieldEncoder
#define __pyx_n_s_FieldHints __pyx_mstate_global->__pyx_n_s_FieldHints
#define __pyx_n_s_FixedTupleFieldEncoder __pyx_mstate_global->__pyx_n_s_FixedTupleFieldEncoder
#define __pyx_n_s_FixedTupleFieldEncoder___reduce __pyx_mstate_global->__pyx_n_s_FixedTupleFieldEncoder___reduce
#define __pyx_n_s_FixedTupleFieldEncoder___setstat __pyx_mstate_global->__pyx_n_s_FixedTupleFieldEncoder___setstat
#define __pyx_n_s_FixedTupleFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_FixedTupleFieldEncoder_dump
#define __pyx_n_s_FixedTupleFieldEncoder_json_sche __pyx_mstate_global->__pyx_n_s_FixedTupleFieldEncoder_json_sche
#define __pyx_n_s_FixedTupleFieldEncoder_load __pyx_mstate_global->__pyx_n_s_FixedTupleFieldEncoder_load
#define __pyx_n_s_ITERABLE_TYPES_MAPPING __pyx_mstate_global->__pyx_n_s_ITERABLE_TYPES_MAPPING
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2
#define __pyx_kp_u_Invalid_number_of_items_for_tupl __pyx_mstate_global->__pyx_kp_u_Invalid_number_of_items_for_tupl
#define __pyx_n_s_Iterable __pyx_mstate_global->__pyx_n_s_Iterable
#define __pyx_n_s_IterableFieldEncoder __pyx_mstate_global->__pyx_n_s_IterableFieldEncoder
#define __pyx_n_s_IterableFieldEncoder___reduce_cy __pyx_mstate_global->__pyx_n_s_IterableFieldEncoder___reduce_cy
#define __pyx_n_s_IterableFieldEncoder___setstate __pyx_mstate_global->__pyx_n_s_IterableFieldEncoder___setstate
#define __pyx_n_s_IterableFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_IterableFieldEncoder_dump
#define __pyx_n_s_IterableFieldEncoder_json_schema __pyx_mstate_global->__pyx_n_s_IterableFieldEncoder_json_schema
#define __pyx_n_s_IterableFieldEncoder_load __pyx_mstate_global->__pyx_n_s_IterableFieldEncoder_load
#define __pyx_n_s_JSON_ENCODABLE_TYPES __pyx_mstate_global->__pyx_n_s_JSON_ENCODABLE_TYPES
#define __pyx_n_s_JsonDict __pyx_mstate_global->__pyx_n_s_JsonDict
#define __pyx_n_s_JsonEncodable __pyx_mstate_global->__pyx_n_s_JsonEncodable
#define __pyx_n_s_KeyError __pyx_mstate_global->__pyx_n_s_KeyError
#define __pyx_n_s_List __pyx_mstate_global->__pyx_n_s_List
#define __pyx_n_s_MISSING __pyx_mstate_global->__pyx_n_s_MISSING
#define __pyx_n_s_Mapping __pyx_mstate_global->__pyx_n_s_Mapping
#define __pyx_n_s_NoEncoderError __pyx_mstate_global->__pyx_n_s_NoEncoderError
#define __pyx_kp_u_No_encoder_for __pyx_mstate_global->__pyx_kp_u_No_encoder_for
#define __pyx_n_s_None __pyx_mstate_global->__pyx_n_s_None
#define __pyx_kp_u_None __pyx_mstate_global->__pyx_kp_u_None
#define __pyx_n_s_NotADataClassError __pyx_mstate_global->__pyx_n_s_NotADataClassError
#define __pyx_n_s_OverflowError __pyx_mstate_global->__pyx_n_s_OverflowError
#define __pyx_n_s_POST_DUMP __pyx_mstate_global->__pyx_n_s_POST_DUMP
#define __pyx_n_s_POST_LOAD __pyx_mstate_global->__pyx_n_s_POST_LOAD
#define __pyx_n_s_PRE_DUMP __pyx_mstate_global->__pyx_n_s_PRE_DUMP
#define __pyx_n_s_PRE_LOAD __pyx_mstate_global->__pyx_n_s_PRE_LOAD
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_n_s_RapidJsonValidator __pyx_mstate_global->__pyx_n_s_RapidJsonValidator
#define __pyx_n_s_SchemaBuilder __pyx_mstate_global->__pyx_n_s_SchemaBuilder
#define __pyx_n_s_Serializer __pyx_mstate_global->__pyx_n_s_Serializer
#define __pyx_n_s_SerializerField __pyx_mstate_global->__pyx_n_s_SerializerField
#define __pyx_n_s_SerializerField___reduce_cython __pyx_mstate_global->__pyx_n_s_SerializerField___reduce_cython
#define __pyx_n_s_SerializerField___setstate_cytho __pyx_mstate_global->__pyx_n_s_SerializerField___setstate_cytho
#define __pyx_kp_s_Serializer_2 __pyx_mstate_global->__pyx_kp_s_Serializer_2
#define __pyx_n_s_Serializer___reduce_cython __pyx_mstate_global->__pyx_n_s_Serializer___reduce_cython
#define __pyx_n_s_Serializer___setstate_cython __pyx_mstate_global->__pyx_n_s_Serializer___setstate_cython
#define __pyx_n_s_Serializer__get_encoder __pyx_mstate_global->__pyx_n_s_Serializer__get_encoder
#define __pyx_n_s_Serializer__get_field_serializer __pyx_mstate_global->__pyx_n_s_Serializer__get_field_serializer
#define __pyx_n_s_Serializer_dataclass __pyx_mstate_global->__pyx_n_s_Serializer_dataclass
#define __pyx_n_s_Serializer_dump __pyx_mstate_global->__pyx_n_s_Serializer_dump
#define __pyx_n_s_Serializer_dump_json __pyx_mstate_global->__pyx_n_s_Serializer_dump_json
#define __pyx_n_s_Serializer_get_dict_path __pyx_mstate_global->__pyx_n_s_Serializer_get_dict_path
#define __pyx_n_s_Serializer_get_object_path __pyx_mstate_global->__pyx_n_s_Serializer_get_object_path
#define __pyx_n_s_Serializer_json_schema __pyx_mstate_global->__pyx_n_s_Serializer_json_schema
#define __pyx_n_s_Serializer_load __pyx_mstate_global->__pyx_n_s_Serializer_load
#define __pyx_n_s_Serializer_load_json __pyx_mstate_global->__pyx_n_s_Serializer_load_json
#define __pyx_n_s_Serializer_register_global_type __pyx_mstate_global->__pyx_n_s_Serializer_register_global_type
#define __pyx_n_s_Serializer_unregister_global_typ __pyx_mstate_global->__pyx_n_s_Serializer_unregister_global_typ
#define __pyx_n_s_Set __pyx_mstate_global->__pyx_n_s_Set
#define __pyx_n_s_Tuple __pyx_mstate_global->__pyx_n_s_Tuple
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_n_s_UNTYPED_DICT_TYPES __pyx_mstate_global->__pyx_n_s_UNTYPED_DICT_TYPES
#define __pyx_n_s_UNTYPED_ITERABLE_TYPES __pyx_mstate_global->__pyx_n_s_UNTYPED_ITERABLE_TYPES
#define __pyx_n_s_UUID __pyx_mstate_global->__pyx_n_s_UUID
#define __pyx_n_s_UnionFieldEncoder __pyx_mstate_global->__pyx_n_s_UnionFieldEncoder
#define __pyx_n_s_UnionFieldEncoder___reduce_cytho __pyx_mstate_global->__pyx_n_s_UnionFieldEncoder___reduce_cytho
#define __pyx_n_s_UnionFieldEncoder___setstate_cyt __pyx_mstate_global->__pyx_n_s_UnionFieldEncoder___setstate_cyt
#define __pyx_n_s_UnionFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_UnionFieldEncoder_dump
#define __pyx_n_s_UnionFieldEncoder_json_schema __pyx_mstate_global->__pyx_n_s_UnionFieldEncoder_json_schema
#define __pyx_n_s_UnionFieldEncoder_load __pyx_mstate_global->__pyx_n_s_UnionFieldEncoder_load
#define __pyx_kp_u_Unknown_decorator_type __pyx_mstate_global->__pyx_kp_u_Unknown_decorator_type
#define __pyx_kp_u_Unknown_dict_key __pyx_mstate_global->__pyx_kp_u_Unknown_dict_key
#define __pyx_kp_u_Unknown_field __pyx_mstate_global->__pyx_kp_u_Unknown_field
#define __pyx_n_s_UuidFieldEncoder __pyx_mstate_global->__pyx_n_s_UuidFieldEncoder
#define __pyx_n_s_UuidFieldEncoder___reduce_cython __pyx_mstate_global->__pyx_n_s_UuidFieldEncoder___reduce_cython
#define __pyx_n_s_UuidFieldEncoder___setstate_cyth __pyx_mstate_global->__pyx_n_s_UuidFieldEncoder___setstate_cyth
#define __pyx_n_s_UuidFieldEncoder_dump __pyx_mstate_global->__pyx_n_s_UuidFieldEncoder_dump
#define __pyx_n_s_UuidFieldEncoder_json_schema __pyx_mstate_global->__pyx_n_s_UuidFieldEncoder_json_schema
#define __pyx_n_s_UuidFieldEncoder_load __pyx_mstate_global->__pyx_n_s_UuidFieldEncoder_load
#define __pyx_n_s_ValidationError __pyx_mstate_global->__pyx_n_s_ValidationError
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_kp_u__3 __pyx_mstate_global->__pyx_kp_u__3
#define __pyx_kp_u__4 __pyx_mstate_global->__pyx_kp_u__4
#define __pyx_kp_u__5 __pyx_mstate_global->__pyx_kp_u__5
#define __pyx_kp_u__7 __pyx_mstate_global->__pyx_kp_u__7
#define __pyx_n_s__9 __pyx_mstate_global->__pyx_n_s__9
#define __pyx_n_s__97 __pyx_mstate_global->__pyx_n_s__97
#define __pyx_n_s_arg __pyx_mstate_global->__pyx_n_s_arg
#define __pyx_n_s_arg_type __pyx_mstate_global->__pyx_n_s_arg_type
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_s_arguments __pyx_mstate_global->__pyx_n_s_arguments
#define __pyx_kp_u_as __pyx_mstate_global->__pyx_kp_u_as
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_bool __pyx_mstate_global->__pyx_n_s_bool
#define __pyx_n_s_cast_on_load __pyx_mstate_global->__pyx_n_s_cast_on_load
#define __pyx_n_s_caster __pyx_mstate_global->__pyx_n_s_caster
#define __pyx_n_s_cinit___locals_genexpr __pyx_mstate_global->__pyx_n_s_cinit___locals_genexpr
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_cls __pyx_mstate_global->__pyx_n_s_cls
#define __pyx_n_s_data __pyx_mstate_global->__pyx_n_s_data
#define __pyx_kp_u_data_dictionary_is_missing_requi __pyx_mstate_global->__pyx_kp_u_data_dictionary_is_missing_requi
#define __pyx_n_s_dataclass __pyx_mstate_global->__pyx_n_s_dataclass
#define __pyx_n_s_dataclass_params __pyx_mstate_global->__pyx_n_s_dataclass_params
#define __pyx_n_s_dataclass_params_2 __pyx_mstate_global->__pyx_n_s_dataclass_params_2
#define __pyx_n_s_dataclasses __pyx_mstate_global->__pyx_n_s_dataclasses
#define __pyx_kp_u_date_time __pyx_mstate_global->__pyx_kp_u_date_time
#define __pyx_n_s_datetime __pyx_mstate_global->__pyx_n_s_datetime
#define __pyx_n_s_dateutil __pyx_mstate_global->__pyx_n_s_dateutil
#define __pyx_n_s_dateutil_parser __pyx_mstate_global->__pyx_n_s_dateutil_parser
#define __pyx_n_s_default __pyx_mstate_global->__pyx_n_s_default
#define __pyx_n_s_default_factory __pyx_mstate_global->__pyx_n_s_default_factory
#define __pyx_n_s_dencoder __pyx_mstate_global->__pyx_n_s_dencoder
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_n_s_dict_encoder __pyx_mstate_global->__pyx_n_s_dict_encoder
#define __pyx_n_s_dict_key __pyx_mstate_global->__pyx_n_s_dict_key
#define __pyx_n_s_dict_path __pyx_mstate_global->__pyx_n_s_dict_path
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_diter_encoder __pyx_mstate_global->__pyx_n_s_diter_encoder
#define __pyx_n_s_dump __pyx_mstate_global->__pyx_n_s_dump
#define __pyx_n_s_dump_json __pyx_mstate_global->__pyx_n_s_dump_json
#define __pyx_n_s_dumps __pyx_mstate_global->__pyx_n_s_dumps
#define __pyx_n_s_e __pyx_mstate_global->__pyx_n_s_e
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_encoder __pyx_mstate_global->__pyx_n_s_encoder
#define __pyx_n_s_enum __pyx_mstate_global->__pyx_n_s_enum
#define __pyx_n_s_enum_type __pyx_mstate_global->__pyx_n_s_enum_type
#define __pyx_n_s_evaluate __pyx_mstate_global->__pyx_n_s_evaluate
#define __pyx_n_s_exclude __pyx_mstate_global->__pyx_n_s_exclude
#define __pyx_n_s_excluded_field_names __pyx_mstate_global->__pyx_n_s_excluded_field_names
#define __pyx_n_s_f __pyx_mstate_global->__pyx_n_s_f
#define __pyx_kp_u_field __pyx_mstate_global->__pyx_kp_u_field
#define __pyx_n_s_field_name __pyx_mstate_global->__pyx_n_s_field_name
#define __pyx_n_s_field_type __pyx_mstate_global->__pyx_n_s_field_type
#define __pyx_n_s_fields __pyx_mstate_global->__pyx_n_s_fields
#define __pyx_kp_u_for_class __pyx_mstate_global->__pyx_kp_u_for_class
#define __pyx_n_u_format __pyx_mstate_global->__pyx_n_u_format
#define __pyx_n_s_frozen __pyx_mstate_global->__pyx_n_s_frozen
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_genexpr __pyx_mstate_global->__pyx_n_s_genexpr
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_get_args __pyx_mstate_global->__pyx_n_s_get_args
#define __pyx_n_s_get_dict_path __pyx_mstate_global->__pyx_n_s_get_dict_path
#define __pyx_n_s_get_encoder __pyx_mstate_global->__pyx_n_s_get_encoder
#define __pyx_n_s_get_encoder_locals_genexpr __pyx_mstate_global->__pyx_n_s_get_encoder_locals_genexpr
#define __pyx_n_s_get_field_serializer __pyx_mstate_global->__pyx_n_s_get_field_serializer
#define __pyx_n_s_get_object_path __pyx_mstate_global->__pyx_n_s_get_object_path
#define __pyx_n_s_get_origin __pyx_mstate_global->__pyx_n_s_get_origin
#define __pyx_n_s_get_type_hints __pyx_mstate_global->__pyx_n_s_get_type_hints
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_n_s_getter __pyx_mstate_global->__pyx_n_s_getter
#define __pyx_n_s_global_types __pyx_mstate_global->__pyx_n_s_global_types
#define __pyx_n_s_h __pyx_mstate_global->__pyx_n_s_h
#define __pyx_kp_u_has_a_wrong_type_expected_any_o __pyx_mstate_global->__pyx_kp_u_has_a_wrong_type_expected_any_o
#define __pyx_n_s_hints __pyx_mstate_global->__pyx_n_s_hints
#define __pyx_n_s_ignore __pyx_mstate_global->__pyx_n_s_ignore
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_kp_u_in __pyx_mstate_global->__pyx_kp_u_in
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_kp_u_is_excluded_but_has_no_default __pyx_mstate_global->__pyx_kp_u_is_excluded_but_has_no_default
#define __pyx_n_s_is_generic __pyx_mstate_global->__pyx_n_s_is_generic
#define __pyx_n_s_is_new_type __pyx_mstate_global->__pyx_n_s_is_new_type
#define __pyx_kp_u_is_not_a_dataclass __pyx_mstate_global->__pyx_kp_u_is_not_a_dataclass
#define __pyx_kp_u_is_not_a_datetime_datetime_inst __pyx_mstate_global->__pyx_kp_u_is_not_a_datetime_datetime_inst
#define __pyx_kp_u_is_not_a_valid_datetime __pyx_mstate_global->__pyx_kp_u_is_not_a_valid_datetime
#define __pyx_n_s_is_union __pyx_mstate_global->__pyx_n_s_is_union
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_iso8601_pattern __pyx_mstate_global->__pyx_n_s_iso8601_pattern
#define __pyx_n_s_isoformat __pyx_mstate_global->__pyx_n_s_isoformat
#define __pyx_n_s_issubclass_safe __pyx_mstate_global->__pyx_n_s_issubclass_safe
#define __pyx_n_s_item_encoder __pyx_mstate_global->__pyx_n_s_item_encoder
#define __pyx_n_s_item_encoders __pyx_mstate_global->__pyx_n_s_item_encoders
#define __pyx_n_s_item_type __pyx_mstate_global->__pyx_n_s_item_type
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_iter_encoder __pyx_mstate_global->__pyx_n_s_iter_encoder
#define __pyx_n_s_js __pyx_mstate_global->__pyx_n_s_js
#define __pyx_n_s_json_schema __pyx_mstate_global->__pyx_n_s_json_schema
#define __pyx_n_s_key_encoder __pyx_mstate_global->__pyx_n_s_key_encoder
#define __pyx_n_s_keys __pyx_mstate_global->__pyx_n_s_keys
#define __pyx_n_s_load __pyx_mstate_global->__pyx_n_s_load
#define __pyx_n_s_load_as_type __pyx_mstate_global->__pyx_n_s_load_as_type
#define __pyx_n_s_load_json __pyx_mstate_global->__pyx_n_s_load_json
#define __pyx_n_s_loads __pyx_mstate_global->__pyx_n_s_loads
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_many __pyx_mstate_global->__pyx_n_s_many
#define __pyx_n_s_map __pyx_mstate_global->__pyx_n_s_map
#define __pyx_n_s_metadata __pyx_mstate_global->__pyx_n_s_metadata
#define __pyx_n_s_metadata_name __pyx_mstate_global->__pyx_n_s_metadata_name
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_kp_s_no_default___reduce___due_to_non __pyx_mstate_global->__pyx_kp_s_no_default___reduce___due_to_non
#define __pyx_n_s_obj __pyx_mstate_global->__pyx_n_s_obj
#define __pyx_n_s_obj_path __pyx_mstate_global->__pyx_n_s_obj_path
#define __pyx_n_s_object __pyx_mstate_global->__pyx_n_s_object
#define __pyx_n_s_omit_none __pyx_mstate_global->__pyx_n_s_omit_none
#define __pyx_n_s_only __pyx_mstate_global->__pyx_n_s_only
#define __pyx_n_s_param __pyx_mstate_global->__pyx_n_s_param
#define __pyx_n_s_param_args __pyx_mstate_global->__pyx_n_s_param_args
#define __pyx_n_s_parameters __pyx_mstate_global->__pyx_n_s_parameters
#define __pyx_n_s_params __pyx_mstate_global->__pyx_n_s_params
#define __pyx_n_s_parent_serializers __pyx_mstate_global->__pyx_n_s_parent_serializers
#define __pyx_n_s_parse __pyx_mstate_global->__pyx_n_s_parse
#define __pyx_n_s_parser __pyx_mstate_global->__pyx_n_s_parser
#define __pyx_n_s_part __pyx_mstate_global->__pyx_n_s_part
#define __pyx_n_u_pattern __pyx_mstate_global->__pyx_n_u_pattern
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_post_init __pyx_mstate_global->__pyx_n_s_post_init
#define __pyx_n_u_post_init __pyx_mstate_global->__pyx_n_u_post_init
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_DateTimeFieldEnco __pyx_mstate_global->__pyx_n_s_pyx_unpickle_DateTimeFieldEnco
#define __pyx_n_s_pyx_unpickle_SerializerField __pyx_mstate_global->__pyx_n_s_pyx_unpickle_SerializerField
#define __pyx_n_s_pyx_unpickle_UuidFieldEncoder __pyx_mstate_global->__pyx_n_s_pyx_unpickle_UuidFieldEncoder
#define __pyx_n_s_pyx_vtable __pyx_mstate_global->__pyx_n_s_pyx_vtable
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_rapidjson __pyx_mstate_global->__pyx_n_s_rapidjson
#define __pyx_n_s_re __pyx_mstate_global->__pyx_n_s_re
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_register_global_type __pyx_mstate_global->__pyx_n_s_register_global_type
#define __pyx_n_s_remove __pyx_mstate_global->__pyx_n_s_remove
#define __pyx_n_s_resolve_type __pyx_mstate_global->__pyx_n_s_resolve_type
#define __pyx_n_s_return __pyx_mstate_global->__pyx_n_s_return
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_n_s_send __pyx_mstate_global->__pyx_n_s_send
#define __pyx_n_s_sequence_type __pyx_mstate_global->__pyx_n_s_sequence_type
#define __pyx_n_s_ser __pyx_mstate_global->__pyx_n_s_ser
#define __pyx_n_s_serializer __pyx_mstate_global->__pyx_n_s_serializer
#define __pyx_n_s_serpyco_decorator __pyx_mstate_global->__pyx_n_s_serpyco_decorator
#define __pyx_n_s_serpyco_exception __pyx_mstate_global->__pyx_n_s_serpyco_exception
#define __pyx_n_s_serpyco_field __pyx_mstate_global->__pyx_n_s_serpyco_field
#define __pyx_n_s_serpyco_schema __pyx_mstate_global->__pyx_n_s_serpyco_schema
#define __pyx_n_s_serpyco_serializer __pyx_mstate_global->__pyx_n_s_serpyco_serializer
#define __pyx_kp_s_serpyco_serializer_pyx __pyx_mstate_global->__pyx_kp_s_serpyco_serializer_pyx
#define __pyx_n_s_serpyco_tags __pyx_mstate_global->__pyx_n_s_serpyco_tags
#define __pyx_n_s_serpyco_util __pyx_mstate_global->__pyx_n_s_serpyco_util
#define __pyx_n_s_serpyco_validator __pyx_mstate_global->__pyx_n_s_serpyco_validator
#define __pyx_n_s_setattr __pyx_mstate_global->__pyx_n_s_setattr
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_sfield __pyx_mstate_global->__pyx_n_s_sfield
#define __pyx_n_s_sh __pyx_mstate_global->__pyx_n_s_sh
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_strict __pyx_mstate_global->__pyx_n_s_strict
#define __pyx_n_u_string __pyx_mstate_global->__pyx_n_u_string
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_supertype __pyx_mstate_global->__pyx_n_s_supertype
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_throw __pyx_mstate_global->__pyx_n_s_throw
#define __pyx_n_s_type __pyx_mstate_global->__pyx_n_s_type
#define __pyx_n_s_type_2 __pyx_mstate_global->__pyx_n_s_type_2
#define __pyx_n_u_type_2 __pyx_mstate_global->__pyx_n_u_type_2
#define __pyx_n_s_type_encoders __pyx_mstate_global->__pyx_n_s_type_encoders
#define __pyx_n_s_typing __pyx_mstate_global->__pyx_n_s_typing
#define __pyx_kp_s_typing_Any __pyx_mstate_global->__pyx_kp_s_typing_Any
#define __pyx_kp_s_typing_List_str __pyx_mstate_global->__pyx_kp_s_typing_List_str
#define __pyx_kp_s_typing_Sequence_str __pyx_mstate_global->__pyx_kp_s_typing_Sequence_str
#define __pyx_kp_s_typing_Union_dict_typing_Iterabl __pyx_mstate_global->__pyx_kp_s_typing_Union_dict_typing_Iterabl
#define __pyx_kp_s_typing_Union_object_typing_Itera __pyx_mstate_global->__pyx_kp_s_typing_Union_object_typing_Itera
#define __pyx_n_s_typing_inspect __pyx_mstate_global->__pyx_n_s_typing_inspect
#define __pyx_n_s_unregister_global_type __pyx_mstate_global->__pyx_n_s_unregister_global_type
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_use_setstate __pyx_mstate_global->__pyx_n_s_use_setstate
#define __pyx_n_s_uuid __pyx_mstate_global->__pyx_n_s_uuid
#define __pyx_n_u_uuid __pyx_mstate_global->__pyx_n_u_uuid
#define __pyx_n_s_validate __pyx_mstate_global->__pyx_n_s_validate
#define __pyx_n_s_validate_json __pyx_mstate_global->__pyx_n_s_validate_json
#define __pyx_n_s_validate_user __pyx_mstate_global->__pyx_n_s_validate_user
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_n_s_value_encoder __pyx_mstate_global->__pyx_n_s_value_encoder
#define __pyx_n_s_zip __pyx_mstate_global->__pyx_n_s_zip
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_79851409 __pyx_mstate_global->__pyx_int_79851409
#define __pyx_int_146220692 __pyx_mstate_global->__pyx_int_146220692
#define __pyx_int_222419149 __pyx_mstate_global->__pyx_int_222419149
#define __pyx_int_228825662 __pyx_mstate_global->__pyx_int_228825662
#define __pyx_int_238750788 __pyx_mstate_global->__pyx_int_238750788
#define __pyx_int_246984282 __pyx_mstate_global->__pyx_int_246984282
#define __pyx_slice__2 __pyx_mstate_global->__pyx_slice__2
#define __pyx_tuple__6 __pyx_mstate_global->__pyx_tuple__6
#define __pyx_tuple__8 __pyx_mstate_global->__pyx_tuple__8
#define __pyx_tuple__10 __pyx_mstate_global->__pyx_tuple__10
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__13 __pyx_mstate_global->__pyx_tuple__13
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__18 __pyx_mstate_global->__pyx_tuple__18
#define __pyx_tuple__20 __pyx_mstate_global->__pyx_tuple__20
#define __pyx_tuple__21 __pyx_mstate_global->__pyx_tuple__21
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__25 __pyx_mstate_global->__pyx_tuple__25
#define __pyx_tuple__27 __pyx_mstate_global->__pyx_tuple__27
#define __pyx_tuple__30 __pyx_mstate_global->__pyx_tuple__30
#define __pyx_tuple__32 __pyx_mstate_global->__pyx_tuple__32
#define __pyx_tuple__33 __pyx_mstate_global->__pyx_tuple__33
#define __pyx_tuple__35 __pyx_mstate_global->__pyx_tuple__35
#define __pyx_tuple__37 __pyx_mstate_global->__pyx_tuple__37
#define __pyx_tuple__38 __pyx_mstate_global->__pyx_tuple__38
#define __pyx_tuple__40 __pyx_mstate_global->__pyx_tuple__40
#define __pyx_tuple__41 __pyx_mstate_global->__pyx_tuple__41
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__47 __pyx_mstate_global->__pyx_tuple__47
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_codeobj__12 __pyx_mstate_global->__pyx_codeobj__12
#define __pyx_codeobj__14 __pyx_mstate_global->__pyx_codeobj__14
#define __pyx_codeobj__16 __pyx_mstate_global->__pyx_codeobj__16
#define __pyx_codeobj__17 __pyx_mstate_global->__pyx_codeobj__17
#define __pyx_codeobj__19 __pyx_mstate_global->__pyx_codeobj__19
#define __pyx_codeobj__22 __pyx_mstate_global->__pyx_codeobj__22
#define __pyx_codeobj__24 __pyx_mstate_global->__pyx_codeobj__24
#define __pyx_codeobj__26 __pyx_mstate_global->__pyx_codeobj__26
#define __pyx_codeobj__28 __pyx_mstate_global->__pyx_codeobj__28
#define __pyx_codeobj__29 __pyx_mstate_global->__pyx_codeobj__29
#define __pyx_codeobj__31 __pyx_mstate_global->__pyx_codeobj__31
#define __pyx_codeobj__34 __pyx_mstate_global->__pyx_codeobj__34
#define __pyx_codeobj__36 __pyx_mstate_global->__pyx_codeobj__36
#define __pyx_codeobj__39 __pyx_mstate_global->__pyx_codeobj__39
#define __pyx_codeobj__42 __pyx_mstate_global->__pyx_codeobj__42
#define __pyx_codeobj__44 __pyx_mstate_global->__pyx_codeobj__44
#define __pyx_codeobj__45 __pyx_mstate_global->__pyx_codeobj__45
#define __pyx_codeobj__46 __pyx_mstate_global->__pyx_codeobj__46
#define __pyx_codeobj__48 __pyx_mstate_global->__pyx_codeobj__48
#define __pyx_codeobj__49 __pyx_mstate_global->__pyx_codeobj__49
#define __pyx_codeobj__50 __pyx_mstate_global->__pyx_codeobj__50
#define __pyx_codeobj__51 __pyx_mstate_global->__pyx_codeobj__51
#define __pyx_codeobj__52 __pyx_mstate_global->__pyx_codeobj__52
#define __pyx_codeobj__53 __pyx_mstate_global->__pyx_codeobj__53
#define __pyx_codeobj__54 __pyx_mstate_global->__pyx_codeobj__54
#define __pyx_codeobj__55 __pyx_mstate_global->__pyx_codeobj__55
#define __pyx_codeobj__56 __pyx_mstate_global->__pyx_codeobj__56
#define __pyx_codeobj__57 __pyx_mstate_global->__pyx_codeobj__57
#define __pyx_codeobj__58 __pyx_mstate_global->__pyx_codeobj__58
#define __pyx_codeobj__59 __pyx_mstate_global->__pyx_codeobj__59
#define __pyx_codeobj__60 __pyx_mstate_global->__pyx_codeobj__60
#define __pyx_codeobj__61 __pyx_mstate_global->__pyx_codeobj__61
#define __pyx_codeobj__62 __pyx_mstate_global->__pyx_codeobj__62
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__64 __pyx_mstate_global->__pyx_codeobj__64
#define __pyx_codeobj__65 __pyx_mstate_global->__pyx_codeobj__65
#define __pyx_codeobj__66 __pyx_mstate_global->__pyx_codeobj__66
#define __pyx_codeobj__67 __pyx_mstate_global->__pyx_codeobj__67
#define __pyx_codeobj__68 __pyx_mstate_global->__pyx_codeobj__68
#define __pyx_codeobj__69 __pyx_mstate_global->__pyx_codeobj__69
#define __pyx_codeobj__70 __pyx_mstate_global->__pyx_codeobj__70
#define __pyx_codeobj__71 __pyx_mstate_global->__pyx_codeobj__71
#define __pyx_codeobj__72 __pyx_mstate_global->__pyx_codeobj__72
#define __pyx_codeobj__73 __pyx_mstate_global->__pyx_codeobj__73
#define __pyx_codeobj__74 __pyx_mstate_global->__pyx_codeobj__74
#define __pyx_codeobj__75 __pyx_mstate_global->__pyx_codeobj__75
#define __pyx_codeobj__76 __pyx_mstate_global->__pyx_codeobj__76
#define __pyx_codeobj__77 __pyx_mstate_global->__pyx_codeobj__77
#define __pyx_codeobj__78 __pyx_mstate_global->__pyx_codeobj__78
#define __pyx_codeobj__79 __pyx_mstate_global->__pyx_codeobj__79
#define __pyx_codeobj__80 __pyx_mstate_global->__pyx_codeobj__80
#define __pyx_codeobj__81 __pyx_mstate_global->__pyx_codeobj__81
#define __pyx_codeobj__82 __pyx_mstate_global->__pyx_codeobj__82
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__84 __pyx_mstate_global->__pyx_codeobj__84
#define __pyx_codeobj__85 __pyx_mstate_global->__pyx_codeobj__85
#define __pyx_codeobj__86 __pyx_mstate_global->__pyx_codeobj__86
#define __pyx_codeobj__87 __pyx_mstate_global->__pyx_codeobj__87
#define __pyx_codeobj__88 __pyx_mstate_global->__pyx_codeobj__88
#define __pyx_codeobj__89 __pyx_mstate_global->__pyx_codeobj__89
#define __pyx_codeobj__90 __pyx_mstate_global->__pyx_codeobj__90
#define __pyx_codeobj__91 __pyx_mstate_global->__pyx_codeobj__91
#define __pyx_codeobj__92 __pyx_mstate_global->__pyx_codeobj__92
#define __pyx_codeobj__94 __pyx_mstate_global->__pyx_codeobj__94
#define __pyx_codeobj__95 __pyx_mstate_global->__pyx_codeobj__95
#define __pyx_codeobj__96 __pyx_mstate_global->__pyx_codeobj__96
/* #### Code section: module_code ### */

/* "serpyco/serializer.pyx":59
 *     cdef object default_factory
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         str field_name,
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_15SerializerField_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_15SerializerField_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_field_name = 0;
  PyObject *__pyx_v_dict_key = 0;
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder = 0;
  PyObject *__pyx_v_getter = 0;
  int __pyx_v_init;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_v_default_factory = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 59, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_field_name,&__pyx_n_s_dict_key,&__pyx_n_s_encoder,&__pyx_n_s_getter,&__pyx_n_s_init,&__pyx_n_s_default,&__pyx_n_s_default_factory,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_field_name)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dict_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 7, 7, 1); __PYX_ERR(0, 59, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_encoder)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 7, 7, 2); __PYX_ERR(0, 59, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_getter)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 7, 7, 3); __PYX_ERR(0, 59, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_init)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 7, 7, 4); __PYX_ERR(0, 59, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_default)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[5]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 7, 7, 5); __PYX_ERR(0, 59, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_default_factory)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[6]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 7, 7, 6); __PYX_ERR(0, 59, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 59, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 7)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
      values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
      values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
      values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
      values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
      values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
    }
    __pyx_v_field_name = ((PyObject*)values[0]);
    __pyx_v_dict_key = ((PyObject*)values[1]);
    __pyx_v_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)values[2]);
    __pyx_v_getter = values[3];
    __pyx_v_init = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_init == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 65, __pyx_L3_error)
    __pyx_v_default = values[5];
    __pyx_v_default_factory = values[6];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 7, 7, __pyx_nargs); __PYX_ERR(0, 59, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.SerializerField.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_field_name), (&PyUnicode_Type), 1, "field_name", 1))) __PYX_ERR(0, 61, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dict_key), (&PyUnicode_Type), 1, "dict_key", 1))) __PYX_ERR(0, 62, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_7encoder_FieldEncoder, 1, "encoder", 0))) __PYX_ERR(0, 63, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_15SerializerField___init__(((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_v_self), __pyx_v_field_name, __pyx_v_dict_key, __pyx_v_encoder, __pyx_v_getter, __pyx_v_init, __pyx_v_default, __pyx_v_default_factory);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_15SerializerField___init__(struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_self, PyObject *__pyx_v_field_name, PyObject *__pyx_v_dict_key, struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder, PyObject *__pyx_v_getter, int __pyx_v_init, PyObject *__pyx_v_default, PyObject *__pyx_v_default_factory) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "serpyco/serializer.pyx":69
 *         object default_factory
 *     ):
 *         self.field_name = field_name             # <<<<<<<<<<<<<<
 *         self.dict_key = dict_key
 *         self.encoder = encoder
 */
  __Pyx_INCREF(__pyx_v_field_name);
  __Pyx_GIVEREF(__pyx_v_field_name);
  __Pyx_GOTREF(__pyx_v_self->field_name);
  __Pyx_DECREF(__pyx_v_self->field_name);
  __pyx_v_self->field_name = __pyx_v_field_name;

  /* "serpyco/serializer.pyx":70
 *     ):
 *         self.field_name = field_name
 *         self.dict_key = dict_key             # <<<<<<<<<<<<<<
 *         self.encoder = encoder
 *         self.getter = getter
 */
  __Pyx_INCREF(__pyx_v_dict_key);
  __Pyx_GIVEREF(__pyx_v_dict_key);
  __Pyx_GOTREF(__pyx_v_self->dict_key);
  __Pyx_DECREF(__pyx_v_self->dict_key);
  __pyx_v_self->dict_key = __pyx_v_dict_key;

  /* "serpyco/serializer.pyx":71
 *         self.field_name = field_name
 *         self.dict_key = dict_key
 *         self.encoder = encoder             # <<<<<<<<<<<<<<
 *         self.getter = getter
 *         self.init = init
 */
  __Pyx_INCREF((PyObject *)__pyx_v_encoder);
  __Pyx_GIVEREF((PyObject *)__pyx_v_encoder);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->encoder);
  __Pyx_DECREF((PyObject *)__pyx_v_self->encoder);
  __pyx_v_self->encoder = __pyx_v_encoder;

  /* "serpyco/serializer.pyx":72
 *         self.dict_key = dict_key
 *         self.encoder = encoder
 *         self.getter = getter             # <<<<<<<<<<<<<<
 *         self.init = init
 *         self.default = default
 */
  __Pyx_INCREF(__pyx_v_getter);
  __Pyx_GIVEREF(__pyx_v_getter);
  __Pyx_GOTREF(__pyx_v_self->getter);
  __Pyx_DECREF(__pyx_v_self->getter);
  __pyx_v_self->getter = __pyx_v_getter;

  /* "serpyco/serializer.pyx":73
 *         self.encoder = encoder
 *         self.getter = getter
 *         self.init = init             # <<<<<<<<<<<<<<
 *         self.default = default
 *         self.default_factory = default_factory
 */
  __pyx_v_self->init = __pyx_v_init;

  /* "serpyco/serializer.pyx":74
 *         self.getter = getter
 *         self.init = init
 *         self.default = default             # <<<<<<<<<<<<<<
 *         self.default_factory = default_factory
 * 
 */
  __Pyx_INCREF(__pyx_v_default);
  __Pyx_GIVEREF(__pyx_v_default);
  __Pyx_GOTREF(__pyx_v_self->__pyx_default);
  __Pyx_DECREF(__pyx_v_self->__pyx_default);
  __pyx_v_self->__pyx_default = __pyx_v_default;

  /* "serpyco/serializer.pyx":75
 *         self.init = init
 *         self.default = default
 *         self.default_factory = default_factory             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF(__pyx_v_default_factory);
  __Pyx_GIVEREF(__pyx_v_default_factory);
  __Pyx_GOTREF(__pyx_v_self->default_factory);
  __Pyx_DECREF(__pyx_v_self->default_factory);
  __pyx_v_self->default_factory = __pyx_v_default_factory;

  /* "serpyco/serializer.pyx":59
 *     cdef object default_factory
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         str field_name,
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_15SerializerField_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_15SerializerField_2__reduce_cython__, "SerializerField.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_15SerializerField_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_15SerializerField_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_15SerializerField_2__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_15SerializerField_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.SerializerField.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_15SerializerField_2__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_15SerializerField_2__reduce_cython__(struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.default, self.default_factory, self.dict_key, self.encoder, self.field_name, self.getter, self.init)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->init); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(7); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->__pyx_default);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_default);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->__pyx_default)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->default_factory);
  __Pyx_GIVEREF(__pyx_v_self->default_factory);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->default_factory)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->dict_key);
  __Pyx_GIVEREF(__pyx_v_self->dict_key);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_self->dict_key)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->encoder);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->encoder);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, ((PyObject *)__pyx_v_self->encoder))) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->field_name);
  __Pyx_GIVEREF(__pyx_v_self->field_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_v_self->field_name)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->getter);
  __Pyx_GIVEREF(__pyx_v_self->getter);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_v_self->getter)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 6, __pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.default, self.default_factory, self.dict_key, self.encoder, self.field_name, self.getter, self.init)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v__dict = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":7
 *     state = (self.default, self.default_factory, self.dict_key, self.encoder, self.field_name, self.getter, self.init)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.default is not None or self.default_factory is not None or self.dict_key is not None or self.encoder is not None or self.field_name is not None or self.getter is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.default, self.default_factory, self.dict_key, self.encoder, self.field_name, self.getter, self.init)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.default is not None or self.default_factory is not None or self.dict_key is not None or self.encoder is not None or self.field_name is not None or self.getter is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, None), state
 */
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->__pyx_default != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->default_factory != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->dict_key != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (((PyObject *)__pyx_v_self->encoder) != Py_None);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->field_name != ((PyObject*)Py_None));
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->getter != Py_None);
    __pyx_t_3 = __pyx_t_4;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.default is not None or self.default_factory is not None or self.dict_key is not None or self.encoder is not None or self.field_name is not None or self.getter is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.default is not None or self.default_factory is not None or self.dict_key is not None or self.encoder is not None or self.field_name is not None or self.getter is not None
 *     if use_setstate:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pyx_unpickle_SerializerField); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_79851409);
    __Pyx_GIVEREF(__pyx_int_79851409);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_79851409)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.default is not None or self.default_factory is not None or self.dict_key is not None or self.encoder is not None or self.field_name is not None or self.getter is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, None), state
 *     else:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_SerializerField__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle_SerializerField); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_79851409);
    __Pyx_GIVEREF(__pyx_int_79851409);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_79851409)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.SerializerField.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_SerializerField__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_15SerializerField_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_15SerializerField_4__setstate_cython__, "SerializerField.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_15SerializerField_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_15SerializerField_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_15SerializerField_4__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_15SerializerField_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 16, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.SerializerField.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_15SerializerField_4__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_15SerializerField_4__setstate_cython__(struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_SerializerField__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7serpyco_10serializer___pyx_unpickle_SerializerField__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_SerializerField__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.SerializerField.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":82
 *     cdef object caster
 * 
 *     def __cinit__(self, str dict_key, object caster):             # <<<<<<<<<<<<<<
 *         self.dict_key = dict_key
 *         self.caster = caster
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_6Caster_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_6Caster_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_dict_key = 0;
  PyObject *__pyx_v_caster = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 82, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dict_key,&__pyx_n_s_caster,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dict_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 82, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_caster)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 82, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(0, 82, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 82, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_dict_key = ((PyObject*)values[0]);
    __pyx_v_caster = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 82, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Caster.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dict_key), (&PyUnicode_Type), 1, "dict_key", 1))) __PYX_ERR(0, 82, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_6Caster___cinit__(((struct __pyx_obj_7serpyco_10serializer_Caster *)__pyx_v_self), __pyx_v_dict_key, __pyx_v_caster);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_6Caster___cinit__(struct __pyx_obj_7serpyco_10serializer_Caster *__pyx_v_self, PyObject *__pyx_v_dict_key, PyObject *__pyx_v_caster) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":83
 * 
 *     def __cinit__(self, str dict_key, object caster):
 *         self.dict_key = dict_key             # <<<<<<<<<<<<<<
 *         self.caster = caster
 * 
 */
  __Pyx_INCREF(__pyx_v_dict_key);
  __Pyx_GIVEREF(__pyx_v_dict_key);
  __Pyx_GOTREF(__pyx_v_self->dict_key);
  __Pyx_DECREF(__pyx_v_self->dict_key);
  __pyx_v_self->dict_key = __pyx_v_dict_key;

  /* "serpyco/serializer.pyx":84
 *     def __cinit__(self, str dict_key, object caster):
 *         self.dict_key = dict_key
 *         self.caster = caster             # <<<<<<<<<<<<<<
 * 
 * cdef inline int cast_fields(tuple casters, dict data) except -1:
 */
  __Pyx_INCREF(__pyx_v_caster);
  __Pyx_GIVEREF(__pyx_v_caster);
  __Pyx_GOTREF(__pyx_v_self->caster);
  __Pyx_DECREF(__pyx_v_self->caster);
  __pyx_v_self->caster = __pyx_v_caster;

  /* "serpyco/serializer.pyx":82
 *     cdef object caster
 * 
 *     def __cinit__(self, str dict_key, object caster):             # <<<<<<<<<<<<<<
 *         self.dict_key = dict_key
 *         self.caster = caster
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_6Caster_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_6Caster_2__reduce_cython__, "Caster.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_6Caster_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_6Caster_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_6Caster_2__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_6Caster_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.Caster.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_6Caster_2__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_Caster *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_6Caster_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Caster *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.Caster.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_6Caster_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_6Caster_4__setstate_cython__, "Caster.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_6Caster_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_6Caster_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_6Caster_4__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_6Caster_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Caster.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_6Caster_4__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_Caster *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_6Caster_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Caster *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.Caster.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":86
 *         self.caster = caster
 * 
 * cdef inline int cast_fields(tuple casters, dict data) except -1:             # <<<<<<<<<<<<<<
 *     cdef Caster caster
 *     for caster in casters:
 */

static CYTHON_INLINE int __pyx_f_7serpyco_10serializer_cast_fields(PyObject *__pyx_v_casters, PyObject *__pyx_v_data) {
  struct __pyx_obj_7serpyco_10serializer_Caster *__pyx_v_caster = 0;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_types = NULL;
  PyObject *__pyx_v_casted = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_type_ = NULL;
  PyObject *__pyx_v_ex = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cast_fields", 0);

  /* "serpyco/serializer.pyx":88
 * cdef inline int cast_fields(tuple casters, dict data) except -1:
 *     cdef Caster caster
 *     for caster in casters:             # <<<<<<<<<<<<<<
 *         try:
 *             v = data[caster.dict_key]
 */
  if (unlikely(__pyx_v_casters == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 88, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_casters; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 88, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_7serpyco_10serializer_Caster))))) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_caster, ((struct __pyx_obj_7serpyco_10serializer_Caster *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":89
 *     cdef Caster caster
 *     for caster in casters:
 *         try:             # <<<<<<<<<<<<<<
 *             v = data[caster.dict_key]
 *         except KeyError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "serpyco/serializer.pyx":90
 *     for caster in casters:
 *         try:
 *             v = data[caster.dict_key]             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             continue
 */
        if (unlikely(__pyx_v_data == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 90, __pyx_L5_error)
        }
        __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_data, __pyx_v_caster->dict_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 90, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "serpyco/serializer.pyx":89
 *     cdef Caster caster
 *     for caster in casters:
 *         try:             # <<<<<<<<<<<<<<
 *             v = data[caster.dict_key]
 *         except KeyError:
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":91
 *         try:
 *             v = data[caster.dict_key]
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             continue
 *         if _is_union(caster.caster):
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_7) {
        __Pyx_AddTraceback("serpyco.serializer.cast_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 91, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);

        /* "serpyco/serializer.pyx":92
 *             v = data[caster.dict_key]
 *         except KeyError:
 *             continue             # <<<<<<<<<<<<<<
 *         if _is_union(caster.caster):
 *             types = list(typing_inspect.get_args(caster.caster, evaluate=True))
 */
        goto __pyx_L13_except_continue;
        __pyx_L13_except_continue:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L11_try_continue;
      }
      goto __pyx_L7_except_error;

      /* "serpyco/serializer.pyx":89
 *     cdef Caster caster
 *     for caster in casters:
 *         try:             # <<<<<<<<<<<<<<
 *             v = data[caster.dict_key]
 *         except KeyError:
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L11_try_continue:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L3_continue;
      __pyx_L12_try_end:;
    }

    /* "serpyco/serializer.pyx":93
 *         except KeyError:
 *             continue
 *         if _is_union(caster.caster):             # <<<<<<<<<<<<<<
 *             types = list(typing_inspect.get_args(caster.caster, evaluate=True))
 *             types.remove(type(None))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_is_union); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_caster->caster};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 93, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 93, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_10) {

      /* "serpyco/serializer.pyx":94
 *             continue
 *         if _is_union(caster.caster):
 *             types = list(typing_inspect.get_args(caster.caster, evaluate=True))             # <<<<<<<<<<<<<<
 *             types.remove(type(None))
 *         else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_typing_inspect); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_get_args); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_v_caster->caster);
      __Pyx_GIVEREF(__pyx_v_caster->caster);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_caster->caster)) __PYX_ERR(0, 94, __pyx_L1_error);
      __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_evaluate, Py_True) < 0) __PYX_ERR(0, 94, __pyx_L1_error)
      __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PySequence_ListKeepNew(__pyx_t_11); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_v_types, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":95
 *         if _is_union(caster.caster):
 *             types = list(typing_inspect.get_args(caster.caster, evaluate=True))
 *             types.remove(type(None))             # <<<<<<<<<<<<<<
 *         else:
 *             types = [caster.caster]
 */
      __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyList_Type_remove, __pyx_v_types, ((PyObject *)Py_TYPE(Py_None))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":93
 *         except KeyError:
 *             continue
 *         if _is_union(caster.caster):             # <<<<<<<<<<<<<<
 *             types = list(typing_inspect.get_args(caster.caster, evaluate=True))
 *             types.remove(type(None))
 */
      goto __pyx_L15;
    }

    /* "serpyco/serializer.pyx":97
 *             types.remove(type(None))
 *         else:
 *             types = [caster.caster]             # <<<<<<<<<<<<<<
 *         casted = None
 *         exc = None
 */
    /*else*/ {
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_caster->caster);
      __Pyx_GIVEREF(__pyx_v_caster->caster);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_caster->caster)) __PYX_ERR(0, 97, __pyx_L1_error);
      __Pyx_XDECREF_SET(__pyx_v_types, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;
    }
    __pyx_L15:;

    /* "serpyco/serializer.pyx":98
 *         else:
 *             types = [caster.caster]
 *         casted = None             # <<<<<<<<<<<<<<
 *         exc = None
 *         for type_ in types:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF_SET(__pyx_v_casted, Py_None);

    /* "serpyco/serializer.pyx":99
 *             types = [caster.caster]
 *         casted = None
 *         exc = None             # <<<<<<<<<<<<<<
 *         for type_ in types:
 *             try:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF_SET(__pyx_v_exc, Py_None);

    /* "serpyco/serializer.pyx":100
 *         casted = None
 *         exc = None
 *         for type_ in types:             # <<<<<<<<<<<<<<
 *             try:
 *                 casted = type_(v)
 */
    __pyx_t_3 = __pyx_v_types; __Pyx_INCREF(__pyx_t_3); __pyx_t_12 = 0;
    for (;;) {
      if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_11 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_12); __Pyx_INCREF(__pyx_t_11); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 100, __pyx_L1_error)
      #else
      __pyx_t_11 = PySequence_ITEM(__pyx_t_3, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 100, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_type_, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "serpyco/serializer.pyx":101
 *         exc = None
 *         for type_ in types:
 *             try:             # <<<<<<<<<<<<<<
 *                 casted = type_(v)
 *                 break
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        /*try:*/ {

          /* "serpyco/serializer.pyx":102
 *         for type_ in types:
 *             try:
 *                 casted = type_(v)             # <<<<<<<<<<<<<<
 *                 break
 *             except Exception as ex:
 */
          __Pyx_INCREF(__pyx_v_type_);
          __pyx_t_9 = __pyx_v_type_; __pyx_t_8 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_v};
            __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 102, __pyx_L18_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_casted, __pyx_t_11);
          __pyx_t_11 = 0;

          /* "serpyco/serializer.pyx":103
 *             try:
 *                 casted = type_(v)
 *                 break             # <<<<<<<<<<<<<<
 *             except Exception as ex:
 *                 exc = ex
 */
          goto __pyx_L23_try_break;

          /* "serpyco/serializer.pyx":101
 *         exc = None
 *         for type_ in types:
 *             try:             # <<<<<<<<<<<<<<
 *                 casted = type_(v)
 *                 break
 */
        }
        __pyx_L18_error:;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "serpyco/serializer.pyx":104
 *                 casted = type_(v)
 *                 break
 *             except Exception as ex:             # <<<<<<<<<<<<<<
 *                 exc = ex
 *         if casted is None:
 */
        __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
        if (__pyx_t_7) {
          __Pyx_AddTraceback("serpyco.serializer.cast_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_9, &__pyx_t_8) < 0) __PYX_ERR(0, 104, __pyx_L20_except_error)
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __pyx_v_ex = __pyx_t_9;
          /*try:*/ {

            /* "serpyco/serializer.pyx":105
 *                 break
 *             except Exception as ex:
 *                 exc = ex             # <<<<<<<<<<<<<<
 *         if casted is None:
 *             raise ValidationError(f"Could not cast field {caster.dict_key}: {exc}")
 */
            __Pyx_INCREF(__pyx_v_ex);
            __Pyx_DECREF_SET(__pyx_v_exc, __pyx_v_ex);
          }

          /* "serpyco/serializer.pyx":104
 *                 casted = type_(v)
 *                 break
 *             except Exception as ex:             # <<<<<<<<<<<<<<
 *                 exc = ex
 *         if casted is None:
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
              goto __pyx_L32;
            }
            __pyx_L32:;
          }
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L19_exception_handled;
        }
        goto __pyx_L20_except_error;

        /* "serpyco/serializer.pyx":101
 *         exc = None
 *         for type_ in types:
 *             try:             # <<<<<<<<<<<<<<
 *                 casted = type_(v)
 *                 break
 */
        __pyx_L20_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        goto __pyx_L1_error;
        __pyx_L23_try_break:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        goto __pyx_L17_break;
        __pyx_L19_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
      }

      /* "serpyco/serializer.pyx":100
 *         casted = None
 *         exc = None
 *         for type_ in types:             # <<<<<<<<<<<<<<
 *             try:
 *                 casted = type_(v)
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L33_for_end;
    __pyx_L17_break:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L33_for_end;
    __pyx_L33_for_end:;

    /* "serpyco/serializer.pyx":106
 *             except Exception as ex:
 *                 exc = ex
 *         if casted is None:             # <<<<<<<<<<<<<<
 *             raise ValidationError(f"Could not cast field {caster.dict_key}: {exc}")
 *         data[caster.dict_key] = casted
 */
    __pyx_t_10 = (__pyx_v_casted == Py_None);
    if (unlikely(__pyx_t_10)) {

      /* "serpyco/serializer.pyx":107
 *                 exc = ex
 *         if casted is None:
 *             raise ValidationError(f"Could not cast field {caster.dict_key}: {exc}")             # <<<<<<<<<<<<<<
 *         data[caster.dict_key] = casted
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = PyTuple_New(4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_12 = 0;
      __pyx_t_13 = 127;
      __Pyx_INCREF(__pyx_kp_u_Could_not_cast_field);
      __pyx_t_12 += 21;
      __Pyx_GIVEREF(__pyx_kp_u_Could_not_cast_field);
      PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_kp_u_Could_not_cast_field);
      __pyx_t_11 = __Pyx_PyUnicode_Unicode(__pyx_v_caster->dict_key); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11) : __pyx_t_13;
      __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_11);
      __pyx_t_11 = 0;
      __Pyx_INCREF(__pyx_kp_u_);
      __pyx_t_12 += 2;
      __Pyx_GIVEREF(__pyx_kp_u_);
      PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_kp_u_);
      __pyx_t_11 = __Pyx_PyObject_FormatSimple(__pyx_v_exc, __pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_11) : __pyx_t_13;
      __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_11);
      __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_9, 4, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_11};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 107, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 107, __pyx_L1_error)

      /* "serpyco/serializer.pyx":106
 *             except Exception as ex:
 *                 exc = ex
 *         if casted is None:             # <<<<<<<<<<<<<<
 *             raise ValidationError(f"Could not cast field {caster.dict_key}: {exc}")
 *         data[caster.dict_key] = casted
 */
    }

    /* "serpyco/serializer.pyx":108
 *         if casted is None:
 *             raise ValidationError(f"Could not cast field {caster.dict_key}: {exc}")
 *         data[caster.dict_key] = casted             # <<<<<<<<<<<<<<
 * 
 * 
 */
    if (unlikely(__pyx_v_data == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 108, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_data, __pyx_v_caster->dict_key, __pyx_v_casted) < 0))) __PYX_ERR(0, 108, __pyx_L1_error)

    /* "serpyco/serializer.pyx":88
 * cdef inline int cast_fields(tuple casters, dict data) except -1:
 *     cdef Caster caster
 *     for caster in casters:             # <<<<<<<<<<<<<<
 *         try:
 *             v = data[caster.dict_key]
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":86
 *         self.caster = caster
 * 
 * cdef inline int cast_fields(tuple casters, dict data) except -1:             # <<<<<<<<<<<<<<
 *     cdef Caster caster
 *     for caster in casters:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("serpyco.serializer.cast_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_caster);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_types);
  __Pyx_XDECREF(__pyx_v_casted);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_type_);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":141
 *         SchemaBuilder.register_global_type(f, e)
 * 
 *     def __cinit__(             # <<<<<<<<<<<<<<
 *         self,
 *         dataclass,
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_10Serializer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_10Serializer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_dataclass = 0;
  CYTHON_UNUSED PyObject *__pyx_v_omit_none = 0;
  PyObject *__pyx_v_type_encoders = 0;
  PyObject *__pyx_v_only = 0;
  PyObject *__pyx_v_exclude = 0;
  PyObject *__pyx_v_strict = 0;
  PyTypeObject *__pyx_v_load_as_type = 0;
  PyObject *__pyx_v__parent_serializers = 0;
  PyObject *__pyx_v__dataclass_params = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 141, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dataclass,&__pyx_n_s_omit_none,&__pyx_n_s_type_encoders,&__pyx_n_s_only,&__pyx_n_s_exclude,&__pyx_n_s_strict,&__pyx_n_s_load_as_type,&__pyx_n_s_parent_serializers,&__pyx_n_s_dataclass_params,0};

    /* "serpyco/serializer.pyx":144
 *         self,
 *         dataclass,
 *         omit_none: bool = True,             # <<<<<<<<<<<<<<
 *         type_encoders: typing.Dict[type, FieldEncoder] = None,
 *         only: typing.Optional[typing.List[str]] = None,
 */
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_True));

    /* "serpyco/serializer.pyx":145
 *         dataclass,
 *         omit_none: bool = True,
 *         type_encoders: typing.Dict[type, FieldEncoder] = None,             # <<<<<<<<<<<<<<
 *         only: typing.Optional[typing.List[str]] = None,
 *         exclude: typing.Optional[typing.List[str]] = None,
 */
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject*)Py_None));

    /* "serpyco/serializer.pyx":146
 *         omit_none: bool = True,
 *         type_encoders: typing.Dict[type, FieldEncoder] = None,
 *         only: typing.Optional[typing.List[str]] = None,             # <<<<<<<<<<<<<<
 *         exclude: typing.Optional[typing.List[str]] = None,
 *         strict: bool = False,
 */
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject*)Py_None));

    /* "serpyco/serializer.pyx":147
 *         type_encoders: typing.Dict[type, FieldEncoder] = None,
 *         only: typing.Optional[typing.List[str]] = None,
 *         exclude: typing.Optional[typing.List[str]] = None,             # <<<<<<<<<<<<<<
 *         strict: bool = False,
 *         load_as_type: typing.Optional[type] = None,
 */
    values[4] = __Pyx_Arg_NewRef_VARARGS(((PyObject*)Py_None));

    /* "serpyco/serializer.pyx":148
 *         only: typing.Optional[typing.List[str]] = None,
 *         exclude: typing.Optional[typing.List[str]] = None,
 *         strict: bool = False,             # <<<<<<<<<<<<<<
 *         load_as_type: typing.Optional[type] = None,
 *         _parent_serializers: typing.List["Serializer"] = None,
 */
    values[5] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));

    /* "serpyco/serializer.pyx":149
 *         exclude: typing.Optional[typing.List[str]] = None,
 *         strict: bool = False,
 *         load_as_type: typing.Optional[type] = None,             # <<<<<<<<<<<<<<
 *         _parent_serializers: typing.List["Serializer"] = None,
 *         _dataclass_params: typing.Optional[_DataClassParams] = None,
 */
    values[6] = __Pyx_Arg_NewRef_VARARGS((PyObject *)((PyTypeObject*)Py_None));

    /* "serpyco/serializer.pyx":150
 *         strict: bool = False,
 *         load_as_type: typing.Optional[type] = None,
 *         _parent_serializers: typing.List["Serializer"] = None,             # <<<<<<<<<<<<<<
 *         _dataclass_params: typing.Optional[_DataClassParams] = None,
 *     ):
 */
    values[7] = __Pyx_Arg_NewRef_VARARGS(((PyObject*)Py_None));

    /* "serpyco/serializer.pyx":151
 *         load_as_type: typing.Optional[type] = None,
 *         _parent_serializers: typing.List["Serializer"] = None,
 *         _dataclass_params: typing.Optional[_DataClassParams] = None,             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
    values[8] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_VARARGS(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_VARARGS(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dataclass)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_omit_none);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_type_encoders);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_only);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exclude);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_strict);
          if (value) { values[5] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_load_as_type);
          if (value) { values[6] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_parent_serializers);
          if (value) { values[7] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dataclass_params);
          if (value) { values[8] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 141, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 141, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_VARARGS(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_VARARGS(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_dataclass = values[0];
    __pyx_v_omit_none = values[1];
    __pyx_v_type_encoders = ((PyObject*)values[2]);
    __pyx_v_only = ((PyObject*)values[3]);
    __pyx_v_exclude = ((PyObject*)values[4]);
    __pyx_v_strict = values[5];
    __pyx_v_load_as_type = ((PyTypeObject*)values[6]);
    __pyx_v__parent_serializers = ((PyObject*)values[7]);
    __pyx_v__dataclass_params = values[8];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 9, __pyx_nargs); __PYX_ERR(0, 141, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_type_encoders), (&PyDict_Type), 1, "type_encoders", 1))) __PYX_ERR(0, 145, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_only), (&PyList_Type), 1, "only", 1))) __PYX_ERR(0, 146, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_exclude), (&PyList_Type), 1, "exclude", 1))) __PYX_ERR(0, 147, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_load_as_type), (&PyType_Type), 1, "load_as_type", 1))) __PYX_ERR(0, 149, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v__parent_serializers), (&PyList_Type), 1, "_parent_serializers", 1))) __PYX_ERR(0, 150, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer___cinit__(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_dataclass, __pyx_v_omit_none, __pyx_v_type_encoders, __pyx_v_only, __pyx_v_exclude, __pyx_v_strict, __pyx_v_load_as_type, __pyx_v__parent_serializers, __pyx_v__dataclass_params);

  /* "serpyco/serializer.pyx":141
 *         SchemaBuilder.register_global_type(f, e)
 * 
 *     def __cinit__(             # <<<<<<<<<<<<<<
 *         self,
 *         dataclass,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_7serpyco_10serializer_10Serializer_9__cinit___2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "serpyco/serializer.pyx":219
 *             if hints.cast_on_load:
 *                 field_casters.append(Caster(hints.dict_key, field_type))
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)             # <<<<<<<<<<<<<<
 * 
 *         builder = SchemaBuilder(
 */

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_9__cinit___genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *)__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct__genexpr(__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 219, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_7serpyco_10serializer_10Serializer_9__cinit___2generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_cinit___locals_genexpr, __pyx_n_s_serpyco_serializer); if (unlikely(!gen)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__cinit__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_7serpyco_10serializer_10Serializer_9__cinit___2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *__pyx_cur_scope = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L8_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 219, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 219, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 219, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 219, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
      index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 219, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 219, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_serializer_field);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_serializer_field, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v__);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v__, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_serializer_field);
    __pyx_r = __pyx_cur_scope->__pyx_v_serializer_field;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L8_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 219, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":141
 *         SchemaBuilder.register_global_type(f, e)
 * 
 *     def __cinit__(             # <<<<<<<<<<<<<<
 *         self,
 *         dataclass,
 */

static int __pyx_pf_7serpyco_10serializer_10Serializer___cinit__(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_dataclass, CYTHON_UNUSED PyObject *__pyx_v_omit_none, PyObject *__pyx_v_type_encoders, PyObject *__pyx_v_only, PyObject *__pyx_v_exclude, PyObject *__pyx_v_strict, PyTypeObject *__pyx_v_load_as_type, PyObject *__pyx_v__parent_serializers, PyObject *__pyx_v__dataclass_params) {
  struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_parent = 0;
  struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_serializer_field = 0;
  PyObject *__pyx_v_fields = NULL;
  PyObject *__pyx_v_excluded_fields = NULL;
  PyObject *__pyx_v_dataclass_field = NULL;
  PyObject *__pyx_v_hints = NULL;
  PyObject *__pyx_v_field_casters = NULL;
  PyObject *__pyx_v_type_hints = NULL;
  PyObject *__pyx_v_field_type = NULL;
  PyObject *__pyx_v_encoder = NULL;
  PyObject *__pyx_v_builder = NULL;
  PyObject *__pyx_v_attr_name = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_tag = NULL;
  PyObject *__pyx_gb_7serpyco_10serializer_10Serializer_9__cinit___2generator = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *(*__pyx_t_15)(PyObject *);
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":169
 *         cdef Serializer parent
 *         cdef SerializerField serializer_field
 *         self._dataclass_params = _dataclass_params or _DataClassParams(dataclass)             # <<<<<<<<<<<<<<
 *         self._dataclass = self._dataclass_params.type_
 *         self._type_encoders = type_encoders or {}
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v__dataclass_params); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 169, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v__dataclass_params);
    __pyx_t_1 = __pyx_v__dataclass_params;
    goto __pyx_L3_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_DataClassParams); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_dataclass};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_dataclass_params);
  __Pyx_DECREF(__pyx_v_self->_dataclass_params);
  __pyx_v_self->_dataclass_params = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":170
 *         cdef SerializerField serializer_field
 *         self._dataclass_params = _dataclass_params or _DataClassParams(dataclass)
 *         self._dataclass = self._dataclass_params.type_             # <<<<<<<<<<<<<<
 *         self._type_encoders = type_encoders or {}
 *         self._parent_serializers = _parent_serializers or []
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass_params, __pyx_n_s_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_dataclass);
  __Pyx_DECREF(__pyx_v_self->_dataclass);
  __pyx_v_self->_dataclass = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":171
 *         self._dataclass_params = _dataclass_params or _DataClassParams(dataclass)
 *         self._dataclass = self._dataclass_params.type_
 *         self._type_encoders = type_encoders or {}             # <<<<<<<<<<<<<<
 *         self._parent_serializers = _parent_serializers or []
 *         self._parent_serializers.append(self)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_type_encoders); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 171, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_type_encoders);
    __pyx_t_1 = __pyx_v_type_encoders;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L5_bool_binop_done:;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_type_encoders);
  __Pyx_DECREF(__pyx_v_self->_type_encoders);
  __pyx_v_self->_type_encoders = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":172
 *         self._dataclass = self._dataclass_params.type_
 *         self._type_encoders = type_encoders or {}
 *         self._parent_serializers = _parent_serializers or []             # <<<<<<<<<<<<<<
 *         self._parent_serializers.append(self)
 *         self._excluded_fields = tuple()
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v__parent_serializers); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 172, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v__parent_serializers);
    __pyx_t_1 = __pyx_v__parent_serializers;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L7_bool_binop_done:;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_parent_serializers);
  __Pyx_DECREF(__pyx_v_self->_parent_serializers);
  __pyx_v_self->_parent_serializers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":173
 *         self._type_encoders = type_encoders or {}
 *         self._parent_serializers = _parent_serializers or []
 *         self._parent_serializers.append(self)             # <<<<<<<<<<<<<<
 *         self._excluded_fields = tuple()
 *         fields = []
 */
  if (unlikely(__pyx_v_self->_parent_serializers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 173, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->_parent_serializers, ((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 173, __pyx_L1_error)

  /* "serpyco/serializer.pyx":174
 *         self._parent_serializers = _parent_serializers or []
 *         self._parent_serializers.append(self)
 *         self._excluded_fields = tuple()             # <<<<<<<<<<<<<<
 *         fields = []
 *         excluded_fields = []
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)(&PyTuple_Type))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_excluded_fields);
  __Pyx_DECREF(__pyx_v_self->_excluded_fields);
  __pyx_v_self->_excluded_fields = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":175
 *         self._parent_serializers.append(self)
 *         self._excluded_fields = tuple()
 *         fields = []             # <<<<<<<<<<<<<<
 *         excluded_fields = []
 *         for dataclass_field in dataclasses.fields(self._dataclass):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fields = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":176
 *         self._excluded_fields = tuple()
 *         fields = []
 *         excluded_fields = []             # <<<<<<<<<<<<<<
 *         for dataclass_field in dataclasses.fields(self._dataclass):
 *             hints = dataclass_field.metadata.get(
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_excluded_fields = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":177
 *         fields = []
 *         excluded_fields = []
 *         for dataclass_field in dataclasses.fields(self._dataclass):             # <<<<<<<<<<<<<<
 *             hints = dataclass_field.metadata.get(
 *                 _metadata_name,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_dataclasses); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_fields); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self->_dataclass};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_8 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 177, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 177, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 177, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 177, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_9(__pyx_t_4);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 177, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_dataclass_field, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":178
 *         excluded_fields = []
 *         for dataclass_field in dataclasses.fields(self._dataclass):
 *             hints = dataclass_field.metadata.get(             # <<<<<<<<<<<<<<
 *                 _metadata_name,
 *                 FieldHints(dict_key=dataclass_field.name)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_metadata); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":179
 *         for dataclass_field in dataclasses.fields(self._dataclass):
 *             hints = dataclass_field.metadata.get(
 *                 _metadata_name,             # <<<<<<<<<<<<<<
 *                 FieldHints(dict_key=dataclass_field.name)
 *             )
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_metadata_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "serpyco/serializer.pyx":180
 *             hints = dataclass_field.metadata.get(
 *                 _metadata_name,
 *                 FieldHints(dict_key=dataclass_field.name)             # <<<<<<<<<<<<<<
 *             )
 *             if hints.dict_key is None:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_FieldHints); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_dict_key, __pyx_t_12) < 0) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_empty_tuple, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_3, __pyx_t_12};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_hints, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":182
 *                 FieldHints(dict_key=dataclass_field.name)
 *             )
 *             if hints.dict_key is None:             # <<<<<<<<<<<<<<
 *                 hints.dict_key = dataclass_field.name
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_hints, __pyx_n_s_dict_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "serpyco/serializer.pyx":183
 *             )
 *             if hints.dict_key is None:
 *                 hints.dict_key = dataclass_field.name             # <<<<<<<<<<<<<<
 * 
 *             serializer_field = SerializerField(
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_hints, __pyx_n_s_dict_key, __pyx_t_1) < 0) __PYX_ERR(0, 183, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "serpyco/serializer.pyx":182
 *                 FieldHints(dict_key=dataclass_field.name)
 *             )
 *             if hints.dict_key is None:             # <<<<<<<<<<<<<<
 *                 hints.dict_key = dataclass_field.name
 * 
 */
    }

    /* "serpyco/serializer.pyx":186
 * 
 *             serializer_field = SerializerField(
 *                 dataclass_field.name,             # <<<<<<<<<<<<<<
 *                 hints.dict_key,
 *                 None,
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "serpyco/serializer.pyx":187
 *             serializer_field = SerializerField(
 *                 dataclass_field.name,
 *                 hints.dict_key,             # <<<<<<<<<<<<<<
 *                 None,
 *                 hints.getter,
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_hints, __pyx_n_s_dict_key); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "serpyco/serializer.pyx":189
 *                 hints.dict_key,
 *                 None,
 *                 hints.getter,             # <<<<<<<<<<<<<<
 *                 dataclass_field.init,
 *                 dataclass_field.default,
 */
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_hints, __pyx_n_s_getter); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);

    /* "serpyco/serializer.pyx":190
 *                 None,
 *                 hints.getter,
 *                 dataclass_field.init,             # <<<<<<<<<<<<<<
 *                 dataclass_field.default,
 *                 dataclass_field.default_factory
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "serpyco/serializer.pyx":191
 *                 hints.getter,
 *                 dataclass_field.init,
 *                 dataclass_field.default,             # <<<<<<<<<<<<<<
 *                 dataclass_field.default_factory
 *             )
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_default); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);

    /* "serpyco/serializer.pyx":192
 *                 dataclass_field.init,
 *                 dataclass_field.default,
 *                 dataclass_field.default_factory             # <<<<<<<<<<<<<<
 *             )
 *             if (
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_default_factory); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);

    /* "serpyco/serializer.pyx":185
 *                 hints.dict_key = dataclass_field.name
 * 
 *             serializer_field = SerializerField(             # <<<<<<<<<<<<<<
 *                 dataclass_field.name,
 *                 hints.dict_key,
 */
    __pyx_t_13 = PyTuple_New(7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_1)) __PYX_ERR(0, 185, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_5)) __PYX_ERR(0, 185, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 2, Py_None)) __PYX_ERR(0, 185, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_12);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 3, __pyx_t_12)) __PYX_ERR(0, 185, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 4, __pyx_t_3)) __PYX_ERR(0, 185, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_11);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 5, __pyx_t_11)) __PYX_ERR(0, 185, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_10);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 6, __pyx_t_10)) __PYX_ERR(0, 185, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_5 = 0;
    __pyx_t_12 = 0;
    __pyx_t_3 = 0;
    __pyx_t_11 = 0;
    __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7serpyco_10serializer_SerializerField), __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF_SET(__pyx_v_serializer_field, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_10));
    __pyx_t_10 = 0;

    /* "serpyco/serializer.pyx":195
 *             )
 *             if (
 *                 hints.ignore             # <<<<<<<<<<<<<<
 *                 or (only and dataclass_field.name not in only)
 *                 or (exclude and dataclass_field.name in exclude)
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_hints, __pyx_n_s_ignore); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 195, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (!__pyx_t_14) {
    } else {
      __pyx_t_2 = __pyx_t_14;
      goto __pyx_L13_bool_binop_done;
    }

    /* "serpyco/serializer.pyx":196
 *             if (
 *                 hints.ignore
 *                 or (only and dataclass_field.name not in only)             # <<<<<<<<<<<<<<
 *                 or (exclude and dataclass_field.name in exclude)
 *             ):
 */
    __pyx_t_14 = (__pyx_v_only != Py_None)&&(PyList_GET_SIZE(__pyx_v_only) != 0);
    if (!__pyx_t_14) {
      goto __pyx_L15_next_or;
    } else {
    }
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_t_10, __pyx_v_only, Py_NE)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 196, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (!__pyx_t_14) {
    } else {
      __pyx_t_2 = __pyx_t_14;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_L15_next_or:;

    /* "serpyco/serializer.pyx":197
 *                 hints.ignore
 *                 or (only and dataclass_field.name not in only)
 *                 or (exclude and dataclass_field.name in exclude)             # <<<<<<<<<<<<<<
 *             ):
 *                 excluded_fields.append(serializer_field)
 */
    __pyx_t_14 = (__pyx_v_exclude != Py_None)&&(PyList_GET_SIZE(__pyx_v_exclude) != 0);
    if (__pyx_t_14) {
    } else {
      __pyx_t_2 = __pyx_t_14;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_dataclass_field, __pyx_n_s_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_t_10, __pyx_v_exclude, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_2 = __pyx_t_14;
    __pyx_L13_bool_binop_done:;

    /* "serpyco/serializer.pyx":194
 *                 dataclass_field.default_factory
 *             )
 *             if (             # <<<<<<<<<<<<<<
 *                 hints.ignore
 *                 or (only and dataclass_field.name not in only)
 */
    if (__pyx_t_2) {

      /* "serpyco/serializer.pyx":199
 *                 or (exclude and dataclass_field.name in exclude)
 *             ):
 *                 excluded_fields.append(serializer_field)             # <<<<<<<<<<<<<<
 *             else:
 *                 fields.append((serializer_field, hints))
 */
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_excluded_fields, ((PyObject *)__pyx_v_serializer_field)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 199, __pyx_L1_error)

      /* "serpyco/serializer.pyx":194
 *                 dataclass_field.default_factory
 *             )
 *             if (             # <<<<<<<<<<<<<<
 *                 hints.ignore
 *                 or (only and dataclass_field.name not in only)
 */
      goto __pyx_L12;
    }

    /* "serpyco/serializer.pyx":201
 *                 excluded_fields.append(serializer_field)
 *             else:
 *                 fields.append((serializer_field, hints))             # <<<<<<<<<<<<<<
 *         self._excluded_fields = tuple(excluded_fields)
 * 
 */
    /*else*/ {
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF((PyObject *)__pyx_v_serializer_field);
      __Pyx_GIVEREF((PyObject *)__pyx_v_serializer_field);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_v_serializer_field))) __PYX_ERR(0, 201, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_hints);
      __Pyx_GIVEREF(__pyx_v_hints);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_v_hints)) __PYX_ERR(0, 201, __pyx_L1_error);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_fields, __pyx_t_10); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 201, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __pyx_L12:;

    /* "serpyco/serializer.pyx":177
 *         fields = []
 *         excluded_fields = []
 *         for dataclass_field in dataclasses.fields(self._dataclass):             # <<<<<<<<<<<<<<
 *             hints = dataclass_field.metadata.get(
 *                 _metadata_name,
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":202
 *             else:
 *                 fields.append((serializer_field, hints))
 *         self._excluded_fields = tuple(excluded_fields)             # <<<<<<<<<<<<<<
 * 
 *         self._field_encoders = {}
 */
  __pyx_t_4 = PyList_AsTuple(__pyx_v_excluded_fields); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->_excluded_fields);
  __Pyx_DECREF(__pyx_v_self->_excluded_fields);
  __pyx_v_self->_excluded_fields = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":204
 *         self._excluded_fields = tuple(excluded_fields)
 * 
 *         self._field_encoders = {}             # <<<<<<<<<<<<<<
 *         field_casters = []
 *         type_hints = typing.get_type_hints(self._dataclass)
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->_field_encoders);
  __Pyx_DECREF(__pyx_v_self->_field_encoders);
  __pyx_v_self->_field_encoders = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":205
 * 
 *         self._field_encoders = {}
 *         field_casters = []             # <<<<<<<<<<<<<<
 *         type_hints = typing.get_type_hints(self._dataclass)
 *         for parent in self._parent_serializers:
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_field_casters = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":206
 *         self._field_encoders = {}
 *         field_casters = []
 *         type_hints = typing.get_type_hints(self._dataclass)             # <<<<<<<<<<<<<<
 *         for parent in self._parent_serializers:
 *             self._field_encoders.update(parent._field_encoders)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_typing); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_get_type_hints); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_self->_dataclass};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __pyx_v_type_hints = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":207
 *         field_casters = []
 *         type_hints = typing.get_type_hints(self._dataclass)
 *         for parent in self._parent_serializers:             # <<<<<<<<<<<<<<
 *             self._field_encoders.update(parent._field_encoders)
 *         for serializer_field, hints in fields:
 */
  if (unlikely(__pyx_v_self->_parent_serializers == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 207, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_v_self->_parent_serializers; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
  for (;;) {
    if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_13 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_13); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 207, __pyx_L1_error)
    #else
    __pyx_t_13 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    #endif
    if (!(likely(((__pyx_t_13) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_13, __pyx_ptype_7serpyco_10serializer_Serializer))))) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_parent, ((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_t_13));
    __pyx_t_13 = 0;

    /* "serpyco/serializer.pyx":208
 *         type_hints = typing.get_type_hints(self._dataclass)
 *         for parent in self._parent_serializers:
 *             self._field_encoders.update(parent._field_encoders)             # <<<<<<<<<<<<<<
 *         for serializer_field, hints in fields:
 *             field_type = self._dataclass_params.resolve_type(
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_field_encoders, __pyx_n_s_update); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_v_parent->_field_encoders};
      __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "serpyco/serializer.pyx":207
 *         field_casters = []
 *         type_hints = typing.get_type_hints(self._dataclass)
 *         for parent in self._parent_serializers:             # <<<<<<<<<<<<<<
 *             self._field_encoders.update(parent._field_encoders)
 *         for serializer_field, hints in fields:
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":209
 *         for parent in self._parent_serializers:
 *             self._field_encoders.update(parent._field_encoders)
 *         for serializer_field, hints in fields:             # <<<<<<<<<<<<<<
 *             field_type = self._dataclass_params.resolve_type(
 *                 type_hints[serializer_field.field_name]
 */
  __pyx_t_4 = __pyx_v_fields; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
  for (;;) {
    if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_13 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_13); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 209, __pyx_L1_error)
    #else
    __pyx_t_13 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_13))) || (PyList_CheckExact(__pyx_t_13))) {
      PyObject* sequence = __pyx_t_13;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 209, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_10 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_11 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_11);
      #else
      __pyx_t_10 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      #endif
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_3 = PyObject_GetIter(__pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
      index = 0; __pyx_t_10 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_10)) goto __pyx_L24_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_10);
      index = 1; __pyx_t_11 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_11)) goto __pyx_L24_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_11);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_3), 2) < 0) __PYX_ERR(0, 209, __pyx_L1_error)
      __pyx_t_15 = NULL;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L25_unpacking_done;
      __pyx_L24_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_15 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 209, __pyx_L1_error)
      __pyx_L25_unpacking_done:;
    }
    if (!(likely(((__pyx_t_10) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_10, __pyx_ptype_7serpyco_10serializer_SerializerField))))) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_serializer_field, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_10));
    __pyx_t_10 = 0;
    __Pyx_XDECREF_SET(__pyx_v_hints, __pyx_t_11);
    __pyx_t_11 = 0;

    /* "serpyco/serializer.pyx":210
 *             self._field_encoders.update(parent._field_encoders)
 *         for serializer_field, hints in fields:
 *             field_type = self._dataclass_params.resolve_type(             # <<<<<<<<<<<<<<
 *                 type_hints[serializer_field.field_name]
 *             )
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass_params, __pyx_n_s_resolve_type); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);

    /* "serpyco/serializer.pyx":211
 *         for serializer_field, hints in fields:
 *             field_type = self._dataclass_params.resolve_type(
 *                 type_hints[serializer_field.field_name]             # <<<<<<<<<<<<<<
 *             )
 *             encoder = self._get_encoder(field_type, hints)
 */
    __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_type_hints, __pyx_v_serializer_field->field_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_10};
      __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_field_type, __pyx_t_13);
    __pyx_t_13 = 0;

    /* "serpyco/serializer.pyx":213
 *                 type_hints[serializer_field.field_name]
 *             )
 *             encoder = self._get_encoder(field_type, hints)             # <<<<<<<<<<<<<<
 *             if encoder:
 *                 self._field_encoders[field_type] = encoder
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_encoder); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_10 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_v_field_type, __pyx_v_hints};
      __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_encoder, __pyx_t_13);
    __pyx_t_13 = 0;

    /* "serpyco/serializer.pyx":214
 *             )
 *             encoder = self._get_encoder(field_type, hints)
 *             if encoder:             # <<<<<<<<<<<<<<
 *                 self._field_encoders[field_type] = encoder
 *                 serializer_field.encoder = encoder
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_encoder); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 214, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "serpyco/serializer.pyx":215
 *             encoder = self._get_encoder(field_type, hints)
 *             if encoder:
 *                 self._field_encoders[field_type] = encoder             # <<<<<<<<<<<<<<
 *                 serializer_field.encoder = encoder
 *             if hints.cast_on_load:
 */
      if (unlikely(__pyx_v_self->_field_encoders == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 215, __pyx_L1_error)
      }
      if (unlikely((PyDict_SetItem(__pyx_v_self->_field_encoders, __pyx_v_field_type, __pyx_v_encoder) < 0))) __PYX_ERR(0, 215, __pyx_L1_error)

      /* "serpyco/serializer.pyx":216
 *             if encoder:
 *                 self._field_encoders[field_type] = encoder
 *                 serializer_field.encoder = encoder             # <<<<<<<<<<<<<<
 *             if hints.cast_on_load:
 *                 field_casters.append(Caster(hints.dict_key, field_type))
 */
      if (!(likely(((__pyx_v_encoder) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_encoder, __pyx_ptype_7serpyco_7encoder_FieldEncoder))))) __PYX_ERR(0, 216, __pyx_L1_error)
      __pyx_t_13 = __pyx_v_encoder;
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_13);
      __Pyx_GOTREF((PyObject *)__pyx_v_serializer_field->encoder);
      __Pyx_DECREF((PyObject *)__pyx_v_serializer_field->encoder);
      __pyx_v_serializer_field->encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_13);
      __pyx_t_13 = 0;

      /* "serpyco/serializer.pyx":214
 *             )
 *             encoder = self._get_encoder(field_type, hints)
 *             if encoder:             # <<<<<<<<<<<<<<
 *                 self._field_encoders[field_type] = encoder
 *                 serializer_field.encoder = encoder
 */
    }

    /* "serpyco/serializer.pyx":217
 *                 self._field_encoders[field_type] = encoder
 *                 serializer_field.encoder = encoder
 *             if hints.cast_on_load:             # <<<<<<<<<<<<<<
 *                 field_casters.append(Caster(hints.dict_key, field_type))
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)
 */
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_hints, __pyx_n_s_cast_on_load); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 217, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (__pyx_t_2) {

      /* "serpyco/serializer.pyx":218
 *                 serializer_field.encoder = encoder
 *             if hints.cast_on_load:
 *                 field_casters.append(Caster(hints.dict_key, field_type))             # <<<<<<<<<<<<<<
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)
 * 
 */
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_hints, __pyx_n_s_dict_key); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_13);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_13)) __PYX_ERR(0, 218, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_field_type);
      __Pyx_GIVEREF(__pyx_v_field_type);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_v_field_type)) __PYX_ERR(0, 218, __pyx_L1_error);
      __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7serpyco_10serializer_Caster), __pyx_t_11, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_field_casters, __pyx_t_13); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 218, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "serpyco/serializer.pyx":217
 *                 self._field_encoders[field_type] = encoder
 *                 serializer_field.encoder = encoder
 *             if hints.cast_on_load:             # <<<<<<<<<<<<<<
 *                 field_casters.append(Caster(hints.dict_key, field_type))
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)
 */
    }

    /* "serpyco/serializer.pyx":209
 *         for parent in self._parent_serializers:
 *             self._field_encoders.update(parent._field_encoders)
 *         for serializer_field, hints in fields:             # <<<<<<<<<<<<<<
 *             field_type = self._dataclass_params.resolve_type(
 *                 type_hints[serializer_field.field_name]
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":219
 *             if hints.cast_on_load:
 *                 field_casters.append(Caster(hints.dict_key, field_type))
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)             # <<<<<<<<<<<<<<
 * 
 *         builder = SchemaBuilder(
 */
  __pyx_t_4 = __pyx_pf_7serpyco_10serializer_10Serializer_9__cinit___genexpr(NULL, __pyx_v_fields); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = __Pyx_PySequence_Tuple(__pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GIVEREF(__pyx_t_13);
  __Pyx_GOTREF(__pyx_v_self->_fields);
  __Pyx_DECREF(__pyx_v_self->_fields);
  __pyx_v_self->_fields = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;

  /* "serpyco/serializer.pyx":221
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)
 * 
 *         builder = SchemaBuilder(             # <<<<<<<<<<<<<<
 *             dataclass,
 *             only=only,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_SchemaBuilder); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);

  /* "serpyco/serializer.pyx":222
 * 
 *         builder = SchemaBuilder(
 *             dataclass,             # <<<<<<<<<<<<<<
 *             only=only,
 *             exclude=exclude,
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_dataclass);
  __Pyx_GIVEREF(__pyx_v_dataclass);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_dataclass)) __PYX_ERR(0, 221, __pyx_L1_error);

  /* "serpyco/serializer.pyx":223
 *         builder = SchemaBuilder(
 *             dataclass,
 *             only=only,             # <<<<<<<<<<<<<<
 *             exclude=exclude,
 *             type_encoders={**self._global_types, **self._type_encoders},
 */
  __pyx_t_11 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_only, __pyx_v_only) < 0) __PYX_ERR(0, 223, __pyx_L1_error)

  /* "serpyco/serializer.pyx":224
 *             dataclass,
 *             only=only,
 *             exclude=exclude,             # <<<<<<<<<<<<<<
 *             type_encoders={**self._global_types, **self._type_encoders},
 *             strict=strict,
 */
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_exclude, __pyx_v_exclude) < 0) __PYX_ERR(0, 223, __pyx_L1_error)

  /* "serpyco/serializer.pyx":225
 *             only=only,
 *             exclude=exclude,
 *             type_encoders={**self._global_types, **self._type_encoders},             # <<<<<<<<<<<<<<
 *             strict=strict,
 *             _dataclass_params=self._dataclass_params,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_global_types); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 225, __pyx_L1_error)
  }
  if (likely(PyDict_CheckExact(__pyx_t_3))) {
    __pyx_t_10 = PyDict_Copy(__pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_10 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (unlikely(__pyx_v_self->_type_encoders == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 225, __pyx_L1_error)
  }
  if (unlikely(PyDict_Update(__pyx_t_10, __pyx_v_self->_type_encoders) < 0)) {
    if (PyErr_ExceptionMatches(PyExc_AttributeError)) __Pyx_RaiseMappingExpectedError(__pyx_v_self->_type_encoders);
    __PYX_ERR(0, 225, __pyx_L1_error)
  }
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_type_encoders, __pyx_t_10) < 0) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":226
 *             exclude=exclude,
 *             type_encoders={**self._global_types, **self._type_encoders},
 *             strict=strict,             # <<<<<<<<<<<<<<
 *             _dataclass_params=self._dataclass_params,
 *         )
 */
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_strict, __pyx_v_strict) < 0) __PYX_ERR(0, 223, __pyx_L1_error)

  /* "serpyco/serializer.pyx":227
 *             type_encoders={**self._global_types, **self._type_encoders},
 *             strict=strict,
 *             _dataclass_params=self._dataclass_params,             # <<<<<<<<<<<<<<
 *         )
 *         self._validator = RapidJsonValidator(builder)
 */
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_dataclass_params, __pyx_v_self->_dataclass_params) < 0) __PYX_ERR(0, 223, __pyx_L1_error)

  /* "serpyco/serializer.pyx":221
 *         self._fields = tuple(serializer_field for serializer_field, _ in fields)
 * 
 *         builder = SchemaBuilder(             # <<<<<<<<<<<<<<
 *             dataclass,
 *             only=only,
 */
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_4, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_v_builder = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":229
 *             _dataclass_params=self._dataclass_params,
 *         )
 *         self._validator = RapidJsonValidator(builder)             # <<<<<<<<<<<<<<
 * 
 *         # pre/post load/dump methods
 */
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_RapidJsonValidator); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_builder};
    __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->_validator);
  __Pyx_DECREF(__pyx_v_self->_validator);
  __pyx_v_self->_validator = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":232
 * 
 *         # pre/post load/dump methods
 *         self._post_dumpers = []             # <<<<<<<<<<<<<<
 *         self._pre_dumpers = []
 *         self._post_loaders = []
 */
  __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->_post_dumpers);
  __Pyx_DECREF(__pyx_v_self->_post_dumpers);
  __pyx_v_self->_post_dumpers = ((PyObject*)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":233
 *         # pre/post load/dump methods
 *         self._post_dumpers = []
 *         self._pre_dumpers = []             # <<<<<<<<<<<<<<
 *         self._post_loaders = []
 *         self._pre_loaders = []
 */
  __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->_pre_dumpers);
  __Pyx_DECREF(__pyx_v_self->_pre_dumpers);
  __pyx_v_self->_pre_dumpers = ((PyObject*)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":234
 *         self._post_dumpers = []
 *         self._pre_dumpers = []
 *         self._post_loaders = []             # <<<<<<<<<<<<<<
 *         self._pre_loaders = []
 *         for attr_name in dir(self._dataclass):
 */
  __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->_post_loaders);
  __Pyx_DECREF(__pyx_v_self->_post_loaders);
  __pyx_v_self->_post_loaders = ((PyObject*)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":235
 *         self._pre_dumpers = []
 *         self._post_loaders = []
 *         self._pre_loaders = []             # <<<<<<<<<<<<<<
 *         for attr_name in dir(self._dataclass):
 *             attr = getattr(self._dataclass, attr_name)
 */
  __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->_pre_loaders);
  __Pyx_DECREF(__pyx_v_self->_pre_loaders);
  __pyx_v_self->_pre_loaders = ((PyObject*)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":236
 *         self._post_loaders = []
 *         self._pre_loaders = []
 *         for attr_name in dir(self._dataclass):             # <<<<<<<<<<<<<<
 *             attr = getattr(self._dataclass, attr_name)
 *             try:
 */
  __pyx_t_10 = __pyx_v_self->_dataclass;
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_11 = PyObject_Dir(__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (likely(PyList_CheckExact(__pyx_t_11)) || PyTuple_CheckExact(__pyx_t_11)) {
    __pyx_t_10 = __pyx_t_11; __Pyx_INCREF(__pyx_t_10); __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_8 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 236, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_10))) {
        if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_10)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_11 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_8); __Pyx_INCREF(__pyx_t_11); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 236, __pyx_L1_error)
        #else
        __pyx_t_11 = PySequence_ITEM(__pyx_t_10, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 236, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        #endif
      } else {
        if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_11 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_8); __Pyx_INCREF(__pyx_t_11); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 236, __pyx_L1_error)
        #else
        __pyx_t_11 = PySequence_ITEM(__pyx_t_10, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 236, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        #endif
      }
    } else {
      __pyx_t_11 = __pyx_t_9(__pyx_t_10);
      if (unlikely(!__pyx_t_11)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 236, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_11);
    }
    __Pyx_XDECREF_SET(__pyx_v_attr_name, __pyx_t_11);
    __pyx_t_11 = 0;

    /* "serpyco/serializer.pyx":237
 *         self._pre_loaders = []
 *         for attr_name in dir(self._dataclass):
 *             attr = getattr(self._dataclass, attr_name)             # <<<<<<<<<<<<<<
 *             try:
 *                 tag = getattr(attr, _serpyco_tags)
 */
    __pyx_t_11 = __pyx_v_self->_dataclass;
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_4 = __Pyx_GetAttr(__pyx_t_11, __pyx_v_attr_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "serpyco/serializer.pyx":238
 *         for attr_name in dir(self._dataclass):
 *             attr = getattr(self._dataclass, attr_name)
 *             try:             # <<<<<<<<<<<<<<
 *                 tag = getattr(attr, _serpyco_tags)
 *                 if DecoratorType.POST_DUMP==tag:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      /*try:*/ {

        /* "serpyco/serializer.pyx":239
 *             attr = getattr(self._dataclass, attr_name)
 *             try:
 *                 tag = getattr(attr, _serpyco_tags)             # <<<<<<<<<<<<<<
 *                 if DecoratorType.POST_DUMP==tag:
 *                     self._post_dumpers.append(attr)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_serpyco_tags); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 239, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_11 = __Pyx_GetAttr(__pyx_v_attr, __pyx_t_4); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 239, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF_SET(__pyx_v_tag, __pyx_t_11);
        __pyx_t_11 = 0;

        /* "serpyco/serializer.pyx":240
 *             try:
 *                 tag = getattr(attr, _serpyco_tags)
 *                 if DecoratorType.POST_DUMP==tag:             # <<<<<<<<<<<<<<
 *                     self._post_dumpers.append(attr)
 *                 elif DecoratorType.PRE_DUMP==tag:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_DecoratorType); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 240, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_POST_DUMP); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 240, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyObject_RichCompare(__pyx_t_4, __pyx_v_tag, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 240, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 240, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_2) {

          /* "serpyco/serializer.pyx":241
 *                 tag = getattr(attr, _serpyco_tags)
 *                 if DecoratorType.POST_DUMP==tag:
 *                     self._post_dumpers.append(attr)             # <<<<<<<<<<<<<<
 *                 elif DecoratorType.PRE_DUMP==tag:
 *                     self._pre_dumpers.append(attr)
 */
          if (unlikely(__pyx_v_self->_post_dumpers == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 241, __pyx_L31_error)
          }
          __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->_post_dumpers, __pyx_v_attr); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 241, __pyx_L31_error)

          /* "serpyco/serializer.pyx":240
 *             try:
 *                 tag = getattr(attr, _serpyco_tags)
 *                 if DecoratorType.POST_DUMP==tag:             # <<<<<<<<<<<<<<
 *                     self._post_dumpers.append(attr)
 *                 elif DecoratorType.PRE_DUMP==tag:
 */
          goto __pyx_L39;
        }

        /* "serpyco/serializer.pyx":242
 *                 if DecoratorType.POST_DUMP==tag:
 *                     self._post_dumpers.append(attr)
 *                 elif DecoratorType.PRE_DUMP==tag:             # <<<<<<<<<<<<<<
 *                     self._pre_dumpers.append(attr)
 *                 elif DecoratorType.POST_LOAD==tag:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_DecoratorType); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 242, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_PRE_DUMP); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 242, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyObject_RichCompare(__pyx_t_4, __pyx_v_tag, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 242, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 242, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_2) {

          /* "serpyco/serializer.pyx":243
 *                     self._post_dumpers.append(attr)
 *                 elif DecoratorType.PRE_DUMP==tag:
 *                     self._pre_dumpers.append(attr)             # <<<<<<<<<<<<<<
 *                 elif DecoratorType.POST_LOAD==tag:
 *                     self._post_loaders.append(attr)
 */
          if (unlikely(__pyx_v_self->_pre_dumpers == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 243, __pyx_L31_error)
          }
          __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->_pre_dumpers, __pyx_v_attr); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 243, __pyx_L31_error)

          /* "serpyco/serializer.pyx":242
 *                 if DecoratorType.POST_DUMP==tag:
 *                     self._post_dumpers.append(attr)
 *                 elif DecoratorType.PRE_DUMP==tag:             # <<<<<<<<<<<<<<
 *                     self._pre_dumpers.append(attr)
 *                 elif DecoratorType.POST_LOAD==tag:
 */
          goto __pyx_L39;
        }

        /* "serpyco/serializer.pyx":244
 *                 elif DecoratorType.PRE_DUMP==tag:
 *                     self._pre_dumpers.append(attr)
 *                 elif DecoratorType.POST_LOAD==tag:             # <<<<<<<<<<<<<<
 *                     self._post_loaders.append(attr)
 *                 elif DecoratorType.PRE_LOAD==tag:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_DecoratorType); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 244, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_POST_LOAD); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 244, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyObject_RichCompare(__pyx_t_4, __pyx_v_tag, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 244, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 244, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_2) {

          /* "serpyco/serializer.pyx":245
 *                     self._pre_dumpers.append(attr)
 *                 elif DecoratorType.POST_LOAD==tag:
 *                     self._post_loaders.append(attr)             # <<<<<<<<<<<<<<
 *                 elif DecoratorType.PRE_LOAD==tag:
 *                     self._pre_loaders.append(attr)
 */
          if (unlikely(__pyx_v_self->_post_loaders == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 245, __pyx_L31_error)
          }
          __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->_post_loaders, __pyx_v_attr); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 245, __pyx_L31_error)

          /* "serpyco/serializer.pyx":244
 *                 elif DecoratorType.PRE_DUMP==tag:
 *                     self._pre_dumpers.append(attr)
 *                 elif DecoratorType.POST_LOAD==tag:             # <<<<<<<<<<<<<<
 *                     self._post_loaders.append(attr)
 *                 elif DecoratorType.PRE_LOAD==tag:
 */
          goto __pyx_L39;
        }

        /* "serpyco/serializer.pyx":246
 *                 elif DecoratorType.POST_LOAD==tag:
 *                     self._post_loaders.append(attr)
 *                 elif DecoratorType.PRE_LOAD==tag:             # <<<<<<<<<<<<<<
 *                     self._pre_loaders.append(attr)
 *                 else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_DecoratorType); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 246, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_PRE_LOAD); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 246, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyObject_RichCompare(__pyx_t_4, __pyx_v_tag, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 246, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 246, __pyx_L31_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (likely(__pyx_t_2)) {

          /* "serpyco/serializer.pyx":247
 *                     self._post_loaders.append(attr)
 *                 elif DecoratorType.PRE_LOAD==tag:
 *                     self._pre_loaders.append(attr)             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(f"Unknown decorator type {tag}")
 */
          if (unlikely(__pyx_v_self->_pre_loaders == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 247, __pyx_L31_error)
          }
          __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->_pre_loaders, __pyx_v_attr); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 247, __pyx_L31_error)

          /* "serpyco/serializer.pyx":246
 *                 elif DecoratorType.POST_LOAD==tag:
 *                     self._post_loaders.append(attr)
 *                 elif DecoratorType.PRE_LOAD==tag:             # <<<<<<<<<<<<<<
 *                     self._pre_loaders.append(attr)
 *                 else:
 */
          goto __pyx_L39;
        }

        /* "serpyco/serializer.pyx":249
 *                     self._pre_loaders.append(attr)
 *                 else:
 *                     raise ValueError(f"Unknown decorator type {tag}")             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 continue
 */
        /*else*/ {
          __pyx_t_11 = __Pyx_PyObject_FormatSimple(__pyx_v_tag, __pyx_empty_unicode); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 249, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Unknown_decorator_type, __pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 249, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 249, __pyx_L31_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_Raise(__pyx_t_11, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __PYX_ERR(0, 249, __pyx_L31_error)
        }
        __pyx_L39:;

        /* "serpyco/serializer.pyx":238
 *         for attr_name in dir(self._dataclass):
 *             attr = getattr(self._dataclass, attr_name)
 *             try:             # <<<<<<<<<<<<<<
 *                 tag = getattr(attr, _serpyco_tags)
 *                 if DecoratorType.POST_DUMP==tag:
 */
      }
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      goto __pyx_L38_try_end;
      __pyx_L31_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "serpyco/serializer.pyx":250
 *                 else:
 *                     raise ValueError(f"Unknown decorator type {tag}")
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 continue
 *         self._field_casters = tuple(field_casters)
 */
      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
      if (__pyx_t_6) {
        __Pyx_AddTraceback("serpyco.serializer.Serializer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_4, &__pyx_t_13) < 0) __PYX_ERR(0, 250, __pyx_L33_except_error)
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_13);

        /* "serpyco/serializer.pyx":251
 *                     raise ValueError(f"Unknown decorator type {tag}")
 *             except AttributeError:
 *                 continue             # <<<<<<<<<<<<<<
 *         self._field_casters = tuple(field_casters)
 *         self._load_as_type = load_as_type or self._dataclass
 */
        goto __pyx_L40_except_continue;
        __pyx_L40_except_continue:;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L37_try_continue;
      }
      goto __pyx_L33_except_error;

      /* "serpyco/serializer.pyx":238
 *         for attr_name in dir(self._dataclass):
 *             attr = getattr(self._dataclass, attr_name)
 *             try:             # <<<<<<<<<<<<<<
 *                 tag = getattr(attr, _serpyco_tags)
 *                 if DecoratorType.POST_DUMP==tag:
 */
      __pyx_L33_except_error:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      goto __pyx_L1_error;
      __pyx_L37_try_continue:;
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      goto __pyx_L29_continue;
      __pyx_L38_try_end:;
    }

    /* "serpyco/serializer.pyx":236
 *         self._post_loaders = []
 *         self._pre_loaders = []
 *         for attr_name in dir(self._dataclass):             # <<<<<<<<<<<<<<
 *             attr = getattr(self._dataclass, attr_name)
 *             try:
 */
    __pyx_L29_continue:;
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":252
 *             except AttributeError:
 *                 continue
 *         self._field_casters = tuple(field_casters)             # <<<<<<<<<<<<<<
 *         self._load_as_type = load_as_type or self._dataclass
 *         # Check if the dataclass is frozen or not
 */
  __pyx_t_10 = PyList_AsTuple(__pyx_v_field_casters); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->_field_casters);
  __Pyx_DECREF(__pyx_v_self->_field_casters);
  __pyx_v_self->_field_casters = ((PyObject*)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":253
 *                 continue
 *         self._field_casters = tuple(field_casters)
 *         self._load_as_type = load_as_type or self._dataclass             # <<<<<<<<<<<<<<
 *         # Check if the dataclass is frozen or not
 *         self._frozen_dataclass = self._dataclass.__dataclass_params__.frozen
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_load_as_type)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 253, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF((PyObject *)__pyx_v_load_as_type);
    __pyx_t_10 = ((PyObject *)__pyx_v_load_as_type);
    goto __pyx_L43_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_self->_dataclass);
  __pyx_t_10 = __pyx_v_self->_dataclass;
  __pyx_L43_bool_binop_done:;
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->_load_as_type);
  __Pyx_DECREF(__pyx_v_self->_load_as_type);
  __pyx_v_self->_load_as_type = __pyx_t_10;
  __pyx_t_10 = 0;

  /* "serpyco/serializer.pyx":255
 *         self._load_as_type = load_as_type or self._dataclass
 *         # Check if the dataclass is frozen or not
 *         self._frozen_dataclass = self._dataclass.__dataclass_params__.frozen             # <<<<<<<<<<<<<<
 *         self._has_post_init = hasattr(self._dataclass, "__post_init__")
 * 
 */
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass, __pyx_n_s_dataclass_params_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_frozen); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_v_self->_frozen_dataclass = __pyx_t_2;

  /* "serpyco/serializer.pyx":256
 *         # Check if the dataclass is frozen or not
 *         self._frozen_dataclass = self._dataclass.__dataclass_params__.frozen
 *         self._has_post_init = hasattr(self._dataclass, "__post_init__")             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
 */
  __pyx_t_13 = __pyx_v_self->_dataclass;
  __Pyx_INCREF(__pyx_t_13);
  __pyx_t_2 = __Pyx_HasAttr(__pyx_t_13, __pyx_n_u_post_init); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_v_self->_has_post_init = __pyx_t_2;

  /* "serpyco/serializer.pyx":141
 *         SchemaBuilder.register_global_type(f, e)
 * 
 *     def __cinit__(             # <<<<<<<<<<<<<<
 *         self,
 *         dataclass,
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_parent);
  __Pyx_XDECREF((PyObject *)__pyx_v_serializer_field);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_excluded_fields);
  __Pyx_XDECREF(__pyx_v_dataclass_field);
  __Pyx_XDECREF(__pyx_v_hints);
  __Pyx_XDECREF(__pyx_v_field_casters);
  __Pyx_XDECREF(__pyx_v_type_hints);
  __Pyx_XDECREF(__pyx_v_field_type);
  __Pyx_XDECREF(__pyx_v_encoder);
  __Pyx_XDECREF(__pyx_v_builder);
  __Pyx_XDECREF(__pyx_v_attr_name);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_tag);
  __Pyx_XDECREF(__pyx_gb_7serpyco_10serializer_10Serializer_9__cinit___2generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":258
 *         self._has_post_init = hasattr(self._dataclass, "__post_init__")
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         cdef SerializerField sfield
 *         excluded_field_names = []
 */

/* Python wrapper */
static Py_hash_t __pyx_pw_7serpyco_10serializer_10Serializer_3__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_7serpyco_10serializer_10Serializer_3__hash__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_2__hash__(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_7serpyco_10serializer_10Serializer_2__hash__(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield = 0;
  PyObject *__pyx_v_excluded_field_names = NULL;
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_hash_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "serpyco/serializer.pyx":260
 *     def __hash__(self):
 *         cdef SerializerField sfield
 *         excluded_field_names = []             # <<<<<<<<<<<<<<
 *         for sfield in self._excluded_fields:
 *             excluded_field_names.append(sfield.field_name)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_excluded_field_names = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":261
 *         cdef SerializerField sfield
 *         excluded_field_names = []
 *         for sfield in self._excluded_fields:             # <<<<<<<<<<<<<<
 *             excluded_field_names.append(sfield.field_name)
 *         return hash((
 */
  if (unlikely(__pyx_v_self->_excluded_fields == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 261, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_excluded_fields; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 261, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_7serpyco_10serializer_SerializerField))))) __PYX_ERR(0, 261, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_sfield, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":262
 *         excluded_field_names = []
 *         for sfield in self._excluded_fields:
 *             excluded_field_names.append(sfield.field_name)             # <<<<<<<<<<<<<<
 *         return hash((
 *             self._dataclass,
 */
    __pyx_t_3 = __pyx_v_sfield->field_name;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_excluded_field_names, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":261
 *         cdef SerializerField sfield
 *         excluded_field_names = []
 *         for sfield in self._excluded_fields:             # <<<<<<<<<<<<<<
 *             excluded_field_names.append(sfield.field_name)
 *         return hash((
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":265
 *         return hash((
 *             self._dataclass,
 *             self._dataclass_params.arguments,             # <<<<<<<<<<<<<<
 *             tuple(excluded_field_names)
 *         ))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass_params, __pyx_n_s_arguments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "serpyco/serializer.pyx":266
 *             self._dataclass,
 *             self._dataclass_params.arguments,
 *             tuple(excluded_field_names)             # <<<<<<<<<<<<<<
 *         ))
 * 
 */
  __pyx_t_3 = PyList_AsTuple(__pyx_v_excluded_field_names); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "serpyco/serializer.pyx":264
 *             excluded_field_names.append(sfield.field_name)
 *         return hash((
 *             self._dataclass,             # <<<<<<<<<<<<<<
 *             self._dataclass_params.arguments,
 *             tuple(excluded_field_names)
 */
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_self->_dataclass);
  __Pyx_GIVEREF(__pyx_v_self->_dataclass);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_self->_dataclass)) __PYX_ERR(0, 264, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1)) __PYX_ERR(0, 264, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3)) __PYX_ERR(0, 264, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":263
 *         for sfield in self._excluded_fields:
 *             excluded_field_names.append(sfield.field_name)
 *         return hash((             # <<<<<<<<<<<<<<
 *             self._dataclass,
 *             self._dataclass_params.arguments,
 */
  __pyx_t_6 = PyObject_Hash(__pyx_t_5); if (unlikely(__pyx_t_6 == ((Py_hash_t)-1))) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":258
 *         self._has_post_init = hasattr(self._dataclass, "__post_init__")
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         cdef SerializerField sfield
 *         excluded_field_names = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sfield);
  __Pyx_XDECREF(__pyx_v_excluded_field_names);
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":269
 *         ))
 * 
 *     def json_schema(self, many: bool = False) -> JsonDict:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the JSON schema of the underlying validator.
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_5json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_4json_schema, "Serializer.json_schema(self, many: bool = False) -> JsonDict\n\n        Returns the JSON schema of the underlying validator.\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_5json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_5json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_4json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_5json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_many = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 269, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_many,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_many);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 269, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "json_schema") < 0)) __PYX_ERR(0, 269, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_many = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("json_schema", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 269, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_4json_schema(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_many);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_4json_schema(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_many) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":273
 *         Returns the JSON schema of the underlying validator.
 *         """
 *         return self._validator.json_schema(many=many)             # <<<<<<<<<<<<<<
 * 
 *     def get_dict_path(self, obj_path: typing.Sequence[str]) -> typing.List[str]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_json_schema); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_many, __pyx_v_many) < 0) __PYX_ERR(0, 273, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":269
 *         ))
 * 
 *     def json_schema(self, many: bool = False) -> JsonDict:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the JSON schema of the underlying validator.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":275
 *         return self._validator.json_schema(many=many)
 * 
 *     def get_dict_path(self, obj_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in dumped dictionaries.
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_7get_dict_path(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_6get_dict_path, "Serializer.get_dict_path(self, obj_path: typing.Sequence[str]) -> typing.List[str]\n\n        Returns the path of a field in dumped dictionaries.\n        :param obj_path: list of field names, for example\n        [\"foo\", \"bar\"] to get the dict path of foo.bar\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_7get_dict_path = {"get_dict_path", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_7get_dict_path, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_6get_dict_path};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_7get_dict_path(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj_path = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dict_path (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 275, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj_path,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 275, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dict_path") < 0)) __PYX_ERR(0, 275, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj_path = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dict_path", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 275, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.get_dict_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_6get_dict_path(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_obj_path);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_6get_dict_path(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj_path) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield = 0;
  struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_ser = 0;
  PyObject *__pyx_v_part = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dict_path", 0);

  /* "serpyco/serializer.pyx":283
 *         cdef SerializerField sfield
 *         cdef Serializer ser
 *         part = obj_path[0]             # <<<<<<<<<<<<<<
 *         for sfield in self._fields:
 *             if sfield.field_name==part:
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_obj_path, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_part = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":284
 *         cdef Serializer ser
 *         part = obj_path[0]
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             if sfield.field_name==part:
 *                 break
 */
  if (unlikely(__pyx_v_self->_fields == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 284, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_fields; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 284, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_7serpyco_10serializer_SerializerField))))) __PYX_ERR(0, 284, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_sfield, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":285
 *         part = obj_path[0]
 *         for sfield in self._fields:
 *             if sfield.field_name==part:             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_sfield->field_name, __pyx_v_part, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 285, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "serpyco/serializer.pyx":286
 *         for sfield in self._fields:
 *             if sfield.field_name==part:
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(f"Unknown field {part} in {self._dataclass}")
 */
      goto __pyx_L4_break;

      /* "serpyco/serializer.pyx":285
 *         part = obj_path[0]
 *         for sfield in self._fields:
 *             if sfield.field_name==part:             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
    }

    /* "serpyco/serializer.pyx":284
 *         cdef Serializer ser
 *         part = obj_path[0]
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             if sfield.field_name==part:
 *                 break
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L6_for_else;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L7_for_end;
  /*else*/ {
    __pyx_L6_for_else:;

    /* "serpyco/serializer.pyx":288
 *                 break
 *         else:
 *             raise KeyError(f"Unknown field {part} in {self._dataclass}")             # <<<<<<<<<<<<<<
 * 
 *         if 1 == len(obj_path):
 */
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_Unknown_field);
    __pyx_t_2 += 14;
    __Pyx_GIVEREF(__pyx_kp_u_Unknown_field);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_Unknown_field);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_part, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_in);
    __pyx_t_2 += 4;
    __Pyx_GIVEREF(__pyx_kp_u_in);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_in);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_self->_dataclass, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 288, __pyx_L1_error)
  }
  __pyx_L7_for_end:;

  /* "serpyco/serializer.pyx":290
 *             raise KeyError(f"Unknown field {part} in {self._dataclass}")
 * 
 *         if 1 == len(obj_path):             # <<<<<<<<<<<<<<
 *             return [sfield.dict_key]
 * 
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_obj_path); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 290, __pyx_L1_error)
  __pyx_t_4 = (1 == __pyx_t_2);
  if (__pyx_t_4) {

    /* "serpyco/serializer.pyx":291
 * 
 *         if 1 == len(obj_path):
 *             return [sfield.dict_key]             # <<<<<<<<<<<<<<
 * 
 *         ser = self._get_field_serializer(sfield)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_sfield->dict_key);
    __Pyx_GIVEREF(__pyx_v_sfield->dict_key);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_sfield->dict_key)) __PYX_ERR(0, 291, __pyx_L1_error);
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":290
 *             raise KeyError(f"Unknown field {part} in {self._dataclass}")
 * 
 *         if 1 == len(obj_path):             # <<<<<<<<<<<<<<
 *             return [sfield.dict_key]
 * 
 */
  }

  /* "serpyco/serializer.pyx":293
 *             return [sfield.dict_key]
 * 
 *         ser = self._get_field_serializer(sfield)             # <<<<<<<<<<<<<<
 *         return [sfield.dict_key] + ser.get_dict_path(obj_path[1:])
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_field_serializer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, ((PyObject *)__pyx_v_sfield)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7serpyco_10serializer_Serializer))))) __PYX_ERR(0, 293, __pyx_L1_error)
  __pyx_v_ser = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":294
 * 
 *         ser = self._get_field_serializer(sfield)
 *         return [sfield.dict_key] + ser.get_dict_path(obj_path[1:])             # <<<<<<<<<<<<<<
 * 
 *     def get_object_path(self, dict_path: typing.Sequence[str]) -> typing.List[str]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_sfield->dict_key);
  __Pyx_GIVEREF(__pyx_v_sfield->dict_key);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_sfield->dict_key)) __PYX_ERR(0, 294, __pyx_L1_error);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_ser), __pyx_n_s_get_dict_path); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_v_obj_path, 1, 0, NULL, NULL, &__pyx_slice__2, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(PyList_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_6))) __PYX_ERR(0, 294, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":275
 *         return self._validator.json_schema(many=many)
 * 
 *     def get_dict_path(self, obj_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in dumped dictionaries.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.get_dict_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sfield);
  __Pyx_XDECREF((PyObject *)__pyx_v_ser);
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":296
 *         return [sfield.dict_key] + ser.get_dict_path(obj_path[1:])
 * 
 *     def get_object_path(self, dict_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in loaded objects.
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_9get_object_path(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_8get_object_path, "Serializer.get_object_path(self, dict_path: typing.Sequence[str]) -> typing.List[str]\n\n        Returns the path of a field in loaded objects.\n        :param dict_path: list of dictionary keys, for example\n        [\"foo\", \"bar\"] to get the object path of {\"foo\": {\"bar\": 42}}\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_9get_object_path = {"get_object_path", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_9get_object_path, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_8get_object_path};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_9get_object_path(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dict_path = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_object_path (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 296, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dict_path,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dict_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 296, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_object_path") < 0)) __PYX_ERR(0, 296, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dict_path = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_object_path", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 296, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.get_object_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_8get_object_path(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_dict_path);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_8get_object_path(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_dict_path) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield = 0;
  struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_ser = 0;
  PyObject *__pyx_v_part = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_object_path", 0);

  /* "serpyco/serializer.pyx":304
 *         cdef SerializerField sfield
 *         cdef Serializer ser
 *         part = dict_path[0]             # <<<<<<<<<<<<<<
 *         for sfield in self._fields:
 *             if sfield.dict_key==part:
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_dict_path, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_part = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":305
 *         cdef Serializer ser
 *         part = dict_path[0]
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             if sfield.dict_key==part:
 *                 break
 */
  if (unlikely(__pyx_v_self->_fields == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 305, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_fields; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 305, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_7serpyco_10serializer_SerializerField))))) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_sfield, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":306
 *         part = dict_path[0]
 *         for sfield in self._fields:
 *             if sfield.dict_key==part:             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_sfield->dict_key, __pyx_v_part, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 306, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "serpyco/serializer.pyx":307
 *         for sfield in self._fields:
 *             if sfield.dict_key==part:
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(f"Unknown dict key {part} in {self._dataclass}")
 */
      goto __pyx_L4_break;

      /* "serpyco/serializer.pyx":306
 *         part = dict_path[0]
 *         for sfield in self._fields:
 *             if sfield.dict_key==part:             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
    }

    /* "serpyco/serializer.pyx":305
 *         cdef Serializer ser
 *         part = dict_path[0]
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             if sfield.dict_key==part:
 *                 break
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L6_for_else;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L7_for_end;
  /*else*/ {
    __pyx_L6_for_else:;

    /* "serpyco/serializer.pyx":309
 *                 break
 *         else:
 *             raise KeyError(f"Unknown dict key {part} in {self._dataclass}")             # <<<<<<<<<<<<<<
 * 
 *         if 1 == len(dict_path):
 */
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_Unknown_dict_key);
    __pyx_t_2 += 17;
    __Pyx_GIVEREF(__pyx_kp_u_Unknown_dict_key);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_Unknown_dict_key);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_part, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_in);
    __pyx_t_2 += 4;
    __Pyx_GIVEREF(__pyx_kp_u_in);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_in);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_self->_dataclass, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 309, __pyx_L1_error)
  }
  __pyx_L7_for_end:;

  /* "serpyco/serializer.pyx":311
 *             raise KeyError(f"Unknown dict key {part} in {self._dataclass}")
 * 
 *         if 1 == len(dict_path):             # <<<<<<<<<<<<<<
 *             return [sfield.field_name]
 * 
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_dict_path); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 311, __pyx_L1_error)
  __pyx_t_4 = (1 == __pyx_t_2);
  if (__pyx_t_4) {

    /* "serpyco/serializer.pyx":312
 * 
 *         if 1 == len(dict_path):
 *             return [sfield.field_name]             # <<<<<<<<<<<<<<
 * 
 *         ser = self._get_field_serializer(sfield)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_sfield->field_name);
    __Pyx_GIVEREF(__pyx_v_sfield->field_name);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_sfield->field_name)) __PYX_ERR(0, 312, __pyx_L1_error);
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":311
 *             raise KeyError(f"Unknown dict key {part} in {self._dataclass}")
 * 
 *         if 1 == len(dict_path):             # <<<<<<<<<<<<<<
 *             return [sfield.field_name]
 * 
 */
  }

  /* "serpyco/serializer.pyx":314
 *             return [sfield.field_name]
 * 
 *         ser = self._get_field_serializer(sfield)             # <<<<<<<<<<<<<<
 *         return [sfield.field_name] + ser.get_object_path(dict_path[1:])
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_field_serializer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, ((PyObject *)__pyx_v_sfield)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7serpyco_10serializer_Serializer))))) __PYX_ERR(0, 314, __pyx_L1_error)
  __pyx_v_ser = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":315
 * 
 *         ser = self._get_field_serializer(sfield)
 *         return [sfield.field_name] + ser.get_object_path(dict_path[1:])             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_sfield->field_name);
  __Pyx_GIVEREF(__pyx_v_sfield->field_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_sfield->field_name)) __PYX_ERR(0, 315, __pyx_L1_error);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_ser), __pyx_n_s_get_object_path); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_v_dict_path, 1, 0, NULL, NULL, &__pyx_slice__2, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(PyList_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_6))) __PYX_ERR(0, 315, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":296
 *         return [sfield.dict_key] + ser.get_dict_path(obj_path[1:])
 * 
 *     def get_object_path(self, dict_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in loaded objects.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.get_object_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sfield);
  __Pyx_XDECREF((PyObject *)__pyx_v_ser);
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":317
 *         return [sfield.field_name] + ser.get_object_path(dict_path[1:])
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register_global_type(
 *         cls,
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_11register_global_type(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_10register_global_type, "Serializer.register_global_type(cls, field_type: typing.Any, FieldEncoder encoder: FieldEncoder) -> None\n\n        Registers a encoder/decoder for the given type.\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_11register_global_type = {"register_global_type", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_11register_global_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_10register_global_type};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_11register_global_type(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_field_type = 0;
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("register_global_type (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 317, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_field_type,&__pyx_n_s_encoder,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_field_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 317, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_encoder)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 317, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("register_global_type", 1, 2, 2, 1); __PYX_ERR(0, 317, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "register_global_type") < 0)) __PYX_ERR(0, 317, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_field_type = values[0];
    __pyx_v_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("register_global_type", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 317, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.register_global_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_7encoder_FieldEncoder, 0, "encoder", 0))) __PYX_ERR(0, 321, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_10register_global_type(((PyTypeObject*)__pyx_v_cls), __pyx_v_field_type, __pyx_v_encoder);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_10register_global_type(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_field_type, struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("register_global_type", 0);

  /* "serpyco/serializer.pyx":326
 *         Registers a encoder/decoder for the given type.
 *         """
 *         cls._global_types[field_type] = encoder             # <<<<<<<<<<<<<<
 *         SchemaBuilder.register_global_type(field_type, encoder.json_schema())
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_global_types); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_field_type, ((PyObject *)__pyx_v_encoder)) < 0))) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":327
 *         """
 *         cls._global_types[field_type] = encoder
 *         SchemaBuilder.register_global_type(field_type, encoder.json_schema())             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SchemaBuilder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_register_global_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_encoder), __pyx_n_s_json_schema); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_5, };
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_field_type, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":317
 *         return [sfield.field_name] + ser.get_object_path(dict_path[1:])
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register_global_type(
 *         cls,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.register_global_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":329
 *         SchemaBuilder.register_global_type(field_type, encoder.json_schema())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def unregister_global_type(cls, field_type: typing.Any) -> None:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_13unregister_global_type(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_12unregister_global_type, "Serializer.unregister_global_type(cls, field_type: typing.Any) -> None\n\n        Removes a previously registered encoder for the given type.\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_13unregister_global_type = {"unregister_global_type", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_13unregister_global_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_12unregister_global_type};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_13unregister_global_type(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_field_type = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unregister_global_type (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 329, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_field_type,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_field_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 329, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unregister_global_type") < 0)) __PYX_ERR(0, 329, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_field_type = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unregister_global_type", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 329, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.unregister_global_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_12unregister_global_type(((PyTypeObject*)__pyx_v_cls), __pyx_v_field_type);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_12unregister_global_type(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_field_type) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unregister_global_type", 0);

  /* "serpyco/serializer.pyx":334
 *         Removes a previously registered encoder for the given type.
 *         """
 *         del cls._global_types[field_type]             # <<<<<<<<<<<<<<
 *         SchemaBuilder.unregister_global_type(field_type)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_global_types); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_DelItem(__pyx_t_1, __pyx_v_field_type) < 0))) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":335
 *         """
 *         del cls._global_types[field_type]
 *         SchemaBuilder.unregister_global_type(field_type)             # <<<<<<<<<<<<<<
 * 
 *     def dataclass(self) -> type:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SchemaBuilder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_unregister_global_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_field_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":329
 *         SchemaBuilder.register_global_type(field_type, encoder.json_schema())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def unregister_global_type(cls, field_type: typing.Any) -> None:
 *         """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.unregister_global_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":337
 *         SchemaBuilder.unregister_global_type(field_type)
 * 
 *     def dataclass(self) -> type:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the dataclass used to construct this serializer.
 */

/* Python wrapper */
static PyTypeObject *__pyx_pw_7serpyco_10serializer_10Serializer_15dataclass(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_14dataclass, "Serializer.dataclass(self) -> type\n\n        Returns the dataclass used to construct this serializer.\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_15dataclass = {"dataclass", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_15dataclass, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_14dataclass};
static PyTypeObject *__pyx_pw_7serpyco_10serializer_10Serializer_15dataclass(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyTypeObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dataclass (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 337, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("dataclass", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dataclass", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dataclass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_14dataclass(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyTypeObject *__pyx_pf_7serpyco_10serializer_10Serializer_14dataclass(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self) {
  PyTypeObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dataclass", 0);

  /* "serpyco/serializer.pyx":341
 *         Returns the dataclass used to construct this serializer.
 *         """
 *         return self._dataclass             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(PyType_CheckExact(__pyx_v_self->_dataclass))||((__pyx_v_self->_dataclass) == Py_None) || __Pyx_RaiseUnexpectedTypeError("type", __pyx_v_self->_dataclass))) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_self->_dataclass);
  __pyx_r = ((PyTypeObject*)__pyx_v_self->_dataclass);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":337
 *         SchemaBuilder.unregister_global_type(field_type)
 * 
 *     def dataclass(self) -> type:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the dataclass used to construct this serializer.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dataclass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":343
 *         return self._dataclass
 * 
 *     cpdef inline dump(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */

static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_17dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_dump(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump *__pyx_optional_args) {

  /* "serpyco/serializer.pyx":346
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,             # <<<<<<<<<<<<<<
 *         bint many: bool=False,
 *     ):
 */
  int __pyx_v_validate = ((int)0);

  /* "serpyco/serializer.pyx":347
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,
 *         bint many: bool=False,             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
  int __pyx_v_many = ((int)0);
  PyObject *__pyx_v_objs = 0;
  PyObject *__pyx_v_pre_dump = NULL;
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_post_dump = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_o = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_validate = __pyx_optional_args->validate;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_many = __pyx_optional_args->many;
      }
    }
  }
  __Pyx_INCREF(__pyx_v_obj);

  /* "serpyco/serializer.pyx":356
 *         """
 *         cdef list objs
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":357
 *         cdef list objs
 *         if many:
 *             objs = obj             # <<<<<<<<<<<<<<
 *             for pre_dump in self._pre_dumpers:
 *                 objs = map(pre_dump, objs)
 */
    if (!(likely(PyList_CheckExact(__pyx_v_obj))||((__pyx_v_obj) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_v_obj))) __PYX_ERR(0, 357, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_obj;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_objs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":358
 *         if many:
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 objs = map(pre_dump, objs)
 *             data = [self._dump(o) for o in objs]
 */
    if (unlikely(__pyx_v_self->_pre_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 358, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 358, __pyx_L1_error)
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 358, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_dump, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":359
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:
 *                 objs = map(pre_dump, objs)             # <<<<<<<<<<<<<<
 *             data = [self._dump(o) for o in objs]
 *         else:
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_pre_dump);
      __Pyx_GIVEREF(__pyx_v_pre_dump);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_pre_dump)) __PYX_ERR(0, 359, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_objs);
      __Pyx_GIVEREF(__pyx_v_objs);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_objs)) __PYX_ERR(0, 359, __pyx_L1_error);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!(likely(PyList_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_4))) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_objs, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":358
 *         if many:
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 objs = map(pre_dump, objs)
 *             data = [self._dump(o) for o in objs]
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":360
 *             for pre_dump in self._pre_dumpers:
 *                 objs = map(pre_dump, objs)
 *             data = [self._dump(o) for o in objs]             # <<<<<<<<<<<<<<
 *         else:
 *             for pre_dump in self._pre_dumpers:
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 360, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_v_objs == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 360, __pyx_L9_error)
      }
      __pyx_t_4 = __pyx_v_objs; __Pyx_INCREF(__pyx_t_4); __pyx_t_2 = 0;
      for (;;) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 360, __pyx_L9_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 360, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_o, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_3 = __pyx_f_7serpyco_10serializer_10Serializer__dump(__pyx_v_self, __pyx_8genexpr1__pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 360, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 360, __pyx_L9_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_o); __pyx_8genexpr1__pyx_v_o = 0;
      goto __pyx_L13_exit_scope;
      __pyx_L9_error:;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_o); __pyx_8genexpr1__pyx_v_o = 0;
      goto __pyx_L1_error;
      __pyx_L13_exit_scope:;
    } /* exit inner scope */
    __pyx_v_data = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":356
 *         """
 *         cdef list objs
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:
 */
    goto __pyx_L3;
  }

  /* "serpyco/serializer.pyx":362
 *             data = [self._dump(o) for o in objs]
 *         else:
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 obj = pre_dump(obj)
 *             data = self._dump(obj)
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->_pre_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 362, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 362, __pyx_L1_error)
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 362, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_dump, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":363
 *         else:
 *             for pre_dump in self._pre_dumpers:
 *                 obj = pre_dump(obj)             # <<<<<<<<<<<<<<
 *             data = self._dump(obj)
 * 
 */
      __Pyx_INCREF(__pyx_v_pre_dump);
      __pyx_t_3 = __pyx_v_pre_dump; __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_obj};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":362
 *             data = [self._dump(o) for o in objs]
 *         else:
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 obj = pre_dump(obj)
 *             data = self._dump(obj)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":364
 *             for pre_dump in self._pre_dumpers:
 *                 obj = pre_dump(obj)
 *             data = self._dump(obj)             # <<<<<<<<<<<<<<
 * 
 *         if validate:
 */
    __pyx_t_1 = __pyx_f_7serpyco_10serializer_10Serializer__dump(__pyx_v_self, __pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_data = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "serpyco/serializer.pyx":366
 *             data = self._dump(obj)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  if (__pyx_v_validate) {

    /* "serpyco/serializer.pyx":367
 * 
 *         if validate:
 *             self._validator.validate(data, many=many)             # <<<<<<<<<<<<<<
 *             self._validator.validate_user(data, many=many)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_data)) __PYX_ERR(0, 367, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_many, __pyx_t_5) < 0) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "serpyco/serializer.pyx":368
 *         if validate:
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)             # <<<<<<<<<<<<<<
 * 
 *         if many:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate_user); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_data)) __PYX_ERR(0, 368, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_many, __pyx_t_1) < 0) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":366
 *             data = self._dump(obj)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  }

  /* "serpyco/serializer.pyx":370
 *             self._validator.validate_user(data, many=many)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             for post_dump in self._post_dumpers:
 *                 data = map(post_dump, data)
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":371
 * 
 *         if many:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = map(post_dump, data)
 *         else:
 */
    if (unlikely(__pyx_v_self->_post_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 371, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_post_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 371, __pyx_L1_error)
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_post_dump, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":372
 *         if many:
 *             for post_dump in self._post_dumpers:
 *                 data = map(post_dump, data)             # <<<<<<<<<<<<<<
 *         else:
 *             for post_dump in self._post_dumpers:
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 372, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_post_dump);
      __Pyx_GIVEREF(__pyx_v_post_dump);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_post_dump)) __PYX_ERR(0, 372, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_data);
      __Pyx_GIVEREF(__pyx_v_data);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_data)) __PYX_ERR(0, 372, __pyx_L1_error);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 372, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":371
 * 
 *         if many:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = map(post_dump, data)
 *         else:
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":370
 *             self._validator.validate_user(data, many=many)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             for post_dump in self._post_dumpers:
 *                 data = map(post_dump, data)
 */
    goto __pyx_L18;
  }

  /* "serpyco/serializer.pyx":374
 *                 data = map(post_dump, data)
 *         else:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = post_dump(data)
 * 
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->_post_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 374, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_post_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 374, __pyx_L1_error)
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 374, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_post_dump, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":375
 *         else:
 *             for post_dump in self._post_dumpers:
 *                 data = post_dump(data)             # <<<<<<<<<<<<<<
 * 
 *         return data
 */
      __Pyx_INCREF(__pyx_v_post_dump);
      __pyx_t_4 = __pyx_v_post_dump; __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_data};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 375, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":374
 *                 data = map(post_dump, data)
 *         else:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = post_dump(data)
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L18:;

  /* "serpyco/serializer.pyx":377
 *                 data = post_dump(data)
 * 
 *         return data             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_data);
  __pyx_r = __pyx_v_data;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":343
 *         return self._dataclass
 * 
 *     cpdef inline dump(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_objs);
  __Pyx_XDECREF(__pyx_v_pre_dump);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_post_dump);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_o);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_17dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_16dump, "Serializer.dump(self, obj: typing.Union[object, typing.Iterable[object]], bool validate: bool = False, bool many: bool = False)\n\n        Dumps the object(s) in the form of a dict/list only\n        composed of builtin python types.\n\n        :param validate: if True, the dumped data will be validated.\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_17dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_17dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_16dump};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_17dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  int __pyx_v_validate;
  int __pyx_v_many;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 343, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,&__pyx_n_s_validate,&__pyx_n_s_many,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 343, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validate);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 343, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_many);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 343, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 343, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_obj = values[0];
    if (values[1]) {
      __pyx_v_validate = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_validate == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 346, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":346
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,             # <<<<<<<<<<<<<<
 *         bint many: bool=False,
 *     ):
 */
      __pyx_v_validate = ((int)0);
    }
    if (values[2]) {
      __pyx_v_many = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_many == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 347, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":347
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,
 *         bint many: bool=False,             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
      __pyx_v_many = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 343, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_16dump(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_obj, __pyx_v_validate, __pyx_v_many);

  /* "serpyco/serializer.pyx":343
 *         return self._dataclass
 * 
 *     cpdef inline dump(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_16dump(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_validate, int __pyx_v_many) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.validate = __pyx_v_validate;
  __pyx_t_2.many = __pyx_v_many;
  __pyx_t_1 = __pyx_vtabptr_7serpyco_10serializer_Serializer->dump(__pyx_v_self, __pyx_v_obj, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":379
 *         return data
 * 
 *     cpdef inline load(             # <<<<<<<<<<<<<<
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 */

static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_19load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_load(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_data, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load *__pyx_optional_args) {

  /* "serpyco/serializer.pyx":382
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 *         bint validate: bool=True,             # <<<<<<<<<<<<<<
 *         bint many: bool=False,
 *     ):
 */
  int __pyx_v_validate = ((int)1);

  /* "serpyco/serializer.pyx":383
 *         data: typing.Union[dict, typing.Iterable[dict]],
 *         bint validate: bool=True,
 *         bint many: bool=False,             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
  int __pyx_v_many = ((int)0);
  PyObject *__pyx_v_datas = 0;
  PyObject *__pyx_v_objs = 0;
  PyObject *__pyx_v_obj = 0;
  PyObject *__pyx_v_pre_load = NULL;
  PyObject *__pyx_v_post_load = NULL;
  PyObject *__pyx_8genexpr2__pyx_v_d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_validate = __pyx_optional_args->validate;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_many = __pyx_optional_args->many;
      }
    }
  }
  __Pyx_INCREF(__pyx_v_data);

  /* "serpyco/serializer.pyx":396
 *         cdef object obj
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             datas = data
 *             if self._field_casters:
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":397
 * 
 *         if many:
 *             datas = data             # <<<<<<<<<<<<<<
 *             if self._field_casters:
 *                 for data in datas:
 */
    if (!(likely(PyList_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_v_data))) __PYX_ERR(0, 397, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_data;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_datas = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":398
 *         if many:
 *             datas = data
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 */
    __pyx_t_2 = (__pyx_v_self->_field_casters != Py_None)&&(PyTuple_GET_SIZE(__pyx_v_self->_field_casters) != 0);
    if (__pyx_t_2) {

      /* "serpyco/serializer.pyx":399
 *             datas = data
 *             if self._field_casters:
 *                 for data in datas:             # <<<<<<<<<<<<<<
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
      if (unlikely(__pyx_v_datas == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 399, __pyx_L1_error)
      }
      __pyx_t_1 = __pyx_v_datas; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
      for (;;) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 399, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 399, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "serpyco/serializer.pyx":400
 *             if self._field_casters:
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)             # <<<<<<<<<<<<<<
 *             for pre_load in self._pre_loaders:
 *                 datas = map(pre_load, datas)
 */
        __pyx_t_4 = __pyx_v_self->_field_casters;
        __Pyx_INCREF(__pyx_t_4);
        if (!(likely(PyDict_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_v_data))) __PYX_ERR(0, 400, __pyx_L1_error)
        __pyx_t_5 = __pyx_f_7serpyco_10serializer_cast_fields(((PyObject*)__pyx_t_4), ((PyObject*)__pyx_v_data)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 400, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "serpyco/serializer.pyx":399
 *             datas = data
 *             if self._field_casters:
 *                 for data in datas:             # <<<<<<<<<<<<<<
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "serpyco/serializer.pyx":398
 *         if many:
 *             datas = data
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 */
    }

    /* "serpyco/serializer.pyx":401
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 datas = map(pre_load, datas)
 *             data = datas
 */
    if (unlikely(__pyx_v_self->_pre_loaders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 401, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    for (;;) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 401, __pyx_L1_error)
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_load, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":402
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 *                 datas = map(pre_load, datas)             # <<<<<<<<<<<<<<
 *             data = datas
 *         else:
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 402, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_pre_load);
      __Pyx_GIVEREF(__pyx_v_pre_load);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_pre_load)) __PYX_ERR(0, 402, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_datas);
      __Pyx_GIVEREF(__pyx_v_datas);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_datas)) __PYX_ERR(0, 402, __pyx_L1_error);
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 402, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!(likely(PyList_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_6))) __PYX_ERR(0, 402, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_datas, ((PyObject*)__pyx_t_6));
      __pyx_t_6 = 0;

      /* "serpyco/serializer.pyx":401
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 datas = map(pre_load, datas)
 *             data = datas
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":403
 *             for pre_load in self._pre_loaders:
 *                 datas = map(pre_load, datas)
 *             data = datas             # <<<<<<<<<<<<<<
 *         else:
 *             if self._field_casters:
 */
    __Pyx_INCREF(__pyx_v_datas);
    __Pyx_DECREF_SET(__pyx_v_data, __pyx_v_datas);

    /* "serpyco/serializer.pyx":396
 *         cdef object obj
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             datas = data
 *             if self._field_casters:
 */
    goto __pyx_L3;
  }

  /* "serpyco/serializer.pyx":405
 *             data = datas
 *         else:
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->_field_casters != Py_None)&&(PyTuple_GET_SIZE(__pyx_v_self->_field_casters) != 0);
    if (__pyx_t_2) {

      /* "serpyco/serializer.pyx":406
 *         else:
 *             if self._field_casters:
 *                 cast_fields(self._field_casters, data)             # <<<<<<<<<<<<<<
 *             for pre_load in self._pre_loaders:
 *                 data = pre_load(data)
 */
      __pyx_t_1 = __pyx_v_self->_field_casters;
      __Pyx_INCREF(__pyx_t_1);
      if (!(likely(PyDict_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_v_data))) __PYX_ERR(0, 406, __pyx_L1_error)
      __pyx_t_5 = __pyx_f_7serpyco_10serializer_cast_fields(((PyObject*)__pyx_t_1), ((PyObject*)__pyx_v_data)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 406, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "serpyco/serializer.pyx":405
 *             data = datas
 *         else:
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
    }

    /* "serpyco/serializer.pyx":407
 *             if self._field_casters:
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 data = pre_load(data)
 * 
 */
    if (unlikely(__pyx_v_self->_pre_loaders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 407, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    for (;;) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_6); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 407, __pyx_L1_error)
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_load, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "serpyco/serializer.pyx":408
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 *                 data = pre_load(data)             # <<<<<<<<<<<<<<
 * 
 *         if validate:
 */
      __Pyx_INCREF(__pyx_v_pre_load);
      __pyx_t_4 = __pyx_v_pre_load; __pyx_t_7 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_data};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 408, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "serpyco/serializer.pyx":407
 *             if self._field_casters:
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 data = pre_load(data)
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "serpyco/serializer.pyx":410
 *                 data = pre_load(data)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  if (__pyx_v_validate) {

    /* "serpyco/serializer.pyx":411
 * 
 *         if validate:
 *             self._validator.validate(data, many=many)             # <<<<<<<<<<<<<<
 *             self._validator.validate_user(data, many=many)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_data)) __PYX_ERR(0, 411, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_many, __pyx_t_7) < 0) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":412
 *         if validate:
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)             # <<<<<<<<<<<<<<
 * 
 *         if many:
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate_user); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_data)) __PYX_ERR(0, 412, __pyx_L1_error);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_many, __pyx_t_1) < 0) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":410
 *                 data = pre_load(data)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  }

  /* "serpyco/serializer.pyx":414
 *             self._validator.validate_user(data, many=many)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":415
 * 
 *         if many:
 *             objs = [self._load(d) for d in datas]             # <<<<<<<<<<<<<<
 *             for post_load in self._post_loaders:
 *                 objs = map(post_load, objs)
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(!__pyx_v_datas)) { __Pyx_RaiseUnboundLocalError("datas"); __PYX_ERR(0, 415, __pyx_L19_error) }
      if (unlikely(__pyx_v_datas == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 415, __pyx_L19_error)
      }
      __pyx_t_6 = __pyx_v_datas; __Pyx_INCREF(__pyx_t_6); __pyx_t_3 = 0;
      for (;;) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 415, __pyx_L19_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_6, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 415, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_d, __pyx_t_4);
        __pyx_t_4 = 0;
        if (!(likely(PyDict_CheckExact(__pyx_8genexpr2__pyx_v_d))||((__pyx_8genexpr2__pyx_v_d) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_8genexpr2__pyx_v_d))) __PYX_ERR(0, 415, __pyx_L19_error)
        __pyx_t_4 = __pyx_f_7serpyco_10serializer_10Serializer__load(__pyx_v_self, ((PyObject*)__pyx_8genexpr2__pyx_v_d)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 415, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 415, __pyx_L19_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_d); __pyx_8genexpr2__pyx_v_d = 0;
      goto __pyx_L23_exit_scope;
      __pyx_L19_error:;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_d); __pyx_8genexpr2__pyx_v_d = 0;
      goto __pyx_L1_error;
      __pyx_L23_exit_scope:;
    } /* exit inner scope */
    __pyx_v_objs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":416
 *         if many:
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *                 objs = map(post_load, objs)
 *             return objs
 */
    if (unlikely(__pyx_v_self->_post_loaders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 416, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_post_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    for (;;) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_6); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 416, __pyx_L1_error)
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_post_load, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "serpyco/serializer.pyx":417
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:
 *                 objs = map(post_load, objs)             # <<<<<<<<<<<<<<
 *             return objs
 * 
 */
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_post_load);
      __Pyx_GIVEREF(__pyx_v_post_load);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_post_load)) __PYX_ERR(0, 417, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_objs);
      __Pyx_GIVEREF(__pyx_v_objs);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_objs)) __PYX_ERR(0, 417, __pyx_L1_error);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (!(likely(PyList_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_4))) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_objs, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":416
 *         if many:
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *                 objs = map(post_load, objs)
 *             return objs
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":418
 *             for post_load in self._post_loaders:
 *                 objs = map(post_load, objs)
 *             return objs             # <<<<<<<<<<<<<<
 * 
 *         obj = self._load(data)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_objs);
    __pyx_r = __pyx_v_objs;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":414
 *             self._validator.validate_user(data, many=many)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:
 */
  }

  /* "serpyco/serializer.pyx":420
 *             return objs
 * 
 *         obj = self._load(data)             # <<<<<<<<<<<<<<
 *         for post_load in self._post_loaders:
 *             obj = post_load(obj)
 */
  if (!(likely(PyDict_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_v_data))) __PYX_ERR(0, 420, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_10Serializer__load(__pyx_v_self, ((PyObject*)__pyx_v_data)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_obj = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":421
 * 
 *         obj = self._load(data)
 *         for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *             obj = post_load(obj)
 *         return obj
 */
  if (unlikely(__pyx_v_self->_post_loaders == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 421, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_post_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
  for (;;) {
    if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 421, __pyx_L1_error)
    #else
    __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_post_load, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "serpyco/serializer.pyx":422
 *         obj = self._load(data)
 *         for post_load in self._post_loaders:
 *             obj = post_load(obj)             # <<<<<<<<<<<<<<
 *         return obj
 * 
 */
    __Pyx_INCREF(__pyx_v_post_load);
    __pyx_t_6 = __pyx_v_post_load; __pyx_t_7 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_obj};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 422, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "serpyco/serializer.pyx":421
 * 
 *         obj = self._load(data)
 *         for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *             obj = post_load(obj)
 *         return obj
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":423
 *         for post_load in self._post_loaders:
 *             obj = post_load(obj)
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline str dump_json(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":379
 *         return data
 * 
 *     cpdef inline load(             # <<<<<<<<<<<<<<
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_datas);
  __Pyx_XDECREF(__pyx_v_objs);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XDECREF(__pyx_v_pre_load);
  __Pyx_XDECREF(__pyx_v_post_load);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_19load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_18load, "Serializer.load(self, data: typing.Union[dict, typing.Iterable[dict]], bool validate: bool = True, bool many: bool = False)\n\n        Loads the given data and returns object(s) of this serializer's\n        dataclass.\n\n        :param validate: if True, the data will be validated before\n            creating objects\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_19load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_19load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_18load};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_19load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data = 0;
  int __pyx_v_validate;
  int __pyx_v_many;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 379, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,&__pyx_n_s_validate,&__pyx_n_s_many,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 379, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validate);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 379, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_many);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 379, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 379, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_data = values[0];
    if (values[1]) {
      __pyx_v_validate = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_validate == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 382, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":382
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 *         bint validate: bool=True,             # <<<<<<<<<<<<<<
 *         bint many: bool=False,
 *     ):
 */
      __pyx_v_validate = ((int)1);
    }
    if (values[2]) {
      __pyx_v_many = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_many == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 383, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":383
 *         data: typing.Union[dict, typing.Iterable[dict]],
 *         bint validate: bool=True,
 *         bint many: bool=False,             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
      __pyx_v_many = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 379, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_18load(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_data, __pyx_v_validate, __pyx_v_many);

  /* "serpyco/serializer.pyx":379
 *         return data
 * 
 *     cpdef inline load(             # <<<<<<<<<<<<<<
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_18load(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_data, int __pyx_v_validate, int __pyx_v_many) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.validate = __pyx_v_validate;
  __pyx_t_2.many = __pyx_v_many;
  __pyx_t_1 = __pyx_vtabptr_7serpyco_10serializer_Serializer->load(__pyx_v_self, __pyx_v_data, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":425
 *         return obj
 * 
 *     cpdef inline str dump_json(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */

static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_21dump_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_dump_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json *__pyx_optional_args) {

  /* "serpyco/serializer.pyx":428
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,             # <<<<<<<<<<<<<<
 *         bint many: bool=False
 *     ):
 */
  int __pyx_v_validate = ((int)0);

  /* "serpyco/serializer.pyx":429
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,
 *         bint many: bool=False             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
  int __pyx_v_many = ((int)0);
  PyObject *__pyx_v_objs = 0;
  PyObject *__pyx_v_pre_dump = NULL;
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_js = NULL;
  PyObject *__pyx_v_post_dump = NULL;
  PyObject *__pyx_8genexpr3__pyx_v_o = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_json", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_validate = __pyx_optional_args->validate;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_many = __pyx_optional_args->many;
      }
    }
  }
  __Pyx_INCREF(__pyx_v_obj);

  /* "serpyco/serializer.pyx":438
 *         cdef list objs
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":439
 * 
 *         if many:
 *             objs = obj             # <<<<<<<<<<<<<<
 *             for pre_dump in self._pre_dumpers:
 *                 objs = map(pre_dump, objs)
 */
    if (!(likely(PyList_CheckExact(__pyx_v_obj))||((__pyx_v_obj) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_v_obj))) __PYX_ERR(0, 439, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_obj;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_objs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":440
 *         if many:
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 objs = map(pre_dump, objs)
 *             data = [self._dump(o) for o in objs]
 */
    if (unlikely(__pyx_v_self->_pre_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 440, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 440, __pyx_L1_error)
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 440, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_dump, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":441
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:
 *                 objs = map(pre_dump, objs)             # <<<<<<<<<<<<<<
 *             data = [self._dump(o) for o in objs]
 *         else:
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_pre_dump);
      __Pyx_GIVEREF(__pyx_v_pre_dump);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_pre_dump)) __PYX_ERR(0, 441, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_objs);
      __Pyx_GIVEREF(__pyx_v_objs);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_objs)) __PYX_ERR(0, 441, __pyx_L1_error);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!(likely(PyList_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_4))) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_objs, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":440
 *         if many:
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 objs = map(pre_dump, objs)
 *             data = [self._dump(o) for o in objs]
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":442
 *             for pre_dump in self._pre_dumpers:
 *                 objs = map(pre_dump, objs)
 *             data = [self._dump(o) for o in objs]             # <<<<<<<<<<<<<<
 *         else:
 *             for pre_dump in self._pre_dumpers:
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_v_objs == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 442, __pyx_L9_error)
      }
      __pyx_t_4 = __pyx_v_objs; __Pyx_INCREF(__pyx_t_4); __pyx_t_2 = 0;
      for (;;) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 442, __pyx_L9_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 442, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_o, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_3 = __pyx_f_7serpyco_10serializer_10Serializer__dump(__pyx_v_self, __pyx_8genexpr3__pyx_v_o); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 442, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 442, __pyx_L9_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_o); __pyx_8genexpr3__pyx_v_o = 0;
      goto __pyx_L13_exit_scope;
      __pyx_L9_error:;
      __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_o); __pyx_8genexpr3__pyx_v_o = 0;
      goto __pyx_L1_error;
      __pyx_L13_exit_scope:;
    } /* exit inner scope */
    __pyx_v_data = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":438
 *         cdef list objs
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = obj
 *             for pre_dump in self._pre_dumpers:
 */
    goto __pyx_L3;
  }

  /* "serpyco/serializer.pyx":444
 *             data = [self._dump(o) for o in objs]
 *         else:
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 obj = pre_dump(obj)
 *             data = self._dump(obj)
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->_pre_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 444, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 444, __pyx_L1_error)
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_dump, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":445
 *         else:
 *             for pre_dump in self._pre_dumpers:
 *                 obj = pre_dump(obj)             # <<<<<<<<<<<<<<
 *             data = self._dump(obj)
 * 
 */
      __Pyx_INCREF(__pyx_v_pre_dump);
      __pyx_t_3 = __pyx_v_pre_dump; __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_obj};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 445, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":444
 *             data = [self._dump(o) for o in objs]
 *         else:
 *             for pre_dump in self._pre_dumpers:             # <<<<<<<<<<<<<<
 *                 obj = pre_dump(obj)
 *             data = self._dump(obj)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":446
 *             for pre_dump in self._pre_dumpers:
 *                 obj = pre_dump(obj)
 *             data = self._dump(obj)             # <<<<<<<<<<<<<<
 * 
 *         # Needed to validate
 */
    __pyx_t_1 = __pyx_f_7serpyco_10serializer_10Serializer__dump(__pyx_v_self, __pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_data = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "serpyco/serializer.pyx":449
 * 
 *         # Needed to validate
 *         js = rapidjson.dumps(data)             # <<<<<<<<<<<<<<
 * 
 *         if validate:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_rapidjson); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dumps); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_data};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_js = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":451
 *         js = rapidjson.dumps(data)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate_json(js, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  if (__pyx_v_validate) {

    /* "serpyco/serializer.pyx":452
 * 
 *         if validate:
 *             self._validator.validate_json(js, many=many)             # <<<<<<<<<<<<<<
 *             self._validator.validate_user(data, many=many)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate_json); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_js);
    __Pyx_GIVEREF(__pyx_v_js);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_js)) __PYX_ERR(0, 452, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_many, __pyx_t_5) < 0) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "serpyco/serializer.pyx":453
 *         if validate:
 *             self._validator.validate_json(js, many=many)
 *             self._validator.validate_user(data, many=many)             # <<<<<<<<<<<<<<
 * 
 *         if not self._post_dumpers:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate_user); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_data)) __PYX_ERR(0, 453, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_many, __pyx_t_1) < 0) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":451
 *         js = rapidjson.dumps(data)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate_json(js, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  }

  /* "serpyco/serializer.pyx":455
 *             self._validator.validate_user(data, many=many)
 * 
 *         if not self._post_dumpers:             # <<<<<<<<<<<<<<
 *             return js
 * 
 */
  __pyx_t_7 = (__pyx_v_self->_post_dumpers != Py_None)&&(PyList_GET_SIZE(__pyx_v_self->_post_dumpers) != 0);
  __pyx_t_8 = (!__pyx_t_7);
  if (__pyx_t_8) {

    /* "serpyco/serializer.pyx":456
 * 
 *         if not self._post_dumpers:
 *             return js             # <<<<<<<<<<<<<<
 * 
 *         if many:
 */
    __Pyx_XDECREF(__pyx_r);
    if (!(likely(PyUnicode_CheckExact(__pyx_v_js))||((__pyx_v_js) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_v_js))) __PYX_ERR(0, 456, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_js);
    __pyx_r = ((PyObject*)__pyx_v_js);
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":455
 *             self._validator.validate_user(data, many=many)
 * 
 *         if not self._post_dumpers:             # <<<<<<<<<<<<<<
 *             return js
 * 
 */
  }

  /* "serpyco/serializer.pyx":458
 *             return js
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             for post_dump in self._post_dumpers:
 *                 data = map(post_dump, data)
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":459
 * 
 *         if many:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = map(post_dump, data)
 *         else:
 */
    if (unlikely(__pyx_v_self->_post_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 459, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_post_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 459, __pyx_L1_error)
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 459, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_post_dump, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":460
 *         if many:
 *             for post_dump in self._post_dumpers:
 *                 data = map(post_dump, data)             # <<<<<<<<<<<<<<
 *         else:
 *             for post_dump in self._post_dumpers:
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_post_dump);
      __Pyx_GIVEREF(__pyx_v_post_dump);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_post_dump)) __PYX_ERR(0, 460, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_data);
      __Pyx_GIVEREF(__pyx_v_data);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_data)) __PYX_ERR(0, 460, __pyx_L1_error);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":459
 * 
 *         if many:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = map(post_dump, data)
 *         else:
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":458
 *             return js
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             for post_dump in self._post_dumpers:
 *                 data = map(post_dump, data)
 */
    goto __pyx_L19;
  }

  /* "serpyco/serializer.pyx":462
 *                 data = map(post_dump, data)
 *         else:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = post_dump(data)
 * 
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->_post_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 462, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_post_dumpers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 462, __pyx_L1_error)
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_post_dump, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":463
 *         else:
 *             for post_dump in self._post_dumpers:
 *                 data = post_dump(data)             # <<<<<<<<<<<<<<
 * 
 *         # We need to dump in JSON again as post_dump can modify data.
 */
      __Pyx_INCREF(__pyx_v_post_dump);
      __pyx_t_3 = __pyx_v_post_dump; __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_data};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 463, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":462
 *                 data = map(post_dump, data)
 *         else:
 *             for post_dump in self._post_dumpers:             # <<<<<<<<<<<<<<
 *                 data = post_dump(data)
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L19:;

  /* "serpyco/serializer.pyx":466
 * 
 *         # We need to dump in JSON again as post_dump can modify data.
 *         return rapidjson.dumps(data)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load_json(
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_rapidjson); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dumps); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_data};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 466, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":425
 *         return obj
 * 
 *     cpdef inline str dump_json(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dump_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_objs);
  __Pyx_XDECREF(__pyx_v_pre_dump);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_js);
  __Pyx_XDECREF(__pyx_v_post_dump);
  __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_o);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_21dump_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_20dump_json, "Serializer.dump_json(self, obj: typing.Union[object, typing.Iterable[object]], bool validate: bool = False, bool many: bool = False) -> unicode\n\n        Dumps the object(s) in the form of a JSON string.\n\n        :param validate: if True, the dumped data will be validated\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_21dump_json = {"dump_json", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_21dump_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_20dump_json};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_21dump_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  int __pyx_v_validate;
  int __pyx_v_many;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 425, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,&__pyx_n_s_validate,&__pyx_n_s_many,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validate);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_many);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump_json") < 0)) __PYX_ERR(0, 425, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_obj = values[0];
    if (values[1]) {
      __pyx_v_validate = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_validate == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 428, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":428
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,             # <<<<<<<<<<<<<<
 *         bint many: bool=False
 *     ):
 */
      __pyx_v_validate = ((int)0);
    }
    if (values[2]) {
      __pyx_v_many = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_many == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 429, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":429
 *         obj: typing.Union[object, typing.Iterable[object]],
 *         bint validate: bool=False,
 *         bint many: bool=False             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
      __pyx_v_many = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump_json", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 425, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dump_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_20dump_json(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_obj, __pyx_v_validate, __pyx_v_many);

  /* "serpyco/serializer.pyx":425
 *         return obj
 * 
 *     cpdef inline str dump_json(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_20dump_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_validate, int __pyx_v_many) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_json", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.validate = __pyx_v_validate;
  __pyx_t_2.many = __pyx_v_many;
  __pyx_t_1 = __pyx_vtabptr_7serpyco_10serializer_Serializer->dump_json(__pyx_v_self, __pyx_v_obj, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.dump_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":468
 *         return rapidjson.dumps(data)
 * 
 *     cpdef inline load_json(             # <<<<<<<<<<<<<<
 *         self,
 *         str js,
 */

static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_23load_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer_load_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_js, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json *__pyx_optional_args) {

  /* "serpyco/serializer.pyx":471
 *         self,
 *         str js,
 *         bint validate: bool=True,             # <<<<<<<<<<<<<<
 *         bint many: bool=False
 *     ):
 */
  int __pyx_v_validate = ((int)1);

  /* "serpyco/serializer.pyx":472
 *         str js,
 *         bint validate: bool=True,
 *         bint many: bool=False             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
  int __pyx_v_many = ((int)0);
  PyObject *__pyx_v_datas = 0;
  PyObject *__pyx_v_objs = 0;
  PyObject *__pyx_v_obj = 0;
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_pre_load = NULL;
  PyObject *__pyx_v_post_load = NULL;
  PyObject *__pyx_8genexpr4__pyx_v_d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load_json", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_validate = __pyx_optional_args->validate;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_many = __pyx_optional_args->many;
      }
    }
  }

  /* "serpyco/serializer.pyx":485
 *         cdef object obj
 * 
 *         data = rapidjson.loads(js)             # <<<<<<<<<<<<<<
 * 
 *         if many:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_rapidjson); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_loads); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_js};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_data = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":487
 *         data = rapidjson.loads(js)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             datas = data
 *             if self._field_casters:
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":488
 * 
 *         if many:
 *             datas = data             # <<<<<<<<<<<<<<
 *             if self._field_casters:
 *                 for data in datas:
 */
    if (!(likely(PyList_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_v_data))) __PYX_ERR(0, 488, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_data;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_datas = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":489
 *         if many:
 *             datas = data
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 */
    __pyx_t_5 = (__pyx_v_self->_field_casters != Py_None)&&(PyTuple_GET_SIZE(__pyx_v_self->_field_casters) != 0);
    if (__pyx_t_5) {

      /* "serpyco/serializer.pyx":490
 *             datas = data
 *             if self._field_casters:
 *                 for data in datas:             # <<<<<<<<<<<<<<
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
      if (unlikely(__pyx_v_datas == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 490, __pyx_L1_error)
      }
      __pyx_t_1 = __pyx_v_datas; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
      for (;;) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 490, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 490, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "serpyco/serializer.pyx":491
 *             if self._field_casters:
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)             # <<<<<<<<<<<<<<
 *             for pre_load in self._pre_loaders:
 *                 datas = map(pre_load, datas)
 */
        __pyx_t_3 = __pyx_v_self->_field_casters;
        __Pyx_INCREF(__pyx_t_3);
        if (!(likely(PyDict_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_v_data))) __PYX_ERR(0, 491, __pyx_L1_error)
        __pyx_t_4 = __pyx_f_7serpyco_10serializer_cast_fields(((PyObject*)__pyx_t_3), ((PyObject*)__pyx_v_data)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 491, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "serpyco/serializer.pyx":490
 *             datas = data
 *             if self._field_casters:
 *                 for data in datas:             # <<<<<<<<<<<<<<
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "serpyco/serializer.pyx":489
 *         if many:
 *             datas = data
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 */
    }

    /* "serpyco/serializer.pyx":492
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 datas = map(pre_load, datas)
 *             data = datas
 */
    if (unlikely(__pyx_v_self->_pre_loaders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 492, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
    for (;;) {
      if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 492, __pyx_L1_error)
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 492, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_load, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":493
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 *                 datas = map(pre_load, datas)             # <<<<<<<<<<<<<<
 *             data = datas
 *         else:
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_pre_load);
      __Pyx_GIVEREF(__pyx_v_pre_load);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_pre_load)) __PYX_ERR(0, 493, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_datas);
      __Pyx_GIVEREF(__pyx_v_datas);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_datas)) __PYX_ERR(0, 493, __pyx_L1_error);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_2))) __PYX_ERR(0, 493, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_datas, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "serpyco/serializer.pyx":492
 *                 for data in datas:
 *                     cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 datas = map(pre_load, datas)
 *             data = datas
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":494
 *             for pre_load in self._pre_loaders:
 *                 datas = map(pre_load, datas)
 *             data = datas             # <<<<<<<<<<<<<<
 *         else:
 *             if self._field_casters:
 */
    __Pyx_INCREF(__pyx_v_datas);
    __Pyx_DECREF_SET(__pyx_v_data, __pyx_v_datas);

    /* "serpyco/serializer.pyx":487
 *         data = rapidjson.loads(js)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             datas = data
 *             if self._field_casters:
 */
    goto __pyx_L3;
  }

  /* "serpyco/serializer.pyx":496
 *             data = datas
 *         else:
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
  /*else*/ {
    __pyx_t_5 = (__pyx_v_self->_field_casters != Py_None)&&(PyTuple_GET_SIZE(__pyx_v_self->_field_casters) != 0);
    if (__pyx_t_5) {

      /* "serpyco/serializer.pyx":497
 *         else:
 *             if self._field_casters:
 *                 cast_fields(self._field_casters, data)             # <<<<<<<<<<<<<<
 *             for pre_load in self._pre_loaders:
 *                 data = pre_load(data)
 */
      __pyx_t_1 = __pyx_v_self->_field_casters;
      __Pyx_INCREF(__pyx_t_1);
      if (!(likely(PyDict_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_v_data))) __PYX_ERR(0, 497, __pyx_L1_error)
      __pyx_t_4 = __pyx_f_7serpyco_10serializer_cast_fields(((PyObject*)__pyx_t_1), ((PyObject*)__pyx_v_data)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 497, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "serpyco/serializer.pyx":496
 *             data = datas
 *         else:
 *             if self._field_casters:             # <<<<<<<<<<<<<<
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 */
    }

    /* "serpyco/serializer.pyx":498
 *             if self._field_casters:
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 data = pre_load(data)
 * 
 */
    if (unlikely(__pyx_v_self->_pre_loaders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 498, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_pre_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
    for (;;) {
      if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 498, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 498, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_pre_load, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "serpyco/serializer.pyx":499
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:
 *                 data = pre_load(data)             # <<<<<<<<<<<<<<
 * 
 *         if validate:
 */
      __Pyx_INCREF(__pyx_v_pre_load);
      __pyx_t_3 = __pyx_v_pre_load; __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_data};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 499, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "serpyco/serializer.pyx":498
 *             if self._field_casters:
 *                 cast_fields(self._field_casters, data)
 *             for pre_load in self._pre_loaders:             # <<<<<<<<<<<<<<
 *                 data = pre_load(data)
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "serpyco/serializer.pyx":501
 *                 data = pre_load(data)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  if (__pyx_v_validate) {

    /* "serpyco/serializer.pyx":502
 * 
 *         if validate:
 *             self._validator.validate(data, many=many)             # <<<<<<<<<<<<<<
 *             self._validator.validate_user(data, many=many)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_data)) __PYX_ERR(0, 502, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_many, __pyx_t_7) < 0) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":503
 *         if validate:
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)             # <<<<<<<<<<<<<<
 * 
 *         if many:
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_validator, __pyx_n_s_validate_user); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_data)) __PYX_ERR(0, 503, __pyx_L1_error);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_many); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_many, __pyx_t_1) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":501
 *                 data = pre_load(data)
 * 
 *         if validate:             # <<<<<<<<<<<<<<
 *             self._validator.validate(data, many=many)
 *             self._validator.validate_user(data, many=many)
 */
  }

  /* "serpyco/serializer.pyx":505
 *             self._validator.validate_user(data, many=many)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:
 */
  if (__pyx_v_many) {

    /* "serpyco/serializer.pyx":506
 * 
 *         if many:
 *             objs = [self._load(d) for d in datas]             # <<<<<<<<<<<<<<
 *             for post_load in self._post_loaders:
 *                 objs = map(post_load, objs)
 */
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 506, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(!__pyx_v_datas)) { __Pyx_RaiseUnboundLocalError("datas"); __PYX_ERR(0, 506, __pyx_L19_error) }
      if (unlikely(__pyx_v_datas == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 506, __pyx_L19_error)
      }
      __pyx_t_2 = __pyx_v_datas; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
      for (;;) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 506, __pyx_L19_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_XDECREF_SET(__pyx_8genexpr4__pyx_v_d, __pyx_t_3);
        __pyx_t_3 = 0;
        if (!(likely(PyDict_CheckExact(__pyx_8genexpr4__pyx_v_d))||((__pyx_8genexpr4__pyx_v_d) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_8genexpr4__pyx_v_d))) __PYX_ERR(0, 506, __pyx_L19_error)
        __pyx_t_3 = __pyx_f_7serpyco_10serializer_10Serializer__load(__pyx_v_self, ((PyObject*)__pyx_8genexpr4__pyx_v_d)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 506, __pyx_L19_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_d); __pyx_8genexpr4__pyx_v_d = 0;
      goto __pyx_L23_exit_scope;
      __pyx_L19_error:;
      __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_d); __pyx_8genexpr4__pyx_v_d = 0;
      goto __pyx_L1_error;
      __pyx_L23_exit_scope:;
    } /* exit inner scope */
    __pyx_v_objs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":507
 *         if many:
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *                 objs = map(post_load, objs)
 *             return objs
 */
    if (unlikely(__pyx_v_self->_post_loaders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 507, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_post_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
    for (;;) {
      if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 507, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_post_load, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "serpyco/serializer.pyx":508
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:
 *                 objs = map(post_load, objs)             # <<<<<<<<<<<<<<
 *             return objs
 *         obj = self._load(data)
 */
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_post_load);
      __Pyx_GIVEREF(__pyx_v_post_load);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_post_load)) __PYX_ERR(0, 508, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_objs);
      __Pyx_GIVEREF(__pyx_v_objs);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_objs)) __PYX_ERR(0, 508, __pyx_L1_error);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyList_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_3))) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_objs, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":507
 *         if many:
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *                 objs = map(post_load, objs)
 *             return objs
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":509
 *             for post_load in self._post_loaders:
 *                 objs = map(post_load, objs)
 *             return objs             # <<<<<<<<<<<<<<
 *         obj = self._load(data)
 *         for post_load in self._post_loaders:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_objs);
    __pyx_r = __pyx_v_objs;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":505
 *             self._validator.validate_user(data, many=many)
 * 
 *         if many:             # <<<<<<<<<<<<<<
 *             objs = [self._load(d) for d in datas]
 *             for post_load in self._post_loaders:
 */
  }

  /* "serpyco/serializer.pyx":510
 *                 objs = map(post_load, objs)
 *             return objs
 *         obj = self._load(data)             # <<<<<<<<<<<<<<
 *         for post_load in self._post_loaders:
 *             obj = post_load(obj)
 */
  if (!(likely(PyDict_CheckExact(__pyx_v_data))||((__pyx_v_data) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_v_data))) __PYX_ERR(0, 510, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_10Serializer__load(__pyx_v_self, ((PyObject*)__pyx_v_data)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_obj = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":511
 *             return objs
 *         obj = self._load(data)
 *         for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *             obj = post_load(obj)
 *         return obj
 */
  if (unlikely(__pyx_v_self->_post_loaders == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 511, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_post_loaders; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
  for (;;) {
    if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 511, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_post_load, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":512
 *         obj = self._load(data)
 *         for post_load in self._post_loaders:
 *             obj = post_load(obj)             # <<<<<<<<<<<<<<
 *         return obj
 * 
 */
    __Pyx_INCREF(__pyx_v_post_load);
    __pyx_t_2 = __pyx_v_post_load; __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_obj};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":511
 *             return objs
 *         obj = self._load(data)
 *         for post_load in self._post_loaders:             # <<<<<<<<<<<<<<
 *             obj = post_load(obj)
 *         return obj
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":513
 *         for post_load in self._post_loaders:
 *             obj = post_load(obj)
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     cdef inline dict _dump(self, object obj):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":468
 *         return rapidjson.dumps(data)
 * 
 *     cpdef inline load_json(             # <<<<<<<<<<<<<<
 *         self,
 *         str js,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.load_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_datas);
  __Pyx_XDECREF(__pyx_v_objs);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_pre_load);
  __Pyx_XDECREF(__pyx_v_post_load);
  __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_23load_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_22load_json, "Serializer.load_json(self, unicode js, bool validate: bool = True, bool many: bool = False)\n\n        Loads the given JSON string and returns object(s) of this serializer's\n        dataclass.\n\n        :param validate: if True, the JSON will be validated before\n            creating objects\n        ");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_23load_json = {"load_json", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_23load_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_22load_json};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_23load_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_js = 0;
  int __pyx_v_validate;
  int __pyx_v_many;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 468, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_js,&__pyx_n_s_validate,&__pyx_n_s_many,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_js)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 468, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_validate);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 468, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_many);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 468, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load_json") < 0)) __PYX_ERR(0, 468, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_js = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_validate = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_validate == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 471, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":471
 *         self,
 *         str js,
 *         bint validate: bool=True,             # <<<<<<<<<<<<<<
 *         bint many: bool=False
 *     ):
 */
      __pyx_v_validate = ((int)1);
    }
    if (values[2]) {
      __pyx_v_many = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_many == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 472, __pyx_L3_error)
    } else {

      /* "serpyco/serializer.pyx":472
 *         str js,
 *         bint validate: bool=True,
 *         bint many: bool=False             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
      __pyx_v_many = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load_json", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 468, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.load_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_js), (&PyUnicode_Type), 1, "js", 1))) __PYX_ERR(0, 470, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_22load_json(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_js, __pyx_v_validate, __pyx_v_many);

  /* "serpyco/serializer.pyx":468
 *         return rapidjson.dumps(data)
 * 
 *     cpdef inline load_json(             # <<<<<<<<<<<<<<
 *         self,
 *         str js,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_22load_json(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_js, int __pyx_v_validate, int __pyx_v_many) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load_json", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.validate = __pyx_v_validate;
  __pyx_t_2.many = __pyx_v_many;
  __pyx_t_1 = __pyx_vtabptr_7serpyco_10serializer_Serializer->load_json(__pyx_v_self, __pyx_v_js, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.Serializer.load_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":515
 *         return obj
 * 
 *     cdef inline dict _dump(self, object obj):             # <<<<<<<<<<<<<<
 *         cdef SerializerField sfield
 *         cdef object encoded
 */

static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer__dump(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_obj) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield = 0;
  PyObject *__pyx_v_encoded = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_dump", 0);

  /* "serpyco/serializer.pyx":518
 *         cdef SerializerField sfield
 *         cdef object encoded
 *         cdef dict data = {}             # <<<<<<<<<<<<<<
 *         for sfield in self._fields:
 *             if sfield.getter is not None:
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_data = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":519
 *         cdef object encoded
 *         cdef dict data = {}
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             if sfield.getter is not None:
 *                 encoded = sfield.getter(obj)
 */
  if (unlikely(__pyx_v_self->_fields == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 519, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_fields; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 519, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_7serpyco_10serializer_SerializerField))))) __PYX_ERR(0, 519, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_sfield, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":520
 *         cdef dict data = {}
 *         for sfield in self._fields:
 *             if sfield.getter is not None:             # <<<<<<<<<<<<<<
 *                 encoded = sfield.getter(obj)
 *             else:
 */
    __pyx_t_4 = (__pyx_v_sfield->getter != Py_None);
    if (__pyx_t_4) {

      /* "serpyco/serializer.pyx":521
 *         for sfield in self._fields:
 *             if sfield.getter is not None:
 *                 encoded = sfield.getter(obj)             # <<<<<<<<<<<<<<
 *             else:
 *                 encoded = getattr(obj, sfield.field_name)
 */
      __Pyx_INCREF(__pyx_v_sfield->getter);
      __pyx_t_5 = __pyx_v_sfield->getter; __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_obj};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 521, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_encoded, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":520
 *         cdef dict data = {}
 *         for sfield in self._fields:
 *             if sfield.getter is not None:             # <<<<<<<<<<<<<<
 *                 encoded = sfield.getter(obj)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "serpyco/serializer.pyx":523
 *                 encoded = sfield.getter(obj)
 *             else:
 *                 encoded = getattr(obj, sfield.field_name)             # <<<<<<<<<<<<<<
 *             if sfield.encoder is not None and encoded is not None:
 *                 encoded = sfield.encoder.dump(encoded)
 */
    /*else*/ {
      __pyx_t_3 = __pyx_v_sfield->field_name;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_GetAttr(__pyx_v_obj, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_encoded, __pyx_t_5);
      __pyx_t_5 = 0;
    }
    __pyx_L5:;

    /* "serpyco/serializer.pyx":524
 *             else:
 *                 encoded = getattr(obj, sfield.field_name)
 *             if sfield.encoder is not None and encoded is not None:             # <<<<<<<<<<<<<<
 *                 encoded = sfield.encoder.dump(encoded)
 *             data[sfield.dict_key] = encoded
 */
    __pyx_t_8 = (((PyObject *)__pyx_v_sfield->encoder) != Py_None);
    if (__pyx_t_8) {
    } else {
      __pyx_t_4 = __pyx_t_8;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_encoded != Py_None);
    __pyx_t_4 = __pyx_t_8;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_4) {

      /* "serpyco/serializer.pyx":525
 *                 encoded = getattr(obj, sfield.field_name)
 *             if sfield.encoder is not None and encoded is not None:
 *                 encoded = sfield.encoder.dump(encoded)             # <<<<<<<<<<<<<<
 *             data[sfield.dict_key] = encoded
 *         return data
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_sfield->encoder->__pyx_vtab)->dump(__pyx_v_sfield->encoder, __pyx_v_encoded, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_encoded, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "serpyco/serializer.pyx":524
 *             else:
 *                 encoded = getattr(obj, sfield.field_name)
 *             if sfield.encoder is not None and encoded is not None:             # <<<<<<<<<<<<<<
 *                 encoded = sfield.encoder.dump(encoded)
 *             data[sfield.dict_key] = encoded
 */
    }

    /* "serpyco/serializer.pyx":526
 *             if sfield.encoder is not None and encoded is not None:
 *                 encoded = sfield.encoder.dump(encoded)
 *             data[sfield.dict_key] = encoded             # <<<<<<<<<<<<<<
 *         return data
 * 
 */
    if (unlikely((PyDict_SetItem(__pyx_v_data, __pyx_v_sfield->dict_key, __pyx_v_encoded) < 0))) __PYX_ERR(0, 526, __pyx_L1_error)

    /* "serpyco/serializer.pyx":519
 *         cdef object encoded
 *         cdef dict data = {}
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             if sfield.getter is not None:
 *                 encoded = sfield.getter(obj)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":527
 *                 encoded = sfield.encoder.dump(encoded)
 *             data[sfield.dict_key] = encoded
 *         return data             # <<<<<<<<<<<<<<
 * 
 *     cdef inline object _load(self, dict data):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_data);
  __pyx_r = __pyx_v_data;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":515
 *         return obj
 * 
 *     cdef inline dict _dump(self, object obj):             # <<<<<<<<<<<<<<
 *         cdef SerializerField sfield
 *         cdef object encoded
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("serpyco.serializer.Serializer._dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sfield);
  __Pyx_XDECREF(__pyx_v_encoded);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":529
 *         return data
 * 
 *     cdef inline object _load(self, dict data):             # <<<<<<<<<<<<<<
 *         cdef SerializerField sfield
 *         cdef object decoded
 */

static CYTHON_INLINE PyObject *__pyx_f_7serpyco_10serializer_10Serializer__load(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_data) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield = 0;
  PyObject *__pyx_v_decoded = 0;
  PyObject *__pyx_v_obj = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_UCS4 __pyx_t_16;
  int __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_load", 0);

  /* "serpyco/serializer.pyx":533
 *         cdef object decoded
 *         cdef object obj
 *         obj = new_object(self._load_as_type)             # <<<<<<<<<<<<<<
 *         for sfield in self._fields:
 *             try:
 */
  __Pyx_INCREF(__pyx_v_7serpyco_10serializer_new_object);
  __pyx_t_2 = __pyx_v_7serpyco_10serializer_new_object; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self->_load_as_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_obj = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":534
 *         cdef object obj
 *         obj = new_object(self._load_as_type)
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             try:
 *                 decoded = data[sfield.dict_key]
 */
  if (unlikely(__pyx_v_self->_fields == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 534, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_fields; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
  for (;;) {
    if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 534, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_7serpyco_10serializer_SerializerField))))) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_sfield, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "serpyco/serializer.pyx":535
 *         obj = new_object(self._load_as_type)
 *         for sfield in self._fields:
 *             try:             # <<<<<<<<<<<<<<
 *                 decoded = data[sfield.dict_key]
 *                 if sfield.encoder is not None and decoded is not None:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "serpyco/serializer.pyx":536
 *         for sfield in self._fields:
 *             try:
 *                 decoded = data[sfield.dict_key]             # <<<<<<<<<<<<<<
 *                 if sfield.encoder is not None and decoded is not None:
 *                     decoded = sfield.encoder.load(decoded)
 */
        if (unlikely(__pyx_v_data == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 536, __pyx_L5_error)
        }
        __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_data, __pyx_v_sfield->dict_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 536, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_decoded, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "serpyco/serializer.pyx":537
 *             try:
 *                 decoded = data[sfield.dict_key]
 *                 if sfield.encoder is not None and decoded is not None:             # <<<<<<<<<<<<<<
 *                     decoded = sfield.encoder.load(decoded)
 *             except KeyError:
 */
        __pyx_t_10 = (((PyObject *)__pyx_v_sfield->encoder) != Py_None);
        if (__pyx_t_10) {
        } else {
          __pyx_t_9 = __pyx_t_10;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_10 = (__pyx_v_decoded != Py_None);
        __pyx_t_9 = __pyx_t_10;
        __pyx_L14_bool_binop_done:;
        if (__pyx_t_9) {

          /* "serpyco/serializer.pyx":538
 *                 decoded = data[sfield.dict_key]
 *                 if sfield.encoder is not None and decoded is not None:
 *                     decoded = sfield.encoder.load(decoded)             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 if sfield.default is not dataclasses_MISSING:
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_sfield->encoder->__pyx_vtab)->load(__pyx_v_sfield->encoder, __pyx_v_decoded, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 538, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF_SET(__pyx_v_decoded, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "serpyco/serializer.pyx":537
 *             try:
 *                 decoded = data[sfield.dict_key]
 *                 if sfield.encoder is not None and decoded is not None:             # <<<<<<<<<<<<<<
 *                     decoded = sfield.encoder.load(decoded)
 *             except KeyError:
 */
        }

        /* "serpyco/serializer.pyx":535
 *         obj = new_object(self._load_as_type)
 *         for sfield in self._fields:
 *             try:             # <<<<<<<<<<<<<<
 *                 decoded = data[sfield.dict_key]
 *                 if sfield.encoder is not None and decoded is not None:
 */
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":539
 *                 if sfield.encoder is not None and decoded is not None:
 *                     decoded = sfield.encoder.load(decoded)
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 if sfield.default is not dataclasses_MISSING:
 *                     decoded = sfield.default
 */
      __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_4) {
        __Pyx_AddTraceback("serpyco.serializer.Serializer._load", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_11) < 0) __PYX_ERR(0, 539, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_11);

        /* "serpyco/serializer.pyx":540
 *                     decoded = sfield.encoder.load(decoded)
 *             except KeyError:
 *                 if sfield.default is not dataclasses_MISSING:             # <<<<<<<<<<<<<<
 *                     decoded = sfield.default
 *                 elif sfield.default_factory is not dataclasses_MISSING:
 */
        __pyx_t_9 = (__pyx_v_sfield->__pyx_default != __pyx_v_7serpyco_10serializer_dataclasses_MISSING);
        if (__pyx_t_9) {

          /* "serpyco/serializer.pyx":541
 *             except KeyError:
 *                 if sfield.default is not dataclasses_MISSING:
 *                     decoded = sfield.default             # <<<<<<<<<<<<<<
 *                 elif sfield.default_factory is not dataclasses_MISSING:
 *                     decoded = sfield.default_factory()
 */
          __pyx_t_12 = __pyx_v_sfield->__pyx_default;
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_XDECREF_SET(__pyx_v_decoded, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "serpyco/serializer.pyx":540
 *                     decoded = sfield.encoder.load(decoded)
 *             except KeyError:
 *                 if sfield.default is not dataclasses_MISSING:             # <<<<<<<<<<<<<<
 *                     decoded = sfield.default
 *                 elif sfield.default_factory is not dataclasses_MISSING:
 */
          goto __pyx_L18;
        }

        /* "serpyco/serializer.pyx":542
 *                 if sfield.default is not dataclasses_MISSING:
 *                     decoded = sfield.default
 *                 elif sfield.default_factory is not dataclasses_MISSING:             # <<<<<<<<<<<<<<
 *                     decoded = sfield.default_factory()
 *                 else:
 */
        __pyx_t_9 = (__pyx_v_sfield->default_factory != __pyx_v_7serpyco_10serializer_dataclasses_MISSING);
        if (likely(__pyx_t_9)) {

          /* "serpyco/serializer.pyx":543
 *                     decoded = sfield.default
 *                 elif sfield.default_factory is not dataclasses_MISSING:
 *                     decoded = sfield.default_factory()             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise TypeError(
 */
          __Pyx_INCREF(__pyx_v_sfield->default_factory);
          __pyx_t_13 = __pyx_v_sfield->default_factory; __pyx_t_14 = NULL;
          __pyx_t_4 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
              __pyx_t_4 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[1] = {__pyx_t_14, };
            __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 543, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
          __Pyx_XDECREF_SET(__pyx_v_decoded, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "serpyco/serializer.pyx":542
 *                 if sfield.default is not dataclasses_MISSING:
 *                     decoded = sfield.default
 *                 elif sfield.default_factory is not dataclasses_MISSING:             # <<<<<<<<<<<<<<
 *                     decoded = sfield.default_factory()
 *                 else:
 */
          goto __pyx_L18;
        }

        /* "serpyco/serializer.pyx":545
 *                     decoded = sfield.default_factory()
 *                 else:
 *                     raise TypeError(             # <<<<<<<<<<<<<<
 *                         "data dictionary is missing "
 *                         f"required parameter '{sfield.field_name}' "
 */
        /*else*/ {

          /* "serpyco/serializer.pyx":546
 *                 else:
 *                     raise TypeError(
 *                         "data dictionary is missing "             # <<<<<<<<<<<<<<
 *                         f"required parameter '{sfield.field_name}' "
 *                         f"for class '{self._dataclass.__qualname__}'"
 */
          __pyx_t_12 = PyTuple_New(5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 546, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_15 = 0;
          __pyx_t_16 = 127;
          __Pyx_INCREF(__pyx_kp_u_data_dictionary_is_missing_requi);
          __pyx_t_15 += 47;
          __Pyx_GIVEREF(__pyx_kp_u_data_dictionary_is_missing_requi);
          PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_kp_u_data_dictionary_is_missing_requi);

          /* "serpyco/serializer.pyx":547
 *                     raise TypeError(
 *                         "data dictionary is missing "
 *                         f"required parameter '{sfield.field_name}' "             # <<<<<<<<<<<<<<
 *                         f"for class '{self._dataclass.__qualname__}'"
 *                     )
 */
          __pyx_t_13 = __Pyx_PyUnicode_Unicode(__pyx_v_sfield->field_name); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 547, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) : __pyx_t_16;
          __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_13);
          __pyx_t_13 = 0;
          __Pyx_INCREF(__pyx_kp_u_for_class);
          __pyx_t_15 += 13;
          __Pyx_GIVEREF(__pyx_kp_u_for_class);
          PyTuple_SET_ITEM(__pyx_t_12, 2, __pyx_kp_u_for_class);

          /* "serpyco/serializer.pyx":548
 *                         "data dictionary is missing "
 *                         f"required parameter '{sfield.field_name}' "
 *                         f"for class '{self._dataclass.__qualname__}'"             # <<<<<<<<<<<<<<
 *                     )
 *             # Cannot use setattr() on frozen dataclasses
 */
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass, __pyx_n_s_qualname); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 548, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __Pyx_PyObject_FormatSimple(__pyx_t_13, __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 548, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_16;
          __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_12, 3, __pyx_t_14);
          __pyx_t_14 = 0;
          __Pyx_INCREF(__pyx_kp_u__3);
          __pyx_t_15 += 1;
          __Pyx_GIVEREF(__pyx_kp_u__3);
          PyTuple_SET_ITEM(__pyx_t_12, 4, __pyx_kp_u__3);

          /* "serpyco/serializer.pyx":546
 *                 else:
 *                     raise TypeError(
 *                         "data dictionary is missing "             # <<<<<<<<<<<<<<
 *                         f"required parameter '{sfield.field_name}' "
 *                         f"for class '{self._dataclass.__qualname__}'"
 */
          __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_12, 5, __pyx_t_15, __pyx_t_16); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 546, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "serpyco/serializer.pyx":545
 *                     decoded = sfield.default_factory()
 *                 else:
 *                     raise TypeError(             # <<<<<<<<<<<<<<
 *                         "data dictionary is missing "
 *                         f"required parameter '{sfield.field_name}' "
 */
          __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_14); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 545, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_Raise(__pyx_t_12, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __PYX_ERR(0, 545, __pyx_L7_except_error)
        }
        __pyx_L18:;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;

      /* "serpyco/serializer.pyx":535
 *         obj = new_object(self._load_as_type)
 *         for sfield in self._fields:
 *             try:             # <<<<<<<<<<<<<<
 *                 decoded = data[sfield.dict_key]
 *                 if sfield.encoder is not None and decoded is not None:
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L12_try_end:;
    }

    /* "serpyco/serializer.pyx":551
 *                     )
 *             # Cannot use setattr() on frozen dataclasses
 *             if not self._frozen_dataclass:             # <<<<<<<<<<<<<<
 *                 setattr(obj, sfield.field_name, decoded)
 *             else:
 */
    __pyx_t_9 = (!__pyx_v_self->_frozen_dataclass);
    if (__pyx_t_9) {

      /* "serpyco/serializer.pyx":552
 *             # Cannot use setattr() on frozen dataclasses
 *             if not self._frozen_dataclass:
 *                 setattr(obj, sfield.field_name, decoded)             # <<<<<<<<<<<<<<
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 */
      __pyx_t_11 = __pyx_v_sfield->field_name;
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_17 = PyObject_SetAttr(__pyx_v_obj, __pyx_t_11, __pyx_v_decoded); if (unlikely(__pyx_t_17 == ((int)-1))) __PYX_ERR(0, 552, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "serpyco/serializer.pyx":551
 *                     )
 *             # Cannot use setattr() on frozen dataclasses
 *             if not self._frozen_dataclass:             # <<<<<<<<<<<<<<
 *                 setattr(obj, sfield.field_name, decoded)
 *             else:
 */
      goto __pyx_L19;
    }

    /* "serpyco/serializer.pyx":554
 *                 setattr(obj, sfield.field_name, decoded)
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)             # <<<<<<<<<<<<<<
 *         for sfield in self._excluded_fields:
 *             if sfield.default is not dataclasses.MISSING:
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_setattr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_obj, __pyx_v_sfield->field_name, __pyx_v_decoded};
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 554, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __pyx_L19:;

    /* "serpyco/serializer.pyx":534
 *         cdef object obj
 *         obj = new_object(self._load_as_type)
 *         for sfield in self._fields:             # <<<<<<<<<<<<<<
 *             try:
 *                 decoded = data[sfield.dict_key]
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":555
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 *         for sfield in self._excluded_fields:             # <<<<<<<<<<<<<<
 *             if sfield.default is not dataclasses.MISSING:
 *                 decoded = sfield.default
 */
  if (unlikely(__pyx_v_self->_excluded_fields == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 555, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_excluded_fields; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
  for (;;) {
    if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_11 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_11); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 555, __pyx_L1_error)
    #else
    __pyx_t_11 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    #endif
    if (!(likely(((__pyx_t_11) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_11, __pyx_ptype_7serpyco_10serializer_SerializerField))))) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_sfield, ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_t_11));
    __pyx_t_11 = 0;

    /* "serpyco/serializer.pyx":556
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 *         for sfield in self._excluded_fields:
 *             if sfield.default is not dataclasses.MISSING:             # <<<<<<<<<<<<<<
 *                 decoded = sfield.default
 *             elif sfield.default_factory is not dataclasses.MISSING:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_dataclasses); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_MISSING); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_9 = (__pyx_v_sfield->__pyx_default != __pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {

      /* "serpyco/serializer.pyx":557
 *         for sfield in self._excluded_fields:
 *             if sfield.default is not dataclasses.MISSING:
 *                 decoded = sfield.default             # <<<<<<<<<<<<<<
 *             elif sfield.default_factory is not dataclasses.MISSING:
 *                 decoded = sfield.default_factory()
 */
      __pyx_t_3 = __pyx_v_sfield->__pyx_default;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_decoded, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":556
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 *         for sfield in self._excluded_fields:
 *             if sfield.default is not dataclasses.MISSING:             # <<<<<<<<<<<<<<
 *                 decoded = sfield.default
 *             elif sfield.default_factory is not dataclasses.MISSING:
 */
      goto __pyx_L23;
    }

    /* "serpyco/serializer.pyx":558
 *             if sfield.default is not dataclasses.MISSING:
 *                 decoded = sfield.default
 *             elif sfield.default_factory is not dataclasses.MISSING:             # <<<<<<<<<<<<<<
 *                 decoded = sfield.default_factory()
 *             else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_dataclasses); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MISSING); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 558, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = (__pyx_v_sfield->default_factory != __pyx_t_11);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (likely(__pyx_t_9)) {

      /* "serpyco/serializer.pyx":559
 *                 decoded = sfield.default
 *             elif sfield.default_factory is not dataclasses.MISSING:
 *                 decoded = sfield.default_factory()             # <<<<<<<<<<<<<<
 *             else:
 *                 raise TypeError(
 */
      __Pyx_INCREF(__pyx_v_sfield->default_factory);
      __pyx_t_3 = __pyx_v_sfield->default_factory; __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[1] = {__pyx_t_2, };
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 559, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_decoded, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "serpyco/serializer.pyx":558
 *             if sfield.default is not dataclasses.MISSING:
 *                 decoded = sfield.default
 *             elif sfield.default_factory is not dataclasses.MISSING:             # <<<<<<<<<<<<<<
 *                 decoded = sfield.default_factory()
 *             else:
 */
      goto __pyx_L23;
    }

    /* "serpyco/serializer.pyx":561
 *                 decoded = sfield.default_factory()
 *             else:
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     f"Cannot create '{self._dataclass.__qualname__}' as "
 *                     f"'{sfield.field_name}' is excluded but has no "
 */
    /*else*/ {

      /* "serpyco/serializer.pyx":562
 *             else:
 *                 raise TypeError(
 *                     f"Cannot create '{self._dataclass.__qualname__}' as "             # <<<<<<<<<<<<<<
 *                     f"'{sfield.field_name}' is excluded but has no "
 *                     "default value/factory"
 */
      __pyx_t_11 = PyTuple_New(5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_15 = 0;
      __pyx_t_16 = 127;
      __Pyx_INCREF(__pyx_kp_u_Cannot_create);
      __pyx_t_15 += 15;
      __Pyx_GIVEREF(__pyx_kp_u_Cannot_create);
      PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_kp_u_Cannot_create);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass, __pyx_n_s_qualname); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_16;
      __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_INCREF(__pyx_kp_u_as);
      __pyx_t_15 += 6;
      __Pyx_GIVEREF(__pyx_kp_u_as);
      PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_kp_u_as);

      /* "serpyco/serializer.pyx":563
 *                 raise TypeError(
 *                     f"Cannot create '{self._dataclass.__qualname__}' as "
 *                     f"'{sfield.field_name}' is excluded but has no "             # <<<<<<<<<<<<<<
 *                     "default value/factory"
 *                 )
 */
      __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_sfield->field_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 563, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_16;
      __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_INCREF(__pyx_kp_u_is_excluded_but_has_no_default);
      __pyx_t_15 += 46;
      __Pyx_GIVEREF(__pyx_kp_u_is_excluded_but_has_no_default);
      PyTuple_SET_ITEM(__pyx_t_11, 4, __pyx_kp_u_is_excluded_but_has_no_default);

      /* "serpyco/serializer.pyx":562
 *             else:
 *                 raise TypeError(
 *                     f"Cannot create '{self._dataclass.__qualname__}' as "             # <<<<<<<<<<<<<<
 *                     f"'{sfield.field_name}' is excluded but has no "
 *                     "default value/factory"
 */
      __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_11, 5, __pyx_t_15, __pyx_t_16); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "serpyco/serializer.pyx":561
 *                 decoded = sfield.default_factory()
 *             else:
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     f"Cannot create '{self._dataclass.__qualname__}' as "
 *                     f"'{sfield.field_name}' is excluded but has no "
 */
      __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 561, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_11, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __PYX_ERR(0, 561, __pyx_L1_error)
    }
    __pyx_L23:;

    /* "serpyco/serializer.pyx":567
 *                 )
 *             # Cannot use setattr() on frozen dataclasses
 *             if not self._frozen_dataclass:             # <<<<<<<<<<<<<<
 *                 setattr(obj, sfield.field_name, decoded)
 *             else:
 */
    __pyx_t_9 = (!__pyx_v_self->_frozen_dataclass);
    if (__pyx_t_9) {

      /* "serpyco/serializer.pyx":568
 *             # Cannot use setattr() on frozen dataclasses
 *             if not self._frozen_dataclass:
 *                 setattr(obj, sfield.field_name, decoded)             # <<<<<<<<<<<<<<
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 */
      __pyx_t_11 = __pyx_v_sfield->field_name;
      __Pyx_INCREF(__pyx_t_11);
      __pyx_t_17 = PyObject_SetAttr(__pyx_v_obj, __pyx_t_11, __pyx_v_decoded); if (unlikely(__pyx_t_17 == ((int)-1))) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "serpyco/serializer.pyx":567
 *                 )
 *             # Cannot use setattr() on frozen dataclasses
 *             if not self._frozen_dataclass:             # <<<<<<<<<<<<<<
 *                 setattr(obj, sfield.field_name, decoded)
 *             else:
 */
      goto __pyx_L24;
    }

    /* "serpyco/serializer.pyx":570
 *                 setattr(obj, sfield.field_name, decoded)
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)             # <<<<<<<<<<<<<<
 *         if self._has_post_init:
 *             obj.__post_init__()
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_setattr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_obj, __pyx_v_sfield->field_name, __pyx_v_decoded};
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 570, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __pyx_L24:;

    /* "serpyco/serializer.pyx":555
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 *         for sfield in self._excluded_fields:             # <<<<<<<<<<<<<<
 *             if sfield.default is not dataclasses.MISSING:
 *                 decoded = sfield.default
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":571
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 *         if self._has_post_init:             # <<<<<<<<<<<<<<
 *             obj.__post_init__()
 *         return obj
 */
  if (__pyx_v_self->_has_post_init) {

    /* "serpyco/serializer.pyx":572
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 *         if self._has_post_init:
 *             obj.__post_init__()             # <<<<<<<<<<<<<<
 *         return obj
 * 
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_post_init); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[1] = {__pyx_t_2, };
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":571
 *             else:
 *                 object.__setattr__(obj, sfield.field_name, decoded)
 *         if self._has_post_init:             # <<<<<<<<<<<<<<
 *             obj.__post_init__()
 *         return obj
 */
  }

  /* "serpyco/serializer.pyx":573
 *         if self._has_post_init:
 *             obj.__post_init__()
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     def _get_field_serializer(self, sfield: SerializerField) -> "Serializer":
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":529
 *         return data
 * 
 *     cdef inline object _load(self, dict data):             # <<<<<<<<<<<<<<
 *         cdef SerializerField sfield
 *         cdef object decoded
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("serpyco.serializer.Serializer._load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sfield);
  __Pyx_XDECREF(__pyx_v_decoded);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":575
 *         return obj
 * 
 *     def _get_field_serializer(self, sfield: SerializerField) -> "Serializer":             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder = sfield.encoder
 *         cdef DataClassFieldEncoder dencoder
 */

/* Python wrapper */
static struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_pw_7serpyco_10serializer_10Serializer_25_get_field_serializer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_24_get_field_serializer, "Serializer._get_field_serializer(self, SerializerField sfield: SerializerField) -> 'Serializer'");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_25_get_field_serializer = {"_get_field_serializer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_25_get_field_serializer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_24_get_field_serializer};
static struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_pw_7serpyco_10serializer_10Serializer_25_get_field_serializer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_field_serializer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 575, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sfield,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sfield)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 575, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_field_serializer") < 0)) __PYX_ERR(0, 575, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_sfield = ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_field_serializer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 575, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer._get_field_serializer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_sfield), __pyx_ptype_7serpyco_10serializer_SerializerField, 0, "sfield", 0))) __PYX_ERR(0, 575, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_24_get_field_serializer(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_sfield);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_pf_7serpyco_10serializer_10Serializer_24_get_field_serializer(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v_sfield) {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder = 0;
  struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_dencoder = 0;
  struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_iter_encoder = 0;
  struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_diter_encoder = 0;
  struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_dict_encoder = 0;
  struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_field_serializer", 0);

  /* "serpyco/serializer.pyx":576
 * 
 *     def _get_field_serializer(self, sfield: SerializerField) -> "Serializer":
 *         cdef FieldEncoder encoder = sfield.encoder             # <<<<<<<<<<<<<<
 *         cdef DataClassFieldEncoder dencoder
 *         cdef IterableFieldEncoder iter_encoder
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_sfield->encoder);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":581
 *         cdef DataClassIterableFieldEncoder diter_encoder
 *         cdef DictFieldEncoder dict_encoder
 *         encoder = sfield.encoder             # <<<<<<<<<<<<<<
 *         if isinstance(encoder, IterableFieldEncoder):
 *             iter_encoder = encoder
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_sfield->encoder);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_encoder, ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1));
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":582
 *         cdef DictFieldEncoder dict_encoder
 *         encoder = sfield.encoder
 *         if isinstance(encoder, IterableFieldEncoder):             # <<<<<<<<<<<<<<
 *             iter_encoder = encoder
 *             dencoder = iter_encoder._item_encoder
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder); 
  if (__pyx_t_2) {

    /* "serpyco/serializer.pyx":583
 *         encoder = sfield.encoder
 *         if isinstance(encoder, IterableFieldEncoder):
 *             iter_encoder = encoder             # <<<<<<<<<<<<<<
 *             dencoder = iter_encoder._item_encoder
 *             return dencoder._serializer
 */
    if (!(likely(((((PyObject *)__pyx_v_encoder)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder))))) __PYX_ERR(0, 583, __pyx_L1_error)
    __pyx_t_1 = ((PyObject *)__pyx_v_encoder);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_iter_encoder = ((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":584
 *         if isinstance(encoder, IterableFieldEncoder):
 *             iter_encoder = encoder
 *             dencoder = iter_encoder._item_encoder             # <<<<<<<<<<<<<<
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassIterableFieldEncoder):
 */
    if (!(likely(((((PyObject *)__pyx_v_iter_encoder->_item_encoder)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_iter_encoder->_item_encoder), __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder))))) __PYX_ERR(0, 584, __pyx_L1_error)
    __pyx_t_1 = ((PyObject *)__pyx_v_iter_encoder->_item_encoder);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_dencoder = ((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":585
 *             iter_encoder = encoder
 *             dencoder = iter_encoder._item_encoder
 *             return dencoder._serializer             # <<<<<<<<<<<<<<
 *         elif isinstance(encoder, DataClassIterableFieldEncoder):
 *             diter_encoder = encoder
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_dencoder->_serializer);
    __pyx_r = __pyx_v_dencoder->_serializer;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":582
 *         cdef DictFieldEncoder dict_encoder
 *         encoder = sfield.encoder
 *         if isinstance(encoder, IterableFieldEncoder):             # <<<<<<<<<<<<<<
 *             iter_encoder = encoder
 *             dencoder = iter_encoder._item_encoder
 */
  }

  /* "serpyco/serializer.pyx":586
 *             dencoder = iter_encoder._item_encoder
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassIterableFieldEncoder):             # <<<<<<<<<<<<<<
 *             diter_encoder = encoder
 *             return diter_encoder._serializer
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder); 
  if (__pyx_t_2) {

    /* "serpyco/serializer.pyx":587
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassIterableFieldEncoder):
 *             diter_encoder = encoder             # <<<<<<<<<<<<<<
 *             return diter_encoder._serializer
 *         elif isinstance(encoder, DictFieldEncoder):
 */
    if (!(likely(((((PyObject *)__pyx_v_encoder)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder))))) __PYX_ERR(0, 587, __pyx_L1_error)
    __pyx_t_1 = ((PyObject *)__pyx_v_encoder);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_diter_encoder = ((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":588
 *         elif isinstance(encoder, DataClassIterableFieldEncoder):
 *             diter_encoder = encoder
 *             return diter_encoder._serializer             # <<<<<<<<<<<<<<
 *         elif isinstance(encoder, DictFieldEncoder):
 *             dict_encoder = encoder
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_diter_encoder->_serializer);
    __pyx_r = __pyx_v_diter_encoder->_serializer;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":586
 *             dencoder = iter_encoder._item_encoder
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassIterableFieldEncoder):             # <<<<<<<<<<<<<<
 *             diter_encoder = encoder
 *             return diter_encoder._serializer
 */
  }

  /* "serpyco/serializer.pyx":589
 *             diter_encoder = encoder
 *             return diter_encoder._serializer
 *         elif isinstance(encoder, DictFieldEncoder):             # <<<<<<<<<<<<<<
 *             dict_encoder = encoder
 *             dencoder = dict_encoder._value_encoder
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_DictFieldEncoder); 
  if (__pyx_t_2) {

    /* "serpyco/serializer.pyx":590
 *             return diter_encoder._serializer
 *         elif isinstance(encoder, DictFieldEncoder):
 *             dict_encoder = encoder             # <<<<<<<<<<<<<<
 *             dencoder = dict_encoder._value_encoder
 *             return dencoder._serializer
 */
    if (!(likely(((((PyObject *)__pyx_v_encoder)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_DictFieldEncoder))))) __PYX_ERR(0, 590, __pyx_L1_error)
    __pyx_t_1 = ((PyObject *)__pyx_v_encoder);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_dict_encoder = ((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":591
 *         elif isinstance(encoder, DictFieldEncoder):
 *             dict_encoder = encoder
 *             dencoder = dict_encoder._value_encoder             # <<<<<<<<<<<<<<
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassFieldEncoder):
 */
    if (!(likely(((((PyObject *)__pyx_v_dict_encoder->_value_encoder)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_dict_encoder->_value_encoder), __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder))))) __PYX_ERR(0, 591, __pyx_L1_error)
    __pyx_t_1 = ((PyObject *)__pyx_v_dict_encoder->_value_encoder);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_dencoder = ((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":592
 *             dict_encoder = encoder
 *             dencoder = dict_encoder._value_encoder
 *             return dencoder._serializer             # <<<<<<<<<<<<<<
 *         elif isinstance(encoder, DataClassFieldEncoder):
 *             dencoder = encoder
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_dencoder->_serializer);
    __pyx_r = __pyx_v_dencoder->_serializer;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":589
 *             diter_encoder = encoder
 *             return diter_encoder._serializer
 *         elif isinstance(encoder, DictFieldEncoder):             # <<<<<<<<<<<<<<
 *             dict_encoder = encoder
 *             dencoder = dict_encoder._value_encoder
 */
  }

  /* "serpyco/serializer.pyx":593
 *             dencoder = dict_encoder._value_encoder
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassFieldEncoder):             # <<<<<<<<<<<<<<
 *             dencoder = encoder
 *             return dencoder._serializer
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder); 
  if (__pyx_t_2) {

    /* "serpyco/serializer.pyx":594
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassFieldEncoder):
 *             dencoder = encoder             # <<<<<<<<<<<<<<
 *             return dencoder._serializer
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 */
    if (!(likely(((((PyObject *)__pyx_v_encoder)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_encoder), __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder))))) __PYX_ERR(0, 594, __pyx_L1_error)
    __pyx_t_1 = ((PyObject *)__pyx_v_encoder);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_dencoder = ((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":595
 *         elif isinstance(encoder, DataClassFieldEncoder):
 *             dencoder = encoder
 *             return dencoder._serializer             # <<<<<<<<<<<<<<
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 * 
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_dencoder->_serializer);
    __pyx_r = __pyx_v_dencoder->_serializer;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":593
 *             dencoder = dict_encoder._value_encoder
 *             return dencoder._serializer
 *         elif isinstance(encoder, DataClassFieldEncoder):             # <<<<<<<<<<<<<<
 *             dencoder = encoder
 *             return dencoder._serializer
 */
  }

  /* "serpyco/serializer.pyx":596
 *             dencoder = encoder
 *             return dencoder._serializer
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")             # <<<<<<<<<<<<<<
 * 
 *     def _get_encoder(self, field_type, hints):
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_field);
  __pyx_t_3 += 6;
  __Pyx_GIVEREF(__pyx_kp_u_field);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_field);
  __pyx_t_5 = __Pyx_PyUnicode_Unicode(__pyx_v_sfield->field_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_is_not_a_dataclass);
  __pyx_t_3 += 19;
  __Pyx_GIVEREF(__pyx_kp_u_is_not_a_dataclass);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_is_not_a_dataclass);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 596, __pyx_L1_error)

  /* "serpyco/serializer.pyx":575
 *         return obj
 * 
 *     def _get_field_serializer(self, sfield: SerializerField) -> "Serializer":             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder = sfield.encoder
 *         cdef DataClassFieldEncoder dencoder
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.Serializer._get_field_serializer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_encoder);
  __Pyx_XDECREF((PyObject *)__pyx_v_dencoder);
  __Pyx_XDECREF((PyObject *)__pyx_v_iter_encoder);
  __Pyx_XDECREF((PyObject *)__pyx_v_diter_encoder);
  __Pyx_XDECREF((PyObject *)__pyx_v_dict_encoder);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":598
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 * 
 *     def _get_encoder(self, field_type, hints):             # <<<<<<<<<<<<<<
 *         cdef DataClassFieldEncoder dencoder
 *         cdef Serializer serializer
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_27_get_encoder(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_26_get_encoder, "Serializer._get_encoder(self, field_type, hints)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_27_get_encoder = {"_get_encoder", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_27_get_encoder, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_26_get_encoder};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_27_get_encoder(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_field_type = 0;
  PyObject *__pyx_v_hints = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_encoder (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 598, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_field_type,&__pyx_n_s_hints,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_field_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 598, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_hints)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 598, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_get_encoder", 1, 2, 2, 1); __PYX_ERR(0, 598, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_encoder") < 0)) __PYX_ERR(0, 598, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_field_type = values[0];
    __pyx_v_hints = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_encoder", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 598, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer._get_encoder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_26_get_encoder(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v_field_type, __pyx_v_hints);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_7serpyco_10serializer_10Serializer_12_get_encoder_2generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "serpyco/serializer.pyx":681
 *         # This avoids infinite recursion if dataclasses establish a cycle
 *         excluded_field_names = tuple(
 *             f.name for f in dataclasses.fields(params.type_)             # <<<<<<<<<<<<<<
 *             if (
 *                 hints.ignore
 */

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_12_get_encoder_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *)__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_2_genexpr(__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 681, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_7serpyco_10serializer_10Serializer_12_get_encoder_2generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_get_encoder_locals_genexpr, __pyx_n_s_serpyco_serializer); if (unlikely(!gen)) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.Serializer._get_encoder.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_7serpyco_10serializer_10Serializer_12_get_encoder_2generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *__pyx_cur_scope = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L12_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 681, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 681, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 681, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 681, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 681, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 681, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 681, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 681, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_f);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_f, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "serpyco/serializer.pyx":683
 *             f.name for f in dataclasses.fields(params.type_)
 *             if (
 *                 hints.ignore             # <<<<<<<<<<<<<<
 *                 or (hints.only and f.name not in hints.only)
 *                 or (hints.exclude and f.name in hints.exclude)
 */
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints)) { __Pyx_RaiseClosureNameError("hints"); __PYX_ERR(0, 683, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 683, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }

    /* "serpyco/serializer.pyx":684
 *             if (
 *                 hints.ignore
 *                 or (hints.only and f.name not in hints.only)             # <<<<<<<<<<<<<<
 *                 or (hints.exclude and f.name in hints.exclude)
 *             )
 */
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints)) { __Pyx_RaiseClosureNameError("hints"); __PYX_ERR(0, 684, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints, __pyx_n_s_only); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_6) {
      goto __pyx_L9_next_or;
    } else {
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints)) { __Pyx_RaiseClosureNameError("hints"); __PYX_ERR(0, 684, __pyx_L1_error) }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints, __pyx_n_s_only); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_t_7, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_L9_next_or:;

    /* "serpyco/serializer.pyx":685
 *                 hints.ignore
 *                 or (hints.only and f.name not in hints.only)
 *                 or (hints.exclude and f.name in hints.exclude)             # <<<<<<<<<<<<<<
 *             )
 *         )
 */
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints)) { __Pyx_RaiseClosureNameError("hints"); __PYX_ERR(0, 685, __pyx_L1_error) }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints, __pyx_n_s_exclude); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints)) { __Pyx_RaiseClosureNameError("hints"); __PYX_ERR(0, 685, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_hints, __pyx_n_s_exclude); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_7, __pyx_t_4, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __pyx_t_6;
    __pyx_L7_bool_binop_done:;

    /* "serpyco/serializer.pyx":682
 *         excluded_field_names = tuple(
 *             f.name for f in dataclasses.fields(params.type_)
 *             if (             # <<<<<<<<<<<<<<
 *                 hints.ignore
 *                 or (hints.only and f.name not in hints.only)
 */
    if (__pyx_t_5) {

      /* "serpyco/serializer.pyx":681
 *         # This avoids infinite recursion if dataclasses establish a cycle
 *         excluded_field_names = tuple(
 *             f.name for f in dataclasses.fields(params.type_)             # <<<<<<<<<<<<<<
 *             if (
 *                 hints.ignore
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 681, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L12_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 681, __pyx_L1_error)

      /* "serpyco/serializer.pyx":682
 *         excluded_field_names = tuple(
 *             f.name for f in dataclasses.fields(params.type_)
 *             if (             # <<<<<<<<<<<<<<
 *                 hints.ignore
 *                 or (hints.only and f.name not in hints.only)
 */
    }

    /* "serpyco/serializer.pyx":681
 *         # This avoids infinite recursion if dataclasses establish a cycle
 *         excluded_field_names = tuple(
 *             f.name for f in dataclasses.fields(params.type_)             # <<<<<<<<<<<<<<
 *             if (
 *                 hints.ignore
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":598
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 * 
 *     def _get_encoder(self, field_type, hints):             # <<<<<<<<<<<<<<
 *         cdef DataClassFieldEncoder dencoder
 *         cdef Serializer serializer
 */

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_26_get_encoder(struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, PyObject *__pyx_v_field_type, PyObject *__pyx_v_hints) {
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *__pyx_cur_scope;
  struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_dencoder = 0;
  struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_serializer = 0;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_type_encoders = NULL;
  PyObject *__pyx_v_key_encoder = NULL;
  PyObject *__pyx_v_value_encoder = NULL;
  PyObject *__pyx_v_item_encoders = NULL;
  PyObject *__pyx_v_item_encoder = NULL;
  PyObject *__pyx_v_param_args = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_excluded_field_names = NULL;
  Py_hash_t __pyx_v_h;
  Py_hash_t __pyx_v_sh;
  PyObject *__pyx_8genexpr5__pyx_v_item_type = NULL;
  PyObject *__pyx_8genexpr6__pyx_v_arg_type = NULL;
  PyObject *__pyx_8genexpr7__pyx_v_arg = NULL;
  PyObject *__pyx_8genexpr7__pyx_v_param = NULL;
  PyObject *__pyx_gb_7serpyco_10serializer_10Serializer_12_get_encoder_2generator1 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *(*__pyx_t_16)(PyObject *);
  Py_UCS4 __pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  Py_hash_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_encoder", 0);
  __pyx_cur_scope = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *)__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_1__get_encoder(__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 598, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_hints = __pyx_v_hints;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_hints);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_hints);
  __Pyx_INCREF(__pyx_v_field_type);

  /* "serpyco/serializer.pyx":601
 *         cdef DataClassFieldEncoder dencoder
 *         cdef Serializer serializer
 *         field_type = self._dataclass_params.resolve_type(field_type)             # <<<<<<<<<<<<<<
 *         args = typing_inspect.get_args(field_type, evaluate=True)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass_params, __pyx_n_s_resolve_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_field_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_field_type, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":602
 *         cdef Serializer serializer
 *         field_type = self._dataclass_params.resolve_type(field_type)
 *         args = typing_inspect.get_args(field_type, evaluate=True)             # <<<<<<<<<<<<<<
 * 
 *         if typing_inspect.is_new_type(field_type):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_typing_inspect); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_field_type);
  __Pyx_GIVEREF(__pyx_v_field_type);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_field_type)) __PYX_ERR(0, 602, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_evaluate, Py_True) < 0) __PYX_ERR(0, 602, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_args = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "serpyco/serializer.pyx":604
 *         args = typing_inspect.get_args(field_type, evaluate=True)
 * 
 *         if typing_inspect.is_new_type(field_type):             # <<<<<<<<<<<<<<
 *             field_type = field_type.__supertype__
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_typing_inspect); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_new_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_field_type};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {

    /* "serpyco/serializer.pyx":605
 * 
 *         if typing_inspect.is_new_type(field_type):
 *             field_type = field_type.__supertype__             # <<<<<<<<<<<<<<
 * 
 *         if field_type in self._type_encoders:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_field_type, __pyx_n_s_supertype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_field_type, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "serpyco/serializer.pyx":604
 *         args = typing_inspect.get_args(field_type, evaluate=True)
 * 
 *         if typing_inspect.is_new_type(field_type):             # <<<<<<<<<<<<<<
 *             field_type = field_type.__supertype__
 * 
 */
  }

  /* "serpyco/serializer.pyx":607
 *             field_type = field_type.__supertype__
 * 
 *         if field_type in self._type_encoders:             # <<<<<<<<<<<<<<
 *             return self._type_encoders[field_type]
 *         elif field_type in self._global_types:
 */
  if (unlikely(__pyx_v_self->_type_encoders == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 607, __pyx_L1_error)
  }
  __pyx_t_6 = (__Pyx_PyDict_ContainsTF(__pyx_v_field_type, __pyx_v_self->_type_encoders, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 607, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "serpyco/serializer.pyx":608
 * 
 *         if field_type in self._type_encoders:
 *             return self._type_encoders[field_type]             # <<<<<<<<<<<<<<
 *         elif field_type in self._global_types:
 *             return self._global_types[field_type]
 */
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_self->_type_encoders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 608, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_self->_type_encoders, __pyx_v_field_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 608, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":607
 *             field_type = field_type.__supertype__
 * 
 *         if field_type in self._type_encoders:             # <<<<<<<<<<<<<<
 *             return self._type_encoders[field_type]
 *         elif field_type in self._global_types:
 */
  }

  /* "serpyco/serializer.pyx":609
 *         if field_type in self._type_encoders:
 *             return self._type_encoders[field_type]
 *         elif field_type in self._global_types:             # <<<<<<<<<<<<<<
 *             return self._global_types[field_type]
 *         elif typing.Any == field_type:
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_global_types); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_v_field_type, __pyx_t_5, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {

    /* "serpyco/serializer.pyx":610
 *             return self._type_encoders[field_type]
 *         elif field_type in self._global_types:
 *             return self._global_types[field_type]             # <<<<<<<<<<<<<<
 *         elif typing.Any == field_type:
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_global_types); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_field_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":609
 *         if field_type in self._type_encoders:
 *             return self._type_encoders[field_type]
 *         elif field_type in self._global_types:             # <<<<<<<<<<<<<<
 *             return self._global_types[field_type]
 *         elif typing.Any == field_type:
 */
  }

  /* "serpyco/serializer.pyx":611
 *         elif field_type in self._global_types:
 *             return self._global_types[field_type]
 *         elif typing.Any == field_type:             # <<<<<<<<<<<<<<
 *             return None
 *         elif _issubclass_safe(field_type, enum.Enum):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_typing); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Any); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_5, __pyx_v_field_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "serpyco/serializer.pyx":612
 *             return self._global_types[field_type]
 *         elif typing.Any == field_type:
 *             return None             # <<<<<<<<<<<<<<
 *         elif _issubclass_safe(field_type, enum.Enum):
 *             # Must be first as enums can inherit from another type
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":611
 *         elif field_type in self._global_types:
 *             return self._global_types[field_type]
 *         elif typing.Any == field_type:             # <<<<<<<<<<<<<<
 *             return None
 *         elif _issubclass_safe(field_type, enum.Enum):
 */
  }

  /* "serpyco/serializer.pyx":613
 *         elif typing.Any == field_type:
 *             return None
 *         elif _issubclass_safe(field_type, enum.Enum):             # <<<<<<<<<<<<<<
 *             # Must be first as enums can inherit from another type
 *             return EnumFieldEncoder(field_type)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_issubclass_safe); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_enum); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Enum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_field_type, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "serpyco/serializer.pyx":615
 *         elif _issubclass_safe(field_type, enum.Enum):
 *             # Must be first as enums can inherit from another type
 *             return EnumFieldEncoder(field_type)             # <<<<<<<<<<<<<<
 *         elif _issubclass_safe(field_type, tuple(JSON_ENCODABLE_TYPES.keys())):
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder), __pyx_v_field_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":613
 *         elif typing.Any == field_type:
 *             return None
 *         elif _issubclass_safe(field_type, enum.Enum):             # <<<<<<<<<<<<<<
 *             # Must be first as enums can inherit from another type
 *             return EnumFieldEncoder(field_type)
 */
  }

  /* "serpyco/serializer.pyx":616
 *             # Must be first as enums can inherit from another type
 *             return EnumFieldEncoder(field_type)
 *         elif _issubclass_safe(field_type, tuple(JSON_ENCODABLE_TYPES.keys())):             # <<<<<<<<<<<<<<
 *             return None
 *         elif _is_union(field_type):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_issubclass_safe); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_JSON_ENCODABLE_TYPES); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_keys); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_3, };
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = __Pyx_PySequence_Tuple(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_field_type, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "serpyco/serializer.pyx":617
 *             return EnumFieldEncoder(field_type)
 *         elif _issubclass_safe(field_type, tuple(JSON_ENCODABLE_TYPES.keys())):
 *             return None             # <<<<<<<<<<<<<<
 *         elif _is_union(field_type):
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":616
 *             # Must be first as enums can inherit from another type
 *             return EnumFieldEncoder(field_type)
 *         elif _issubclass_safe(field_type, tuple(JSON_ENCODABLE_TYPES.keys())):             # <<<<<<<<<<<<<<
 *             return None
 *         elif _is_union(field_type):
 */
  }

  /* "serpyco/serializer.pyx":618
 *         elif _issubclass_safe(field_type, tuple(JSON_ENCODABLE_TYPES.keys())):
 *             return None
 *         elif _is_union(field_type):             # <<<<<<<<<<<<<<
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))
 *             try:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_is_union); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_field_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "serpyco/serializer.pyx":619
 *             return None
 *         elif _is_union(field_type):
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))             # <<<<<<<<<<<<<<
 *             try:
 *                 args.remove(type(None))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_typing_inspect); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_args); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_field_type);
    __Pyx_GIVEREF(__pyx_v_field_type);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_field_type)) __PYX_ERR(0, 619, __pyx_L1_error);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_evaluate, Py_True) < 0) __PYX_ERR(0, 619, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PySequence_ListKeepNew(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":620
 *         elif _is_union(field_type):
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))
 *             try:             # <<<<<<<<<<<<<<
 *                 args.remove(type(None))
 *             except ValueError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "serpyco/serializer.pyx":621
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))
 *             try:
 *                 args.remove(type(None))             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 pass
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_args, __pyx_n_s_remove); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)Py_TYPE(Py_None))};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 621, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "serpyco/serializer.pyx":620
 *         elif _is_union(field_type):
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))
 *             try:             # <<<<<<<<<<<<<<
 *                 args.remove(type(None))
 *             except ValueError:
 */
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L10_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "serpyco/serializer.pyx":622
 *             try:
 *                 args.remove(type(None))
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 pass
 *             type_encoders = [
 */
      __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_4) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;

      /* "serpyco/serializer.pyx":620
 *         elif _is_union(field_type):
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))
 *             try:             # <<<<<<<<<<<<<<
 *                 args.remove(type(None))
 *             except ValueError:
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L10_try_end:;
    }

    /* "serpyco/serializer.pyx":624
 *             except ValueError:
 *                 pass
 *             type_encoders = [             # <<<<<<<<<<<<<<
 *                 (item_type, self._get_encoder(item_type, hints))
 *                 for item_type in args
 */
    { /* enter inner scope */
      __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 624, __pyx_L13_error)
      __Pyx_GOTREF(__pyx_t_7);

      /* "serpyco/serializer.pyx":626
 *             type_encoders = [
 *                 (item_type, self._get_encoder(item_type, hints))
 *                 for item_type in args             # <<<<<<<<<<<<<<
 *             ]
 *             if not args:
 */
      if (likely(PyList_CheckExact(__pyx_v_args)) || PyTuple_CheckExact(__pyx_v_args)) {
        __pyx_t_2 = __pyx_v_args; __Pyx_INCREF(__pyx_t_2); __pyx_t_11 = 0;
        __pyx_t_12 = NULL;
      } else {
        __pyx_t_11 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 626, __pyx_L13_error)
      }
      for (;;) {
        if (likely(!__pyx_t_12)) {
          if (likely(PyList_CheckExact(__pyx_t_2))) {
            if (__pyx_t_11 >= PyList_GET_SIZE(__pyx_t_2)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_11); __Pyx_INCREF(__pyx_t_1); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 626, __pyx_L13_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 626, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_11 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_11); __Pyx_INCREF(__pyx_t_1); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 626, __pyx_L13_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 626, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_12(__pyx_t_2);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 626, __pyx_L13_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_item_type, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "serpyco/serializer.pyx":625
 *                 pass
 *             type_encoders = [
 *                 (item_type, self._get_encoder(item_type, hints))             # <<<<<<<<<<<<<<
 *                 for item_type in args
 *             ]
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_encoder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 625, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_8genexpr5__pyx_v_item_type, __pyx_cur_scope->__pyx_v_hints};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 625, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_8genexpr5__pyx_v_item_type);
        __Pyx_GIVEREF(__pyx_8genexpr5__pyx_v_item_type);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_8genexpr5__pyx_v_item_type)) __PYX_ERR(0, 625, __pyx_L13_error);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1)) __PYX_ERR(0, 625, __pyx_L13_error);
        __pyx_t_1 = 0;
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_7, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 624, __pyx_L13_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "serpyco/serializer.pyx":626
 *             type_encoders = [
 *                 (item_type, self._get_encoder(item_type, hints))
 *                 for item_type in args             # <<<<<<<<<<<<<<
 *             ]
 *             if not args:
 */
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_item_type); __pyx_8genexpr5__pyx_v_item_type = 0;
      goto __pyx_L17_exit_scope;
      __pyx_L13_error:;
      __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_item_type); __pyx_8genexpr5__pyx_v_item_type = 0;
      goto __pyx_L1_error;
      __pyx_L17_exit_scope:;
    } /* exit inner scope */
    __pyx_v_type_encoders = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":628
 *                 for item_type in args
 *             ]
 *             if not args:             # <<<<<<<<<<<<<<
 *                 return None
 *             elif len(args)== 1:
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_args); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 628, __pyx_L1_error)
    __pyx_t_13 = (!__pyx_t_6);
    if (__pyx_t_13) {

      /* "serpyco/serializer.pyx":629
 *             ]
 *             if not args:
 *                 return None             # <<<<<<<<<<<<<<
 *             elif len(args)== 1:
 *                 return type_encoders[0][1]
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "serpyco/serializer.pyx":628
 *                 for item_type in args
 *             ]
 *             if not args:             # <<<<<<<<<<<<<<
 *                 return None
 *             elif len(args)== 1:
 */
    }

    /* "serpyco/serializer.pyx":630
 *             if not args:
 *                 return None
 *             elif len(args)== 1:             # <<<<<<<<<<<<<<
 *                 return type_encoders[0][1]
 *             else:
 */
    __pyx_t_11 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 630, __pyx_L1_error)
    __pyx_t_13 = (__pyx_t_11 == 1);
    if (__pyx_t_13) {

      /* "serpyco/serializer.pyx":631
 *                 return None
 *             elif len(args)== 1:
 *                 return type_encoders[0][1]             # <<<<<<<<<<<<<<
 *             else:
 *                 return UnionFieldEncoder(type_encoders)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = __Pyx_GetItemInt(PyList_GET_ITEM(__pyx_v_type_encoders, 0), 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 631, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L0;

      /* "serpyco/serializer.pyx":630
 *             if not args:
 *                 return None
 *             elif len(args)== 1:             # <<<<<<<<<<<<<<
 *                 return type_encoders[0][1]
 *             else:
 */
    }

    /* "serpyco/serializer.pyx":633
 *                 return type_encoders[0][1]
 *             else:
 *                 return UnionFieldEncoder(type_encoders)             # <<<<<<<<<<<<<<
 *         elif field_type in UNTYPED_DICT_TYPES:
 *             return None
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder), __pyx_v_type_encoders); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L0;
    }

    /* "serpyco/serializer.pyx":618
 *         elif _issubclass_safe(field_type, tuple(JSON_ENCODABLE_TYPES.keys())):
 *             return None
 *         elif _is_union(field_type):             # <<<<<<<<<<<<<<
 *             args = list(typing_inspect.get_args(field_type, evaluate=True))
 *             try:
 */
  }

  /* "serpyco/serializer.pyx":634
 *             else:
 *                 return UnionFieldEncoder(type_encoders)
 *         elif field_type in UNTYPED_DICT_TYPES:             # <<<<<<<<<<<<<<
 *             return None
 *         elif _is_generic(field_type, typing.Mapping):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_UNTYPED_DICT_TYPES); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = (__Pyx_PySequence_ContainsTF(__pyx_v_field_type, __pyx_t_7, Py_EQ)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_13) {

    /* "serpyco/serializer.pyx":635
 *                 return UnionFieldEncoder(type_encoders)
 *         elif field_type in UNTYPED_DICT_TYPES:
 *             return None             # <<<<<<<<<<<<<<
 *         elif _is_generic(field_type, typing.Mapping):
 *             key_encoder = self._get_encoder(args[0], hints)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":634
 *             else:
 *                 return UnionFieldEncoder(type_encoders)
 *         elif field_type in UNTYPED_DICT_TYPES:             # <<<<<<<<<<<<<<
 *             return None
 *         elif _is_generic(field_type, typing.Mapping):
 */
  }

  /* "serpyco/serializer.pyx":636
 *         elif field_type in UNTYPED_DICT_TYPES:
 *             return None
 *         elif _is_generic(field_type, typing.Mapping):             # <<<<<<<<<<<<<<
 *             key_encoder = self._get_encoder(args[0], hints)
 *             value_encoder = self._get_encoder(args[1], hints)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_is_generic); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_typing); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Mapping); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_field_type, __pyx_t_1};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_13) {

    /* "serpyco/serializer.pyx":637
 *             return None
 *         elif _is_generic(field_type, typing.Mapping):
 *             key_encoder = self._get_encoder(args[0], hints)             # <<<<<<<<<<<<<<
 *             value_encoder = self._get_encoder(args[1], hints)
 *             if key_encoder or value_encoder:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_encoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_1, __pyx_cur_scope->__pyx_v_hints};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_key_encoder = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":638
 *         elif _is_generic(field_type, typing.Mapping):
 *             key_encoder = self._get_encoder(args[0], hints)
 *             value_encoder = self._get_encoder(args[1], hints)             # <<<<<<<<<<<<<<
 *             if key_encoder or value_encoder:
 *                 return DictFieldEncoder(key_encoder, value_encoder)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_encoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_args, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_1, __pyx_cur_scope->__pyx_v_hints};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_value_encoder = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":639
 *             key_encoder = self._get_encoder(args[0], hints)
 *             value_encoder = self._get_encoder(args[1], hints)
 *             if key_encoder or value_encoder:             # <<<<<<<<<<<<<<
 *                 return DictFieldEncoder(key_encoder, value_encoder)
 *             return None
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_key_encoder); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 639, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_13 = __pyx_t_6;
      goto __pyx_L20_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_value_encoder); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 639, __pyx_L1_error)
    __pyx_t_13 = __pyx_t_6;
    __pyx_L20_bool_binop_done:;
    if (__pyx_t_13) {

      /* "serpyco/serializer.pyx":640
 *             value_encoder = self._get_encoder(args[1], hints)
 *             if key_encoder or value_encoder:
 *                 return DictFieldEncoder(key_encoder, value_encoder)             # <<<<<<<<<<<<<<
 *             return None
 *         elif (
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_key_encoder);
      __Pyx_GIVEREF(__pyx_v_key_encoder);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_key_encoder)) __PYX_ERR(0, 640, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_value_encoder);
      __Pyx_GIVEREF(__pyx_v_value_encoder);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_value_encoder)) __PYX_ERR(0, 640, __pyx_L1_error);
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7serpyco_10serializer_DictFieldEncoder), __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "serpyco/serializer.pyx":639
 *             key_encoder = self._get_encoder(args[0], hints)
 *             value_encoder = self._get_encoder(args[1], hints)
 *             if key_encoder or value_encoder:             # <<<<<<<<<<<<<<
 *                 return DictFieldEncoder(key_encoder, value_encoder)
 *             return None
 */
    }

    /* "serpyco/serializer.pyx":641
 *             if key_encoder or value_encoder:
 *                 return DictFieldEncoder(key_encoder, value_encoder)
 *             return None             # <<<<<<<<<<<<<<
 *         elif (
 *             _is_generic(field_type, typing.Tuple)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":636
 *         elif field_type in UNTYPED_DICT_TYPES:
 *             return None
 *         elif _is_generic(field_type, typing.Mapping):             # <<<<<<<<<<<<<<
 *             key_encoder = self._get_encoder(args[0], hints)
 *             value_encoder = self._get_encoder(args[1], hints)
 */
  }

  /* "serpyco/serializer.pyx":643
 *             return None
 *         elif (
 *             _is_generic(field_type, typing.Tuple)             # <<<<<<<<<<<<<<
 *             and (
 *                 len(args)!=2
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_is_generic); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_typing); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Tuple); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_field_type, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_13 = __pyx_t_6;
    goto __pyx_L22_bool_binop_done;
  }

  /* "serpyco/serializer.pyx":645
 *             _is_generic(field_type, typing.Tuple)
 *             and (
 *                 len(args)!=2             # <<<<<<<<<<<<<<
 *                 or args[len(args)-1] is not ...
 *             )
 */
  __pyx_t_11 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 645, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_11 != 2);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_13 = __pyx_t_6;
    goto __pyx_L22_bool_binop_done;
  }

  /* "serpyco/serializer.pyx":646
 *             and (
 *                 len(args)!=2
 *                 or args[len(args)-1] is not ...             # <<<<<<<<<<<<<<
 *             )
 *         ):
 */
  __pyx_t_11 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 646, __pyx_L1_error)
  __pyx_t_14 = (__pyx_t_11 - 1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_args, __pyx_t_14, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__pyx_t_2 != Py_Ellipsis);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_13 = __pyx_t_6;
  __pyx_L22_bool_binop_done:;

  /* "serpyco/serializer.pyx":642
 *                 return DictFieldEncoder(key_encoder, value_encoder)
 *             return None
 *         elif (             # <<<<<<<<<<<<<<
 *             _is_generic(field_type, typing.Tuple)
 *             and (
 */
  if (__pyx_t_13) {

    /* "serpyco/serializer.pyx":650
 *         ):
 *             # Special case for tuple with fixed-length argument list
 *             item_encoders = [             # <<<<<<<<<<<<<<
 *                 self._get_encoder(arg_type, hints)
 *                 for arg_type in args
 */
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 650, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "serpyco/serializer.pyx":652
 *             item_encoders = [
 *                 self._get_encoder(arg_type, hints)
 *                 for arg_type in args             # <<<<<<<<<<<<<<
 *             ]
 *             return FixedTupleFieldEncoder(item_encoders)
 */
      if (likely(PyList_CheckExact(__pyx_v_args)) || PyTuple_CheckExact(__pyx_v_args)) {
        __pyx_t_7 = __pyx_v_args; __Pyx_INCREF(__pyx_t_7); __pyx_t_14 = 0;
        __pyx_t_12 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_args); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 652, __pyx_L27_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 652, __pyx_L27_error)
      }
      for (;;) {
        if (likely(!__pyx_t_12)) {
          if (likely(PyList_CheckExact(__pyx_t_7))) {
            if (__pyx_t_14 >= PyList_GET_SIZE(__pyx_t_7)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_14); __Pyx_INCREF(__pyx_t_5); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 652, __pyx_L27_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_7, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 652, __pyx_L27_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          } else {
            if (__pyx_t_14 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_14); __Pyx_INCREF(__pyx_t_5); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 652, __pyx_L27_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_7, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 652, __pyx_L27_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          }
        } else {
          __pyx_t_5 = __pyx_t_12(__pyx_t_7);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 652, __pyx_L27_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr6__pyx_v_arg_type, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "serpyco/serializer.pyx":651
 *             # Special case for tuple with fixed-length argument list
 *             item_encoders = [
 *                 self._get_encoder(arg_type, hints)             # <<<<<<<<<<<<<<
 *                 for arg_type in args
 *             ]
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_encoder); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L27_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_8genexpr6__pyx_v_arg_type, __pyx_cur_scope->__pyx_v_hints};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 651, __pyx_L27_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 650, __pyx_L27_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "serpyco/serializer.pyx":652
 *             item_encoders = [
 *                 self._get_encoder(arg_type, hints)
 *                 for arg_type in args             # <<<<<<<<<<<<<<
 *             ]
 *             return FixedTupleFieldEncoder(item_encoders)
 */
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_arg_type); __pyx_8genexpr6__pyx_v_arg_type = 0;
      goto __pyx_L31_exit_scope;
      __pyx_L27_error:;
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_arg_type); __pyx_8genexpr6__pyx_v_arg_type = 0;
      goto __pyx_L1_error;
      __pyx_L31_exit_scope:;
    } /* exit inner scope */
    __pyx_v_item_encoders = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "serpyco/serializer.pyx":654
 *                 for arg_type in args
 *             ]
 *             return FixedTupleFieldEncoder(item_encoders)             # <<<<<<<<<<<<<<
 *         elif field_type in UNTYPED_ITERABLE_TYPES:
 *             return IterableFieldEncoder(None, field_type)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder), __pyx_v_item_encoders); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":642
 *                 return DictFieldEncoder(key_encoder, value_encoder)
 *             return None
 *         elif (             # <<<<<<<<<<<<<<
 *             _is_generic(field_type, typing.Tuple)
 *             and (
 */
  }

  /* "serpyco/serializer.pyx":655
 *             ]
 *             return FixedTupleFieldEncoder(item_encoders)
 *         elif field_type in UNTYPED_ITERABLE_TYPES:             # <<<<<<<<<<<<<<
 *             return IterableFieldEncoder(None, field_type)
 *         # tuples defined with ... are handled by the following elif
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_UNTYPED_ITERABLE_TYPES); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = (__Pyx_PySequence_ContainsTF(__pyx_v_field_type, __pyx_t_2, Py_EQ)); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_13) {

    /* "serpyco/serializer.pyx":656
 *             return FixedTupleFieldEncoder(item_encoders)
 *         elif field_type in UNTYPED_ITERABLE_TYPES:
 *             return IterableFieldEncoder(None, field_type)             # <<<<<<<<<<<<<<
 *         # tuples defined with ... are handled by the following elif
 *         elif _is_generic(field_type, typing.Iterable):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, Py_None)) __PYX_ERR(0, 656, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_field_type);
    __Pyx_GIVEREF(__pyx_v_field_type);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_field_type)) __PYX_ERR(0, 656, __pyx_L1_error);
    __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder), __pyx_t_2, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":655
 *             ]
 *             return FixedTupleFieldEncoder(item_encoders)
 *         elif field_type in UNTYPED_ITERABLE_TYPES:             # <<<<<<<<<<<<<<
 *             return IterableFieldEncoder(None, field_type)
 *         # tuples defined with ... are handled by the following elif
 */
  }

  /* "serpyco/serializer.pyx":658
 *             return IterableFieldEncoder(None, field_type)
 *         # tuples defined with ... are handled by the following elif
 *         elif _is_generic(field_type, typing.Iterable):             # <<<<<<<<<<<<<<
 *             item_encoder = self._get_encoder(args[0], hints)
 *             if isinstance(item_encoder, DataClassFieldEncoder):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_is_generic); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_typing); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_field_type, __pyx_t_1};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_13) {

    /* "serpyco/serializer.pyx":659
 *         # tuples defined with ... are handled by the following elif
 *         elif _is_generic(field_type, typing.Iterable):
 *             item_encoder = self._get_encoder(args[0], hints)             # <<<<<<<<<<<<<<
 *             if isinstance(item_encoder, DataClassFieldEncoder):
 *                 dencoder = item_encoder
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_encoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_1, __pyx_cur_scope->__pyx_v_hints};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 659, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_item_encoder = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":660
 *         elif _is_generic(field_type, typing.Iterable):
 *             item_encoder = self._get_encoder(args[0], hints)
 *             if isinstance(item_encoder, DataClassFieldEncoder):             # <<<<<<<<<<<<<<
 *                 dencoder = item_encoder
 *                 return DataClassIterableFieldEncoder(dencoder._serializer, field_type)
 */
    __pyx_t_13 = __Pyx_TypeCheck(__pyx_v_item_encoder, __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder); 
    if (__pyx_t_13) {

      /* "serpyco/serializer.pyx":661
 *             item_encoder = self._get_encoder(args[0], hints)
 *             if isinstance(item_encoder, DataClassFieldEncoder):
 *                 dencoder = item_encoder             # <<<<<<<<<<<<<<
 *                 return DataClassIterableFieldEncoder(dencoder._serializer, field_type)
 *             return IterableFieldEncoder(item_encoder, field_type)
 */
      if (!(likely(((__pyx_v_item_encoder) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_item_encoder, __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder))))) __PYX_ERR(0, 661, __pyx_L1_error)
      __pyx_t_7 = __pyx_v_item_encoder;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_dencoder = ((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "serpyco/serializer.pyx":662
 *             if isinstance(item_encoder, DataClassFieldEncoder):
 *                 dencoder = item_encoder
 *                 return DataClassIterableFieldEncoder(dencoder._serializer, field_type)             # <<<<<<<<<<<<<<
 *             return IterableFieldEncoder(item_encoder, field_type)
 *         # Is the field a dataclass ?
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF((PyObject *)__pyx_v_dencoder->_serializer);
      __Pyx_GIVEREF((PyObject *)__pyx_v_dencoder->_serializer);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, ((PyObject *)__pyx_v_dencoder->_serializer))) __PYX_ERR(0, 662, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_field_type);
      __Pyx_GIVEREF(__pyx_v_field_type);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_field_type)) __PYX_ERR(0, 662, __pyx_L1_error);
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder), __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "serpyco/serializer.pyx":660
 *         elif _is_generic(field_type, typing.Iterable):
 *             item_encoder = self._get_encoder(args[0], hints)
 *             if isinstance(item_encoder, DataClassFieldEncoder):             # <<<<<<<<<<<<<<
 *                 dencoder = item_encoder
 *                 return DataClassIterableFieldEncoder(dencoder._serializer, field_type)
 */
    }

    /* "serpyco/serializer.pyx":663
 *                 dencoder = item_encoder
 *                 return DataClassIterableFieldEncoder(dencoder._serializer, field_type)
 *             return IterableFieldEncoder(item_encoder, field_type)             # <<<<<<<<<<<<<<
 *         # Is the field a dataclass ?
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_item_encoder);
    __Pyx_GIVEREF(__pyx_v_item_encoder);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_item_encoder)) __PYX_ERR(0, 663, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_field_type);
    __Pyx_GIVEREF(__pyx_v_field_type);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_field_type)) __PYX_ERR(0, 663, __pyx_L1_error);
    __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder), __pyx_t_2, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":658
 *             return IterableFieldEncoder(None, field_type)
 *         # tuples defined with ... are handled by the following elif
 *         elif _is_generic(field_type, typing.Iterable):             # <<<<<<<<<<<<<<
 *             item_encoder = self._get_encoder(args[0], hints)
 *             if isinstance(item_encoder, DataClassFieldEncoder):
 */
  }

  /* "serpyco/serializer.pyx":666
 *         # Is the field a dataclass ?
 * 
 *         param_args = {             # <<<<<<<<<<<<<<
 *             param: arg
 *             for arg, param in zip(
 */
  { /* enter inner scope */
    __pyx_t_7 = PyDict_New(); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 666, __pyx_L35_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "serpyco/serializer.pyx":669
 *             param: arg
 *             for arg, param in zip(
 *                 self._dataclass_params.arguments,             # <<<<<<<<<<<<<<
 *                 self._dataclass_params.parameters
 *             )
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass_params, __pyx_n_s_arguments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L35_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "serpyco/serializer.pyx":670
 *             for arg, param in zip(
 *                 self._dataclass_params.arguments,
 *                 self._dataclass_params.parameters             # <<<<<<<<<<<<<<
 *             )
 *         }
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_dataclass_params, __pyx_n_s_parameters); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L35_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "serpyco/serializer.pyx":668
 *         param_args = {
 *             param: arg
 *             for arg, param in zip(             # <<<<<<<<<<<<<<
 *                 self._dataclass_params.arguments,
 *                 self._dataclass_params.parameters
 */
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 668, __pyx_L35_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 668, __pyx_L35_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1)) __PYX_ERR(0, 668, __pyx_L35_error);
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L35_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5); __pyx_t_14 = 0;
      __pyx_t_12 = NULL;
    } else {
      __pyx_t_14 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 668, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 668, __pyx_L35_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_12)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_14 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_14); __Pyx_INCREF(__pyx_t_1); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 668, __pyx_L35_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          if (__pyx_t_14 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_14); __Pyx_INCREF(__pyx_t_1); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 668, __pyx_L35_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_12(__pyx_t_5);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 668, __pyx_L35_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 668, __pyx_L35_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        #else
        __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L35_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 668, __pyx_L35_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_15 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 668, __pyx_L35_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_16 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_15);
        index = 0; __pyx_t_2 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_2)) goto __pyx_L38_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_3 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_3)) goto __pyx_L38_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_15), 2) < 0) __PYX_ERR(0, 668, __pyx_L35_error)
        __pyx_t_16 = NULL;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        goto __pyx_L39_unpacking_done;
        __pyx_L38_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_16 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 668, __pyx_L35_error)
        __pyx_L39_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr7__pyx_v_arg, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_8genexpr7__pyx_v_param, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "serpyco/serializer.pyx":667
 * 
 *         param_args = {
 *             param: arg             # <<<<<<<<<<<<<<
 *             for arg, param in zip(
 *                 self._dataclass_params.arguments,
 */
      if (unlikely(PyDict_SetItem(__pyx_t_7, (PyObject*)__pyx_8genexpr7__pyx_v_param, (PyObject*)__pyx_8genexpr7__pyx_v_arg))) __PYX_ERR(0, 667, __pyx_L35_error)

      /* "serpyco/serializer.pyx":668
 *         param_args = {
 *             param: arg
 *             for arg, param in zip(             # <<<<<<<<<<<<<<
 *                 self._dataclass_params.arguments,
 *                 self._dataclass_params.parameters
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_arg); __pyx_8genexpr7__pyx_v_arg = 0;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_param); __pyx_8genexpr7__pyx_v_param = 0;
    goto __pyx_L41_exit_scope;
    __pyx_L35_error:;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_arg); __pyx_8genexpr7__pyx_v_arg = 0;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_param); __pyx_8genexpr7__pyx_v_param = 0;
    goto __pyx_L1_error;
    __pyx_L41_exit_scope:;
  } /* exit inner scope */
  __pyx_v_param_args = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "serpyco/serializer.pyx":673
 *             )
 *         }
 *         try:             # <<<<<<<<<<<<<<
 *             params = _DataClassParams(field_type, param_args)
 *         except NotADataClassError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "serpyco/serializer.pyx":674
 *         }
 *         try:
 *             params = _DataClassParams(field_type, param_args)             # <<<<<<<<<<<<<<
 *         except NotADataClassError:
 *             raise NoEncoderError(f"No encoder for '{field_type}'")
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_DataClassParams); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 674, __pyx_L42_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_field_type, __pyx_v_param_args};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L42_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_v_params = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "serpyco/serializer.pyx":673
 *             )
 *         }
 *         try:             # <<<<<<<<<<<<<<
 *             params = _DataClassParams(field_type, param_args)
 *         except NotADataClassError:
 */
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L47_try_end;
    __pyx_L42_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":675
 *         try:
 *             params = _DataClassParams(field_type, param_args)
 *         except NotADataClassError:             # <<<<<<<<<<<<<<
 *             raise NoEncoderError(f"No encoder for '{field_type}'")
 * 
 */
    __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_5, &__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_NotADataClassError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 675, __pyx_L44_except_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_7, __pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_ErrRestore(__pyx_t_7, __pyx_t_5, __pyx_t_1);
    __pyx_t_7 = 0; __pyx_t_5 = 0; __pyx_t_1 = 0;
    if (__pyx_t_4) {
      __Pyx_AddTraceback("serpyco.serializer.Serializer._get_encoder", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 675, __pyx_L44_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "serpyco/serializer.pyx":676
 *             params = _DataClassParams(field_type, param_args)
 *         except NotADataClassError:
 *             raise NoEncoderError(f"No encoder for '{field_type}'")             # <<<<<<<<<<<<<<
 * 
 *         # See if one of our "ancestors" handles this dataclass.
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_NoEncoderError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 676, __pyx_L44_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 676, __pyx_L44_except_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_14 = 0;
      __pyx_t_17 = 127;
      __Pyx_INCREF(__pyx_kp_u_No_encoder_for);
      __pyx_t_14 += 16;
      __Pyx_GIVEREF(__pyx_kp_u_No_encoder_for);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u_No_encoder_for);
      __pyx_t_18 = __Pyx_PyObject_FormatSimple(__pyx_v_field_type, __pyx_empty_unicode); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 676, __pyx_L44_except_error)
      __Pyx_GOTREF(__pyx_t_18);
      __pyx_t_17 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_18) > __pyx_t_17) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_18) : __pyx_t_17;
      __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_18);
      __Pyx_GIVEREF(__pyx_t_18);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_18);
      __pyx_t_18 = 0;
      __Pyx_INCREF(__pyx_kp_u__3);
      __pyx_t_14 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__3);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_kp_u__3);
      __pyx_t_18 = __Pyx_PyUnicode_Join(__pyx_t_15, 3, __pyx_t_14, __pyx_t_17); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 676, __pyx_L44_except_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_15)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_t_18};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 676, __pyx_L44_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 676, __pyx_L44_except_error)
    }
    goto __pyx_L44_except_error;

    /* "serpyco/serializer.pyx":673
 *             )
 *         }
 *         try:             # <<<<<<<<<<<<<<
 *             params = _DataClassParams(field_type, param_args)
 *         except NotADataClassError:
 */
    __pyx_L44_except_error:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L47_try_end:;
  }

  /* "serpyco/serializer.pyx":681
 *         # This avoids infinite recursion if dataclasses establish a cycle
 *         excluded_field_names = tuple(
 *             f.name for f in dataclasses.fields(params.type_)             # <<<<<<<<<<<<<<
 *             if (
 *                 hints.ignore
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_dataclasses); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_fields); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_params, __pyx_n_s_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = __pyx_pf_7serpyco_10serializer_10Serializer_12_get_encoder_genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "serpyco/serializer.pyx":680
 *         # See if one of our "ancestors" handles this dataclass.
 *         # This avoids infinite recursion if dataclasses establish a cycle
 *         excluded_field_names = tuple(             # <<<<<<<<<<<<<<
 *             f.name for f in dataclasses.fields(params.type_)
 *             if (
 */
  __pyx_t_7 = __Pyx_PySequence_Tuple(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_excluded_field_names = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "serpyco/serializer.pyx":688
 *             )
 *         )
 *         h = hash((params.type_, params.arguments, excluded_field_names))             # <<<<<<<<<<<<<<
 * 
 *         for serializer in self._parent_serializers:
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_params, __pyx_n_s_type); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_params, __pyx_n_s_arguments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(0, 688, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_excluded_field_names);
  __Pyx_GIVEREF(__pyx_v_excluded_field_names);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_excluded_field_names)) __PYX_ERR(0, 688, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_1 = 0;
  __pyx_t_19 = PyObject_Hash(__pyx_t_5); if (unlikely(__pyx_t_19 == ((Py_hash_t)-1))) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_h = __pyx_t_19;

  /* "serpyco/serializer.pyx":690
 *         h = hash((params.type_, params.arguments, excluded_field_names))
 * 
 *         for serializer in self._parent_serializers:             # <<<<<<<<<<<<<<
 *             sh = hash(serializer)
 *             if h == sh:
 */
  if (unlikely(__pyx_v_self->_parent_serializers == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 690, __pyx_L1_error)
  }
  __pyx_t_5 = __pyx_v_self->_parent_serializers; __Pyx_INCREF(__pyx_t_5); __pyx_t_14 = 0;
  for (;;) {
    if (__pyx_t_14 >= PyList_GET_SIZE(__pyx_t_5)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_14); __Pyx_INCREF(__pyx_t_1); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 690, __pyx_L1_error)
    #else
    __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7serpyco_10serializer_Serializer))))) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_serializer, ((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":691
 * 
 *         for serializer in self._parent_serializers:
 *             sh = hash(serializer)             # <<<<<<<<<<<<<<
 *             if h == sh:
 *                 break
 */
    __pyx_t_19 = PyObject_Hash(((PyObject *)__pyx_v_serializer)); if (unlikely(__pyx_t_19 == ((Py_hash_t)-1))) __PYX_ERR(0, 691, __pyx_L1_error)
    __pyx_v_sh = __pyx_t_19;

    /* "serpyco/serializer.pyx":692
 *         for serializer in self._parent_serializers:
 *             sh = hash(serializer)
 *             if h == sh:             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
    __pyx_t_13 = (__pyx_v_h == __pyx_v_sh);
    if (__pyx_t_13) {

      /* "serpyco/serializer.pyx":693
 *             sh = hash(serializer)
 *             if h == sh:
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             serializer = Serializer(
 */
      goto __pyx_L51_break;

      /* "serpyco/serializer.pyx":692
 *         for serializer in self._parent_serializers:
 *             sh = hash(serializer)
 *             if h == sh:             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
    }

    /* "serpyco/serializer.pyx":690
 *         h = hash((params.type_, params.arguments, excluded_field_names))
 * 
 *         for serializer in self._parent_serializers:             # <<<<<<<<<<<<<<
 *             sh = hash(serializer)
 *             if h == sh:
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  goto __pyx_L53_for_else;
  __pyx_L51_break:;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  goto __pyx_L54_for_end;
  /*else*/ {
    __pyx_L53_for_else:;

    /* "serpyco/serializer.pyx":695
 *                 break
 *         else:
 *             serializer = Serializer(             # <<<<<<<<<<<<<<
 *                 field_type,
 *                 type_encoders=hints.type_encoders or self._type_encoders,
 */
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_field_type);
    __Pyx_GIVEREF(__pyx_v_field_type);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_field_type)) __PYX_ERR(0, 695, __pyx_L1_error);

    /* "serpyco/serializer.pyx":697
 *             serializer = Serializer(
 *                 field_type,
 *                 type_encoders=hints.type_encoders or self._type_encoders,             # <<<<<<<<<<<<<<
 *                 only=hints.only,
 *                 exclude=hints.exclude,
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_hints, __pyx_n_s_type_encoders); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 697, __pyx_L1_error)
    if (!__pyx_t_13) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_7 = __pyx_t_3;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L55_bool_binop_done;
    }
    __Pyx_INCREF(__pyx_v_self->_type_encoders);
    __pyx_t_7 = __pyx_v_self->_type_encoders;
    __pyx_L55_bool_binop_done:;
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type_encoders, __pyx_t_7) < 0) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":698
 *                 field_type,
 *                 type_encoders=hints.type_encoders or self._type_encoders,
 *                 only=hints.only,             # <<<<<<<<<<<<<<
 *                 exclude=hints.exclude,
 *                 load_as_type=hints.load_as_type,
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_hints, __pyx_n_s_only); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_only, __pyx_t_7) < 0) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":699
 *                 type_encoders=hints.type_encoders or self._type_encoders,
 *                 only=hints.only,
 *                 exclude=hints.exclude,             # <<<<<<<<<<<<<<
 *                 load_as_type=hints.load_as_type,
 *                 _parent_serializers=self._parent_serializers,
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_hints, __pyx_n_s_exclude); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 699, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_exclude, __pyx_t_7) < 0) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":700
 *                 only=hints.only,
 *                 exclude=hints.exclude,
 *                 load_as_type=hints.load_as_type,             # <<<<<<<<<<<<<<
 *                 _parent_serializers=self._parent_serializers,
 *                 _dataclass_params=params,
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_hints, __pyx_n_s_load_as_type); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_load_as_type, __pyx_t_7) < 0) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "serpyco/serializer.pyx":701
 *                 exclude=hints.exclude,
 *                 load_as_type=hints.load_as_type,
 *                 _parent_serializers=self._parent_serializers,             # <<<<<<<<<<<<<<
 *                 _dataclass_params=params,
 *             )
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_parent_serializers, __pyx_v_self->_parent_serializers) < 0) __PYX_ERR(0, 697, __pyx_L1_error)

    /* "serpyco/serializer.pyx":702
 *                 load_as_type=hints.load_as_type,
 *                 _parent_serializers=self._parent_serializers,
 *                 _dataclass_params=params,             # <<<<<<<<<<<<<<
 *             )
 *         return DataClassFieldEncoder(serializer)
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dataclass_params, __pyx_v_params) < 0) __PYX_ERR(0, 697, __pyx_L1_error)

    /* "serpyco/serializer.pyx":695
 *                 break
 *         else:
 *             serializer = Serializer(             # <<<<<<<<<<<<<<
 *                 field_type,
 *                 type_encoders=hints.type_encoders or self._type_encoders,
 */
    __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer), __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_serializer, ((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_t_7));
    __pyx_t_7 = 0;
  }
  __pyx_L54_for_end:;

  /* "serpyco/serializer.pyx":704
 *                 _dataclass_params=params,
 *             )
 *         return DataClassFieldEncoder(serializer)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder), ((PyObject *)__pyx_v_serializer)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":598
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 * 
 *     def _get_encoder(self, field_type, hints):             # <<<<<<<<<<<<<<
 *         cdef DataClassFieldEncoder dencoder
 *         cdef Serializer serializer
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("serpyco.serializer.Serializer._get_encoder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_dencoder);
  __Pyx_XDECREF((PyObject *)__pyx_v_serializer);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_type_encoders);
  __Pyx_XDECREF(__pyx_v_key_encoder);
  __Pyx_XDECREF(__pyx_v_value_encoder);
  __Pyx_XDECREF(__pyx_v_item_encoders);
  __Pyx_XDECREF(__pyx_v_item_encoder);
  __Pyx_XDECREF(__pyx_v_param_args);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_excluded_field_names);
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_item_type);
  __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_arg_type);
  __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_arg);
  __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_param);
  __Pyx_XDECREF(__pyx_gb_7serpyco_10serializer_10Serializer_12_get_encoder_2generator1);
  __Pyx_XDECREF(__pyx_v_field_type);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_29__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_28__reduce_cython__, "Serializer.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_29__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_29__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_28__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_29__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_28__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_31__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_10Serializer_30__setstate_cython__, "Serializer.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_10Serializer_31__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_31__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_30__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_10Serializer_31__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_10Serializer_30__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_10Serializer_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.Serializer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":712
 *     cdef object _enum_type
 * 
 *     def __cinit__(self, enum_type):             # <<<<<<<<<<<<<<
 *         self._enum_type = enum_type
 * 
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_enum_type = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 712, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_enum_type,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_enum_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 712, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 712, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_enum_type = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 712, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder___cinit__(((struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)__pyx_v_self), __pyx_v_enum_type);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_enum_type) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":713
 * 
 *     def __cinit__(self, enum_type):
 *         self._enum_type = enum_type             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value: typing.Any):
 */
  __Pyx_INCREF(__pyx_v_enum_type);
  __Pyx_GIVEREF(__pyx_v_enum_type);
  __Pyx_GOTREF(__pyx_v_self->_enum_type);
  __Pyx_DECREF(__pyx_v_self->_enum_type);
  __pyx_v_self->_enum_type = __pyx_v_enum_type;

  /* "serpyco/serializer.pyx":712
 *     cdef object _enum_type
 * 
 *     def __cinit__(self, enum_type):             # <<<<<<<<<<<<<<
 *         self._enum_type = enum_type
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":715
 *         self._enum_type = enum_type
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return value.value
 * 
 */

static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_3dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16EnumFieldEncoder_dump(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":716
 * 
 *     cpdef inline dump(self, value: typing.Any):
 *         return value.value             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value: typing.Any):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_n_s_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":715
 *         self._enum_type = enum_type
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return value.value
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_3dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_2dump, "EnumFieldEncoder.dump(self, value: typing.Any)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_3dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_3dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_2dump};
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_3dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 715, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 715, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 715, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 715, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_2dump(((struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_2dump(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_16EnumFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":718
 *         return value.value
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return self._enum_type(value)
 * 
 */

static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_5load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16EnumFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":719
 * 
 *     cpdef inline load(self, value: typing.Any):
 *         return self._enum_type(value)             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_enum_type);
  __pyx_t_2 = __pyx_v_self->_enum_type; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_value};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":718
 *         return value.value
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return self._enum_type(value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_5load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_4load, "EnumFieldEncoder.load(self, value: typing.Any)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_5load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_5load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_4load};
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_5load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 718, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 718, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 718, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 718, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_4load(((struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_4load(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_16EnumFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":721
 *         return self._enum_type(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_6json_schema, "EnumFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_7json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_6json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 721, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_6json_schema(((struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":722
 * 
 *     def json_schema(self) -> JsonDict:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":721
 *         return self._enum_type(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_8__reduce_cython__, "EnumFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_8__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_8__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_10__setstate_cython__, "EnumFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_10__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_10__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16EnumFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.EnumFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":729
 *     cdef Serializer _serializer
 * 
 *     def __cinit__(self, Serializer serializer):             # <<<<<<<<<<<<<<
 *         self._serializer = serializer
 * 
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_serializer = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 729, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_serializer,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_serializer)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 729, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 729, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_serializer = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 729, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_serializer), __pyx_ptype_7serpyco_10serializer_Serializer, 1, "serializer", 0))) __PYX_ERR(0, 729, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder___cinit__(((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_v_self), __pyx_v_serializer);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, struct __pyx_obj_7serpyco_10serializer_Serializer *__pyx_v_serializer) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":730
 * 
 *     def __cinit__(self, Serializer serializer):
 *         self._serializer = serializer             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value):
 */
  __Pyx_INCREF((PyObject *)__pyx_v_serializer);
  __Pyx_GIVEREF((PyObject *)__pyx_v_serializer);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_serializer);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_serializer);
  __pyx_v_self->_serializer = __pyx_v_serializer;

  /* "serpyco/serializer.pyx":729
 *     cdef Serializer _serializer
 * 
 *     def __cinit__(self, Serializer serializer):             # <<<<<<<<<<<<<<
 *         self._serializer = serializer
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":732
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._load(value)
 * 
 */

static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":733
 * 
 *     cpdef inline load(self, value):
 *         return self._serializer._load(value)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyDict_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_v_value))) __PYX_ERR(0, 733, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_10Serializer__load(__pyx_v_self->_serializer, ((PyObject*)__pyx_v_value)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":732
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._load(value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_2load, "DataClassFieldEncoder.load(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_3load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_3load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_2load};
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 732, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 732, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 732, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 732, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_2load(((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":735
 *         return self._serializer._load(value)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._dump(value)
 * 
 */

static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":736
 * 
 *     cpdef inline dump(self, value):
 *         return self._serializer._dump(value)             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_10Serializer__dump(__pyx_v_self->_serializer, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":735
 *         return self._serializer._load(value)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._dump(value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_4dump, "DataClassFieldEncoder.dump(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_5dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_5dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_4dump};
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 735, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 735, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 735, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 735, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_4dump(((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":738
 *         return self._serializer._dump(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_6json_schema, "DataClassFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_7json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_6json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 738, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_6json_schema(((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":739
 * 
 *     def json_schema(self) -> JsonDict:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":738
 *         return self._serializer._dump(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_8__reduce_cython__, "DataClassFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_8__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_8__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_10__setstate_cython__, "DataClassFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_10__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_10__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_21DataClassFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":747
 *     cdef object _iterable_type
 * 
 *     def __cinit__(self, serializer, sequence_type):             # <<<<<<<<<<<<<<
 *         origin = typing_inspect.get_origin(sequence_type)
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_serializer = 0;
  PyObject *__pyx_v_sequence_type = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 747, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_serializer,&__pyx_n_s_sequence_type,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_serializer)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 747, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sequence_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 747, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(0, 747, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 747, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_serializer = values[0];
    __pyx_v_sequence_type = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 747, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder___cinit__(((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)__pyx_v_self), __pyx_v_serializer, __pyx_v_sequence_type);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_serializer, PyObject *__pyx_v_sequence_type) {
  PyObject *__pyx_v_origin = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":748
 * 
 *     def __cinit__(self, serializer, sequence_type):
 *         origin = typing_inspect.get_origin(sequence_type)             # <<<<<<<<<<<<<<
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 *         self._serializer = serializer
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_typing_inspect); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_origin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_sequence_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_origin = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":749
 *     def __cinit__(self, serializer, sequence_type):
 *         origin = typing_inspect.get_origin(sequence_type)
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)             # <<<<<<<<<<<<<<
 *         self._serializer = serializer
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ITERABLE_TYPES_MAPPING); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_origin, __pyx_v_origin};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_iterable_type);
  __Pyx_DECREF(__pyx_v_self->_iterable_type);
  __pyx_v_self->_iterable_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":750
 *         origin = typing_inspect.get_origin(sequence_type)
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 *         self._serializer = serializer             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value):
 */
  if (!(likely(((__pyx_v_serializer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_serializer, __pyx_ptype_7serpyco_10serializer_Serializer))))) __PYX_ERR(0, 750, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_serializer;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_serializer);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_serializer);
  __pyx_v_self->_serializer = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":747
 *     cdef object _iterable_type
 * 
 *     def __cinit__(self, serializer, sequence_type):             # <<<<<<<<<<<<<<
 *         origin = typing_inspect.get_origin(sequence_type)
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origin);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":752
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef lst = [
 *             self._serializer._load(v)
 */

static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_lst = 0;
  PyObject *__pyx_8genexpr9__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":753
 * 
 *     cpdef inline load(self, value):
 *         cdef lst = [             # <<<<<<<<<<<<<<
 *             self._serializer._load(v)
 *             if v is not None
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 753, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "serpyco/serializer.pyx":757
 *             if v is not None
 *             else None
 *             for v in value             # <<<<<<<<<<<<<<
 *         ]
 *         return self._iterable_type(lst)
 */
    if (likely(PyList_CheckExact(__pyx_v_value)) || PyTuple_CheckExact(__pyx_v_value)) {
      __pyx_t_2 = __pyx_v_value; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 757, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 757, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 757, __pyx_L5_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 757, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 757, __pyx_L5_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 757, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 757, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr9__pyx_v_v, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "serpyco/serializer.pyx":755
 *         cdef lst = [
 *             self._serializer._load(v)
 *             if v is not None             # <<<<<<<<<<<<<<
 *             else None
 *             for v in value
 */
      __pyx_t_6 = (__pyx_8genexpr9__pyx_v_v != Py_None);
      if (__pyx_t_6) {

        /* "serpyco/serializer.pyx":754
 *     cpdef inline load(self, value):
 *         cdef lst = [
 *             self._serializer._load(v)             # <<<<<<<<<<<<<<
 *             if v is not None
 *             else None
 */
        if (!(likely(PyDict_CheckExact(__pyx_8genexpr9__pyx_v_v))||((__pyx_8genexpr9__pyx_v_v) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_8genexpr9__pyx_v_v))) __PYX_ERR(0, 754, __pyx_L5_error)
        __pyx_t_7 = __pyx_f_7serpyco_10serializer_10Serializer__load(__pyx_v_self->_serializer, ((PyObject*)__pyx_8genexpr9__pyx_v_v)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 754, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __pyx_t_7;
        __pyx_t_7 = 0;
      } else {

        /* "serpyco/serializer.pyx":756
 *             self._serializer._load(v)
 *             if v is not None
 *             else None             # <<<<<<<<<<<<<<
 *             for v in value
 *         ]
 */
        __Pyx_INCREF(Py_None);
        __pyx_t_5 = Py_None;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 753, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "serpyco/serializer.pyx":757
 *             if v is not None
 *             else None
 *             for v in value             # <<<<<<<<<<<<<<
 *         ]
 *         return self._iterable_type(lst)
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_v); __pyx_8genexpr9__pyx_v_v = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_v); __pyx_8genexpr9__pyx_v_v = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_lst = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":759
 *             for v in value
 *         ]
 *         return self._iterable_type(lst)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_iterable_type);
  __pyx_t_2 = __pyx_v_self->_iterable_type; __pyx_t_5 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_lst};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":752
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef lst = [
 *             self._serializer._load(v)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lst);
  __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_2load, "DataClassIterableFieldEncoder.load(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_3load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_3load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_2load};
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 752, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 752, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 752, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 752, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_2load(((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":761
 *         return self._iterable_type(lst)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return [
 *             self._serializer._dump(v)
 */

static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_9genexpr10__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":762
 * 
 *     cpdef inline dump(self, value):
 *         return [             # <<<<<<<<<<<<<<
 *             self._serializer._dump(v)
 *             if v is not None
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 762, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "serpyco/serializer.pyx":766
 *             if v is not None
 *             else None
 *             for v in value             # <<<<<<<<<<<<<<
 *         ]
 * 
 */
    if (likely(PyList_CheckExact(__pyx_v_value)) || PyTuple_CheckExact(__pyx_v_value)) {
      __pyx_t_2 = __pyx_v_value; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 766, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 766, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 766, __pyx_L5_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 766, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 766, __pyx_L5_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 766, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 766, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr10__pyx_v_v, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "serpyco/serializer.pyx":764
 *         return [
 *             self._serializer._dump(v)
 *             if v is not None             # <<<<<<<<<<<<<<
 *             else None
 *             for v in value
 */
      __pyx_t_6 = (__pyx_9genexpr10__pyx_v_v != Py_None);
      if (__pyx_t_6) {

        /* "serpyco/serializer.pyx":763
 *     cpdef inline dump(self, value):
 *         return [
 *             self._serializer._dump(v)             # <<<<<<<<<<<<<<
 *             if v is not None
 *             else None
 */
        __pyx_t_7 = __pyx_f_7serpyco_10serializer_10Serializer__dump(__pyx_v_self->_serializer, __pyx_9genexpr10__pyx_v_v); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 763, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __pyx_t_7;
        __pyx_t_7 = 0;
      } else {

        /* "serpyco/serializer.pyx":765
 *             self._serializer._dump(v)
 *             if v is not None
 *             else None             # <<<<<<<<<<<<<<
 *             for v in value
 *         ]
 */
        __Pyx_INCREF(Py_None);
        __pyx_t_5 = Py_None;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 762, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "serpyco/serializer.pyx":766
 *             if v is not None
 *             else None
 *             for v in value             # <<<<<<<<<<<<<<
 *         ]
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_v); __pyx_9genexpr10__pyx_v_v = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_v); __pyx_9genexpr10__pyx_v_v = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":761
 *         return self._iterable_type(lst)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return [
 *             self._serializer._dump(v)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_4dump, "DataClassIterableFieldEncoder.dump(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_5dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_5dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_4dump};
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 761, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 761, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 761, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 761, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_4dump(((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":769
 *         ]
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_6json_schema, "DataClassIterableFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_7json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_6json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 769, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_6json_schema(((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":770
 * 
 *     def json_schema(self) -> JsonDict:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":769
 *         ]
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_8__reduce_cython__, "DataClassIterableFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_8__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_8__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_10__setstate_cython__, "DataClassIterableFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_10__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_10__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_29DataClassIterableFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.DataClassIterableFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":778
 *     cdef int _item_encoders_count
 * 
 *     def __cinit__(self, item_encoders):             # <<<<<<<<<<<<<<
 *         self._item_encoders = tuple(item_encoders)
 *         self._item_encoders_count = len(self._item_encoders)
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_item_encoders = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 778, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_item_encoders,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_item_encoders)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 778, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 778, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_item_encoders = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 778, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder___cinit__(((struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)__pyx_v_self), __pyx_v_item_encoders);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_item_encoders) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":779
 * 
 *     def __cinit__(self, item_encoders):
 *         self._item_encoders = tuple(item_encoders)             # <<<<<<<<<<<<<<
 *         self._item_encoders_count = len(self._item_encoders)
 * 
 */
  __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_v_item_encoders); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_item_encoders);
  __Pyx_DECREF(__pyx_v_self->_item_encoders);
  __pyx_v_self->_item_encoders = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":780
 *     def __cinit__(self, item_encoders):
 *         self._item_encoders = tuple(item_encoders)
 *         self._item_encoders_count = len(self._item_encoders)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value: typing.Any):
 */
  __pyx_t_1 = __pyx_v_self->_item_encoders;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 780, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyTuple_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 780, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->_item_encoders_count = __pyx_t_2;

  /* "serpyco/serializer.pyx":778
 *     cdef int _item_encoders_count
 * 
 *     def __cinit__(self, item_encoders):             # <<<<<<<<<<<<<<
 *         self._item_encoders = tuple(item_encoders)
 *         self._item_encoders_count = len(self._item_encoders)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":782
 *         self._item_encoders_count = len(self._item_encoders)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */

static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder = 0;
  int __pyx_v_i;
  PyObject *__pyx_v_decoded = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":785
 *         cdef FieldEncoder encoder
 *         cdef int i
 *         decoded = []             # <<<<<<<<<<<<<<
 *         if len(value) != self._item_encoders_count:
 *             raise ValidationError("Invalid number of items for tuple")
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_decoded = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":786
 *         cdef int i
 *         decoded = []
 *         if len(value) != self._item_encoders_count:             # <<<<<<<<<<<<<<
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_value); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 786, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != __pyx_v_self->_item_encoders_count);
  if (unlikely(__pyx_t_3)) {

    /* "serpyco/serializer.pyx":787
 *         decoded = []
 *         if len(value) != self._item_encoders_count:
 *             raise ValidationError("Invalid number of items for tuple")             # <<<<<<<<<<<<<<
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_Invalid_number_of_items_for_tupl};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 787, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 787, __pyx_L1_error)

    /* "serpyco/serializer.pyx":786
 *         cdef int i
 *         decoded = []
 *         if len(value) != self._item_encoders_count:             # <<<<<<<<<<<<<<
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):
 */
  }

  /* "serpyco/serializer.pyx":788
 *         if len(value) != self._item_encoders_count:
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):             # <<<<<<<<<<<<<<
 *             encoder = self._item_encoders[i]
 *             if encoder:
 */
  __pyx_t_6 = __pyx_v_self->_item_encoders_count;
  __pyx_t_7 = __pyx_t_6;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "serpyco/serializer.pyx":789
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]             # <<<<<<<<<<<<<<
 *             if encoder:
 *                 decoded.append(encoder.load(value[i]))
 */
    if (unlikely(__pyx_v_self->_item_encoders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 789, __pyx_L1_error)
    }
    if (!(likely(((PyTuple_GET_ITEM(__pyx_v_self->_item_encoders, __pyx_v_i)) == Py_None) || likely(__Pyx_TypeTest(PyTuple_GET_ITEM(__pyx_v_self->_item_encoders, __pyx_v_i), __pyx_ptype_7serpyco_7encoder_FieldEncoder))))) __PYX_ERR(0, 789, __pyx_L1_error)
    __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v_self->_item_encoders, __pyx_v_i);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_encoder, ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":790
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]
 *             if encoder:             # <<<<<<<<<<<<<<
 *                 decoded.append(encoder.load(value[i]))
 *             else:
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_encoder)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 790, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "serpyco/serializer.pyx":791
 *             encoder = self._item_encoders[i]
 *             if encoder:
 *                 decoded.append(encoder.load(value[i]))             # <<<<<<<<<<<<<<
 *             else:
 *                 decoded.append(value[i])
 */
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 791, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_encoder->__pyx_vtab)->load(__pyx_v_encoder, __pyx_t_1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 791, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_decoded, __pyx_t_4); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 791, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":790
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]
 *             if encoder:             # <<<<<<<<<<<<<<
 *                 decoded.append(encoder.load(value[i]))
 *             else:
 */
      goto __pyx_L6;
    }

    /* "serpyco/serializer.pyx":793
 *                 decoded.append(encoder.load(value[i]))
 *             else:
 *                 decoded.append(value[i])             # <<<<<<<<<<<<<<
 *         return tuple(decoded)
 * 
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_value, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_decoded, __pyx_t_4); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 793, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L6:;
  }

  /* "serpyco/serializer.pyx":794
 *             else:
 *                 decoded.append(value[i])
 *         return tuple(decoded)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value: typing.Any):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyList_AsTuple(__pyx_v_decoded); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":782
 *         self._item_encoders_count = len(self._item_encoders)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_encoder);
  __Pyx_XDECREF(__pyx_v_decoded);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_2load, "FixedTupleFieldEncoder.load(self, value: typing.Any)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_3load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_3load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_2load};
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 782, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 782, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 782, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 782, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_2load(((struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":796
 *         return tuple(decoded)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */

static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  struct __pyx_obj_7serpyco_7encoder_FieldEncoder *__pyx_v_encoder = 0;
  int __pyx_v_i;
  PyObject *__pyx_v_encoded = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":799
 *         cdef FieldEncoder encoder
 *         cdef int i
 *         encoded = []             # <<<<<<<<<<<<<<
 *         if len(value) != self._item_encoders_count:
 *             raise ValidationError("Invalid number of items for tuple")
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_encoded = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":800
 *         cdef int i
 *         encoded = []
 *         if len(value) != self._item_encoders_count:             # <<<<<<<<<<<<<<
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):
 */
  __pyx_t_2 = PyObject_Length(__pyx_v_value); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 800, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != __pyx_v_self->_item_encoders_count);
  if (unlikely(__pyx_t_3)) {

    /* "serpyco/serializer.pyx":801
 *         encoded = []
 *         if len(value) != self._item_encoders_count:
 *             raise ValidationError("Invalid number of items for tuple")             # <<<<<<<<<<<<<<
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_Invalid_number_of_items_for_tupl};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 801, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 801, __pyx_L1_error)

    /* "serpyco/serializer.pyx":800
 *         cdef int i
 *         encoded = []
 *         if len(value) != self._item_encoders_count:             # <<<<<<<<<<<<<<
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):
 */
  }

  /* "serpyco/serializer.pyx":802
 *         if len(value) != self._item_encoders_count:
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):             # <<<<<<<<<<<<<<
 *             encoder = self._item_encoders[i]
 *             if encoder:
 */
  __pyx_t_6 = __pyx_v_self->_item_encoders_count;
  __pyx_t_7 = __pyx_t_6;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "serpyco/serializer.pyx":803
 *             raise ValidationError("Invalid number of items for tuple")
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]             # <<<<<<<<<<<<<<
 *             if encoder:
 *                 encoded.append(encoder.dump(value[i]))
 */
    if (unlikely(__pyx_v_self->_item_encoders == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 803, __pyx_L1_error)
    }
    if (!(likely(((PyTuple_GET_ITEM(__pyx_v_self->_item_encoders, __pyx_v_i)) == Py_None) || likely(__Pyx_TypeTest(PyTuple_GET_ITEM(__pyx_v_self->_item_encoders, __pyx_v_i), __pyx_ptype_7serpyco_7encoder_FieldEncoder))))) __PYX_ERR(0, 803, __pyx_L1_error)
    __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v_self->_item_encoders, __pyx_v_i);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_encoder, ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "serpyco/serializer.pyx":804
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]
 *             if encoder:             # <<<<<<<<<<<<<<
 *                 encoded.append(encoder.dump(value[i]))
 *             else:
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_encoder)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 804, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "serpyco/serializer.pyx":805
 *             encoder = self._item_encoders[i]
 *             if encoder:
 *                 encoded.append(encoder.dump(value[i]))             # <<<<<<<<<<<<<<
 *             else:
 *                 encoded.append(value[i])
 */
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_value, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_encoder->__pyx_vtab)->dump(__pyx_v_encoder, __pyx_t_1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_encoded, __pyx_t_4); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 805, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "serpyco/serializer.pyx":804
 *         for i in range(0, self._item_encoders_count):
 *             encoder = self._item_encoders[i]
 *             if encoder:             # <<<<<<<<<<<<<<
 *                 encoded.append(encoder.dump(value[i]))
 *             else:
 */
      goto __pyx_L6;
    }

    /* "serpyco/serializer.pyx":807
 *                 encoded.append(encoder.dump(value[i]))
 *             else:
 *                 encoded.append(value[i])             # <<<<<<<<<<<<<<
 *         return encoded
 * 
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_value, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 807, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_encoded, __pyx_t_4); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 807, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L6:;
  }

  /* "serpyco/serializer.pyx":808
 *             else:
 *                 encoded.append(value[i])
 *         return encoded             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_encoded);
  __pyx_r = __pyx_v_encoded;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":796
 *         return tuple(decoded)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_encoder);
  __Pyx_XDECREF(__pyx_v_encoded);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_4dump, "FixedTupleFieldEncoder.dump(self, value: typing.Any)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_5dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_5dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_4dump};
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 796, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 796, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 796, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 796, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_4dump(((struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":810
 *         return encoded
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_6json_schema, "FixedTupleFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_7json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_6json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 810, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_6json_schema(((struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":811
 * 
 *     def json_schema(self) -> JsonDict:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":810
 *         return encoded
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_8__reduce_cython__, "FixedTupleFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_8__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_8__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_10__setstate_cython__, "FixedTupleFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_10__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_10__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_22FixedTupleFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.FixedTupleFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":819
 *     cdef object _iterable_type
 * 
 *     def __cinit__(self, item_encoder, sequence_type):             # <<<<<<<<<<<<<<
 *         self._item_encoder = item_encoder
 *         origin = typing_inspect.get_origin(sequence_type)
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_item_encoder = 0;
  PyObject *__pyx_v_sequence_type = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 819, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_item_encoder,&__pyx_n_s_sequence_type,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_item_encoder)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 819, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sequence_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 819, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(0, 819, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 819, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_item_encoder = values[0];
    __pyx_v_sequence_type = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 819, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder___cinit__(((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)__pyx_v_self), __pyx_v_item_encoder, __pyx_v_sequence_type);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_item_encoder, PyObject *__pyx_v_sequence_type) {
  PyObject *__pyx_v_origin = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":820
 * 
 *     def __cinit__(self, item_encoder, sequence_type):
 *         self._item_encoder = item_encoder             # <<<<<<<<<<<<<<
 *         origin = typing_inspect.get_origin(sequence_type)
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 */
  if (!(likely(((__pyx_v_item_encoder) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_item_encoder, __pyx_ptype_7serpyco_7encoder_FieldEncoder))))) __PYX_ERR(0, 820, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_item_encoder;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_item_encoder);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_item_encoder);
  __pyx_v_self->_item_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":821
 *     def __cinit__(self, item_encoder, sequence_type):
 *         self._item_encoder = item_encoder
 *         origin = typing_inspect.get_origin(sequence_type)             # <<<<<<<<<<<<<<
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_typing_inspect); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_origin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_sequence_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_origin = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":822
 *         self._item_encoder = item_encoder
 *         origin = typing_inspect.get_origin(sequence_type)
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value: typing.Any):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ITERABLE_TYPES_MAPPING); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_origin, __pyx_v_origin};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_iterable_type);
  __Pyx_DECREF(__pyx_v_self->_iterable_type);
  __pyx_v_self->_iterable_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":819
 *     cdef object _iterable_type
 * 
 *     def __cinit__(self, item_encoder, sequence_type):             # <<<<<<<<<<<<<<
 *         self._item_encoder = item_encoder
 *         origin = typing_inspect.get_origin(sequence_type)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_origin);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":824
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             value = [
 */

static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20IterableFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_9genexpr11__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_INCREF(__pyx_v_value);

  /* "serpyco/serializer.pyx":825
 * 
 *     cpdef inline load(self, value: typing.Any):
 *         if self._item_encoder:             # <<<<<<<<<<<<<<
 *             value = [
 *                 self._item_encoder.load(v) if v is not None
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_item_encoder)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 825, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":826
 *     cpdef inline load(self, value: typing.Any):
 *         if self._item_encoder:
 *             value = [             # <<<<<<<<<<<<<<
 *                 self._item_encoder.load(v) if v is not None
 *                 else None
 */
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 826, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "serpyco/serializer.pyx":829
 *                 self._item_encoder.load(v) if v is not None
 *                 else None
 *                 for v in value             # <<<<<<<<<<<<<<
 *             ]
 *         return self._iterable_type(value)
 */
      if (likely(PyList_CheckExact(__pyx_v_value)) || PyTuple_CheckExact(__pyx_v_value)) {
        __pyx_t_3 = __pyx_v_value; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
      } else {
        __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 829, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 829, __pyx_L6_error)
      }
      for (;;) {
        if (likely(!__pyx_t_5)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 829, __pyx_L6_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 829, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          } else {
            if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 829, __pyx_L6_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 829, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          }
        } else {
          __pyx_t_6 = __pyx_t_5(__pyx_t_3);
          if (unlikely(!__pyx_t_6)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 829, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr11__pyx_v_v, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "serpyco/serializer.pyx":827
 *         if self._item_encoder:
 *             value = [
 *                 self._item_encoder.load(v) if v is not None             # <<<<<<<<<<<<<<
 *                 else None
 *                 for v in value
 */
        __pyx_t_1 = (__pyx_9genexpr11__pyx_v_v != Py_None);
        if (__pyx_t_1) {
          __pyx_t_7 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_item_encoder->__pyx_vtab)->load(__pyx_v_self->_item_encoder, __pyx_9genexpr11__pyx_v_v, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 827, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = __pyx_t_7;
          __pyx_t_7 = 0;
        } else {

          /* "serpyco/serializer.pyx":828
 *             value = [
 *                 self._item_encoder.load(v) if v is not None
 *                 else None             # <<<<<<<<<<<<<<
 *                 for v in value
 *             ]
 */
          __Pyx_INCREF(Py_None);
          __pyx_t_6 = Py_None;
        }
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 826, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "serpyco/serializer.pyx":829
 *                 self._item_encoder.load(v) if v is not None
 *                 else None
 *                 for v in value             # <<<<<<<<<<<<<<
 *             ]
 *         return self._iterable_type(value)
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
      goto __pyx_L10_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L10_exit_scope:;
    } /* exit inner scope */
    __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "serpyco/serializer.pyx":825
 * 
 *     cpdef inline load(self, value: typing.Any):
 *         if self._item_encoder:             # <<<<<<<<<<<<<<
 *             value = [
 *                 self._item_encoder.load(v) if v is not None
 */
  }

  /* "serpyco/serializer.pyx":831
 *                 for v in value
 *             ]
 *         return self._iterable_type(value)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value: typing.Any):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_iterable_type);
  __pyx_t_3 = __pyx_v_self->_iterable_type; __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_value};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 831, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":824
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             value = [
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_2load, "IterableFieldEncoder.load(self, value: typing.Any)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_3load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_3load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_2load};
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 824, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 824, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 824, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 824, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_2load(((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_20IterableFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":833
 *         return self._iterable_type(value)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             return [
 */

static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20IterableFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_9genexpr12__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":834
 * 
 *     cpdef inline dump(self, value: typing.Any):
 *         if self._item_encoder:             # <<<<<<<<<<<<<<
 *             return [
 *                 self._item_encoder.dump(v) if v is not None
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_item_encoder)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 834, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":835
 *     cpdef inline dump(self, value: typing.Any):
 *         if self._item_encoder:
 *             return [             # <<<<<<<<<<<<<<
 *                 self._item_encoder.dump(v) if v is not None
 *                 else None
 */
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 835, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "serpyco/serializer.pyx":838
 *                 self._item_encoder.dump(v) if v is not None
 *                 else None
 *                 for v in value             # <<<<<<<<<<<<<<
 *             ]
 *         return list(value)
 */
      if (likely(PyList_CheckExact(__pyx_v_value)) || PyTuple_CheckExact(__pyx_v_value)) {
        __pyx_t_3 = __pyx_v_value; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
      } else {
        __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 838, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 838, __pyx_L6_error)
      }
      for (;;) {
        if (likely(!__pyx_t_5)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 838, __pyx_L6_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 838, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          } else {
            if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 838, __pyx_L6_error)
            #else
            __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 838, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          }
        } else {
          __pyx_t_6 = __pyx_t_5(__pyx_t_3);
          if (unlikely(!__pyx_t_6)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 838, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr12__pyx_v_v, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "serpyco/serializer.pyx":836
 *         if self._item_encoder:
 *             return [
 *                 self._item_encoder.dump(v) if v is not None             # <<<<<<<<<<<<<<
 *                 else None
 *                 for v in value
 */
        __pyx_t_1 = (__pyx_9genexpr12__pyx_v_v != Py_None);
        if (__pyx_t_1) {
          __pyx_t_7 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_item_encoder->__pyx_vtab)->dump(__pyx_v_self->_item_encoder, __pyx_9genexpr12__pyx_v_v, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 836, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = __pyx_t_7;
          __pyx_t_7 = 0;
        } else {

          /* "serpyco/serializer.pyx":837
 *             return [
 *                 self._item_encoder.dump(v) if v is not None
 *                 else None             # <<<<<<<<<<<<<<
 *                 for v in value
 *             ]
 */
          __Pyx_INCREF(Py_None);
          __pyx_t_6 = Py_None;
        }
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 835, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "serpyco/serializer.pyx":838
 *                 self._item_encoder.dump(v) if v is not None
 *                 else None
 *                 for v in value             # <<<<<<<<<<<<<<
 *             ]
 *         return list(value)
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_9genexpr12__pyx_v_v); __pyx_9genexpr12__pyx_v_v = 0;
      goto __pyx_L10_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_9genexpr12__pyx_v_v); __pyx_9genexpr12__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L10_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":834
 * 
 *     cpdef inline dump(self, value: typing.Any):
 *         if self._item_encoder:             # <<<<<<<<<<<<<<
 *             return [
 *                 self._item_encoder.dump(v) if v is not None
 */
  }

  /* "serpyco/serializer.pyx":840
 *                 for v in value
 *             ]
 *         return list(value)             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PySequence_List(__pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":833
 *         return self._iterable_type(value)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             return [
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr12__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_4dump, "IterableFieldEncoder.dump(self, value: typing.Any)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_5dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_5dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_4dump};
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 833, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 833, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 833, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 833, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_4dump(((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_20IterableFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":842
 *         return list(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_6json_schema, "IterableFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_7json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_6json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 842, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_6json_schema(((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":843
 * 
 *     def json_schema(self) -> JsonDict:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":842
 *         return list(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_8__reduce_cython__, "IterableFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_8__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_8__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_10__setstate_cython__, "IterableFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_10__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_10__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20IterableFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.IterableFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":851
 *     cdef FieldEncoder _value_encoder
 * 
 *     def __cinit__(self, key_encoder, value_encoder):             # <<<<<<<<<<<<<<
 *         self._key_encoder = key_encoder
 *         self._value_encoder = value_encoder
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_16DictFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_16DictFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_key_encoder = 0;
  PyObject *__pyx_v_value_encoder = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 851, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key_encoder,&__pyx_n_s_value_encoder,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key_encoder)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 851, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value_encoder)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 851, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(0, 851, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 851, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_key_encoder = values[0];
    __pyx_v_value_encoder = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 851, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16DictFieldEncoder___cinit__(((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)__pyx_v_self), __pyx_v_key_encoder, __pyx_v_value_encoder);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_16DictFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_key_encoder, PyObject *__pyx_v_value_encoder) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":852
 * 
 *     def __cinit__(self, key_encoder, value_encoder):
 *         self._key_encoder = key_encoder             # <<<<<<<<<<<<<<
 *         self._value_encoder = value_encoder
 * 
 */
  if (!(likely(((__pyx_v_key_encoder) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_key_encoder, __pyx_ptype_7serpyco_7encoder_FieldEncoder))))) __PYX_ERR(0, 852, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_key_encoder;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_key_encoder);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_key_encoder);
  __pyx_v_self->_key_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":853
 *     def __cinit__(self, key_encoder, value_encoder):
 *         self._key_encoder = key_encoder
 *         self._value_encoder = value_encoder             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value: JsonEncodable):
 */
  if (!(likely(((__pyx_v_value_encoder) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value_encoder, __pyx_ptype_7serpyco_7encoder_FieldEncoder))))) __PYX_ERR(0, 853, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value_encoder;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_value_encoder);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_value_encoder);
  __pyx_v_self->_value_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":851
 *     cdef FieldEncoder _value_encoder
 * 
 *     def __cinit__(self, key_encoder, value_encoder):             # <<<<<<<<<<<<<<
 *         self._key_encoder = key_encoder
 *         self._value_encoder = value_encoder
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":855
 *         self._value_encoder = value_encoder
 * 
 *     cpdef inline load(self, value: JsonEncodable):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */

static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16DictFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_9genexpr13__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr13__pyx_v_v = NULL;
  PyObject *__pyx_9genexpr14__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr14__pyx_v_v = NULL;
  PyObject *__pyx_9genexpr15__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr15__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":856
 * 
 *     cpdef inline load(self, value: JsonEncodable):
 *         if self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.load(k): self._value_encoder.load(v)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_key_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 856, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_value_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 856, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":857
 *     cpdef inline load(self, value: JsonEncodable):
 *         if self._key_encoder and self._value_encoder:
 *             return {             # <<<<<<<<<<<<<<
 *                 self._key_encoder.load(k): self._value_encoder.load(v)
 *                 for k, v in value.items()
 */
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 857, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "serpyco/serializer.pyx":859
 *             return {
 *                 self._key_encoder.load(k): self._value_encoder.load(v)
 *                 for k, v in value.items()             # <<<<<<<<<<<<<<
 *             }
 *         elif self._key_encoder and not self._value_encoder:
 */
      __pyx_t_5 = 0;
      if (unlikely(__pyx_v_value == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 859, __pyx_L8_error)
      }
      __pyx_t_8 = __Pyx_dict_iterator(__pyx_v_value, 0, __pyx_n_s_items, (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 859, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4);
      __pyx_t_4 = __pyx_t_8;
      __pyx_t_8 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_6, &__pyx_t_5, &__pyx_t_8, &__pyx_t_9, NULL, __pyx_t_7);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 859, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_XDECREF_SET(__pyx_9genexpr13__pyx_v_k, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr13__pyx_v_v, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "serpyco/serializer.pyx":858
 *         if self._key_encoder and self._value_encoder:
 *             return {
 *                 self._key_encoder.load(k): self._value_encoder.load(v)             # <<<<<<<<<<<<<<
 *                 for k, v in value.items()
 *             }
 */
        __pyx_t_9 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_key_encoder->__pyx_vtab)->load(__pyx_v_self->_key_encoder, __pyx_9genexpr13__pyx_v_k, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 858, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_8 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_value_encoder->__pyx_vtab)->load(__pyx_v_self->_value_encoder, __pyx_9genexpr13__pyx_v_v, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 858, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(PyDict_SetItem(__pyx_t_3, (PyObject*)__pyx_t_9, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 858, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_k); __pyx_9genexpr13__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_v); __pyx_9genexpr13__pyx_v_v = 0;
      goto __pyx_L11_exit_scope;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_k); __pyx_9genexpr13__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_v); __pyx_9genexpr13__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L11_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":856
 * 
 *     cpdef inline load(self, value: JsonEncodable):
 *         if self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.load(k): self._value_encoder.load(v)
 */
  }

  /* "serpyco/serializer.pyx":861
 *                 for k, v in value.items()
 *             }
 *         elif self._key_encoder and not self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.load(k): v
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_key_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 861, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_value_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 861, __pyx_L1_error)
  __pyx_t_11 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_11;
  __pyx_L12_bool_binop_done:;
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":862
 *             }
 *         elif self._key_encoder and not self._value_encoder:
 *             return {             # <<<<<<<<<<<<<<
 *                 self._key_encoder.load(k): v
 *                 for k, v in value.items()
 */
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 862, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "serpyco/serializer.pyx":864
 *             return {
 *                 self._key_encoder.load(k): v
 *                 for k, v in value.items()             # <<<<<<<<<<<<<<
 *             }
 *         elif not self._key_encoder and self._value_encoder:
 */
      __pyx_t_6 = 0;
      if (unlikely(__pyx_v_value == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 864, __pyx_L16_error)
      }
      __pyx_t_8 = __Pyx_dict_iterator(__pyx_v_value, 0, __pyx_n_s_items, (&__pyx_t_5), (&__pyx_t_7)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 864, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4);
      __pyx_t_4 = __pyx_t_8;
      __pyx_t_8 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_5, &__pyx_t_6, &__pyx_t_8, &__pyx_t_9, NULL, __pyx_t_7);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 864, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_XDECREF_SET(__pyx_9genexpr14__pyx_v_k, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr14__pyx_v_v, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "serpyco/serializer.pyx":863
 *         elif self._key_encoder and not self._value_encoder:
 *             return {
 *                 self._key_encoder.load(k): v             # <<<<<<<<<<<<<<
 *                 for k, v in value.items()
 *             }
 */
        __pyx_t_9 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_key_encoder->__pyx_vtab)->load(__pyx_v_self->_key_encoder, __pyx_9genexpr14__pyx_v_k, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 863, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (unlikely(PyDict_SetItem(__pyx_t_3, (PyObject*)__pyx_t_9, (PyObject*)__pyx_9genexpr14__pyx_v_v))) __PYX_ERR(0, 863, __pyx_L16_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_k); __pyx_9genexpr14__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_v); __pyx_9genexpr14__pyx_v_v = 0;
      goto __pyx_L19_exit_scope;
      __pyx_L16_error:;
      __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_k); __pyx_9genexpr14__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_v); __pyx_9genexpr14__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L19_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":861
 *                 for k, v in value.items()
 *             }
 *         elif self._key_encoder and not self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.load(k): v
 */
  }

  /* "serpyco/serializer.pyx":866
 *                 for k, v in value.items()
 *             }
 *         elif not self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 k: self._value_encoder.load(v)
 */
  __pyx_t_11 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_key_encoder)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 866, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_11);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L20_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_value_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 866, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L20_bool_binop_done:;
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":867
 *             }
 *         elif not self._key_encoder and self._value_encoder:
 *             return {             # <<<<<<<<<<<<<<
 *                 k: self._value_encoder.load(v)
 *                 for k, v in value.items()
 */
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 867, __pyx_L24_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "serpyco/serializer.pyx":869
 *             return {
 *                 k: self._value_encoder.load(v)
 *                 for k, v in value.items()             # <<<<<<<<<<<<<<
 *             }
 *         else:
 */
      __pyx_t_5 = 0;
      if (unlikely(__pyx_v_value == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 869, __pyx_L24_error)
      }
      __pyx_t_9 = __Pyx_dict_iterator(__pyx_v_value, 0, __pyx_n_s_items, (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 869, __pyx_L24_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_4);
      __pyx_t_4 = __pyx_t_9;
      __pyx_t_9 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_6, &__pyx_t_5, &__pyx_t_9, &__pyx_t_8, NULL, __pyx_t_7);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 869, __pyx_L24_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_9genexpr15__pyx_v_k, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr15__pyx_v_v, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "serpyco/serializer.pyx":868
 *         elif not self._key_encoder and self._value_encoder:
 *             return {
 *                 k: self._value_encoder.load(v)             # <<<<<<<<<<<<<<
 *                 for k, v in value.items()
 *             }
 */
        __pyx_t_8 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_value_encoder->__pyx_vtab)->load(__pyx_v_self->_value_encoder, __pyx_9genexpr15__pyx_v_v, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 868, __pyx_L24_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(PyDict_SetItem(__pyx_t_3, (PyObject*)__pyx_9genexpr15__pyx_v_k, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 868, __pyx_L24_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_k); __pyx_9genexpr15__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_v); __pyx_9genexpr15__pyx_v_v = 0;
      goto __pyx_L27_exit_scope;
      __pyx_L24_error:;
      __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_k); __pyx_9genexpr15__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_v); __pyx_9genexpr15__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L27_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":866
 *                 for k, v in value.items()
 *             }
 *         elif not self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 k: self._value_encoder.load(v)
 */
  }

  /* "serpyco/serializer.pyx":872
 *             }
 *         else:
 *             return value             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value: typing.Any):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_value);
    __pyx_r = __pyx_v_value;
    goto __pyx_L0;
  }

  /* "serpyco/serializer.pyx":855
 *         self._value_encoder = value_encoder
 * 
 *     cpdef inline load(self, value: JsonEncodable):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_v);
  __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_v);
  __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16DictFieldEncoder_2load, "DictFieldEncoder.load(self, value: JsonEncodable)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_3load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_3load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_2load};
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 855, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 855, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 855, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 855, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16DictFieldEncoder_2load(((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_16DictFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":874
 *             return value
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */

static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16DictFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_9genexpr16__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr16__pyx_v_v = NULL;
  PyObject *__pyx_9genexpr17__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr17__pyx_v_v = NULL;
  PyObject *__pyx_9genexpr18__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr18__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":875
 * 
 *     cpdef inline dump(self, value: typing.Any):
 *         if self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.dump(k): self._value_encoder.dump(v)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_key_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 875, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_value_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 875, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":876
 *     cpdef inline dump(self, value: typing.Any):
 *         if self._key_encoder and self._value_encoder:
 *             return {             # <<<<<<<<<<<<<<
 *                 self._key_encoder.dump(k): self._value_encoder.dump(v)
 *                 for k, v in value.items()
 */
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 876, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "serpyco/serializer.pyx":878
 *             return {
 *                 self._key_encoder.dump(k): self._value_encoder.dump(v)
 *                 for k, v in value.items()             # <<<<<<<<<<<<<<
 *             }
 *         elif self._key_encoder and not self._value_encoder:
 */
      __pyx_t_5 = 0;
      if (unlikely(__pyx_v_value == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 878, __pyx_L8_error)
      }
      __pyx_t_8 = __Pyx_dict_iterator(__pyx_v_value, 0, __pyx_n_s_items, (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 878, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4);
      __pyx_t_4 = __pyx_t_8;
      __pyx_t_8 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_6, &__pyx_t_5, &__pyx_t_8, &__pyx_t_9, NULL, __pyx_t_7);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 878, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_XDECREF_SET(__pyx_9genexpr16__pyx_v_k, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr16__pyx_v_v, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "serpyco/serializer.pyx":877
 *         if self._key_encoder and self._value_encoder:
 *             return {
 *                 self._key_encoder.dump(k): self._value_encoder.dump(v)             # <<<<<<<<<<<<<<
 *                 for k, v in value.items()
 *             }
 */
        __pyx_t_9 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_key_encoder->__pyx_vtab)->dump(__pyx_v_self->_key_encoder, __pyx_9genexpr16__pyx_v_k, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 877, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_8 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_value_encoder->__pyx_vtab)->dump(__pyx_v_self->_value_encoder, __pyx_9genexpr16__pyx_v_v, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 877, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(PyDict_SetItem(__pyx_t_3, (PyObject*)__pyx_t_9, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 877, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr16__pyx_v_k); __pyx_9genexpr16__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr16__pyx_v_v); __pyx_9genexpr16__pyx_v_v = 0;
      goto __pyx_L11_exit_scope;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_9genexpr16__pyx_v_k); __pyx_9genexpr16__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr16__pyx_v_v); __pyx_9genexpr16__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L11_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":875
 * 
 *     cpdef inline dump(self, value: typing.Any):
 *         if self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.dump(k): self._value_encoder.dump(v)
 */
  }

  /* "serpyco/serializer.pyx":880
 *                 for k, v in value.items()
 *             }
 *         elif self._key_encoder and not self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.dump(k): v
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_key_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 880, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_value_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 880, __pyx_L1_error)
  __pyx_t_11 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_11;
  __pyx_L12_bool_binop_done:;
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":881
 *             }
 *         elif self._key_encoder and not self._value_encoder:
 *             return {             # <<<<<<<<<<<<<<
 *                 self._key_encoder.dump(k): v
 *                 for k, v in value.items()
 */
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 881, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "serpyco/serializer.pyx":883
 *             return {
 *                 self._key_encoder.dump(k): v
 *                 for k, v in value.items()             # <<<<<<<<<<<<<<
 *             }
 *         elif not self._key_encoder and self._value_encoder:
 */
      __pyx_t_6 = 0;
      if (unlikely(__pyx_v_value == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 883, __pyx_L16_error)
      }
      __pyx_t_8 = __Pyx_dict_iterator(__pyx_v_value, 0, __pyx_n_s_items, (&__pyx_t_5), (&__pyx_t_7)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 883, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4);
      __pyx_t_4 = __pyx_t_8;
      __pyx_t_8 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_5, &__pyx_t_6, &__pyx_t_8, &__pyx_t_9, NULL, __pyx_t_7);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 883, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_XDECREF_SET(__pyx_9genexpr17__pyx_v_k, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr17__pyx_v_v, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "serpyco/serializer.pyx":882
 *         elif self._key_encoder and not self._value_encoder:
 *             return {
 *                 self._key_encoder.dump(k): v             # <<<<<<<<<<<<<<
 *                 for k, v in value.items()
 *             }
 */
        __pyx_t_9 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_key_encoder->__pyx_vtab)->dump(__pyx_v_self->_key_encoder, __pyx_9genexpr17__pyx_v_k, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 882, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (unlikely(PyDict_SetItem(__pyx_t_3, (PyObject*)__pyx_t_9, (PyObject*)__pyx_9genexpr17__pyx_v_v))) __PYX_ERR(0, 882, __pyx_L16_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_k); __pyx_9genexpr17__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_v); __pyx_9genexpr17__pyx_v_v = 0;
      goto __pyx_L19_exit_scope;
      __pyx_L16_error:;
      __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_k); __pyx_9genexpr17__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_v); __pyx_9genexpr17__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L19_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":880
 *                 for k, v in value.items()
 *             }
 *         elif self._key_encoder and not self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 self._key_encoder.dump(k): v
 */
  }

  /* "serpyco/serializer.pyx":885
 *                 for k, v in value.items()
 *             }
 *         elif not self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 k: self._value_encoder.dump(v)
 */
  __pyx_t_11 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_key_encoder)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 885, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_11);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L20_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_value_encoder)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 885, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L20_bool_binop_done:;
  if (__pyx_t_1) {

    /* "serpyco/serializer.pyx":886
 *             }
 *         elif not self._key_encoder and self._value_encoder:
 *             return {             # <<<<<<<<<<<<<<
 *                 k: self._value_encoder.dump(v)
 *                 for k, v in value.items()
 */
    __Pyx_XDECREF(__pyx_r);
    { /* enter inner scope */
      __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 886, __pyx_L24_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "serpyco/serializer.pyx":888
 *             return {
 *                 k: self._value_encoder.dump(v)
 *                 for k, v in value.items()             # <<<<<<<<<<<<<<
 *             }
 *         else:
 */
      __pyx_t_5 = 0;
      if (unlikely(__pyx_v_value == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 888, __pyx_L24_error)
      }
      __pyx_t_9 = __Pyx_dict_iterator(__pyx_v_value, 0, __pyx_n_s_items, (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 888, __pyx_L24_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_4);
      __pyx_t_4 = __pyx_t_9;
      __pyx_t_9 = 0;
      while (1) {
        __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_6, &__pyx_t_5, &__pyx_t_9, &__pyx_t_8, NULL, __pyx_t_7);
        if (unlikely(__pyx_t_10 == 0)) break;
        if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 888, __pyx_L24_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_9genexpr18__pyx_v_k, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr18__pyx_v_v, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "serpyco/serializer.pyx":887
 *         elif not self._key_encoder and self._value_encoder:
 *             return {
 *                 k: self._value_encoder.dump(v)             # <<<<<<<<<<<<<<
 *                 for k, v in value.items()
 *             }
 */
        __pyx_t_8 = ((struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder *)__pyx_v_self->_value_encoder->__pyx_vtab)->dump(__pyx_v_self->_value_encoder, __pyx_9genexpr18__pyx_v_v, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 887, __pyx_L24_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(PyDict_SetItem(__pyx_t_3, (PyObject*)__pyx_9genexpr18__pyx_v_k, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 887, __pyx_L24_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_k); __pyx_9genexpr18__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_v); __pyx_9genexpr18__pyx_v_v = 0;
      goto __pyx_L27_exit_scope;
      __pyx_L24_error:;
      __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_k); __pyx_9genexpr18__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_v); __pyx_9genexpr18__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L27_exit_scope:;
    } /* exit inner scope */
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "serpyco/serializer.pyx":885
 *                 for k, v in value.items()
 *             }
 *         elif not self._key_encoder and self._value_encoder:             # <<<<<<<<<<<<<<
 *             return {
 *                 k: self._value_encoder.dump(v)
 */
  }

  /* "serpyco/serializer.pyx":891
 *             }
 *         else:
 *             return value             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_value);
    __pyx_r = __pyx_v_value;
    goto __pyx_L0;
  }

  /* "serpyco/serializer.pyx":874
 *             return value
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_9genexpr16__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr16__pyx_v_v);
  __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr17__pyx_v_v);
  __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr18__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16DictFieldEncoder_4dump, "DictFieldEncoder.dump(self, value: typing.Any)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_5dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_5dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_4dump};
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_5dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 874, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 874, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 874, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 874, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16DictFieldEncoder_4dump(((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_4dump(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_16DictFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":893
 *             return value
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16DictFieldEncoder_6json_schema, "DictFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_7json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_6json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 893, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16DictFieldEncoder_6json_schema(((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":894
 * 
 *     def json_schema(self) -> JsonDict:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":893
 *             return value
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16DictFieldEncoder_8__reduce_cython__, "DictFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_8__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16DictFieldEncoder_8__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16DictFieldEncoder_10__setstate_cython__, "DictFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_10__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16DictFieldEncoder_10__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16DictFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.DictFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":907
 *     )
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return value.isoformat()
 */

static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_1dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_dump(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":908
 * 
 *     cpdef inline dump(self, value):
 *         try:             # <<<<<<<<<<<<<<
 *             return value.isoformat()
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "serpyco/serializer.pyx":909
 *     cpdef inline dump(self, value):
 *         try:
 *             return value.isoformat()             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             raise ValidationError(f"{value} is not a datetime.datetime instance")
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_n_s_isoformat); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 909, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[1] = {__pyx_t_6, };
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 909, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "serpyco/serializer.pyx":908
 * 
 *     cpdef inline dump(self, value):
 *         try:             # <<<<<<<<<<<<<<
 *             return value.isoformat()
 *         except AttributeError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "serpyco/serializer.pyx":910
 *         try:
 *             return value.isoformat()
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             raise ValidationError(f"{value} is not a datetime.datetime instance")
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 910, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "serpyco/serializer.pyx":911
 *             return value.isoformat()
 *         except AttributeError:
 *             raise ValidationError(f"{value} is not a datetime.datetime instance")             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 911, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_FormatSimple(__pyx_v_value, __pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 911, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_10, __pyx_kp_u_is_not_a_datetime_datetime_inst); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 911, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_11};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 911, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 911, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "serpyco/serializer.pyx":908
 * 
 *     cpdef inline dump(self, value):
 *         try:             # <<<<<<<<<<<<<<
 *             return value.isoformat()
 *         except AttributeError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "serpyco/serializer.pyx":907
 *     )
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return value.isoformat()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_1dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_dump, "DateTimeFieldEncoder.dump(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_1dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_1dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_dump};
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_1dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 907, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 907, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 907, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 907, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_dump(((struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":913
 *             raise ValidationError(f"{value} is not a datetime.datetime instance")
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return dateutil.parser.parse(value)
 */

static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_load(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":914
 * 
 *     cpdef inline load(self, value):
 *         try:             # <<<<<<<<<<<<<<
 *             return dateutil.parser.parse(value)
 *         except (ValueError, OverflowError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "serpyco/serializer.pyx":915
 *     cpdef inline load(self, value):
 *         try:
 *             return dateutil.parser.parse(value)             # <<<<<<<<<<<<<<
 *         except (ValueError, OverflowError):
 *             raise ValidationError(f"{value} is not a valid datetime")
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_dateutil); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 915, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_parser); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 915, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_parse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 915, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_value};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 915, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "serpyco/serializer.pyx":914
 * 
 *     cpdef inline load(self, value):
 *         try:             # <<<<<<<<<<<<<<
 *             return dateutil.parser.parse(value)
 *         except (ValueError, OverflowError):
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "serpyco/serializer.pyx":916
 *         try:
 *             return dateutil.parser.parse(value)
 *         except (ValueError, OverflowError):             # <<<<<<<<<<<<<<
 *             raise ValidationError(f"{value} is not a valid datetime")
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches2(__pyx_builtin_ValueError, __pyx_builtin_OverflowError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 916, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "serpyco/serializer.pyx":917
 *             return dateutil.parser.parse(value)
 *         except (ValueError, OverflowError):
 *             raise ValidationError(f"{value} is not a valid datetime")             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 917, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_FormatSimple(__pyx_v_value, __pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 917, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_10, __pyx_kp_u_is_not_a_valid_datetime); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 917, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_11};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 917, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 917, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "serpyco/serializer.pyx":914
 * 
 *     cpdef inline load(self, value):
 *         try:             # <<<<<<<<<<<<<<
 *             return dateutil.parser.parse(value)
 *         except (ValueError, OverflowError):
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "serpyco/serializer.pyx":913
 *             raise ValidationError(f"{value} is not a datetime.datetime instance")
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return dateutil.parser.parse(value)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_2load, "DateTimeFieldEncoder.load(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_3load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_3load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_2load};
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 913, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 913, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 913, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 913, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_2load(((struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":919
 *             raise ValidationError(f"{value} is not a valid datetime")
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {
 *             "type": "string",
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_5json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_4json_schema, "DateTimeFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_5json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_5json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_4json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_5json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 919, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_4json_schema(((struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_4json_schema(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":920
 * 
 *     def json_schema(self) -> JsonDict:
 *         return {             # <<<<<<<<<<<<<<
 *             "type": "string",
 *             "format": "date-time",
 */
  __Pyx_XDECREF(__pyx_r);

  /* "serpyco/serializer.pyx":921
 *     def json_schema(self) -> JsonDict:
 *         return {
 *             "type": "string",             # <<<<<<<<<<<<<<
 *             "format": "date-time",
 *             "pattern": self.iso8601_pattern
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_type_2, __pyx_n_u_string) < 0) __PYX_ERR(0, 921, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_format, __pyx_kp_u_date_time) < 0) __PYX_ERR(0, 921, __pyx_L1_error)

  /* "serpyco/serializer.pyx":923
 *             "type": "string",
 *             "format": "date-time",
 *             "pattern": self.iso8601_pattern             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_iso8601_pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_pattern, __pyx_t_2) < 0) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":919
 *             raise ValidationError(f"{value} is not a valid datetime")
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {
 *             "type": "string",
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_6__reduce_cython__, "DateTimeFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_6__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_6__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_6__reduce_cython__(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_DateTimeFieldEnco); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, None), state
 *     else:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_DateTimeFieldEncoder__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_DateTimeFieldEnco); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DateTimeFieldEncoder__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_8__setstate_cython__, "DateTimeFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_8__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 16, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_8__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_20DateTimeFieldEncoder_8__setstate_cython__(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_DateTimeFieldEncoder__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7serpyco_10serializer___pyx_unpickle_DateTimeFieldEncoder__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DateTimeFieldEncoder__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.DateTimeFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":930
 * cdef class UuidFieldEncoder(FieldEncoder):
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return str(value)
 * 
 */

static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_1dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16UuidFieldEncoder_dump(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":931
 * 
 *     cpdef inline dump(self, value):
 *         return str(value)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_Str(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":930
 * cdef class UuidFieldEncoder(FieldEncoder):
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return str(value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_1dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_dump, "UuidFieldEncoder.dump(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_1dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_1dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_dump};
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_1dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 930, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 930, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 930, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 930, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_dump(((struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_16UuidFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":933
 *         return str(value)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return uuid.UUID(value)
 * 
 */

static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_16UuidFieldEncoder_load(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":934
 * 
 *     cpdef inline load(self, value):
 *         return uuid.UUID(value)             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_uuid); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_UUID); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_value};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":933
 *         return str(value)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return uuid.UUID(value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_2load, "UuidFieldEncoder.load(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_3load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_3load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_2load};
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_3load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 933, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 933, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 933, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 933, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_2load(((struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_2load(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_16UuidFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":936
 *         return uuid.UUID(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {"type": "string", "format": "uuid"}
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_5json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_4json_schema, "UuidFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_5json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_5json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_4json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_5json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 936, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_4json_schema(((struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_4json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":937
 * 
 *     def json_schema(self) -> JsonDict:
 *         return {"type": "string", "format": "uuid"}             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_type_2, __pyx_n_u_string) < 0) __PYX_ERR(0, 937, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_format, __pyx_n_u_uuid) < 0) __PYX_ERR(0, 937, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":936
 *         return uuid.UUID(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {"type": "string", "format": "uuid"}
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_6__reduce_cython__, "UuidFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_6__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_6__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_6__reduce_cython__(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_UuidFieldEncoder); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, None), state
 *     else:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_UuidFieldEncoder__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_UuidFieldEncoder); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_UuidFieldEncoder__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_8__setstate_cython__, "UuidFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_8__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 16, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_8__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_16UuidFieldEncoder_8__setstate_cython__(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_UuidFieldEncoder__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7serpyco_10serializer___pyx_unpickle_UuidFieldEncoder__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_UuidFieldEncoder__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UuidFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":945
 *     cdef tuple _type_encoders
 * 
 *     def __cinit__(             # <<<<<<<<<<<<<<
 *         self,
 *         type_encoders: typing.List[typing.Tuple[type, FieldEncoder]]
 */

/* Python wrapper */
static int __pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_type_encoders = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 945, __pyx_L3_error)
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_type_encoders,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_type_encoders)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 945, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 945, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_type_encoders = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 945, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_type_encoders), (&PyList_Type), 0, "type_encoders", 1))) __PYX_ERR(0, 947, __pyx_L1_error)
  __pyx_r = __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder___cinit__(((struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)__pyx_v_self), __pyx_v_type_encoders);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder___cinit__(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_type_encoders) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "serpyco/serializer.pyx":949
 *         type_encoders: typing.List[typing.Tuple[type, FieldEncoder]]
 *     ):
 *         self._type_encoders = tuple(type_encoders)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline dump(self, value):
 */
  __pyx_t_1 = PyList_AsTuple(__pyx_v_type_encoders); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_type_encoders);
  __Pyx_DECREF(__pyx_v_self->_type_encoders);
  __pyx_v_self->_type_encoders = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":945
 *     cdef tuple _type_encoders
 * 
 *     def __cinit__(             # <<<<<<<<<<<<<<
 *         self,
 *         type_encoders: typing.List[typing.Tuple[type, FieldEncoder]]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":951
 *         self._type_encoders = tuple(type_encoders)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */

static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_3dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_17UnionFieldEncoder_dump(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_value_types = 0;
  PyObject *__pyx_v_value_type = NULL;
  PyObject *__pyx_v_encoder = NULL;
  PyObject *__pyx_v_union = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  Py_UCS4 __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "serpyco/serializer.pyx":952
 * 
 *     cpdef inline dump(self, value):
 *         cdef list value_types = []             # <<<<<<<<<<<<<<
 *         for value_type, encoder in self._type_encoders:
 *             value_types.append(str(value_type))
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_value_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":953
 *     cpdef inline dump(self, value):
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:             # <<<<<<<<<<<<<<
 *             value_types.append(str(value_type))
 *             try:
 */
  if (unlikely(__pyx_v_self->_type_encoders == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 953, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_type_encoders; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 953, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 953, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 953, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
      index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 953, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 953, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_value_type, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_encoder, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "serpyco/serializer.pyx":954
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 *             value_types.append(str(value_type))             # <<<<<<<<<<<<<<
 *             try:
 *                 return encoder.dump(value) if encoder else value
 */
    __pyx_t_3 = __Pyx_PyObject_Str(__pyx_v_value_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_value_types, __pyx_t_3); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 954, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "serpyco/serializer.pyx":955
 *         for value_type, encoder in self._type_encoders:
 *             value_types.append(str(value_type))
 *             try:             # <<<<<<<<<<<<<<
 *                 return encoder.dump(value) if encoder else value
 *             except Exception:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      /*try:*/ {

        /* "serpyco/serializer.pyx":956
 *             value_types.append(str(value_type))
 *             try:
 *                 return encoder.dump(value) if encoder else value             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 pass
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_encoder); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 956, __pyx_L7_error)
        if (__pyx_t_12) {
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_encoder, __pyx_n_s_dump); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 956, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = NULL;
          __pyx_t_13 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_13 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_value};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 956, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_3 = __pyx_t_5;
          __pyx_t_5 = 0;
        } else {
          __Pyx_INCREF(__pyx_v_value);
          __pyx_t_3 = __pyx_v_value;
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L11_try_return;

        /* "serpyco/serializer.pyx":955
 *         for value_type, encoder in self._type_encoders:
 *             value_types.append(str(value_type))
 *             try:             # <<<<<<<<<<<<<<
 *                 return encoder.dump(value) if encoder else value
 *             except Exception:
 */
      }
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "serpyco/serializer.pyx":957
 *             try:
 *                 return encoder.dump(value) if encoder else value
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 pass
 *         union = ",".join(value_types)
 */
      __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_13) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;

      /* "serpyco/serializer.pyx":955
 *         for value_type, encoder in self._type_encoders:
 *             value_types.append(str(value_type))
 *             try:             # <<<<<<<<<<<<<<
 *                 return encoder.dump(value) if encoder else value
 *             except Exception:
 */
      __pyx_L9_except_error:;
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      goto __pyx_L1_error;
      __pyx_L11_try_return:;
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      goto __pyx_L0;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    }

    /* "serpyco/serializer.pyx":953
 *     cpdef inline dump(self, value):
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:             # <<<<<<<<<<<<<<
 *             value_types.append(str(value_type))
 *             try:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":959
 *             except Exception:
 *                 pass
 *         union = ",".join(value_types)             # <<<<<<<<<<<<<<
 *         msg = f"{value} has a wrong type, expected any of [{union}]"
 *         raise ValidationError(msg)
 */
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__4, __pyx_v_value_types); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_union = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":960
 *                 pass
 *         union = ",".join(value_types)
 *         msg = f"{value} has a wrong type, expected any of [{union}]"             # <<<<<<<<<<<<<<
 *         raise ValidationError(msg)
 * 
 */
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_14 = 127;
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_value, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_14) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_14;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u_has_a_wrong_type_expected_any_o);
  __pyx_t_2 += 36;
  __Pyx_GIVEREF(__pyx_kp_u_has_a_wrong_type_expected_any_o);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u_has_a_wrong_type_expected_any_o);
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_union); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_14) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_14;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u__5);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__5);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__5);
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_2, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_msg = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":961
 *         union = ",".join(value_types)
 *         msg = f"{value} has a wrong type, expected any of [{union}]"
 *         raise ValidationError(msg)             # <<<<<<<<<<<<<<
 * 
 *     cpdef inline load(self, value):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  __pyx_t_13 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_13 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_msg};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 961, __pyx_L1_error)

  /* "serpyco/serializer.pyx":951
 *         self._type_encoders = tuple(type_encoders)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value_types);
  __Pyx_XDECREF(__pyx_v_value_type);
  __Pyx_XDECREF(__pyx_v_encoder);
  __Pyx_XDECREF(__pyx_v_union);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_3dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_2dump, "UnionFieldEncoder.dump(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_3dump = {"dump", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_3dump, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_2dump};
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_3dump(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 951, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 951, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "dump") < 0)) __PYX_ERR(0, 951, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 951, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_2dump(((struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_2dump(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_17UnionFieldEncoder_dump(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":963
 *         raise ValidationError(msg)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */

static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_5load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_7serpyco_10serializer_17UnionFieldEncoder_load(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_value_types = 0;
  PyObject *__pyx_v_value_type = NULL;
  PyObject *__pyx_v_encoder = NULL;
  PyObject *__pyx_v_union = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  Py_UCS4 __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "serpyco/serializer.pyx":964
 * 
 *     cpdef inline load(self, value):
 *         cdef list value_types = []             # <<<<<<<<<<<<<<
 *         for value_type, encoder in self._type_encoders:
 *             try:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_value_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":965
 *     cpdef inline load(self, value):
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:             # <<<<<<<<<<<<<<
 *             try:
 *                 value_types.append(str(value_type))
 */
  if (unlikely(__pyx_v_self->_type_encoders == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 965, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_type_encoders; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 965, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 965, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
      index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 965, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 965, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_value_type, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_encoder, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "serpyco/serializer.pyx":966
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 *             try:             # <<<<<<<<<<<<<<
 *                 value_types.append(str(value_type))
 *                 return encoder.load(value) if encoder else value
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "serpyco/serializer.pyx":967
 *         for value_type, encoder in self._type_encoders:
 *             try:
 *                 value_types.append(str(value_type))             # <<<<<<<<<<<<<<
 *                 return encoder.load(value) if encoder else value
 *             except Exception:
 */
        __pyx_t_3 = __Pyx_PyObject_Str(__pyx_v_value_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 967, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_value_types, __pyx_t_3); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 967, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "serpyco/serializer.pyx":968
 *             try:
 *                 value_types.append(str(value_type))
 *                 return encoder.load(value) if encoder else value             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 pass
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_encoder); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 968, __pyx_L7_error)
        if (__pyx_t_12) {
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_encoder, __pyx_n_s_load); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 968, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = NULL;
          __pyx_t_13 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_13 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_value};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 968, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_3 = __pyx_t_5;
          __pyx_t_5 = 0;
        } else {
          __Pyx_INCREF(__pyx_v_value);
          __pyx_t_3 = __pyx_v_value;
        }
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L11_try_return;

        /* "serpyco/serializer.pyx":966
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 *             try:             # <<<<<<<<<<<<<<
 *                 value_types.append(str(value_type))
 *                 return encoder.load(value) if encoder else value
 */
      }
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "serpyco/serializer.pyx":969
 *                 value_types.append(str(value_type))
 *                 return encoder.load(value) if encoder else value
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 pass
 *         union = ",".join(value_types)
 */
      __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_13) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;

      /* "serpyco/serializer.pyx":966
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 *             try:             # <<<<<<<<<<<<<<
 *                 value_types.append(str(value_type))
 *                 return encoder.load(value) if encoder else value
 */
      __pyx_L9_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L11_try_return:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L0;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    }

    /* "serpyco/serializer.pyx":965
 *     cpdef inline load(self, value):
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:             # <<<<<<<<<<<<<<
 *             try:
 *                 value_types.append(str(value_type))
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":971
 *             except Exception:
 *                 pass
 *         union = ",".join(value_types)             # <<<<<<<<<<<<<<
 *         msg = f"{value} has a wrong type, expected any of [{union}]"
 *         raise ValidationError(msg)
 */
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__4, __pyx_v_value_types); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_union = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "serpyco/serializer.pyx":972
 *                 pass
 *         union = ",".join(value_types)
 *         msg = f"{value} has a wrong type, expected any of [{union}]"             # <<<<<<<<<<<<<<
 *         raise ValidationError(msg)
 * 
 */
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_14 = 127;
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_value, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_14) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_14;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u_has_a_wrong_type_expected_any_o);
  __pyx_t_2 += 36;
  __Pyx_GIVEREF(__pyx_kp_u_has_a_wrong_type_expected_any_o);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u_has_a_wrong_type_expected_any_o);
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_union); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_14 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_14) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_14;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u__5);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__5);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__5);
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 4, __pyx_t_2, __pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_msg = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":973
 *         union = ",".join(value_types)
 *         msg = f"{value} has a wrong type, expected any of [{union}]"
 *         raise ValidationError(msg)             # <<<<<<<<<<<<<<
 * 
 *     def json_schema(self) -> JsonDict:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  __pyx_t_13 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_13 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_msg};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 973, __pyx_L1_error)

  /* "serpyco/serializer.pyx":963
 *         raise ValidationError(msg)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value_types);
  __Pyx_XDECREF(__pyx_v_value_type);
  __Pyx_XDECREF(__pyx_v_encoder);
  __Pyx_XDECREF(__pyx_v_union);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_5load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_4load, "UnionFieldEncoder.load(self, value)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_5load = {"load", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_5load, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_4load};
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_5load(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 963, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_value,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 963, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "load") < 0)) __PYX_ERR(0, 963, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_value = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 963, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_4load(((struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)__pyx_v_self), __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_4load(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7serpyco_10serializer_17UnionFieldEncoder_load(__pyx_v_self, __pyx_v_value, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "serpyco/serializer.pyx":975
 *         raise ValidationError(msg)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_6json_schema, "UnionFieldEncoder.json_schema(self) -> JsonDict");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_7json_schema = {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_6json_schema};
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_7json_schema(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(0, 975, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("json_schema", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "json_schema", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.json_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_6json_schema(((struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_6json_schema(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("json_schema", 0);

  /* "serpyco/serializer.pyx":976
 * 
 *     def json_schema(self) -> JsonDict:
 *         return None             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "serpyco/serializer.pyx":975
 *         raise ValidationError(msg)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_8__reduce_cython__, "UnionFieldEncoder.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_8__reduce_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  goto __pyx_L4_argument_unpacking_done;
  goto __pyx_L3_error;
  __pyx_L3_error:;
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_8__reduce_cython__(((struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_10__setstate_cython__, "UnionFieldEncoder.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_10__setstate_cython__};
static PyObject *__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 3, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_10__setstate_cython__(((struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_17UnionFieldEncoder_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("serpyco.serializer.UnionFieldEncoder.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_SerializerField(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_1__pyx_unpickle_SerializerField(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer___pyx_unpickle_SerializerField, "__pyx_unpickle_SerializerField(__pyx_type, long __pyx_checksum, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_1__pyx_unpickle_SerializerField = {"__pyx_unpickle_SerializerField", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_1__pyx_unpickle_SerializerField, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer___pyx_unpickle_SerializerField};
static PyObject *__pyx_pw_7serpyco_10serializer_1__pyx_unpickle_SerializerField(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_SerializerField (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_SerializerField", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_SerializerField", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_SerializerField") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_SerializerField", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_SerializerField", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer___pyx_unpickle_SerializerField(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer___pyx_unpickle_SerializerField(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_SerializerField", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x4c26f91, 0x8b72694, 0xeb8ae5a):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__6, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x4c26f91, 0x8b72694, 0xeb8ae5a):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum
 *     __pyx_result = SerializerField.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0x4c26f91, 0x8b72694, 0xeb8ae5a):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = SerializerField.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x4c26f91, 0x8b72694, 0xeb8ae5a):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum
 *     __pyx_result = SerializerField.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_7serpyco_10serializer_SerializerField), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum
 *     __pyx_result = SerializerField.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = SerializerField.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_7serpyco_10serializer___pyx_unpickle_SerializerField__set_state(((struct __pyx_obj_7serpyco_10serializer_SerializerField *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum
 *     __pyx_result = SerializerField.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_SerializerField(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_SerializerField", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]
 *     if len(__pyx_state) > 7 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_7serpyco_10serializer___pyx_unpickle_SerializerField__set_state(struct __pyx_obj_7serpyco_10serializer_SerializerField *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_SerializerField__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 7 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[7])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v___pyx_state, 0);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_default);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_default);
  __pyx_v___pyx_result->__pyx_default = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v___pyx_state, 1);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->default_factory);
  __Pyx_DECREF(__pyx_v___pyx_result->default_factory);
  __pyx_v___pyx_result->default_factory = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  if (!(likely(PyUnicode_CheckExact(PyTuple_GET_ITEM(__pyx_v___pyx_state, 2)))||((PyTuple_GET_ITEM(__pyx_v___pyx_state, 2)) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", PyTuple_GET_ITEM(__pyx_v___pyx_state, 2)))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v___pyx_state, 2);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->dict_key);
  __Pyx_DECREF(__pyx_v___pyx_result->dict_key);
  __pyx_v___pyx_result->dict_key = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  if (!(likely(((PyTuple_GET_ITEM(__pyx_v___pyx_state, 3)) == Py_None) || likely(__Pyx_TypeTest(PyTuple_GET_ITEM(__pyx_v___pyx_state, 3), __pyx_ptype_7serpyco_7encoder_FieldEncoder))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v___pyx_state, 3);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->encoder);
  __Pyx_DECREF((PyObject *)__pyx_v___pyx_result->encoder);
  __pyx_v___pyx_result->encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  if (!(likely(PyUnicode_CheckExact(PyTuple_GET_ITEM(__pyx_v___pyx_state, 4)))||((PyTuple_GET_ITEM(__pyx_v___pyx_state, 4)) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", PyTuple_GET_ITEM(__pyx_v___pyx_state, 4)))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v___pyx_state, 4);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->field_name);
  __Pyx_DECREF(__pyx_v___pyx_result->field_name);
  __pyx_v___pyx_result->field_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = PyTuple_GET_ITEM(__pyx_v___pyx_state, 5);
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->getter);
  __Pyx_DECREF(__pyx_v___pyx_result->getter);
  __pyx_v___pyx_result->getter = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(PyTuple_GET_ITEM(__pyx_v___pyx_state, 6)); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_v___pyx_result->init = __pyx_t_2;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]
 *     if len(__pyx_state) > 7 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[7])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 > 7);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]
 *     if len(__pyx_state) > 7 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[7])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, PyTuple_GET_ITEM(__pyx_v___pyx_state, 7)};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]
 *     if len(__pyx_state) > 7 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[7])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]
 *     if len(__pyx_state) > 7 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_SerializerField__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_DateTimeFieldEncoder(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_3__pyx_unpickle_DateTimeFieldEncoder(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_2__pyx_unpickle_DateTimeFieldEncoder, "__pyx_unpickle_DateTimeFieldEncoder(__pyx_type, long __pyx_checksum, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_3__pyx_unpickle_DateTimeFieldEncoder = {"__pyx_unpickle_DateTimeFieldEncoder", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_3__pyx_unpickle_DateTimeFieldEncoder, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_2__pyx_unpickle_DateTimeFieldEncoder};
static PyObject *__pyx_pw_7serpyco_10serializer_3__pyx_unpickle_DateTimeFieldEncoder(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_DateTimeFieldEncoder (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_DateTimeFieldEncoder", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_DateTimeFieldEncoder", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_DateTimeFieldEncoder") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_DateTimeFieldEncoder", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_DateTimeFieldEncoder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_2__pyx_unpickle_DateTimeFieldEncoder(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_2__pyx_unpickle_DateTimeFieldEncoder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_DateTimeFieldEncoder", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__8, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = DateTimeFieldEncoder.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = DateTimeFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = DateTimeFieldEncoder.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_DateTimeFieldEncoder__set_state(<DateTimeFieldEncoder> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = DateTimeFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_DateTimeFieldEncoder__set_state(<DateTimeFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = DateTimeFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_DateTimeFieldEncoder__set_state(<DateTimeFieldEncoder> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_DateTimeFieldEncoder__set_state(DateTimeFieldEncoder __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_7serpyco_10serializer___pyx_unpickle_DateTimeFieldEncoder__set_state(((struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = DateTimeFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_DateTimeFieldEncoder__set_state(<DateTimeFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_DateTimeFieldEncoder__set_state(<DateTimeFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_DateTimeFieldEncoder__set_state(DateTimeFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_DateTimeFieldEncoder(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_DateTimeFieldEncoder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_DateTimeFieldEncoder__set_state(<DateTimeFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_DateTimeFieldEncoder__set_state(DateTimeFieldEncoder __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_f_7serpyco_10serializer___pyx_unpickle_DateTimeFieldEncoder__set_state(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_DateTimeFieldEncoder__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_DateTimeFieldEncoder__set_state(DateTimeFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 > 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_DateTimeFieldEncoder__set_state(DateTimeFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, PyTuple_GET_ITEM(__pyx_v___pyx_state, 0)};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_DateTimeFieldEncoder__set_state(DateTimeFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_DateTimeFieldEncoder__set_state(<DateTimeFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_DateTimeFieldEncoder__set_state(DateTimeFieldEncoder __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_DateTimeFieldEncoder__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_UuidFieldEncoder(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_7serpyco_10serializer_5__pyx_unpickle_UuidFieldEncoder(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_7serpyco_10serializer_4__pyx_unpickle_UuidFieldEncoder, "__pyx_unpickle_UuidFieldEncoder(__pyx_type, long __pyx_checksum, __pyx_state)");
static PyMethodDef __pyx_mdef_7serpyco_10serializer_5__pyx_unpickle_UuidFieldEncoder = {"__pyx_unpickle_UuidFieldEncoder", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_5__pyx_unpickle_UuidFieldEncoder, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_4__pyx_unpickle_UuidFieldEncoder};
static PyObject *__pyx_pw_7serpyco_10serializer_5__pyx_unpickle_UuidFieldEncoder(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_UuidFieldEncoder (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args);
  if (unlikely((__pyx_nargs < 0))) __PYX_ERR(1, 1, __pyx_L3_error)
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_UuidFieldEncoder", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_UuidFieldEncoder", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_UuidFieldEncoder") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_UuidFieldEncoder", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  goto __pyx_L3_error;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_UuidFieldEncoder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7serpyco_10serializer_4__pyx_unpickle_UuidFieldEncoder(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7serpyco_10serializer_4__pyx_unpickle_UuidFieldEncoder(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_UuidFieldEncoder", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__8, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = UuidFieldEncoder.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = UuidFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = UuidFieldEncoder.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_UuidFieldEncoder__set_state(<UuidFieldEncoder> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = UuidFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_UuidFieldEncoder__set_state(<UuidFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = UuidFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_UuidFieldEncoder__set_state(<UuidFieldEncoder> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_UuidFieldEncoder__set_state(UuidFieldEncoder __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_7serpyco_10serializer___pyx_unpickle_UuidFieldEncoder__set_state(((struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = UuidFieldEncoder.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_UuidFieldEncoder__set_state(<UuidFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_UuidFieldEncoder__set_state(<UuidFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_UuidFieldEncoder__set_state(UuidFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_UuidFieldEncoder(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_UuidFieldEncoder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_UuidFieldEncoder__set_state(<UuidFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_UuidFieldEncoder__set_state(UuidFieldEncoder __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_f_7serpyco_10serializer___pyx_unpickle_UuidFieldEncoder__set_state(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_UuidFieldEncoder__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_UuidFieldEncoder__set_state(UuidFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 > 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_UuidFieldEncoder__set_state(UuidFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, PyTuple_GET_ITEM(__pyx_v___pyx_state, 0)};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_UuidFieldEncoder__set_state(UuidFieldEncoder __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_UuidFieldEncoder__set_state(<UuidFieldEncoder> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_UuidFieldEncoder__set_state(UuidFieldEncoder __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("serpyco.serializer.__pyx_unpickle_UuidFieldEncoder__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_7serpyco_10serializer_SerializerField(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_7serpyco_10serializer_SerializerField *)o);
  p->field_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->dict_key = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  p->getter = Py_None; Py_INCREF(Py_None);
  p->__pyx_default = Py_None; Py_INCREF(Py_None);
  p->default_factory = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_SerializerField(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_SerializerField *p = (struct __pyx_obj_7serpyco_10serializer_SerializerField *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_SerializerField) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->field_name);
  Py_CLEAR(p->dict_key);
  Py_CLEAR(p->encoder);
  Py_CLEAR(p->getter);
  Py_CLEAR(p->__pyx_default);
  Py_CLEAR(p->default_factory);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_7serpyco_10serializer_SerializerField(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_SerializerField *p = (struct __pyx_obj_7serpyco_10serializer_SerializerField *)o;
  if (p->encoder) {
    e = (*v)(((PyObject *)p->encoder), a); if (e) return e;
  }
  if (p->getter) {
    e = (*v)(p->getter, a); if (e) return e;
  }
  if (p->__pyx_default) {
    e = (*v)(p->__pyx_default, a); if (e) return e;
  }
  if (p->default_factory) {
    e = (*v)(p->default_factory, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_SerializerField(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_SerializerField *p = (struct __pyx_obj_7serpyco_10serializer_SerializerField *)o;
  tmp = ((PyObject*)p->encoder);
  p->encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->getter);
  p->getter = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_default);
  p->__pyx_default = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->default_factory);
  p->default_factory = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_SerializerField[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_15SerializerField_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_15SerializerField_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_15SerializerField_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_15SerializerField_4__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_SerializerField_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_SerializerField},
  {Py_tp_doc, (void *)PyDoc_STR("SerializerField(unicode field_name, unicode dict_key, FieldEncoder encoder, getter, bool init, default, default_factory)")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_SerializerField},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_SerializerField},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_SerializerField},
  {Py_tp_init, (void *)__pyx_pw_7serpyco_10serializer_15SerializerField_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_SerializerField},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_SerializerField_spec = {
  "serpyco.serializer.SerializerField",
  sizeof(struct __pyx_obj_7serpyco_10serializer_SerializerField),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_7serpyco_10serializer_SerializerField_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_SerializerField = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""SerializerField", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_SerializerField), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_SerializerField, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("SerializerField(unicode field_name, unicode dict_key, FieldEncoder encoder, getter, bool init, default, default_factory)"), /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_SerializerField, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_SerializerField, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_SerializerField, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_7serpyco_10serializer_15SerializerField_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_SerializerField, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_7serpyco_10serializer_Caster(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_Caster *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_7serpyco_10serializer_Caster *)o);
  p->dict_key = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->caster = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_6Caster_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_Caster(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_Caster *p = (struct __pyx_obj_7serpyco_10serializer_Caster *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_Caster) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->dict_key);
  Py_CLEAR(p->caster);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_7serpyco_10serializer_Caster(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_Caster *p = (struct __pyx_obj_7serpyco_10serializer_Caster *)o;
  if (p->caster) {
    e = (*v)(p->caster, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_Caster(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_Caster *p = (struct __pyx_obj_7serpyco_10serializer_Caster *)o;
  tmp = ((PyObject*)p->caster);
  p->caster = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_Caster[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_6Caster_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_6Caster_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_6Caster_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_6Caster_4__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_Caster_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_Caster},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_Caster},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_Caster},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_Caster},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_Caster},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_Caster_spec = {
  "serpyco.serializer.Caster",
  sizeof(struct __pyx_obj_7serpyco_10serializer_Caster),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_7serpyco_10serializer_Caster_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_Caster = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""Caster", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_Caster), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_Caster, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_Caster, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_Caster, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_Caster, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_Caster, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_Serializer __pyx_vtable_7serpyco_10serializer_Serializer;

static PyObject *__pyx_tp_new_7serpyco_10serializer_Serializer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_Serializer *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  o = (*t->tp_alloc)(t, 0);
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)o);
  p->__pyx_vtab = __pyx_vtabptr_7serpyco_10serializer_Serializer;
  p->_fields = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_dataclass_params = Py_None; Py_INCREF(Py_None);
  p->_dataclass = Py_None; Py_INCREF(Py_None);
  p->_validator = Py_None; Py_INCREF(Py_None);
  p->_parent_serializers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_pre_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_post_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_pre_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_post_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_field_casters = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_field_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_type_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_load_as_type = Py_None; Py_INCREF(Py_None);
  p->_only = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_excluded_fields = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_10Serializer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_Serializer(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_Serializer *p = (struct __pyx_obj_7serpyco_10serializer_Serializer *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_fields);
  Py_CLEAR(p->_dataclass_params);
  Py_CLEAR(p->_dataclass);
  Py_CLEAR(p->_validator);
  Py_CLEAR(p->_parent_serializers);
  Py_CLEAR(p->_pre_dumpers);
  Py_CLEAR(p->_post_dumpers);
  Py_CLEAR(p->_pre_loaders);
  Py_CLEAR(p->_post_loaders);
  Py_CLEAR(p->_field_casters);
  Py_CLEAR(p->_field_encoders);
  Py_CLEAR(p->_type_encoders);
  Py_CLEAR(p->_load_as_type);
  Py_CLEAR(p->_only);
  Py_CLEAR(p->_excluded_fields);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_7serpyco_10serializer_Serializer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_Serializer *p = (struct __pyx_obj_7serpyco_10serializer_Serializer *)o;
  if (p->_fields) {
    e = (*v)(p->_fields, a); if (e) return e;
  }
  if (p->_dataclass_params) {
    e = (*v)(p->_dataclass_params, a); if (e) return e;
  }
  if (p->_dataclass) {
    e = (*v)(p->_dataclass, a); if (e) return e;
  }
  if (p->_validator) {
    e = (*v)(p->_validator, a); if (e) return e;
  }
  if (p->_parent_serializers) {
    e = (*v)(p->_parent_serializers, a); if (e) return e;
  }
  if (p->_pre_dumpers) {
    e = (*v)(p->_pre_dumpers, a); if (e) return e;
  }
  if (p->_post_dumpers) {
    e = (*v)(p->_post_dumpers, a); if (e) return e;
  }
  if (p->_pre_loaders) {
    e = (*v)(p->_pre_loaders, a); if (e) return e;
  }
  if (p->_post_loaders) {
    e = (*v)(p->_post_loaders, a); if (e) return e;
  }
  if (p->_field_casters) {
    e = (*v)(p->_field_casters, a); if (e) return e;
  }
  if (p->_field_encoders) {
    e = (*v)(p->_field_encoders, a); if (e) return e;
  }
  if (p->_type_encoders) {
    e = (*v)(p->_type_encoders, a); if (e) return e;
  }
  if (p->_load_as_type) {
    e = (*v)(p->_load_as_type, a); if (e) return e;
  }
  if (p->_only) {
    e = (*v)(p->_only, a); if (e) return e;
  }
  if (p->_excluded_fields) {
    e = (*v)(p->_excluded_fields, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_Serializer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_Serializer *p = (struct __pyx_obj_7serpyco_10serializer_Serializer *)o;
  tmp = ((PyObject*)p->_fields);
  p->_fields = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_dataclass_params);
  p->_dataclass_params = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_dataclass);
  p->_dataclass = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_validator);
  p->_validator = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_parent_serializers);
  p->_parent_serializers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_pre_dumpers);
  p->_pre_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_post_dumpers);
  p->_post_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_pre_loaders);
  p->_pre_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_post_loaders);
  p->_post_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_field_casters);
  p->_field_casters = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_field_encoders);
  p->_field_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_type_encoders);
  p->_type_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_load_as_type);
  p->_load_as_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_only);
  p->_only = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_excluded_fields);
  p->_excluded_fields = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_Serializer[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_5json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_4json_schema},
  {"get_dict_path", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_7get_dict_path, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_6get_dict_path},
  {"get_object_path", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_9get_object_path, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_8get_object_path},
  {"register_global_type", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_11register_global_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_10register_global_type},
  {"unregister_global_type", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_13unregister_global_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_12unregister_global_type},
  {"dataclass", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_15dataclass, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_14dataclass},
  {"_get_field_serializer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_25_get_field_serializer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_24_get_field_serializer},
  {"_get_encoder", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_27_get_encoder, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_26_get_encoder},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_29__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_28__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_10Serializer_31__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_10Serializer_30__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_Serializer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_Serializer},
  {Py_tp_hash, (void *)__pyx_pw_7serpyco_10serializer_10Serializer_3__hash__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Serializer class for dataclasses instances.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_Serializer},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_Serializer},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_Serializer},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_Serializer},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_Serializer_spec = {
  "serpyco.serializer.Serializer",
  sizeof(struct __pyx_obj_7serpyco_10serializer_Serializer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_7serpyco_10serializer_Serializer_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_Serializer = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""Serializer", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_Serializer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_Serializer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  __pyx_pw_7serpyco_10serializer_10Serializer_3__hash__, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Serializer class for dataclasses instances.\n    "), /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_Serializer, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_Serializer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_Serializer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_Serializer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_EnumFieldEncoder __pyx_vtable_7serpyco_10serializer_EnumFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_EnumFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_EnumFieldEncoder;
  p->_enum_type = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_EnumFieldEncoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_EnumFieldEncoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_enum_type);
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_7serpyco_10serializer_EnumFieldEncoder);
}

static int __pyx_tp_traverse_7serpyco_10serializer_EnumFieldEncoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)o;
  e = ((likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) ? ((__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse) ? __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_7serpyco_10serializer_EnumFieldEncoder)); if (e) return e;
  if (p->_enum_type) {
    e = (*v)(p->_enum_type, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_EnumFieldEncoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder *)o;
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) { if (__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear) __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_7serpyco_10serializer_EnumFieldEncoder);
  tmp = ((PyObject*)p->_enum_type);
  p->_enum_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_EnumFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_6json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16EnumFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16EnumFieldEncoder_10__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_EnumFieldEncoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_EnumFieldEncoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_EnumFieldEncoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_EnumFieldEncoder},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_EnumFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_EnumFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_EnumFieldEncoder_spec = {
  "serpyco.serializer.EnumFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_EnumFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_EnumFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""EnumFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_EnumFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_EnumFieldEncoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_EnumFieldEncoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_EnumFieldEncoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_EnumFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_EnumFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_DataClassFieldEncoder __pyx_vtable_7serpyco_10serializer_DataClassFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_DataClassFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_DataClassFieldEncoder;
  p->_serializer = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_DataClassFieldEncoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_DataClassFieldEncoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_serializer);
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_7serpyco_10serializer_DataClassFieldEncoder);
}

static int __pyx_tp_traverse_7serpyco_10serializer_DataClassFieldEncoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)o;
  e = ((likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) ? ((__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse) ? __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_7serpyco_10serializer_DataClassFieldEncoder)); if (e) return e;
  if (p->_serializer) {
    e = (*v)(((PyObject *)p->_serializer), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_DataClassFieldEncoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder *)o;
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) { if (__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear) __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_7serpyco_10serializer_DataClassFieldEncoder);
  tmp = ((PyObject*)p->_serializer);
  p->_serializer = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_DataClassFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_6json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_21DataClassFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_21DataClassFieldEncoder_10__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_DataClassFieldEncoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_DataClassFieldEncoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_DataClassFieldEncoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_DataClassFieldEncoder},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_DataClassFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_DataClassFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_DataClassFieldEncoder_spec = {
  "serpyco.serializer.DataClassFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_DataClassFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_DataClassFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""DataClassFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_DataClassFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_DataClassFieldEncoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_DataClassFieldEncoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_DataClassFieldEncoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_DataClassFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_DataClassFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_DataClassIterableFieldEncoder __pyx_vtable_7serpyco_10serializer_DataClassIterableFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_DataClassIterableFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_DataClassIterableFieldEncoder;
  p->_serializer = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)Py_None); Py_INCREF(Py_None);
  p->_iterable_type = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_DataClassIterableFieldEncoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_DataClassIterableFieldEncoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_serializer);
  Py_CLEAR(p->_iterable_type);
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_7serpyco_10serializer_DataClassIterableFieldEncoder);
}

static int __pyx_tp_traverse_7serpyco_10serializer_DataClassIterableFieldEncoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)o;
  e = ((likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) ? ((__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse) ? __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_7serpyco_10serializer_DataClassIterableFieldEncoder)); if (e) return e;
  if (p->_serializer) {
    e = (*v)(((PyObject *)p->_serializer), a); if (e) return e;
  }
  if (p->_iterable_type) {
    e = (*v)(p->_iterable_type, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_DataClassIterableFieldEncoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder *)o;
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) { if (__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear) __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_7serpyco_10serializer_DataClassIterableFieldEncoder);
  tmp = ((PyObject*)p->_serializer);
  p->_serializer = ((struct __pyx_obj_7serpyco_10serializer_Serializer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_iterable_type);
  p->_iterable_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_DataClassIterableFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_6json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_29DataClassIterableFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_29DataClassIterableFieldEncoder_10__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_DataClassIterableFieldEncoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_DataClassIterableFieldEncoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_DataClassIterableFieldEncoder},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_DataClassIterableFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_DataClassIterableFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder_spec = {
  "serpyco.serializer.DataClassIterableFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""DataClassIterableFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_DataClassIterableFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_DataClassIterableFieldEncoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_DataClassIterableFieldEncoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_DataClassIterableFieldEncoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_DataClassIterableFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_DataClassIterableFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_FixedTupleFieldEncoder __pyx_vtable_7serpyco_10serializer_FixedTupleFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_FixedTupleFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_FixedTupleFieldEncoder;
  p->_item_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_FixedTupleFieldEncoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_FixedTupleFieldEncoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_item_encoders);
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_7serpyco_10serializer_FixedTupleFieldEncoder);
}

static int __pyx_tp_traverse_7serpyco_10serializer_FixedTupleFieldEncoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)o;
  e = ((likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) ? ((__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse) ? __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_7serpyco_10serializer_FixedTupleFieldEncoder)); if (e) return e;
  if (p->_item_encoders) {
    e = (*v)(p->_item_encoders, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_FixedTupleFieldEncoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder *)o;
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) { if (__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear) __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_7serpyco_10serializer_FixedTupleFieldEncoder);
  tmp = ((PyObject*)p->_item_encoders);
  p->_item_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_FixedTupleFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_6json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_22FixedTupleFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_22FixedTupleFieldEncoder_10__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_FixedTupleFieldEncoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_FixedTupleFieldEncoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_FixedTupleFieldEncoder},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_FixedTupleFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_FixedTupleFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder_spec = {
  "serpyco.serializer.FixedTupleFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""FixedTupleFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_FixedTupleFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_FixedTupleFieldEncoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_FixedTupleFieldEncoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_FixedTupleFieldEncoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_FixedTupleFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_FixedTupleFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_IterableFieldEncoder __pyx_vtable_7serpyco_10serializer_IterableFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_IterableFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_IterableFieldEncoder;
  p->_item_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  p->_iterable_type = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_IterableFieldEncoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_IterableFieldEncoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_item_encoder);
  Py_CLEAR(p->_iterable_type);
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_7serpyco_10serializer_IterableFieldEncoder);
}

static int __pyx_tp_traverse_7serpyco_10serializer_IterableFieldEncoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)o;
  e = ((likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) ? ((__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse) ? __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_7serpyco_10serializer_IterableFieldEncoder)); if (e) return e;
  if (p->_item_encoder) {
    e = (*v)(((PyObject *)p->_item_encoder), a); if (e) return e;
  }
  if (p->_iterable_type) {
    e = (*v)(p->_iterable_type, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_IterableFieldEncoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder *)o;
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) { if (__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear) __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_7serpyco_10serializer_IterableFieldEncoder);
  tmp = ((PyObject*)p->_item_encoder);
  p->_item_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_iterable_type);
  p->_iterable_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_IterableFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_6json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20IterableFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20IterableFieldEncoder_10__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_IterableFieldEncoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_IterableFieldEncoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_IterableFieldEncoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_IterableFieldEncoder},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_IterableFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_IterableFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_IterableFieldEncoder_spec = {
  "serpyco.serializer.IterableFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_IterableFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_IterableFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""IterableFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_IterableFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_IterableFieldEncoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_IterableFieldEncoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_IterableFieldEncoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_IterableFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_IterableFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_DictFieldEncoder __pyx_vtable_7serpyco_10serializer_DictFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_DictFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_DictFieldEncoder;
  p->_key_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  p->_value_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_DictFieldEncoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_DictFieldEncoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_key_encoder);
  Py_CLEAR(p->_value_encoder);
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_7serpyco_10serializer_DictFieldEncoder);
}

static int __pyx_tp_traverse_7serpyco_10serializer_DictFieldEncoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)o;
  e = ((likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) ? ((__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse) ? __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_7serpyco_10serializer_DictFieldEncoder)); if (e) return e;
  if (p->_key_encoder) {
    e = (*v)(((PyObject *)p->_key_encoder), a); if (e) return e;
  }
  if (p->_value_encoder) {
    e = (*v)(((PyObject *)p->_value_encoder), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_DictFieldEncoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder *)o;
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) { if (__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear) __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_7serpyco_10serializer_DictFieldEncoder);
  tmp = ((PyObject*)p->_key_encoder);
  p->_key_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_value_encoder);
  p->_value_encoder = ((struct __pyx_obj_7serpyco_7encoder_FieldEncoder *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_DictFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_6json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16DictFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16DictFieldEncoder_10__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_DictFieldEncoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_DictFieldEncoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_DictFieldEncoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_DictFieldEncoder},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_DictFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_DictFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_DictFieldEncoder_spec = {
  "serpyco.serializer.DictFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_DictFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_DictFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""DictFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_DictFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_DictFieldEncoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_DictFieldEncoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_DictFieldEncoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_DictFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_DictFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_DateTimeFieldEncoder __pyx_vtable_7serpyco_10serializer_DateTimeFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_DateTimeFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_DateTimeFieldEncoder;
  return o;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_DateTimeFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_5json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_4json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_6__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_20DateTimeFieldEncoder_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_20DateTimeFieldEncoder_8__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_DateTimeFieldEncoder_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("Encodes datetimes to RFC3339/ISO8601 format")},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_DateTimeFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_DateTimeFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_DateTimeFieldEncoder_spec = {
  "serpyco.serializer.DateTimeFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_DateTimeFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_DateTimeFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""DateTimeFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_DateTimeFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  0, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  PyDoc_STR("Encodes datetimes to RFC3339/ISO8601 format"), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_DateTimeFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_DateTimeFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_UuidFieldEncoder __pyx_vtable_7serpyco_10serializer_UuidFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_UuidFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_UuidFieldEncoder;
  return o;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_UuidFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_5json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_4json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_6__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_16UuidFieldEncoder_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_16UuidFieldEncoder_8__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_UuidFieldEncoder_slots[] = {
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_UuidFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_UuidFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_UuidFieldEncoder_spec = {
  "serpyco.serializer.UuidFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_UuidFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_UuidFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""UuidFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_UuidFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  0, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_UuidFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_UuidFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_7serpyco_10serializer_UnionFieldEncoder __pyx_vtable_7serpyco_10serializer_UnionFieldEncoder;

static PyObject *__pyx_tp_new_7serpyco_10serializer_UnionFieldEncoder(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *p;
  PyObject *o = __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_new, newfunc)(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__pyx_vtabptr_7serpyco_10serializer_UnionFieldEncoder;
  p->_type_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_7serpyco_10serializer_UnionFieldEncoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer_UnionFieldEncoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_type_encoders);
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) __Pyx_PyType_GetSlot(__pyx_ptype_7serpyco_7encoder_FieldEncoder, tp_dealloc, destructor)(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_7serpyco_10serializer_UnionFieldEncoder);
}

static int __pyx_tp_traverse_7serpyco_10serializer_UnionFieldEncoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)o;
  e = ((likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) ? ((__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse) ? __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_7serpyco_10serializer_UnionFieldEncoder)); if (e) return e;
  if (p->_type_encoders) {
    e = (*v)(p->_type_encoders, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer_UnionFieldEncoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *p = (struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder *)o;
  if (likely(__pyx_ptype_7serpyco_7encoder_FieldEncoder)) { if (__pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear) __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_7serpyco_10serializer_UnionFieldEncoder);
  tmp = ((PyObject*)p->_type_encoders);
  p->_type_encoders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7serpyco_10serializer_UnionFieldEncoder[] = {
  {"json_schema", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_7json_schema, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_6json_schema},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_7serpyco_10serializer_17UnionFieldEncoder_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_7serpyco_10serializer_17UnionFieldEncoder_10__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer_UnionFieldEncoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer_UnionFieldEncoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer_UnionFieldEncoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer_UnionFieldEncoder},
  {Py_tp_methods, (void *)__pyx_methods_7serpyco_10serializer_UnionFieldEncoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer_UnionFieldEncoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer_UnionFieldEncoder_spec = {
  "serpyco.serializer.UnionFieldEncoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer_UnionFieldEncoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer_UnionFieldEncoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""UnionFieldEncoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer_UnionFieldEncoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer_UnionFieldEncoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer_UnionFieldEncoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer_UnionFieldEncoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7serpyco_10serializer_UnionFieldEncoder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer_UnionFieldEncoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *__pyx_freelist_7serpyco_10serializer___pyx_scope_struct__genexpr[8];
static int __pyx_freecount_7serpyco_10serializer___pyx_scope_struct__genexpr = 0;

static PyObject *__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct__genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_7serpyco_10serializer___pyx_scope_struct__genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr)))) {
    o = (PyObject*)__pyx_freelist_7serpyco_10serializer___pyx_scope_struct__genexpr[--__pyx_freecount_7serpyco_10serializer___pyx_scope_struct__genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct__genexpr(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *p = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct__genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v__);
  Py_CLEAR(p->__pyx_v_serializer_field);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_7serpyco_10serializer___pyx_scope_struct__genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr)))) {
    __pyx_freelist_7serpyco_10serializer___pyx_scope_struct__genexpr[__pyx_freecount_7serpyco_10serializer___pyx_scope_struct__genexpr++] = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct__genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *p = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v__) {
    e = (*v)(p->__pyx_v__, a); if (e) return e;
  }
  if (p->__pyx_v_serializer_field) {
    e = (*v)(p->__pyx_v_serializer_field, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct__genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct__genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct__genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr_spec = {
  "serpyco.serializer.__pyx_scope_struct__genexpr",
  sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""__pyx_scope_struct__genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct__genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct__genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct__genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer___pyx_scope_struct__genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *__pyx_freelist_7serpyco_10serializer___pyx_scope_struct_1__get_encoder[8];
static int __pyx_freecount_7serpyco_10serializer___pyx_scope_struct_1__get_encoder = 0;

static PyObject *__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_1__get_encoder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_1__get_encoder > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder)))) {
    o = (PyObject*)__pyx_freelist_7serpyco_10serializer___pyx_scope_struct_1__get_encoder[--__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_1__get_encoder];
    memset(o, 0, sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_1__get_encoder(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *p = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_1__get_encoder) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_hints);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_1__get_encoder < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder)))) {
    __pyx_freelist_7serpyco_10serializer___pyx_scope_struct_1__get_encoder[__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_1__get_encoder++] = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct_1__get_encoder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *p = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *)o;
  if (p->__pyx_v_hints) {
    e = (*v)(p->__pyx_v_hints, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7serpyco_10serializer___pyx_scope_struct_1__get_encoder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *p = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder *)o;
  tmp = ((PyObject*)p->__pyx_v_hints);
  p->__pyx_v_hints = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_1__get_encoder},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct_1__get_encoder},
  {Py_tp_clear, (void *)__pyx_tp_clear_7serpyco_10serializer___pyx_scope_struct_1__get_encoder},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_1__get_encoder},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder_spec = {
  "serpyco.serializer.__pyx_scope_struct_1__get_encoder",
  sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""__pyx_scope_struct_1__get_encoder", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_1__get_encoder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_1__get_encoder, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct_1__get_encoder, /*tp_traverse*/
  __pyx_tp_clear_7serpyco_10serializer___pyx_scope_struct_1__get_encoder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_1__get_encoder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *__pyx_freelist_7serpyco_10serializer___pyx_scope_struct_2_genexpr[8];
static int __pyx_freecount_7serpyco_10serializer___pyx_scope_struct_2_genexpr = 0;

static PyObject *__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_2_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_2_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr)))) {
    o = (PyObject*)__pyx_freelist_7serpyco_10serializer___pyx_scope_struct_2_genexpr[--__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_2_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_2_genexpr(PyObject *o) {
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_2_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_f);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_2_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr)))) {
    __pyx_freelist_7serpyco_10serializer___pyx_scope_struct_2_genexpr[__pyx_freecount_7serpyco_10serializer___pyx_scope_struct_2_genexpr++] = ((struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct_2_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_f) {
    e = (*v)(p->__pyx_v_f, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_2_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct_2_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_2_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr_spec = {
  "serpyco.serializer.__pyx_scope_struct_2_genexpr",
  sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "serpyco.serializer.""__pyx_scope_struct_2_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_7serpyco_10serializer___pyx_scope_struct_2_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7serpyco_10serializer___pyx_scope_struct_2_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7serpyco_10serializer___pyx_scope_struct_2_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7serpyco_10serializer___pyx_scope_struct_2_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
    {&__pyx_kp_u_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9, __pyx_k_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9, sizeof(__pyx_k_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9), 0, 1, 0, 0},
    {&__pyx_n_s_Any, __pyx_k_Any, sizeof(__pyx_k_Any), 0, 0, 1, 1},
    {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
    {&__pyx_kp_u_Cannot_create, __pyx_k_Cannot_create, sizeof(__pyx_k_Cannot_create), 0, 1, 0, 0},
    {&__pyx_n_s_Caster, __pyx_k_Caster, sizeof(__pyx_k_Caster), 0, 0, 1, 1},
    {&__pyx_n_s_Caster___reduce_cython, __pyx_k_Caster___reduce_cython, sizeof(__pyx_k_Caster___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Caster___setstate_cython, __pyx_k_Caster___setstate_cython, sizeof(__pyx_k_Caster___setstate_cython), 0, 0, 1, 1},
    {&__pyx_kp_u_Could_not_cast_field, __pyx_k_Could_not_cast_field, sizeof(__pyx_k_Could_not_cast_field), 0, 1, 0, 0},
    {&__pyx_n_s_DataClassFieldEncoder, __pyx_k_DataClassFieldEncoder, sizeof(__pyx_k_DataClassFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassFieldEncoder___reduce_c, __pyx_k_DataClassFieldEncoder___reduce_c, sizeof(__pyx_k_DataClassFieldEncoder___reduce_c), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassFieldEncoder___setstate, __pyx_k_DataClassFieldEncoder___setstate, sizeof(__pyx_k_DataClassFieldEncoder___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassFieldEncoder_dump, __pyx_k_DataClassFieldEncoder_dump, sizeof(__pyx_k_DataClassFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassFieldEncoder_json_schem, __pyx_k_DataClassFieldEncoder_json_schem, sizeof(__pyx_k_DataClassFieldEncoder_json_schem), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassFieldEncoder_load, __pyx_k_DataClassFieldEncoder_load, sizeof(__pyx_k_DataClassFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassIterableFieldEncoder, __pyx_k_DataClassIterableFieldEncoder, sizeof(__pyx_k_DataClassIterableFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassIterableFieldEncoder_2, __pyx_k_DataClassIterableFieldEncoder_2, sizeof(__pyx_k_DataClassIterableFieldEncoder_2), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassIterableFieldEncoder_3, __pyx_k_DataClassIterableFieldEncoder_3, sizeof(__pyx_k_DataClassIterableFieldEncoder_3), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassIterableFieldEncoder_du, __pyx_k_DataClassIterableFieldEncoder_du, sizeof(__pyx_k_DataClassIterableFieldEncoder_du), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassIterableFieldEncoder_js, __pyx_k_DataClassIterableFieldEncoder_js, sizeof(__pyx_k_DataClassIterableFieldEncoder_js), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassIterableFieldEncoder_lo, __pyx_k_DataClassIterableFieldEncoder_lo, sizeof(__pyx_k_DataClassIterableFieldEncoder_lo), 0, 0, 1, 1},
    {&__pyx_n_s_DataClassParams, __pyx_k_DataClassParams, sizeof(__pyx_k_DataClassParams), 0, 0, 1, 1},
    {&__pyx_n_s_DateTimeFieldEncoder, __pyx_k_DateTimeFieldEncoder, sizeof(__pyx_k_DateTimeFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_DateTimeFieldEncoder___reduce_cy, __pyx_k_DateTimeFieldEncoder___reduce_cy, sizeof(__pyx_k_DateTimeFieldEncoder___reduce_cy), 0, 0, 1, 1},
    {&__pyx_n_s_DateTimeFieldEncoder___setstate, __pyx_k_DateTimeFieldEncoder___setstate, sizeof(__pyx_k_DateTimeFieldEncoder___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_DateTimeFieldEncoder_dump, __pyx_k_DateTimeFieldEncoder_dump, sizeof(__pyx_k_DateTimeFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_DateTimeFieldEncoder_json_schema, __pyx_k_DateTimeFieldEncoder_json_schema, sizeof(__pyx_k_DateTimeFieldEncoder_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_DateTimeFieldEncoder_load, __pyx_k_DateTimeFieldEncoder_load, sizeof(__pyx_k_DateTimeFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_n_s_DecoratorType, __pyx_k_DecoratorType, sizeof(__pyx_k_DecoratorType), 0, 0, 1, 1},
    {&__pyx_n_s_DictFieldEncoder, __pyx_k_DictFieldEncoder, sizeof(__pyx_k_DictFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_DictFieldEncoder___reduce_cython, __pyx_k_DictFieldEncoder___reduce_cython, sizeof(__pyx_k_DictFieldEncoder___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_DictFieldEncoder___setstate_cyth, __pyx_k_DictFieldEncoder___setstate_cyth, sizeof(__pyx_k_DictFieldEncoder___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_DictFieldEncoder_dump, __pyx_k_DictFieldEncoder_dump, sizeof(__pyx_k_DictFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_DictFieldEncoder_json_schema, __pyx_k_DictFieldEncoder_json_schema, sizeof(__pyx_k_DictFieldEncoder_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_DictFieldEncoder_load, __pyx_k_DictFieldEncoder_load, sizeof(__pyx_k_DictFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_n_s_Enum, __pyx_k_Enum, sizeof(__pyx_k_Enum), 0, 0, 1, 1},
    {&__pyx_n_s_EnumFieldEncoder, __pyx_k_EnumFieldEncoder, sizeof(__pyx_k_EnumFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_EnumFieldEncoder___reduce_cython, __pyx_k_EnumFieldEncoder___reduce_cython, sizeof(__pyx_k_EnumFieldEncoder___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_EnumFieldEncoder___setstate_cyth, __pyx_k_EnumFieldEncoder___setstate_cyth, sizeof(__pyx_k_EnumFieldEncoder___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_EnumFieldEncoder_dump, __pyx_k_EnumFieldEncoder_dump, sizeof(__pyx_k_EnumFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_EnumFieldEncoder_json_schema, __pyx_k_EnumFieldEncoder_json_schema, sizeof(__pyx_k_EnumFieldEncoder_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_EnumFieldEncoder_load, __pyx_k_EnumFieldEncoder_load, sizeof(__pyx_k_EnumFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_n_s_FieldEncoder, __pyx_k_FieldEncoder, sizeof(__pyx_k_FieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_FieldHints, __pyx_k_FieldHints, sizeof(__pyx_k_FieldHints), 0, 0, 1, 1},
    {&__pyx_n_s_FixedTupleFieldEncoder, __pyx_k_FixedTupleFieldEncoder, sizeof(__pyx_k_FixedTupleFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_FixedTupleFieldEncoder___reduce, __pyx_k_FixedTupleFieldEncoder___reduce, sizeof(__pyx_k_FixedTupleFieldEncoder___reduce), 0, 0, 1, 1},
    {&__pyx_n_s_FixedTupleFieldEncoder___setstat, __pyx_k_FixedTupleFieldEncoder___setstat, sizeof(__pyx_k_FixedTupleFieldEncoder___setstat), 0, 0, 1, 1},
    {&__pyx_n_s_FixedTupleFieldEncoder_dump, __pyx_k_FixedTupleFieldEncoder_dump, sizeof(__pyx_k_FixedTupleFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_FixedTupleFieldEncoder_json_sche, __pyx_k_FixedTupleFieldEncoder_json_sche, sizeof(__pyx_k_FixedTupleFieldEncoder_json_sche), 0, 0, 1, 1},
    {&__pyx_n_s_FixedTupleFieldEncoder_load, __pyx_k_FixedTupleFieldEncoder_load, sizeof(__pyx_k_FixedTupleFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_n_s_ITERABLE_TYPES_MAPPING, __pyx_k_ITERABLE_TYPES_MAPPING, sizeof(__pyx_k_ITERABLE_TYPES_MAPPING), 0, 0, 1, 1},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2, __pyx_k_Incompatible_checksums_0x_x_vs_0_2, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0_2), 0, 0, 1, 0},
    {&__pyx_kp_u_Invalid_number_of_items_for_tupl, __pyx_k_Invalid_number_of_items_for_tupl, sizeof(__pyx_k_Invalid_number_of_items_for_tupl), 0, 1, 0, 0},
    {&__pyx_n_s_Iterable, __pyx_k_Iterable, sizeof(__pyx_k_Iterable), 0, 0, 1, 1},
    {&__pyx_n_s_IterableFieldEncoder, __pyx_k_IterableFieldEncoder, sizeof(__pyx_k_IterableFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_IterableFieldEncoder___reduce_cy, __pyx_k_IterableFieldEncoder___reduce_cy, sizeof(__pyx_k_IterableFieldEncoder___reduce_cy), 0, 0, 1, 1},
    {&__pyx_n_s_IterableFieldEncoder___setstate, __pyx_k_IterableFieldEncoder___setstate, sizeof(__pyx_k_IterableFieldEncoder___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_IterableFieldEncoder_dump, __pyx_k_IterableFieldEncoder_dump, sizeof(__pyx_k_IterableFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_IterableFieldEncoder_json_schema, __pyx_k_IterableFieldEncoder_json_schema, sizeof(__pyx_k_IterableFieldEncoder_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_IterableFieldEncoder_load, __pyx_k_IterableFieldEncoder_load, sizeof(__pyx_k_IterableFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_n_s_JSON_ENCODABLE_TYPES, __pyx_k_JSON_ENCODABLE_TYPES, sizeof(__pyx_k_JSON_ENCODABLE_TYPES), 0, 0, 1, 1},
    {&__pyx_n_s_JsonDict, __pyx_k_JsonDict, sizeof(__pyx_k_JsonDict), 0, 0, 1, 1},
    {&__pyx_n_s_JsonEncodable, __pyx_k_JsonEncodable, sizeof(__pyx_k_JsonEncodable), 0, 0, 1, 1},
    {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
    {&__pyx_n_s_List, __pyx_k_List, sizeof(__pyx_k_List), 0, 0, 1, 1},
    {&__pyx_n_s_MISSING, __pyx_k_MISSING, sizeof(__pyx_k_MISSING), 0, 0, 1, 1},
    {&__pyx_n_s_Mapping, __pyx_k_Mapping, sizeof(__pyx_k_Mapping), 0, 0, 1, 1},
    {&__pyx_n_s_NoEncoderError, __pyx_k_NoEncoderError, sizeof(__pyx_k_NoEncoderError), 0, 0, 1, 1},
    {&__pyx_kp_u_No_encoder_for, __pyx_k_No_encoder_for, sizeof(__pyx_k_No_encoder_for), 0, 1, 0, 0},
    {&__pyx_n_s_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 0, 1, 1},
    {&__pyx_kp_u_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 1, 0, 0},
    {&__pyx_n_s_NotADataClassError, __pyx_k_NotADataClassError, sizeof(__pyx_k_NotADataClassError), 0, 0, 1, 1},
    {&__pyx_n_s_OverflowError, __pyx_k_OverflowError, sizeof(__pyx_k_OverflowError), 0, 0, 1, 1},
    {&__pyx_n_s_POST_DUMP, __pyx_k_POST_DUMP, sizeof(__pyx_k_POST_DUMP), 0, 0, 1, 1},
    {&__pyx_n_s_POST_LOAD, __pyx_k_POST_LOAD, sizeof(__pyx_k_POST_LOAD), 0, 0, 1, 1},
    {&__pyx_n_s_PRE_DUMP, __pyx_k_PRE_DUMP, sizeof(__pyx_k_PRE_DUMP), 0, 0, 1, 1},
    {&__pyx_n_s_PRE_LOAD, __pyx_k_PRE_LOAD, sizeof(__pyx_k_PRE_LOAD), 0, 0, 1, 1},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_RapidJsonValidator, __pyx_k_RapidJsonValidator, sizeof(__pyx_k_RapidJsonValidator), 0, 0, 1, 1},
    {&__pyx_n_s_SchemaBuilder, __pyx_k_SchemaBuilder, sizeof(__pyx_k_SchemaBuilder), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer, __pyx_k_Serializer, sizeof(__pyx_k_Serializer), 0, 0, 1, 1},
    {&__pyx_n_s_SerializerField, __pyx_k_SerializerField, sizeof(__pyx_k_SerializerField), 0, 0, 1, 1},
    {&__pyx_n_s_SerializerField___reduce_cython, __pyx_k_SerializerField___reduce_cython, sizeof(__pyx_k_SerializerField___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_SerializerField___setstate_cytho, __pyx_k_SerializerField___setstate_cytho, sizeof(__pyx_k_SerializerField___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_kp_s_Serializer_2, __pyx_k_Serializer_2, sizeof(__pyx_k_Serializer_2), 0, 0, 1, 0},
    {&__pyx_n_s_Serializer___reduce_cython, __pyx_k_Serializer___reduce_cython, sizeof(__pyx_k_Serializer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer___setstate_cython, __pyx_k_Serializer___setstate_cython, sizeof(__pyx_k_Serializer___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer__get_encoder, __pyx_k_Serializer__get_encoder, sizeof(__pyx_k_Serializer__get_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer__get_field_serializer, __pyx_k_Serializer__get_field_serializer, sizeof(__pyx_k_Serializer__get_field_serializer), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_dataclass, __pyx_k_Serializer_dataclass, sizeof(__pyx_k_Serializer_dataclass), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_dump, __pyx_k_Serializer_dump, sizeof(__pyx_k_Serializer_dump), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_dump_json, __pyx_k_Serializer_dump_json, sizeof(__pyx_k_Serializer_dump_json), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_get_dict_path, __pyx_k_Serializer_get_dict_path, sizeof(__pyx_k_Serializer_get_dict_path), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_get_object_path, __pyx_k_Serializer_get_object_path, sizeof(__pyx_k_Serializer_get_object_path), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_json_schema, __pyx_k_Serializer_json_schema, sizeof(__pyx_k_Serializer_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_load, __pyx_k_Serializer_load, sizeof(__pyx_k_Serializer_load), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_load_json, __pyx_k_Serializer_load_json, sizeof(__pyx_k_Serializer_load_json), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_register_global_type, __pyx_k_Serializer_register_global_type, sizeof(__pyx_k_Serializer_register_global_type), 0, 0, 1, 1},
    {&__pyx_n_s_Serializer_unregister_global_typ, __pyx_k_Serializer_unregister_global_typ, sizeof(__pyx_k_Serializer_unregister_global_typ), 0, 0, 1, 1},
    {&__pyx_n_s_Set, __pyx_k_Set, sizeof(__pyx_k_Set), 0, 0, 1, 1},
    {&__pyx_n_s_Tuple, __pyx_k_Tuple, sizeof(__pyx_k_Tuple), 0, 0, 1, 1},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_n_s_UNTYPED_DICT_TYPES, __pyx_k_UNTYPED_DICT_TYPES, sizeof(__pyx_k_UNTYPED_DICT_TYPES), 0, 0, 1, 1},
    {&__pyx_n_s_UNTYPED_ITERABLE_TYPES, __pyx_k_UNTYPED_ITERABLE_TYPES, sizeof(__pyx_k_UNTYPED_ITERABLE_TYPES), 0, 0, 1, 1},
    {&__pyx_n_s_UUID, __pyx_k_UUID, sizeof(__pyx_k_UUID), 0, 0, 1, 1},
    {&__pyx_n_s_UnionFieldEncoder, __pyx_k_UnionFieldEncoder, sizeof(__pyx_k_UnionFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_UnionFieldEncoder___reduce_cytho, __pyx_k_UnionFieldEncoder___reduce_cytho, sizeof(__pyx_k_UnionFieldEncoder___reduce_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_UnionFieldEncoder___setstate_cyt, __pyx_k_UnionFieldEncoder___setstate_cyt, sizeof(__pyx_k_UnionFieldEncoder___setstate_cyt), 0, 0, 1, 1},
    {&__pyx_n_s_UnionFieldEncoder_dump, __pyx_k_UnionFieldEncoder_dump, sizeof(__pyx_k_UnionFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_UnionFieldEncoder_json_schema, __pyx_k_UnionFieldEncoder_json_schema, sizeof(__pyx_k_UnionFieldEncoder_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_UnionFieldEncoder_load, __pyx_k_UnionFieldEncoder_load, sizeof(__pyx_k_UnionFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_kp_u_Unknown_decorator_type, __pyx_k_Unknown_decorator_type, sizeof(__pyx_k_Unknown_decorator_type), 0, 1, 0, 0},
    {&__pyx_kp_u_Unknown_dict_key, __pyx_k_Unknown_dict_key, sizeof(__pyx_k_Unknown_dict_key), 0, 1, 0, 0},
    {&__pyx_kp_u_Unknown_field, __pyx_k_Unknown_field, sizeof(__pyx_k_Unknown_field), 0, 1, 0, 0},
    {&__pyx_n_s_UuidFieldEncoder, __pyx_k_UuidFieldEncoder, sizeof(__pyx_k_UuidFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_UuidFieldEncoder___reduce_cython, __pyx_k_UuidFieldEncoder___reduce_cython, sizeof(__pyx_k_UuidFieldEncoder___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UuidFieldEncoder___setstate_cyth, __pyx_k_UuidFieldEncoder___setstate_cyth, sizeof(__pyx_k_UuidFieldEncoder___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_UuidFieldEncoder_dump, __pyx_k_UuidFieldEncoder_dump, sizeof(__pyx_k_UuidFieldEncoder_dump), 0, 0, 1, 1},
    {&__pyx_n_s_UuidFieldEncoder_json_schema, __pyx_k_UuidFieldEncoder_json_schema, sizeof(__pyx_k_UuidFieldEncoder_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_UuidFieldEncoder_load, __pyx_k_UuidFieldEncoder_load, sizeof(__pyx_k_UuidFieldEncoder_load), 0, 0, 1, 1},
    {&__pyx_n_s_ValidationError, __pyx_k_ValidationError, sizeof(__pyx_k_ValidationError), 0, 0, 1, 1},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
    {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
    {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
    {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
    {&__pyx_n_s__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 0, 1, 1},
    {&__pyx_n_s__97, __pyx_k__97, sizeof(__pyx_k__97), 0, 0, 1, 1},
    {&__pyx_n_s_arg, __pyx_k_arg, sizeof(__pyx_k_arg), 0, 0, 1, 1},
    {&__pyx_n_s_arg_type, __pyx_k_arg_type, sizeof(__pyx_k_arg_type), 0, 0, 1, 1},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_s_arguments, __pyx_k_arguments, sizeof(__pyx_k_arguments), 0, 0, 1, 1},
    {&__pyx_kp_u_as, __pyx_k_as, sizeof(__pyx_k_as), 0, 1, 0, 0},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 0, 1, 1},
    {&__pyx_n_s_cast_on_load, __pyx_k_cast_on_load, sizeof(__pyx_k_cast_on_load), 0, 0, 1, 1},
    {&__pyx_n_s_caster, __pyx_k_caster, sizeof(__pyx_k_caster), 0, 0, 1, 1},
    {&__pyx_n_s_cinit___locals_genexpr, __pyx_k_cinit___locals_genexpr, sizeof(__pyx_k_cinit___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
    {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
    {&__pyx_kp_u_data_dictionary_is_missing_requi, __pyx_k_data_dictionary_is_missing_requi, sizeof(__pyx_k_data_dictionary_is_missing_requi), 0, 1, 0, 0},
    {&__pyx_n_s_dataclass, __pyx_k_dataclass, sizeof(__pyx_k_dataclass), 0, 0, 1, 1},
    {&__pyx_n_s_dataclass_params, __pyx_k_dataclass_params, sizeof(__pyx_k_dataclass_params), 0, 0, 1, 1},
    {&__pyx_n_s_dataclass_params_2, __pyx_k_dataclass_params_2, sizeof(__pyx_k_dataclass_params_2), 0, 0, 1, 1},
    {&__pyx_n_s_dataclasses, __pyx_k_dataclasses, sizeof(__pyx_k_dataclasses), 0, 0, 1, 1},
    {&__pyx_kp_u_date_time, __pyx_k_date_time, sizeof(__pyx_k_date_time), 0, 1, 0, 0},
    {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_dateutil, __pyx_k_dateutil, sizeof(__pyx_k_dateutil), 0, 0, 1, 1},
    {&__pyx_n_s_dateutil_parser, __pyx_k_dateutil_parser, sizeof(__pyx_k_dateutil_parser), 0, 0, 1, 1},
    {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
    {&__pyx_n_s_default_factory, __pyx_k_default_factory, sizeof(__pyx_k_default_factory), 0, 0, 1, 1},
    {&__pyx_n_s_dencoder, __pyx_k_dencoder, sizeof(__pyx_k_dencoder), 0, 0, 1, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
    {&__pyx_n_s_dict_encoder, __pyx_k_dict_encoder, sizeof(__pyx_k_dict_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_dict_key, __pyx_k_dict_key, sizeof(__pyx_k_dict_key), 0, 0, 1, 1},
    {&__pyx_n_s_dict_path, __pyx_k_dict_path, sizeof(__pyx_k_dict_path), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_diter_encoder, __pyx_k_diter_encoder, sizeof(__pyx_k_diter_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_dump, __pyx_k_dump, sizeof(__pyx_k_dump), 0, 0, 1, 1},
    {&__pyx_n_s_dump_json, __pyx_k_dump_json, sizeof(__pyx_k_dump_json), 0, 0, 1, 1},
    {&__pyx_n_s_dumps, __pyx_k_dumps, sizeof(__pyx_k_dumps), 0, 0, 1, 1},
    {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_encoder, __pyx_k_encoder, sizeof(__pyx_k_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_enum, __pyx_k_enum, sizeof(__pyx_k_enum), 0, 0, 1, 1},
    {&__pyx_n_s_enum_type, __pyx_k_enum_type, sizeof(__pyx_k_enum_type), 0, 0, 1, 1},
    {&__pyx_n_s_evaluate, __pyx_k_evaluate, sizeof(__pyx_k_evaluate), 0, 0, 1, 1},
    {&__pyx_n_s_exclude, __pyx_k_exclude, sizeof(__pyx_k_exclude), 0, 0, 1, 1},
    {&__pyx_n_s_excluded_field_names, __pyx_k_excluded_field_names, sizeof(__pyx_k_excluded_field_names), 0, 0, 1, 1},
    {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
    {&__pyx_kp_u_field, __pyx_k_field, sizeof(__pyx_k_field), 0, 1, 0, 0},
    {&__pyx_n_s_field_name, __pyx_k_field_name, sizeof(__pyx_k_field_name), 0, 0, 1, 1},
    {&__pyx_n_s_field_type, __pyx_k_field_type, sizeof(__pyx_k_field_type), 0, 0, 1, 1},
    {&__pyx_n_s_fields, __pyx_k_fields, sizeof(__pyx_k_fields), 0, 0, 1, 1},
    {&__pyx_kp_u_for_class, __pyx_k_for_class, sizeof(__pyx_k_for_class), 0, 1, 0, 0},
    {&__pyx_n_u_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 1, 0, 1},
    {&__pyx_n_s_frozen, __pyx_k_frozen, sizeof(__pyx_k_frozen), 0, 0, 1, 1},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_get_args, __pyx_k_get_args, sizeof(__pyx_k_get_args), 0, 0, 1, 1},
    {&__pyx_n_s_get_dict_path, __pyx_k_get_dict_path, sizeof(__pyx_k_get_dict_path), 0, 0, 1, 1},
    {&__pyx_n_s_get_encoder, __pyx_k_get_encoder, sizeof(__pyx_k_get_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_get_encoder_locals_genexpr, __pyx_k_get_encoder_locals_genexpr, sizeof(__pyx_k_get_encoder_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_get_field_serializer, __pyx_k_get_field_serializer, sizeof(__pyx_k_get_field_serializer), 0, 0, 1, 1},
    {&__pyx_n_s_get_object_path, __pyx_k_get_object_path, sizeof(__pyx_k_get_object_path), 0, 0, 1, 1},
    {&__pyx_n_s_get_origin, __pyx_k_get_origin, sizeof(__pyx_k_get_origin), 0, 0, 1, 1},
    {&__pyx_n_s_get_type_hints, __pyx_k_get_type_hints, sizeof(__pyx_k_get_type_hints), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_n_s_getter, __pyx_k_getter, sizeof(__pyx_k_getter), 0, 0, 1, 1},
    {&__pyx_n_s_global_types, __pyx_k_global_types, sizeof(__pyx_k_global_types), 0, 0, 1, 1},
    {&__pyx_n_s_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 0, 1, 1},
    {&__pyx_kp_u_has_a_wrong_type_expected_any_o, __pyx_k_has_a_wrong_type_expected_any_o, sizeof(__pyx_k_has_a_wrong_type_expected_any_o), 0, 1, 0, 0},
    {&__pyx_n_s_hints, __pyx_k_hints, sizeof(__pyx_k_hints), 0, 0, 1, 1},
    {&__pyx_n_s_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_kp_u_in, __pyx_k_in, sizeof(__pyx_k_in), 0, 1, 0, 0},
    {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_kp_u_is_excluded_but_has_no_default, __pyx_k_is_excluded_but_has_no_default, sizeof(__pyx_k_is_excluded_but_has_no_default), 0, 1, 0, 0},
    {&__pyx_n_s_is_generic, __pyx_k_is_generic, sizeof(__pyx_k_is_generic), 0, 0, 1, 1},
    {&__pyx_n_s_is_new_type, __pyx_k_is_new_type, sizeof(__pyx_k_is_new_type), 0, 0, 1, 1},
    {&__pyx_kp_u_is_not_a_dataclass, __pyx_k_is_not_a_dataclass, sizeof(__pyx_k_is_not_a_dataclass), 0, 1, 0, 0},
    {&__pyx_kp_u_is_not_a_datetime_datetime_inst, __pyx_k_is_not_a_datetime_datetime_inst, sizeof(__pyx_k_is_not_a_datetime_datetime_inst), 0, 1, 0, 0},
    {&__pyx_kp_u_is_not_a_valid_datetime, __pyx_k_is_not_a_valid_datetime, sizeof(__pyx_k_is_not_a_valid_datetime), 0, 1, 0, 0},
    {&__pyx_n_s_is_union, __pyx_k_is_union, sizeof(__pyx_k_is_union), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_iso8601_pattern, __pyx_k_iso8601_pattern, sizeof(__pyx_k_iso8601_pattern), 0, 0, 1, 1},
    {&__pyx_n_s_isoformat, __pyx_k_isoformat, sizeof(__pyx_k_isoformat), 0, 0, 1, 1},
    {&__pyx_n_s_issubclass_safe, __pyx_k_issubclass_safe, sizeof(__pyx_k_issubclass_safe), 0, 0, 1, 1},
    {&__pyx_n_s_item_encoder, __pyx_k_item_encoder, sizeof(__pyx_k_item_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_item_encoders, __pyx_k_item_encoders, sizeof(__pyx_k_item_encoders), 0, 0, 1, 1},
    {&__pyx_n_s_item_type, __pyx_k_item_type, sizeof(__pyx_k_item_type), 0, 0, 1, 1},
    {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
    {&__pyx_n_s_iter_encoder, __pyx_k_iter_encoder, sizeof(__pyx_k_iter_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_js, __pyx_k_js, sizeof(__pyx_k_js), 0, 0, 1, 1},
    {&__pyx_n_s_json_schema, __pyx_k_json_schema, sizeof(__pyx_k_json_schema), 0, 0, 1, 1},
    {&__pyx_n_s_key_encoder, __pyx_k_key_encoder, sizeof(__pyx_k_key_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
    {&__pyx_n_s_load, __pyx_k_load, sizeof(__pyx_k_load), 0, 0, 1, 1},
    {&__pyx_n_s_load_as_type, __pyx_k_load_as_type, sizeof(__pyx_k_load_as_type), 0, 0, 1, 1},
    {&__pyx_n_s_load_json, __pyx_k_load_json, sizeof(__pyx_k_load_json), 0, 0, 1, 1},
    {&__pyx_n_s_loads, __pyx_k_loads, sizeof(__pyx_k_loads), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_many, __pyx_k_many, sizeof(__pyx_k_many), 0, 0, 1, 1},
    {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
    {&__pyx_n_s_metadata, __pyx_k_metadata, sizeof(__pyx_k_metadata), 0, 0, 1, 1},
    {&__pyx_n_s_metadata_name, __pyx_k_metadata_name, sizeof(__pyx_k_metadata_name), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
    {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
    {&__pyx_n_s_obj_path, __pyx_k_obj_path, sizeof(__pyx_k_obj_path), 0, 0, 1, 1},
    {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
    {&__pyx_n_s_omit_none, __pyx_k_omit_none, sizeof(__pyx_k_omit_none), 0, 0, 1, 1},
    {&__pyx_n_s_only, __pyx_k_only, sizeof(__pyx_k_only), 0, 0, 1, 1},
    {&__pyx_n_s_param, __pyx_k_param, sizeof(__pyx_k_param), 0, 0, 1, 1},
    {&__pyx_n_s_param_args, __pyx_k_param_args, sizeof(__pyx_k_param_args), 0, 0, 1, 1},
    {&__pyx_n_s_parameters, __pyx_k_parameters, sizeof(__pyx_k_parameters), 0, 0, 1, 1},
    {&__pyx_n_s_params, __pyx_k_params, sizeof(__pyx_k_params), 0, 0, 1, 1},
    {&__pyx_n_s_parent_serializers, __pyx_k_parent_serializers, sizeof(__pyx_k_parent_serializers), 0, 0, 1, 1},
    {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
    {&__pyx_n_s_parser, __pyx_k_parser, sizeof(__pyx_k_parser), 0, 0, 1, 1},
    {&__pyx_n_s_part, __pyx_k_part, sizeof(__pyx_k_part), 0, 0, 1, 1},
    {&__pyx_n_u_pattern, __pyx_k_pattern, sizeof(__pyx_k_pattern), 0, 1, 0, 1},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_n_s_post_init, __pyx_k_post_init, sizeof(__pyx_k_post_init), 0, 0, 1, 1},
    {&__pyx_n_u_post_init, __pyx_k_post_init, sizeof(__pyx_k_post_init), 0, 1, 0, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_DateTimeFieldEnco, __pyx_k_pyx_unpickle_DateTimeFieldEnco, sizeof(__pyx_k_pyx_unpickle_DateTimeFieldEnco), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_SerializerField, __pyx_k_pyx_unpickle_SerializerField, sizeof(__pyx_k_pyx_unpickle_SerializerField), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_UuidFieldEncoder, __pyx_k_pyx_unpickle_UuidFieldEncoder, sizeof(__pyx_k_pyx_unpickle_UuidFieldEncoder), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_rapidjson, __pyx_k_rapidjson, sizeof(__pyx_k_rapidjson), 0, 0, 1, 1},
    {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_register_global_type, __pyx_k_register_global_type, sizeof(__pyx_k_register_global_type), 0, 0, 1, 1},
    {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
    {&__pyx_n_s_resolve_type, __pyx_k_resolve_type, sizeof(__pyx_k_resolve_type), 0, 0, 1, 1},
    {&__pyx_n_s_return, __pyx_k_return, sizeof(__pyx_k_return), 0, 0, 1, 1},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
    {&__pyx_n_s_sequence_type, __pyx_k_sequence_type, sizeof(__pyx_k_sequence_type), 0, 0, 1, 1},
    {&__pyx_n_s_ser, __pyx_k_ser, sizeof(__pyx_k_ser), 0, 0, 1, 1},
    {&__pyx_n_s_serializer, __pyx_k_serializer, sizeof(__pyx_k_serializer), 0, 0, 1, 1},
    {&__pyx_n_s_serpyco_decorator, __pyx_k_serpyco_decorator, sizeof(__pyx_k_serpyco_decorator), 0, 0, 1, 1},
    {&__pyx_n_s_serpyco_exception, __pyx_k_serpyco_exception, sizeof(__pyx_k_serpyco_exception), 0, 0, 1, 1},
    {&__pyx_n_s_serpyco_field, __pyx_k_serpyco_field, sizeof(__pyx_k_serpyco_field), 0, 0, 1, 1},
    {&__pyx_n_s_serpyco_schema, __pyx_k_serpyco_schema, sizeof(__pyx_k_serpyco_schema), 0, 0, 1, 1},
    {&__pyx_n_s_serpyco_serializer, __pyx_k_serpyco_serializer, sizeof(__pyx_k_serpyco_serializer), 0, 0, 1, 1},
    {&__pyx_kp_s_serpyco_serializer_pyx, __pyx_k_serpyco_serializer_pyx, sizeof(__pyx_k_serpyco_serializer_pyx), 0, 0, 1, 0},
    {&__pyx_n_s_serpyco_tags, __pyx_k_serpyco_tags, sizeof(__pyx_k_serpyco_tags), 0, 0, 1, 1},
    {&__pyx_n_s_serpyco_util, __pyx_k_serpyco_util, sizeof(__pyx_k_serpyco_util), 0, 0, 1, 1},
    {&__pyx_n_s_serpyco_validator, __pyx_k_serpyco_validator, sizeof(__pyx_k_serpyco_validator), 0, 0, 1, 1},
    {&__pyx_n_s_setattr, __pyx_k_setattr, sizeof(__pyx_k_setattr), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_sfield, __pyx_k_sfield, sizeof(__pyx_k_sfield), 0, 0, 1, 1},
    {&__pyx_n_s_sh, __pyx_k_sh, sizeof(__pyx_k_sh), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_strict, __pyx_k_strict, sizeof(__pyx_k_strict), 0, 0, 1, 1},
    {&__pyx_n_u_string, __pyx_k_string, sizeof(__pyx_k_string), 0, 1, 0, 1},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_supertype, __pyx_k_supertype, sizeof(__pyx_k_supertype), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
    {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
    {&__pyx_n_s_type_2, __pyx_k_type_2, sizeof(__pyx_k_type_2), 0, 0, 1, 1},
    {&__pyx_n_u_type_2, __pyx_k_type_2, sizeof(__pyx_k_type_2), 0, 1, 0, 1},
    {&__pyx_n_s_type_encoders, __pyx_k_type_encoders, sizeof(__pyx_k_type_encoders), 0, 0, 1, 1},
    {&__pyx_n_s_typing, __pyx_k_typing, sizeof(__pyx_k_typing), 0, 0, 1, 1},
    {&__pyx_kp_s_typing_Any, __pyx_k_typing_Any, sizeof(__pyx_k_typing_Any), 0, 0, 1, 0},
    {&__pyx_kp_s_typing_List_str, __pyx_k_typing_List_str, sizeof(__pyx_k_typing_List_str), 0, 0, 1, 0},
    {&__pyx_kp_s_typing_Sequence_str, __pyx_k_typing_Sequence_str, sizeof(__pyx_k_typing_Sequence_str), 0, 0, 1, 0},
    {&__pyx_kp_s_typing_Union_dict_typing_Iterabl, __pyx_k_typing_Union_dict_typing_Iterabl, sizeof(__pyx_k_typing_Union_dict_typing_Iterabl), 0, 0, 1, 0},
    {&__pyx_kp_s_typing_Union_object_typing_Itera, __pyx_k_typing_Union_object_typing_Itera, sizeof(__pyx_k_typing_Union_object_typing_Itera), 0, 0, 1, 0},
    {&__pyx_n_s_typing_inspect, __pyx_k_typing_inspect, sizeof(__pyx_k_typing_inspect), 0, 0, 1, 1},
    {&__pyx_n_s_unregister_global_type, __pyx_k_unregister_global_type, sizeof(__pyx_k_unregister_global_type), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_uuid, __pyx_k_uuid, sizeof(__pyx_k_uuid), 0, 0, 1, 1},
    {&__pyx_n_u_uuid, __pyx_k_uuid, sizeof(__pyx_k_uuid), 0, 1, 0, 1},
    {&__pyx_n_s_validate, __pyx_k_validate, sizeof(__pyx_k_validate), 0, 0, 1, 1},
    {&__pyx_n_s_validate_json, __pyx_k_validate_json, sizeof(__pyx_k_validate_json), 0, 0, 1, 1},
    {&__pyx_n_s_validate_user, __pyx_k_validate_user, sizeof(__pyx_k_validate_user), 0, 0, 1, 1},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_n_s_value_encoder, __pyx_k_value_encoder, sizeof(__pyx_k_value_encoder), 0, 0, 1, 1},
    {&__pyx_n_s_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 43, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 91, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 249, __pyx_L1_error)
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 250, __pyx_L1_error)
  __pyx_builtin_map = __Pyx_GetBuiltinName(__pyx_n_s_map); if (!__pyx_builtin_map) __PYX_ERR(0, 359, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_n_s_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 668, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 788, __pyx_L1_error)
  __pyx_builtin_OverflowError = __Pyx_GetBuiltinName(__pyx_n_s_OverflowError); if (!__pyx_builtin_OverflowError) __PYX_ERR(0, 916, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "serpyco/serializer.pyx":294
 * 
 *         ser = self._get_field_serializer(sfield)
 *         return [sfield.dict_key] + ser.get_dict_path(obj_path[1:])             # <<<<<<<<<<<<<<
 * 
 *     def get_object_path(self, dict_path: typing.Sequence[str]) -> typing.List[str]:
 */
  __pyx_slice__2 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__2)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__2);
  __Pyx_GIVEREF(__pyx_slice__2);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x4c26f91, 0x8b72694, 0xeb8ae5a):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x4c26f91, 0x8b72694, 0xeb8ae5a) = (default, default_factory, dict_key, encoder, field_name, getter, init))" % __pyx_checksum
 */
  __pyx_tuple__6 = PyTuple_Pack(3, __pyx_int_79851409, __pyx_int_146220692, __pyx_int_246984282); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);
  __pyx_tuple__8 = PyTuple_Pack(3, __pyx_int_238750788, __pyx_int_228825662, __pyx_int_222419149); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "serpyco/serializer.pyx":17
 * 
 * import cython
 * import dateutil.parser             # <<<<<<<<<<<<<<
 * import rapidjson
 * import typing_inspect
 */
  __pyx_tuple__10 = PyTuple_Pack(2, __pyx_n_s_dateutil, __pyx_n_s_parser); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_tuple__11 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_dict_2, __pyx_n_s_use_setstate); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);
  __pyx_codeobj__12 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__11, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__12)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_SerializerField__set_state(self, __pyx_state)
 */
  __pyx_tuple__13 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);
  __pyx_codeobj__14 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__14)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__17 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__17)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":269
 *         ))
 * 
 *     def json_schema(self, many: bool = False) -> JsonDict:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the JSON schema of the underlying validator.
 */
  __pyx_tuple__18 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_many); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);
  __pyx_codeobj__19 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__18, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 269, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__19)) __PYX_ERR(0, 269, __pyx_L1_error)
  __pyx_tuple__20 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "serpyco/serializer.pyx":275
 *         return self._validator.json_schema(many=many)
 * 
 *     def get_dict_path(self, obj_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in dumped dictionaries.
 */
  __pyx_tuple__21 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_obj_path, __pyx_n_s_sfield, __pyx_n_s_ser, __pyx_n_s_part); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);
  __pyx_codeobj__22 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__21, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_get_dict_path, 275, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__22)) __PYX_ERR(0, 275, __pyx_L1_error)

  /* "serpyco/serializer.pyx":296
 *         return [sfield.dict_key] + ser.get_dict_path(obj_path[1:])
 * 
 *     def get_object_path(self, dict_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in loaded objects.
 */
  __pyx_tuple__23 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_dict_path, __pyx_n_s_sfield, __pyx_n_s_ser, __pyx_n_s_part); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_codeobj__24 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_get_object_path, 296, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__24)) __PYX_ERR(0, 296, __pyx_L1_error)

  /* "serpyco/serializer.pyx":317
 *         return [sfield.field_name] + ser.get_object_path(dict_path[1:])
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register_global_type(
 *         cls,
 */
  __pyx_tuple__25 = PyTuple_Pack(3, __pyx_n_s_cls, __pyx_n_s_field_type, __pyx_n_s_encoder); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);
  __pyx_codeobj__26 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__25, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_register_global_type, 317, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__26)) __PYX_ERR(0, 317, __pyx_L1_error)

  /* "serpyco/serializer.pyx":329
 *         SchemaBuilder.register_global_type(field_type, encoder.json_schema())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def unregister_global_type(cls, field_type: typing.Any) -> None:
 *         """
 */
  __pyx_tuple__27 = PyTuple_Pack(2, __pyx_n_s_cls, __pyx_n_s_field_type); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__27, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_unregister_global_type, 329, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(0, 329, __pyx_L1_error)

  /* "serpyco/serializer.pyx":337
 *         SchemaBuilder.unregister_global_type(field_type)
 * 
 *     def dataclass(self) -> type:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the dataclass used to construct this serializer.
 */
  __pyx_codeobj__29 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dataclass, 337, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__29)) __PYX_ERR(0, 337, __pyx_L1_error)

  /* "serpyco/serializer.pyx":343
 *         return self._dataclass
 * 
 *     cpdef inline dump(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */
  __pyx_tuple__30 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_obj, __pyx_n_s_validate, __pyx_n_s_many); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __pyx_codeobj__31 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__30, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 343, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__31)) __PYX_ERR(0, 343, __pyx_L1_error)
  __pyx_tuple__32 = PyTuple_Pack(2, Py_False, Py_False); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "serpyco/serializer.pyx":379
 *         return data
 * 
 *     cpdef inline load(             # <<<<<<<<<<<<<<
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 */
  __pyx_tuple__33 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_data, __pyx_n_s_validate, __pyx_n_s_many); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_codeobj__34 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__33, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 379, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__34)) __PYX_ERR(0, 379, __pyx_L1_error)
  __pyx_tuple__35 = PyTuple_Pack(2, Py_True, Py_False); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "serpyco/serializer.pyx":425
 *         return obj
 * 
 *     cpdef inline str dump_json(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */
  __pyx_codeobj__36 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__30, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump_json, 425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__36)) __PYX_ERR(0, 425, __pyx_L1_error)
  __pyx_tuple__37 = PyTuple_Pack(2, Py_False, Py_False); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "serpyco/serializer.pyx":468
 *         return rapidjson.dumps(data)
 * 
 *     cpdef inline load_json(             # <<<<<<<<<<<<<<
 *         self,
 *         str js,
 */
  __pyx_tuple__38 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_js, __pyx_n_s_validate, __pyx_n_s_many); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__38, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load_json, 468, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(0, 468, __pyx_L1_error)
  __pyx_tuple__40 = PyTuple_Pack(2, Py_True, Py_False); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "serpyco/serializer.pyx":575
 *         return obj
 * 
 *     def _get_field_serializer(self, sfield: SerializerField) -> "Serializer":             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder = sfield.encoder
 *         cdef DataClassFieldEncoder dencoder
 */
  __pyx_tuple__41 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_sfield, __pyx_n_s_encoder, __pyx_n_s_dencoder, __pyx_n_s_iter_encoder, __pyx_n_s_diter_encoder, __pyx_n_s_dict_encoder); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);
  __pyx_codeobj__42 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__41, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_get_field_serializer, 575, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__42)) __PYX_ERR(0, 575, __pyx_L1_error)

  /* "serpyco/serializer.pyx":598
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 * 
 *     def _get_encoder(self, field_type, hints):             # <<<<<<<<<<<<<<
 *         cdef DataClassFieldEncoder dencoder
 *         cdef Serializer serializer
 */
  __pyx_tuple__43 = PyTuple_Pack(22, __pyx_n_s_self, __pyx_n_s_field_type, __pyx_n_s_hints, __pyx_n_s_dencoder, __pyx_n_s_serializer, __pyx_n_s_args, __pyx_n_s_type_encoders, __pyx_n_s_key_encoder, __pyx_n_s_value_encoder, __pyx_n_s_item_encoders, __pyx_n_s_item_encoder, __pyx_n_s_param_args, __pyx_n_s_params, __pyx_n_s_excluded_field_names, __pyx_n_s_h, __pyx_n_s_sh, __pyx_n_s_item_type, __pyx_n_s_arg_type, __pyx_n_s_arg, __pyx_n_s_param, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);
  __pyx_codeobj__44 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 22, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__43, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_get_encoder, 598, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__44)) __PYX_ERR(0, 598, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__46 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__46)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":715
 *         self._enum_type = enum_type
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return value.value
 * 
 */
  __pyx_tuple__47 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_value); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);
  __pyx_codeobj__48 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 715, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__48)) __PYX_ERR(0, 715, __pyx_L1_error)

  /* "serpyco/serializer.pyx":718
 *         return value.value
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return self._enum_type(value)
 * 
 */
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 718, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 718, __pyx_L1_error)

  /* "serpyco/serializer.pyx":721
 *         return self._enum_type(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_codeobj__50 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 721, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__50)) __PYX_ERR(0, 721, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__52 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__52)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":732
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._load(value)
 * 
 */
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 732, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(0, 732, __pyx_L1_error)

  /* "serpyco/serializer.pyx":735
 *         return self._serializer._load(value)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._dump(value)
 * 
 */
  __pyx_codeobj__54 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 735, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__54)) __PYX_ERR(0, 735, __pyx_L1_error)

  /* "serpyco/serializer.pyx":738
 *         return self._serializer._dump(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 738, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(0, 738, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__56 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__56)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":752
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef lst = [
 *             self._serializer._load(v)
 */
  __pyx_codeobj__58 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 752, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__58)) __PYX_ERR(0, 752, __pyx_L1_error)

  /* "serpyco/serializer.pyx":761
 *         return self._iterable_type(lst)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return [
 *             self._serializer._dump(v)
 */
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 761, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(0, 761, __pyx_L1_error)

  /* "serpyco/serializer.pyx":769
 *         ]
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_codeobj__60 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 769, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__60)) __PYX_ERR(0, 769, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__62 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__62)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":782
 *         self._item_encoders_count = len(self._item_encoders)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 782, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 782, __pyx_L1_error)

  /* "serpyco/serializer.pyx":796
 *         return tuple(decoded)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */
  __pyx_codeobj__64 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 796, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__64)) __PYX_ERR(0, 796, __pyx_L1_error)

  /* "serpyco/serializer.pyx":810
 *         return encoded
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 810, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(0, 810, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__67 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__67)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":824
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             value = [
 */
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 824, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(0, 824, __pyx_L1_error)

  /* "serpyco/serializer.pyx":833
 *         return self._iterable_type(value)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             return [
 */
  __pyx_codeobj__69 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 833, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__69)) __PYX_ERR(0, 833, __pyx_L1_error)

  /* "serpyco/serializer.pyx":842
 *         return list(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 842, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 842, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__71 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__71)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":855
 *         self._value_encoder = value_encoder
 * 
 *     cpdef inline load(self, value: JsonEncodable):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */
  __pyx_codeobj__73 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 855, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__73)) __PYX_ERR(0, 855, __pyx_L1_error)

  /* "serpyco/serializer.pyx":874
 *             return value
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 874, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) __PYX_ERR(0, 874, __pyx_L1_error)

  /* "serpyco/serializer.pyx":893
 *             return value
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_codeobj__75 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 893, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__75)) __PYX_ERR(0, 893, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__76 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__76)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__77 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__77)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "serpyco/serializer.pyx":907
 *     )
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return value.isoformat()
 */
  __pyx_codeobj__78 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 907, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__78)) __PYX_ERR(0, 907, __pyx_L1_error)

  /* "serpyco/serializer.pyx":913
 *             raise ValidationError(f"{value} is not a datetime.datetime instance")
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return dateutil.parser.parse(value)
 */
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 913, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(0, 913, __pyx_L1_error)

  /* "serpyco/serializer.pyx":919
 *             raise ValidationError(f"{value} is not a valid datetime")
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {
 *             "type": "string",
 */
  __pyx_codeobj__80 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 919, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__80)) __PYX_ERR(0, 919, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__11, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DateTimeFieldEncoder__set_state(self, __pyx_state)
 */
  __pyx_codeobj__82 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__82)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "serpyco/serializer.pyx":930
 * cdef class UuidFieldEncoder(FieldEncoder):
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return str(value)
 * 
 */
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 930, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 930, __pyx_L1_error)

  /* "serpyco/serializer.pyx":933
 *         return str(value)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return uuid.UUID(value)
 * 
 */
  __pyx_codeobj__84 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 933, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__84)) __PYX_ERR(0, 933, __pyx_L1_error)

  /* "serpyco/serializer.pyx":936
 *         return uuid.UUID(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {"type": "string", "format": "uuid"}
 * 
 */
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 936, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(0, 936, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_codeobj__86 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__11, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__86)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_UuidFieldEncoder__set_state(self, __pyx_state)
 */
  __pyx_codeobj__87 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__87)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "serpyco/serializer.pyx":951
 *         self._type_encoders = tuple(type_encoders)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */
  __pyx_codeobj__88 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_dump, 951, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__88)) __PYX_ERR(0, 951, __pyx_L1_error)

  /* "serpyco/serializer.pyx":963
 *         raise ValidationError(msg)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__47, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_load, 963, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(0, 963, __pyx_L1_error)

  /* "serpyco/serializer.pyx":975
 *         raise ValidationError(msg)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 */
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_serpyco_serializer_pyx, __pyx_n_s_json_schema, 975, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) __PYX_ERR(0, 975, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__91 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__91)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__92 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__92)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_SerializerField(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__93 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_SerializerField, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_codeobj__95 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_DateTimeFieldEnco, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__95)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_UuidFieldEncoder, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PyList_Type_remove.type = (PyObject*)&PyList_Type;
  __pyx_umethod_PyList_Type_remove.method_name = &__pyx_n_s_remove;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_79851409 = PyInt_FromLong(79851409L); if (unlikely(!__pyx_int_79851409)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_146220692 = PyInt_FromLong(146220692L); if (unlikely(!__pyx_int_146220692)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_222419149 = PyInt_FromLong(222419149L); if (unlikely(!__pyx_int_222419149)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_228825662 = PyInt_FromLong(228825662L); if (unlikely(!__pyx_int_228825662)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_238750788 = PyInt_FromLong(238750788L); if (unlikely(!__pyx_int_238750788)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_246984282 = PyInt_FromLong(246984282L); if (unlikely(!__pyx_int_246984282)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_7serpyco_10serializer_dataclasses_MISSING = Py_None; Py_INCREF(Py_None);
  __pyx_v_7serpyco_10serializer_new_object = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_7serpyco_10serializer_SerializerField = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_SerializerField_spec, NULL); if (unlikely(!__pyx_ptype_7serpyco_10serializer_SerializerField)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_SerializerField_spec, __pyx_ptype_7serpyco_10serializer_SerializerField) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_SerializerField = &__pyx_type_7serpyco_10serializer_SerializerField;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_SerializerField) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_SerializerField->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_SerializerField->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_SerializerField->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_SerializerField->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_SerializerField, (PyObject *) __pyx_ptype_7serpyco_10serializer_SerializerField) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_SerializerField) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_7serpyco_10serializer_Caster = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_Caster_spec, NULL); if (unlikely(!__pyx_ptype_7serpyco_10serializer_Caster)) __PYX_ERR(0, 78, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_Caster_spec, __pyx_ptype_7serpyco_10serializer_Caster) < 0) __PYX_ERR(0, 78, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_Caster = &__pyx_type_7serpyco_10serializer_Caster;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_Caster) < 0) __PYX_ERR(0, 78, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_Caster->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_Caster->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_Caster->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_Caster->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Caster, (PyObject *) __pyx_ptype_7serpyco_10serializer_Caster) < 0) __PYX_ERR(0, 78, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_Caster) < 0) __PYX_ERR(0, 78, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_Serializer = &__pyx_vtable_7serpyco_10serializer_Serializer;
  __pyx_vtable_7serpyco_10serializer_Serializer.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump *__pyx_optional_args))__pyx_f_7serpyco_10serializer_10Serializer_dump;
  __pyx_vtable_7serpyco_10serializer_Serializer.load = (PyObject *(*)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load *__pyx_optional_args))__pyx_f_7serpyco_10serializer_10Serializer_load;
  __pyx_vtable_7serpyco_10serializer_Serializer.dump_json = (PyObject *(*)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_dump_json *__pyx_optional_args))__pyx_f_7serpyco_10serializer_10Serializer_dump_json;
  __pyx_vtable_7serpyco_10serializer_Serializer.load_json = (PyObject *(*)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_7serpyco_10serializer_10Serializer_load_json *__pyx_optional_args))__pyx_f_7serpyco_10serializer_10Serializer_load_json;
  __pyx_vtable_7serpyco_10serializer_Serializer._dump = (PyObject *(*)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *))__pyx_f_7serpyco_10serializer_10Serializer__dump;
  __pyx_vtable_7serpyco_10serializer_Serializer._load = (PyObject *(*)(struct __pyx_obj_7serpyco_10serializer_Serializer *, PyObject *))__pyx_f_7serpyco_10serializer_10Serializer__load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_7serpyco_10serializer_Serializer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_Serializer_spec, NULL); if (unlikely(!__pyx_ptype_7serpyco_10serializer_Serializer)) __PYX_ERR(0, 112, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_Serializer_spec, __pyx_ptype_7serpyco_10serializer_Serializer) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_Serializer = &__pyx_type_7serpyco_10serializer_Serializer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_Serializer) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_Serializer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_Serializer->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_Serializer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_Serializer->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_vtabptr_7serpyco_10serializer_Serializer) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_Serializer) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Serializer, (PyObject *) __pyx_ptype_7serpyco_10serializer_Serializer) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_Serializer) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  #endif
  __pyx_t_1 = PyImport_ImportModule("serpyco.encoder"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7serpyco_7encoder_FieldEncoder = __Pyx_ImportType_3_0_2(__pyx_t_1, "serpyco.encoder", "FieldEncoder", sizeof(struct __pyx_obj_7serpyco_7encoder_FieldEncoder), __PYX_GET_STRUCT_ALIGNMENT_3_0_2(struct __pyx_obj_7serpyco_7encoder_FieldEncoder),__Pyx_ImportType_CheckSize_Warn_3_0_2); if (!__pyx_ptype_7serpyco_7encoder_FieldEncoder) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_7serpyco_7encoder_FieldEncoder = (struct __pyx_vtabstruct_7serpyco_7encoder_FieldEncoder*)__Pyx_GetVtable(__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_vtabptr_7serpyco_7encoder_FieldEncoder)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_7serpyco_10serializer_EnumFieldEncoder = &__pyx_vtable_7serpyco_10serializer_EnumFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_EnumFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_EnumFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_16EnumFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_EnumFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_16EnumFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_EnumFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder)) __PYX_ERR(0, 709, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_EnumFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder) < 0) __PYX_ERR(0, 709, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder = &__pyx_type_7serpyco_10serializer_EnumFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder) < 0) __PYX_ERR(0, 709, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_EnumFieldEncoder) < 0) __PYX_ERR(0, 709, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder) < 0) __PYX_ERR(0, 709, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_EnumFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder) < 0) __PYX_ERR(0, 709, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_EnumFieldEncoder) < 0) __PYX_ERR(0, 709, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_DataClassFieldEncoder = &__pyx_vtable_7serpyco_10serializer_DataClassFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DataClassFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DataClassFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_DataClassFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_21DataClassFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_DataClassFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder)) __PYX_ERR(0, 726, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_DataClassFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder) < 0) __PYX_ERR(0, 726, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder = &__pyx_type_7serpyco_10serializer_DataClassFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder) < 0) __PYX_ERR(0, 726, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_DataClassFieldEncoder) < 0) __PYX_ERR(0, 726, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder) < 0) __PYX_ERR(0, 726, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DataClassFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder) < 0) __PYX_ERR(0, 726, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder) < 0) __PYX_ERR(0, 726, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_DataClassIterableFieldEncoder = &__pyx_vtable_7serpyco_10serializer_DataClassIterableFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DataClassIterableFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DataClassIterableFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_DataClassIterableFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_29DataClassIterableFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder)) __PYX_ERR(0, 743, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder) < 0) __PYX_ERR(0, 743, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder = &__pyx_type_7serpyco_10serializer_DataClassIterableFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder) < 0) __PYX_ERR(0, 743, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_DataClassIterableFieldEncoder) < 0) __PYX_ERR(0, 743, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder) < 0) __PYX_ERR(0, 743, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DataClassIterableFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder) < 0) __PYX_ERR(0, 743, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder) < 0) __PYX_ERR(0, 743, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_FixedTupleFieldEncoder = &__pyx_vtable_7serpyco_10serializer_FixedTupleFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_FixedTupleFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_FixedTupleFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_FixedTupleFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_22FixedTupleFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder)) __PYX_ERR(0, 774, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder) < 0) __PYX_ERR(0, 774, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder = &__pyx_type_7serpyco_10serializer_FixedTupleFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder) < 0) __PYX_ERR(0, 774, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_FixedTupleFieldEncoder) < 0) __PYX_ERR(0, 774, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder) < 0) __PYX_ERR(0, 774, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_FixedTupleFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder) < 0) __PYX_ERR(0, 774, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder) < 0) __PYX_ERR(0, 774, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_IterableFieldEncoder = &__pyx_vtable_7serpyco_10serializer_IterableFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_IterableFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_IterableFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_20IterableFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_IterableFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_20IterableFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_IterableFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder)) __PYX_ERR(0, 815, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_IterableFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder) < 0) __PYX_ERR(0, 815, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder = &__pyx_type_7serpyco_10serializer_IterableFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder) < 0) __PYX_ERR(0, 815, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_IterableFieldEncoder) < 0) __PYX_ERR(0, 815, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder) < 0) __PYX_ERR(0, 815, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_IterableFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder) < 0) __PYX_ERR(0, 815, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_IterableFieldEncoder) < 0) __PYX_ERR(0, 815, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_DictFieldEncoder = &__pyx_vtable_7serpyco_10serializer_DictFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DictFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DictFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_16DictFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_DictFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_16DictFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_DictFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_DictFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_DictFieldEncoder)) __PYX_ERR(0, 847, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_DictFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_DictFieldEncoder) < 0) __PYX_ERR(0, 847, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_DictFieldEncoder = &__pyx_type_7serpyco_10serializer_DictFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_DictFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_DictFieldEncoder) < 0) __PYX_ERR(0, 847, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_DictFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_DictFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_DictFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_DictFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_DictFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_DictFieldEncoder) < 0) __PYX_ERR(0, 847, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_DictFieldEncoder) < 0) __PYX_ERR(0, 847, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DictFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_DictFieldEncoder) < 0) __PYX_ERR(0, 847, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_DictFieldEncoder) < 0) __PYX_ERR(0, 847, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_DateTimeFieldEncoder = &__pyx_vtable_7serpyco_10serializer_DateTimeFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DateTimeFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_DateTimeFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_DateTimeFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_20DateTimeFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_DateTimeFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder)) __PYX_ERR(0, 898, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_DateTimeFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder) < 0) __PYX_ERR(0, 898, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder = &__pyx_type_7serpyco_10serializer_DateTimeFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder->tp_dealloc = __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_dealloc;
  __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder) < 0) __PYX_ERR(0, 898, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_DateTimeFieldEncoder) < 0) __PYX_ERR(0, 898, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder) < 0) __PYX_ERR(0, 898, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DateTimeFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder) < 0) __PYX_ERR(0, 898, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder) < 0) __PYX_ERR(0, 898, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_UuidFieldEncoder = &__pyx_vtable_7serpyco_10serializer_UuidFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_UuidFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_UuidFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_16UuidFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_UuidFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_16UuidFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_UuidFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder)) __PYX_ERR(0, 928, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_UuidFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder = &__pyx_type_7serpyco_10serializer_UuidFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder->tp_dealloc = __pyx_ptype_7serpyco_7encoder_FieldEncoder->tp_dealloc;
  __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_UuidFieldEncoder) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UuidFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_UuidFieldEncoder) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
  #endif
  __pyx_vtabptr_7serpyco_10serializer_UnionFieldEncoder = &__pyx_vtable_7serpyco_10serializer_UnionFieldEncoder;
  __pyx_vtable_7serpyco_10serializer_UnionFieldEncoder.__pyx_base = *__pyx_vtabptr_7serpyco_7encoder_FieldEncoder;
  __pyx_vtable_7serpyco_10serializer_UnionFieldEncoder.__pyx_base.dump = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_17UnionFieldEncoder_dump;
  __pyx_vtable_7serpyco_10serializer_UnionFieldEncoder.__pyx_base.load = (PyObject *(*)(struct __pyx_obj_7serpyco_7encoder_FieldEncoder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7serpyco_10serializer_17UnionFieldEncoder_load;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_2 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_7serpyco_7encoder_FieldEncoder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer_UnionFieldEncoder_spec, __pyx_t_2);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder)) __PYX_ERR(0, 941, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer_UnionFieldEncoder_spec, __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder) < 0) __PYX_ERR(0, 941, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder = &__pyx_type_7serpyco_10serializer_UnionFieldEncoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder->tp_base = __pyx_ptype_7serpyco_7encoder_FieldEncoder;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder) < 0) __PYX_ERR(0, 941, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder, __pyx_vtabptr_7serpyco_10serializer_UnionFieldEncoder) < 0) __PYX_ERR(0, 941, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder) < 0) __PYX_ERR(0, 941, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UnionFieldEncoder, (PyObject *) __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder) < 0) __PYX_ERR(0, 941, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_7serpyco_10serializer_UnionFieldEncoder) < 0) __PYX_ERR(0, 941, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr_spec, NULL); if (unlikely(!__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr)) __PYX_ERR(0, 219, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr_spec, __pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr) < 0) __PYX_ERR(0, 219, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr = &__pyx_type_7serpyco_10serializer___pyx_scope_struct__genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr) < 0) __PYX_ERR(0, 219, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr->tp_dictoffset && __pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer___pyx_scope_struct__genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder_spec, NULL); if (unlikely(!__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder)) __PYX_ERR(0, 598, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder_spec, __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder) < 0) __PYX_ERR(0, 598, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder = &__pyx_type_7serpyco_10serializer___pyx_scope_struct_1__get_encoder;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder) < 0) __PYX_ERR(0, 598, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder->tp_dictoffset && __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_1__get_encoder->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr)) __PYX_ERR(0, 681, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr_spec, __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 681, __pyx_L1_error)
  #else
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr = &__pyx_type_7serpyco_10serializer___pyx_scope_struct_2_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 681, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr->tp_dictoffset && __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_7serpyco_10serializer___pyx_scope_struct_2_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_serializer(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_serializer},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "serializer",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initserializer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initserializer(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_serializer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_serializer(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_serializer(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'serializer' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("serializer", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to serializer pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_serializer(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_serpyco__serializer) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "serpyco.serializer")) {
      if (unlikely((PyDict_SetItemString(modules, "serpyco.serializer", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "serpyco/serializer.pyx":9
 * 
 * 
 * import dataclasses             # <<<<<<<<<<<<<<
 * import datetime
 * import enum
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_dataclasses, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dataclasses, __pyx_t_2) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":10
 * 
 * import dataclasses
 * import datetime             # <<<<<<<<<<<<<<
 * import enum
 * import re
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_datetime, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_2) < 0) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":11
 * import dataclasses
 * import datetime
 * import enum             # <<<<<<<<<<<<<<
 * import re
 * import typing
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_enum, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_enum, __pyx_t_2) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":12
 * import datetime
 * import enum
 * import re             # <<<<<<<<<<<<<<
 * import typing
 * import uuid
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_re, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_2) < 0) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":13
 * import enum
 * import re
 * import typing             # <<<<<<<<<<<<<<
 * import uuid
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_typing, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_typing, __pyx_t_2) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":14
 * import re
 * import typing
 * import uuid             # <<<<<<<<<<<<<<
 * 
 * import cython
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_uuid, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_uuid, __pyx_t_2) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":17
 * 
 * import cython
 * import dateutil.parser             # <<<<<<<<<<<<<<
 * import rapidjson
 * import typing_inspect
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_dateutil_parser, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dateutil, __pyx_t_2) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":18
 * import cython
 * import dateutil.parser
 * import rapidjson             # <<<<<<<<<<<<<<
 * import typing_inspect
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_rapidjson, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_rapidjson, __pyx_t_2) < 0) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":19
 * import dateutil.parser
 * import rapidjson
 * import typing_inspect             # <<<<<<<<<<<<<<
 * 
 * from serpyco.decorator import DecoratorType, _serpyco_tags
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_typing_inspect, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_typing_inspect, __pyx_t_2) < 0) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":21
 * import typing_inspect
 * 
 * from serpyco.decorator import DecoratorType, _serpyco_tags             # <<<<<<<<<<<<<<
 * 
 * from serpyco.encoder cimport FieldEncoder
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_DecoratorType);
  __Pyx_GIVEREF(__pyx_n_s_DecoratorType);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_DecoratorType)) __PYX_ERR(0, 21, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_serpyco_tags);
  __Pyx_GIVEREF(__pyx_n_s_serpyco_tags);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_serpyco_tags)) __PYX_ERR(0, 21, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_serpyco_decorator, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_DecoratorType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DecoratorType, __pyx_t_2) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_serpyco_tags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_serpyco_tags, __pyx_t_2) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":25
 * from serpyco.encoder cimport FieldEncoder
 * 
 * from serpyco.exception import NoEncoderError, NotADataClassError, ValidationError             # <<<<<<<<<<<<<<
 * from serpyco.field import FieldHints, _metadata_name
 * from serpyco.schema import SchemaBuilder
 */
  __pyx_t_3 = PyList_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_NoEncoderError);
  __Pyx_GIVEREF(__pyx_n_s_NoEncoderError);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_NoEncoderError)) __PYX_ERR(0, 25, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_NotADataClassError);
  __Pyx_GIVEREF(__pyx_n_s_NotADataClassError);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_NotADataClassError)) __PYX_ERR(0, 25, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ValidationError);
  __Pyx_GIVEREF(__pyx_n_s_ValidationError);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_ValidationError)) __PYX_ERR(0, 25, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_serpyco_exception, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_NoEncoderError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NoEncoderError, __pyx_t_3) < 0) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_NotADataClassError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NotADataClassError, __pyx_t_3) < 0) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_ValidationError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ValidationError, __pyx_t_3) < 0) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":26
 * 
 * from serpyco.exception import NoEncoderError, NotADataClassError, ValidationError
 * from serpyco.field import FieldHints, _metadata_name             # <<<<<<<<<<<<<<
 * from serpyco.schema import SchemaBuilder
 * from serpyco.util import (
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_FieldHints);
  __Pyx_GIVEREF(__pyx_n_s_FieldHints);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_FieldHints)) __PYX_ERR(0, 26, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_metadata_name);
  __Pyx_GIVEREF(__pyx_n_s_metadata_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_metadata_name)) __PYX_ERR(0, 26, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_serpyco_field, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_FieldHints); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FieldHints, __pyx_t_2) < 0) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_metadata_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_metadata_name, __pyx_t_2) < 0) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":27
 * from serpyco.exception import NoEncoderError, NotADataClassError, ValidationError
 * from serpyco.field import FieldHints, _metadata_name
 * from serpyco.schema import SchemaBuilder             # <<<<<<<<<<<<<<
 * from serpyco.util import (
 *     JSON_ENCODABLE_TYPES,
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_SchemaBuilder);
  __Pyx_GIVEREF(__pyx_n_s_SchemaBuilder);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_SchemaBuilder)) __PYX_ERR(0, 27, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_serpyco_schema, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_SchemaBuilder); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SchemaBuilder, __pyx_t_3) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":29
 * from serpyco.schema import SchemaBuilder
 * from serpyco.util import (
 *     JSON_ENCODABLE_TYPES,             # <<<<<<<<<<<<<<
 *     UNTYPED_DICT_TYPES,
 *     UNTYPED_ITERABLE_TYPES,
 */
  __pyx_t_2 = PyList_New(9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_JSON_ENCODABLE_TYPES);
  __Pyx_GIVEREF(__pyx_n_s_JSON_ENCODABLE_TYPES);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_JSON_ENCODABLE_TYPES)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_UNTYPED_DICT_TYPES);
  __Pyx_GIVEREF(__pyx_n_s_UNTYPED_DICT_TYPES);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_UNTYPED_DICT_TYPES)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_UNTYPED_ITERABLE_TYPES);
  __Pyx_GIVEREF(__pyx_n_s_UNTYPED_ITERABLE_TYPES);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_UNTYPED_ITERABLE_TYPES)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_JsonDict);
  __Pyx_GIVEREF(__pyx_n_s_JsonDict);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_JsonDict)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_JsonEncodable);
  __Pyx_GIVEREF(__pyx_n_s_JsonEncodable);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_JsonEncodable)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DataClassParams);
  __Pyx_GIVEREF(__pyx_n_s_DataClassParams);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_s_DataClassParams)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_generic);
  __Pyx_GIVEREF(__pyx_n_s_is_generic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_s_is_generic)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_union);
  __Pyx_GIVEREF(__pyx_n_s_is_union);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 7, __pyx_n_s_is_union)) __PYX_ERR(0, 29, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_issubclass_safe);
  __Pyx_GIVEREF(__pyx_n_s_issubclass_safe);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 8, __pyx_n_s_issubclass_safe)) __PYX_ERR(0, 29, __pyx_L1_error);

  /* "serpyco/serializer.pyx":28
 * from serpyco.field import FieldHints, _metadata_name
 * from serpyco.schema import SchemaBuilder
 * from serpyco.util import (             # <<<<<<<<<<<<<<
 *     JSON_ENCODABLE_TYPES,
 *     UNTYPED_DICT_TYPES,
 */
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_serpyco_util, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_JSON_ENCODABLE_TYPES); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_JSON_ENCODABLE_TYPES, __pyx_t_2) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_UNTYPED_DICT_TYPES); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UNTYPED_DICT_TYPES, __pyx_t_2) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_UNTYPED_ITERABLE_TYPES); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UNTYPED_ITERABLE_TYPES, __pyx_t_2) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_JsonDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_JsonDict, __pyx_t_2) < 0) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_JsonEncodable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_JsonEncodable, __pyx_t_2) < 0) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_DataClassParams); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DataClassParams, __pyx_t_2) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_is_generic); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_is_generic, __pyx_t_2) < 0) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_is_union); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_is_union, __pyx_t_2) < 0) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_issubclass_safe); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_issubclass_safe, __pyx_t_2) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":39
 *     _issubclass_safe,
 * )
 * from serpyco.validator import RapidJsonValidator             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_RapidJsonValidator);
  __Pyx_GIVEREF(__pyx_n_s_RapidJsonValidator);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_RapidJsonValidator)) __PYX_ERR(0, 39, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_serpyco_validator, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_RapidJsonValidator); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_RapidJsonValidator, __pyx_t_3) < 0) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":42
 * 
 * 
 * cdef object dataclasses_MISSING = dataclasses.MISSING             # <<<<<<<<<<<<<<
 * cdef object new_object = object.__new__
 * _ITERABLE_TYPES_MAPPING = {
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_dataclasses); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_MISSING); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_7serpyco_10serializer_dataclasses_MISSING);
  __Pyx_DECREF_SET(__pyx_v_7serpyco_10serializer_dataclasses_MISSING, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":43
 * 
 * cdef object dataclasses_MISSING = dataclasses.MISSING
 * cdef object new_object = object.__new__             # <<<<<<<<<<<<<<
 * _ITERABLE_TYPES_MAPPING = {
 *     typing.Tuple: tuple,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XGOTREF(__pyx_v_7serpyco_10serializer_new_object);
  __Pyx_DECREF_SET(__pyx_v_7serpyco_10serializer_new_object, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":45
 * cdef object new_object = object.__new__
 * _ITERABLE_TYPES_MAPPING = {
 *     typing.Tuple: tuple,             # <<<<<<<<<<<<<<
 *     typing.List: list,
 *     typing.Set: set,
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_typing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Tuple); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_4, ((PyObject *)(&PyTuple_Type))) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":46
 * _ITERABLE_TYPES_MAPPING = {
 *     typing.Tuple: tuple,
 *     typing.List: list,             # <<<<<<<<<<<<<<
 *     typing.Set: set,
 * }
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_typing); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_List); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_2, ((PyObject *)(&PyList_Type))) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "serpyco/serializer.pyx":47
 *     typing.Tuple: tuple,
 *     typing.List: list,
 *     typing.Set: set,             # <<<<<<<<<<<<<<
 * }
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_typing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Set); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_4, ((PyObject *)(&PySet_Type))) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ITERABLE_TYPES_MAPPING, __pyx_t_3) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_15SerializerField_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SerializerField___reduce_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__12)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_SerializerField, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_SerializerField);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_SerializerField, (type(self), 0x4c26f91, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_SerializerField__set_state(self, __pyx_state)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_15SerializerField_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SerializerField___setstate_cytho, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__14)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_SerializerField, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_SerializerField);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_6Caster_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Caster___reduce_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__16)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_6Caster_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Caster___setstate_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__17)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":135
 *     cdef tuple _excluded_fields
 *     _global_types = {
 *         datetime.datetime: DateTimeFieldEncoder(),             # <<<<<<<<<<<<<<
 *         uuid.UUID: UuidFieldEncoder()
 *     }
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_datetime); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_2, __pyx_t_4) < 0) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":136
 *     _global_types = {
 *         datetime.datetime: DateTimeFieldEncoder(),
 *         uuid.UUID: UuidFieldEncoder()             # <<<<<<<<<<<<<<
 *     }
 *     for f, e in _global_types.items():
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_uuid); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_UUID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_t_2, __pyx_t_4) < 0) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_global_types, __pyx_t_3) < 0) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":138
 *         uuid.UUID: UuidFieldEncoder()
 *     }
 *     for f, e in _global_types.items():             # <<<<<<<<<<<<<<
 *         SchemaBuilder.register_global_type(f, e)
 * 
 */
  __pyx_t_5 = 0;
  __Pyx_GetNameInClass(__pyx_t_4, (PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_global_types); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (unlikely(__pyx_t_4 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 138, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_dict_iterator(__pyx_t_4, 0, __pyx_n_s_items, (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XDECREF(__pyx_t_3);
  __pyx_t_3 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_8 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_6, &__pyx_t_5, &__pyx_t_2, &__pyx_t_4, NULL, __pyx_t_7);
    if (unlikely(__pyx_t_8 == 0)) break;
    if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_f, __pyx_t_2) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);
    if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_e, __pyx_t_4) < 0) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

    /* "serpyco/serializer.pyx":139
 *     }
 *     for f, e in _global_types.items():
 *         SchemaBuilder.register_global_type(f, e)             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SchemaBuilder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_register_global_type); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_f); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetNameInClass(__pyx_t_10, (PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_e); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_2, __pyx_t_10};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":269
 *         ))
 * 
 *     def json_schema(self, many: bool = False) -> JsonDict:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the JSON schema of the underlying validator.
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_many, __pyx_n_s_bool) < 0) __PYX_ERR(0, 269, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 269, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_5json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_json_schema, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__19)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__20);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_json_schema, __pyx_t_4) < 0) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":275
 *         return self._validator.json_schema(many=many)
 * 
 *     def get_dict_path(self, obj_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in dumped dictionaries.
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_obj_path, __pyx_kp_s_typing_Sequence_str) < 0) __PYX_ERR(0, 275, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_typing_List_str) < 0) __PYX_ERR(0, 275, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_7get_dict_path, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_get_dict_path, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__22)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_get_dict_path, __pyx_t_3) < 0) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":296
 *         return [sfield.dict_key] + ser.get_dict_path(obj_path[1:])
 * 
 *     def get_object_path(self, dict_path: typing.Sequence[str]) -> typing.List[str]:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the path of a field in loaded objects.
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dict_path, __pyx_kp_s_typing_Sequence_str) < 0) __PYX_ERR(0, 296, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_typing_List_str) < 0) __PYX_ERR(0, 296, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_9get_object_path, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_get_object_path, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__24)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_get_object_path, __pyx_t_4) < 0) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":317
 *         return [sfield.field_name] + ser.get_object_path(dict_path[1:])
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def register_global_type(
 *         cls,
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_field_type, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_encoder, __pyx_n_s_FieldEncoder) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_11register_global_type, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_register_global_type, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__26)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_register_global_type, __pyx_t_3) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);
  __Pyx_GetNameInClass(__pyx_t_3, (PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_register_global_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_Method_ClassMethod(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_register_global_type, __pyx_t_4) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":329
 *         SchemaBuilder.register_global_type(field_type, encoder.json_schema())
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def unregister_global_type(cls, field_type: typing.Any) -> None:
 *         """
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_field_type, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 329, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(0, 329, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_13unregister_global_type, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_unregister_global_typ, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__28)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_unregister_global_type, __pyx_t_3) < 0) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);
  __Pyx_GetNameInClass(__pyx_t_3, (PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_unregister_global_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_Method_ClassMethod(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_unregister_global_type, __pyx_t_4) < 0) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":337
 *         SchemaBuilder.unregister_global_type(field_type)
 * 
 *     def dataclass(self) -> type:             # <<<<<<<<<<<<<<
 *         """
 *         Returns the dataclass used to construct this serializer.
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_type_2) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_15dataclass, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_dataclass, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__29)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_dataclass, __pyx_t_3) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":343
 *         return self._dataclass
 * 
 *     cpdef inline dump(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_obj, __pyx_kp_s_typing_Union_object_typing_Itera) < 0) __PYX_ERR(0, 343, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_validate, __pyx_n_s_bool) < 0) __PYX_ERR(0, 343, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_many, __pyx_n_s_bool) < 0) __PYX_ERR(0, 343, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_17dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__31)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__32);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_dump, __pyx_t_4) < 0) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":379
 *         return data
 * 
 *     cpdef inline load(             # <<<<<<<<<<<<<<
 *         self,
 *         data: typing.Union[dict, typing.Iterable[dict]],
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_data, __pyx_kp_s_typing_Union_dict_typing_Iterabl) < 0) __PYX_ERR(0, 379, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_validate, __pyx_n_s_bool) < 0) __PYX_ERR(0, 379, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_many, __pyx_n_s_bool) < 0) __PYX_ERR(0, 379, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_19load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__34)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__35);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_load, __pyx_t_3) < 0) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":425
 *         return obj
 * 
 *     cpdef inline str dump_json(             # <<<<<<<<<<<<<<
 *         self,
 *         obj: typing.Union[object, typing.Iterable[object]],
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_obj, __pyx_kp_s_typing_Union_object_typing_Itera) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_validate, __pyx_n_s_bool) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_many, __pyx_n_s_bool) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_21dump_json, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_dump_json, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__36)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__37);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_dump_json, __pyx_t_4) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":468
 *         return rapidjson.dumps(data)
 * 
 *     cpdef inline load_json(             # <<<<<<<<<<<<<<
 *         self,
 *         str js,
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_validate, __pyx_n_s_bool) < 0) __PYX_ERR(0, 468, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_many, __pyx_n_s_bool) < 0) __PYX_ERR(0, 468, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_23load_json, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer_load_json, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__39)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_3, __pyx_tuple__40);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_load_json, __pyx_t_3) < 0) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":575
 *         return obj
 * 
 *     def _get_field_serializer(self, sfield: SerializerField) -> "Serializer":             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder = sfield.encoder
 *         cdef DataClassFieldEncoder dencoder
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_sfield, __pyx_n_s_SerializerField) < 0) __PYX_ERR(0, 575, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_kp_s_Serializer_2) < 0) __PYX_ERR(0, 575, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_25_get_field_serializer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer__get_field_serializer, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__42)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_get_field_serializer, __pyx_t_4) < 0) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "serpyco/serializer.pyx":598
 *         raise ValueError(f"field {sfield.field_name} is not a dataclass")
 * 
 *     def _get_encoder(self, field_type, hints):             # <<<<<<<<<<<<<<
 *         cdef DataClassFieldEncoder dencoder
 *         cdef Serializer serializer
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_27_get_encoder, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer__get_encoder, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__44)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_Serializer, __pyx_n_s_get_encoder, __pyx_t_4) < 0) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_Serializer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_29__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer___reduce_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_10Serializer_31__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Serializer___setstate_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__46)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":715
 *         self._enum_type = enum_type
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return value.value
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 715, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_3dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_EnumFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__48)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder, __pyx_n_s_dump, __pyx_t_3) < 0) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder);

  /* "serpyco/serializer.pyx":718
 *         return value.value
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         return self._enum_type(value)
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_value, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 718, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_5load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_EnumFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder, __pyx_n_s_load, __pyx_t_4) < 0) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder);

  /* "serpyco/serializer.pyx":721
 *         return self._enum_type(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 721, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_7json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_EnumFieldEncoder_json_schema, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__50)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder, __pyx_n_s_json_schema, __pyx_t_3) < 0) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_EnumFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_EnumFieldEncoder___reduce_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16EnumFieldEncoder_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_EnumFieldEncoder___setstate_cyth, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__52)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":732
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._load(value)
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__53)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder, __pyx_n_s_load, __pyx_t_3) < 0) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder);

  /* "serpyco/serializer.pyx":735
 *         return self._serializer._load(value)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return self._serializer._dump(value)
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_5dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__54)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder, __pyx_n_s_dump, __pyx_t_3) < 0) __PYX_ERR(0, 735, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder);

  /* "serpyco/serializer.pyx":738
 *         return self._serializer._dump(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 738, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_7json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassFieldEncoder_json_schem, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__55)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder, __pyx_n_s_json_schema, __pyx_t_4) < 0) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DataClassFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassFieldEncoder___reduce_c, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__56)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_21DataClassFieldEncoder_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassFieldEncoder___setstate, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__57)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":752
 *         self._serializer = serializer
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef lst = [
 *             self._serializer._load(v)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassIterableFieldEncoder_lo, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__58)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder, __pyx_n_s_load, __pyx_t_4) < 0) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder);

  /* "serpyco/serializer.pyx":761
 *         return self._iterable_type(lst)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return [
 *             self._serializer._dump(v)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_5dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassIterableFieldEncoder_du, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__59)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder, __pyx_n_s_dump, __pyx_t_4) < 0) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder);

  /* "serpyco/serializer.pyx":769
 *         ]
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 769, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_7json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassIterableFieldEncoder_js, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__60)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder, __pyx_n_s_json_schema, __pyx_t_3) < 0) __PYX_ERR(0, 769, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DataClassIterableFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassIterableFieldEncoder_2, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__61)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_29DataClassIterableFieldEncoder_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DataClassIterableFieldEncoder_3, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__62)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":782
 *         self._item_encoders_count = len(self._item_encoders)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_value, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 782, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FixedTupleFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder, __pyx_n_s_load, __pyx_t_4) < 0) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder);

  /* "serpyco/serializer.pyx":796
 *         return tuple(decoded)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         cdef FieldEncoder encoder
 *         cdef int i
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 796, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_5dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FixedTupleFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__64)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder, __pyx_n_s_dump, __pyx_t_3) < 0) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder);

  /* "serpyco/serializer.pyx":810
 *         return encoded
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 810, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_7json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FixedTupleFieldEncoder_json_sche, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__65)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder, __pyx_n_s_json_schema, __pyx_t_4) < 0) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_FixedTupleFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FixedTupleFieldEncoder___reduce, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__66)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_22FixedTupleFieldEncoder_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FixedTupleFieldEncoder___setstat, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__67)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":824
 *         self._iterable_type = _ITERABLE_TYPES_MAPPING.get(origin, origin)
 * 
 *     cpdef inline load(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             value = [
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 824, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_IterableFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__68)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder, __pyx_n_s_load, __pyx_t_3) < 0) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder);

  /* "serpyco/serializer.pyx":833
 *         return self._iterable_type(value)
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._item_encoder:
 *             return [
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_value, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 833, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_5dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_IterableFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__69)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder, __pyx_n_s_dump, __pyx_t_4) < 0) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder);

  /* "serpyco/serializer.pyx":842
 *         return list(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 842, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_7json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_IterableFieldEncoder_json_schema, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder, __pyx_n_s_json_schema, __pyx_t_3) < 0) __PYX_ERR(0, 842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_IterableFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_IterableFieldEncoder___reduce_cy, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__71)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20IterableFieldEncoder_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_IterableFieldEncoder___setstate, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__72)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":855
 *         self._value_encoder = value_encoder
 * 
 *     cpdef inline load(self, value: JsonEncodable):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_value, __pyx_n_s_JsonEncodable) < 0) __PYX_ERR(0, 855, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DictFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__73)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DictFieldEncoder, __pyx_n_s_load, __pyx_t_4) < 0) __PYX_ERR(0, 855, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DictFieldEncoder);

  /* "serpyco/serializer.pyx":874
 *             return value
 * 
 *     cpdef inline dump(self, value: typing.Any):             # <<<<<<<<<<<<<<
 *         if self._key_encoder and self._value_encoder:
 *             return {
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_s_typing_Any) < 0) __PYX_ERR(0, 874, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_5dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DictFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__74)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DictFieldEncoder, __pyx_n_s_dump, __pyx_t_3) < 0) __PYX_ERR(0, 874, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DictFieldEncoder);

  /* "serpyco/serializer.pyx":893
 *             return value
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 893, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_7json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DictFieldEncoder_json_schema, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__75)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DictFieldEncoder, __pyx_n_s_json_schema, __pyx_t_4) < 0) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DictFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DictFieldEncoder___reduce_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__76)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16DictFieldEncoder_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DictFieldEncoder___setstate_cyth, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__77)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "serpyco/serializer.pyx":902
 * 
 *     iso8601_pattern = (
 *         r"^[0-9]{4}-[0-9][0-9]-[0-9][0-9]T"  # YYYY-MM-DD             # <<<<<<<<<<<<<<
 *         r"[0-9][0-9]:[0-9][0-9]:[0-9][0-9](\.[0-9]+)"  # HH:mm:ss.ssss
 *         r"?(([+-][0-9][0-9]:[0-9][0-9])|Z)?$"  # timezone
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder, __pyx_n_s_iso8601_pattern, __pyx_kp_u_0_9_4_0_9_0_9_0_9_0_9_T_0_9_0_9) < 0) __PYX_ERR(0, 901, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);

  /* "serpyco/serializer.pyx":907
 *     )
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return value.isoformat()
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_1dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DateTimeFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__78)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder, __pyx_n_s_dump, __pyx_t_4) < 0) __PYX_ERR(0, 907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);

  /* "serpyco/serializer.pyx":913
 *             raise ValidationError(f"{value} is not a datetime.datetime instance")
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         try:
 *             return dateutil.parser.parse(value)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DateTimeFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__79)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder, __pyx_n_s_load, __pyx_t_4) < 0) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);

  /* "serpyco/serializer.pyx":919
 *             raise ValidationError(f"{value} is not a valid datetime")
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {
 *             "type": "string",
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 919, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_5json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DateTimeFieldEncoder_json_schema, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__80)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder, __pyx_n_s_json_schema, __pyx_t_3) < 0) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DateTimeFieldEncoder___reduce_cy, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__81)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DateTimeFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DateTimeFieldEncoder__set_state(self, __pyx_state)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_20DateTimeFieldEncoder_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DateTimeFieldEncoder___setstate, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__82)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_DateTimeFieldEncoder);

  /* "serpyco/serializer.pyx":930
 * cdef class UuidFieldEncoder(FieldEncoder):
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         return str(value)
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_1dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UuidFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder, __pyx_n_s_dump, __pyx_t_3) < 0) __PYX_ERR(0, 930, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder);

  /* "serpyco/serializer.pyx":933
 *         return str(value)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         return uuid.UUID(value)
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UuidFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__84)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder, __pyx_n_s_load, __pyx_t_3) < 0) __PYX_ERR(0, 933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder);

  /* "serpyco/serializer.pyx":936
 *         return uuid.UUID(value)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return {"type": "string", "format": "uuid"}
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 936, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_5json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UuidFieldEncoder_json_schema, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__85)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder, __pyx_n_s_json_schema, __pyx_t_4) < 0) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UuidFieldEncoder___reduce_cython, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__86)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_UuidFieldEncoder, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_UuidFieldEncoder__set_state(self, __pyx_state)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_16UuidFieldEncoder_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UuidFieldEncoder___setstate_cyth, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__87)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UuidFieldEncoder);

  /* "serpyco/serializer.pyx":951
 *         self._type_encoders = tuple(type_encoders)
 * 
 *     cpdef inline dump(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_3dump, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UnionFieldEncoder_dump, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__88)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder, __pyx_n_s_dump, __pyx_t_4) < 0) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder);

  /* "serpyco/serializer.pyx":963
 *         raise ValidationError(msg)
 * 
 *     cpdef inline load(self, value):             # <<<<<<<<<<<<<<
 *         cdef list value_types = []
 *         for value_type, encoder in self._type_encoders:
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_5load, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UnionFieldEncoder_load, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__89)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder, __pyx_n_s_load, __pyx_t_4) < 0) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder);

  /* "serpyco/serializer.pyx":975
 *         raise ValidationError(msg)
 * 
 *     def json_schema(self) -> JsonDict:             # <<<<<<<<<<<<<<
 *         return None
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_JsonDict) < 0) __PYX_ERR(0, 975, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_7json_schema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UnionFieldEncoder_json_schema, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder, __pyx_n_s_json_schema, __pyx_t_3) < 0) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_7serpyco_10serializer_UnionFieldEncoder);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UnionFieldEncoder___reduce_cytho, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__91)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_17UnionFieldEncoder_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UnionFieldEncoder___setstate_cyt, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__92)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_3) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_SerializerField(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_1__pyx_unpickle_SerializerField, 0, __pyx_n_s_pyx_unpickle_SerializerField, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__94)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_SerializerField, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_SerializerField__set_state(<SerializerField> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_SerializerField__set_state(SerializerField __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.default = __pyx_state[0]; __pyx_result.default_factory = __pyx_state[1]; __pyx_result.dict_key = __pyx_state[2]; __pyx_result.encoder = __pyx_state[3]; __pyx_result.field_name = __pyx_state[4]; __pyx_result.getter = __pyx_state[5]; __pyx_result.init = __pyx_state[6]
 *     if len(__pyx_state) > 7 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_3__pyx_unpickle_DateTimeFieldEncoder, 0, __pyx_n_s_pyx_unpickle_DateTimeFieldEnco, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__95)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_DateTimeFieldEnco, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_UuidFieldEncoder(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_7serpyco_10serializer_5__pyx_unpickle_UuidFieldEncoder, 0, __pyx_n_s_pyx_unpickle_UuidFieldEncoder, NULL, __pyx_n_s_serpyco_serializer, __pyx_d, ((PyObject *)__pyx_codeobj__96)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_UuidFieldEncoder, __pyx_t_3) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "serpyco/serializer.pyx":1
 * # -*- coding: utf-8 -*-             # <<<<<<<<<<<<<<
 * # cython: language_level=3
 * # cython: embedsignature=True
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init serpyco.serializer", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init serpyco.serializer");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;  // error
            return kwvalues[i];
        }
    }
    return NULL;  // not found (no exception set)
}
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value); // transfer ownership of value to values
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;  // ownership transferred to values
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL; // ownership transferred to values
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        Py_ssize_t kwsize;
#if CYTHON_ASSUME_SAFE_MACROS
        kwsize = PyTuple_GET_SIZE(kw);
#else
        kwsize = PyTuple_Size(kw);
        if (kwsize < 0) return 0;
#endif
        if (unlikely(kwsize == 0))
            return 1;
        if (!kw_allowed) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, 0);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < kwsize; pos++) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, pos);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
#endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
#if defined(__Pyx_CyFunction_USED) && defined(NDEBUG)
        if (__Pyx_IsCyOrPyCFunction(func))
#else
        if (PyCFunction_Check(func))
#endif
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
                return __Pyx_PyObject_CallMethO(func, NULL);
            }
        }
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (PyCFunction_Check(func))
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
                return __Pyx_PyObject_CallMethO(func, args[0]);
            }
        }
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    #if CYTHON_VECTORCALL
    #if Py_VERSION_HEX < 0x03090000
    vectorcallfunc f = _PyVectorcall_Function(func);
    #else
    vectorcallfunc f = PyVectorcall_Function(func);
    #endif
    if (f) {
        return f(func, args, (size_t)nargs, kwargs);
    }
    #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
    if (__Pyx_CyFunction_CheckExact(func)) {
        __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
        if (f) return f(func, args, (size_t)nargs, kwargs);
    }
    #endif
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
}

/* UnpackUnboundCMethod */
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    PyObject *result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!PyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if defined(CYTHON_COMPILING_IN_PYPY)
#elif PY_VERSION_HEX >= 0x03090000
    if (PyCFunction_CheckExact(method))
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030D0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    PyObject* exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc;
    __Pyx_PyThreadState_declare
    #ifdef __Pyx_StopAsyncIteration_USED
    int is_async_stopiteration = 0;
    #endif
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    cur_exc = PyErr_Occurred();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        #ifdef __Pyx_StopAsyncIteration_USED
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, __Pyx_PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else
        #endif
            return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(val);
    Py_XDECREF(tb);
    PyErr_SetString(PyExc_RuntimeError,
        #ifdef __Pyx_StopAsyncIteration_USED
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        #endif
        "generator raised StopIteration");
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg = NULL;
    return __Pyx_PyObject_FastCall(func, (&arg)+1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* RaiseMappingExpected */
static void __Pyx_RaiseMappingExpectedError(PyObject* arg) {
    __Pyx_TypeName arg_type_name = __Pyx_PyType_GetName(Py_TYPE(arg));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not a mapping", arg_type_name);
    __Pyx_DECREF_TypeName(arg_type_name);
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* RaiseClosureNameError */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (meth) {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
static int
__Pyx_unicode_modifiable(PyObject *unicode)
{
    if (Py_REFCNT(unicode) != 1)
        return 0;
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        __Pyx_GIVEREF(*p_left);
        if (unlikely(PyUnicode_Resize(p_left, new_len) != 0)) {
            __Pyx_GOTREF(*p_left);
            return NULL;
        }
        __Pyx_INCREF(*p_left);
        #if PY_VERSION_HEX >= 0x030D0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__7);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    destructor tp_dealloc = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_dealloc, destructor) != current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_dealloc = __Pyx_PyType_GetSlot(type, tp_dealloc, destructor)) == current_tp_dealloc)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type)
        tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#if !CYTHON_USE_TYPE_SLOTS
        if (dictoffset == 0) {
            PyErr_Format(PyExc_TypeError,
                "extension type '%s.200s': "
                "unable to validate whether bases have a __dict__ "
                "when CYTHON_USE_TYPE_SLOTS is off "
                "(likely because you are building in the limited API). "
                "Therefore, all extension types with multiple bases "
                "must add 'cdef dict __dict__' in this compilation mode",
                type_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#else
        if (dictoffset == 0 && b->tp_dictoffset)
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "extension type '%.200s' has no __dict__ slot, "
                "but base type '" __Pyx_FMT_TYPENAME "' has: "
                "either add 'cdef dict __dict__' to the extension type "
                "or add '__slots__ = [...]' to the base type",
                type_name, b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetupReduce */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_n_s_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_n_s_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_n_s_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_n_s_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i;
    void** base_vtables;
    __Pyx_TypeName tp_base_name;
    __Pyx_TypeName base_name;
    void* unknown = (void*)-1;
    PyObject* bases = type->tp_bases;
    int base_depth = 0;
    {
        PyTypeObject* base = type->tp_base;
        while (base) {
            base_depth += 1;
            base = base->tp_base;
        }
    }
    base_vtables = (void**) malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
    for (i = 1; i < PyTuple_GET_SIZE(bases); i++) {
        void* base_vtable = __Pyx_GetVtable(((PyTypeObject*)PyTuple_GET_ITEM(bases, i)));
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = type->tp_base;
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = base->tp_base;
            }
        }
    }
    PyErr_Clear();
    free(base_vtables);
    return 0;
bad:
    tp_base_name = __Pyx_PyType_GetName(type->tp_base);
    base_name = __Pyx_PyType_GetName((PyTypeObject*)PyTuple_GET_ITEM(bases, i));
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
    free(base_vtables);
    return -1;
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_0_2
#define __PYX_HAVE_RT_ImportType_3_0_2
static PyTypeObject *__Pyx_ImportType_3_0_2(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_2 check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_0_2 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_0_2 && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__9;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    PyObject *abi_module = PyImport_AddModule((char*) __PYX_ABI_MODULE_NAME);
    if (unlikely(!abi_module)) return NULL;
    Py_INCREF(abi_module);
    return abi_module;
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_n_s_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    #if PY_MAJOR_VERSION == 2
    static PyTypeObject *methoddescr_type = NULL;
    if (unlikely(methoddescr_type == NULL)) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (unlikely(!meth)) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    #else
    PyTypeObject *methoddescr_type = &PyMethodDescr_Type;
    #endif
    if (__Pyx_TypeCheck(method, methoddescr_type))
#endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    PyErr_Clear();
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyInt_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        kwds = PyDict_New();
        if (!kwds) goto limited_bad;
        if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(!is_unsigned ? Py_True : Py_False))) goto limited_bad;
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(from_bytes);
        Py_XDECREF(py_bytes);
        Py_XDECREF(order_str);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(kwds);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyInt_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        kwds = PyDict_New();
        if (!kwds) goto limited_bad;
        if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(!is_unsigned ? Py_True : Py_False))) goto limited_bad;
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(from_bytes);
        Py_XDECREF(py_bytes);
        Py_XDECREF(order_str);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(kwds);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__97);
    }
    return name;
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* CoroutineBase */
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(PyObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body(self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(PyObject* gen, PyObject *retval) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
            _PyGen_SetStopIterationValue(result);
        }
        Py_CLEAR(result);
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval))
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    gen->is_running = 0;
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        Py_TYPE(gen)->tp_del(self);
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (likely(--self->ob_refcnt == 0)) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context)
{
    PyObject *frame = self->gi_frame;
    CYTHON_UNUSED_VAR(context);
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (unlikely(!module)) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) __Pyx_PyObject_GenericGetAttrNoDict},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    __pyx_GeneratorType_slots
};
#else
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_Generator_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_GeneratorType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
#endif
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[5];
    int same=1, i, found_dot;
    const char* rt_from_call = Py_GetVersion();
    PyOS_snprintf(ctversion, 5, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    found_dot = 0;
    for (i = 0; i < 4; i++) {
        if (!ctversion[i]) {
            same = (rt_from_call[i] < '0' || rt_from_call[i] > '9');
            break;
        }
        if (rt_from_call[i] != ctversion[i]) {
            same = 0;
            break;
        }
    }
    if (!same) {
        char rtversion[5] = {'\0'};
        char message[200];
        for (i=0; i<4; ++i) {
            if (rt_from_call[i] == '.') {
                if (found_dot) break;
                found_dot = 1;
            } else if (rt_from_call[i] < '0' || rt_from_call[i] > '9') {
                break;
            }
            rtversion[i] = rt_from_call[i];
        }
        PyOS_snprintf(message, sizeof(message),
                      "compile time version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
